-- MariaDB dump 10.19  Distrib 10.5.22-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: heat
-- ------------------------------------------------------
-- Server version	10.5.22-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `event`
--

DROP TABLE IF EXISTS `event`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `event` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `resource_action` varchar(255) DEFAULT NULL,
  `resource_status` varchar(255) DEFAULT NULL,
  `resource_name` varchar(255) DEFAULT NULL,
  `physical_resource_id` varchar(255) DEFAULT NULL,
  `resource_status_reason` varchar(255) DEFAULT NULL,
  `resource_type` varchar(255) DEFAULT NULL,
  `resource_properties` blob DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `ev_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  CONSTRAINT `ev_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `event_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=3033 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event`
--

LOCK TABLES `event` WRITE;
/*!40000 ALTER TABLE `event` DISABLE KEYS */;
INSERT INTO `event` VALUES (1,'4800d876-0ea3-4b29-beec-347f0775a4e0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:43',NULL,'CREATE','IN_PROGRESS','overcloud','a373631c-90fc-4131-92e5-bf52321b3306','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2,'d1795e60-45a5-465f-ad32-c626dcab1295','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:45',NULL,'CREATE','IN_PROGRESS','ObjectStorageRoleUserData','overcloud-ObjectStorageRoleUserData-yokinlxemaup','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(3,'54c461c5-953e-4c92-95cd-81f7c4397a60','27d181a3-f9bf-4e43-b986-980d13b2cba3','2026-06-13 07:49:46',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageRoleUserData-yokinlxemaup','27d181a3-f9bf-4e43-b986-980d13b2cba3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(4,'8fd29f3d-53a1-4434-9bb4-05dc4b8929af','27d181a3-f9bf-4e43-b986-980d13b2cba3','2026-06-13 07:49:46',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ObjectStorageRoleUserData-yokinlxemaup-userdata-ou3mtxj66kz3','state changed','OS::Heat::MultipartMime',NULL,NULL),(5,'0ff4e2cf-142b-4f73-b11c-8d12081bfa94','27d181a3-f9bf-4e43-b986-980d13b2cba3','2026-06-13 07:49:46',NULL,'CREATE','COMPLETE','userdata','fe928ca9-30b1-4fe5-82f1-b84aeaac43e3','state changed','OS::Heat::MultipartMime',NULL,NULL),(6,'7e224086-ac29-4de6-a6e2-3e2fb47f8918','27d181a3-f9bf-4e43-b986-980d13b2cba3','2026-06-13 07:49:46',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageRoleUserData-yokinlxemaup','27d181a3-f9bf-4e43-b986-980d13b2cba3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(7,'73976619-6a4f-4ded-97ff-e3ba62fe9928','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:46',NULL,'CREATE','IN_PROGRESS','BlockStorageRoleUserData','overcloud-BlockStorageRoleUserData-omqtp2mjpqgr','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(8,'fab33b36-acdf-409b-bfe0-4f1148a5de9e','8d16e814-984d-4ceb-98fc-5a809f33838e','2026-06-13 07:49:46',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageRoleUserData-omqtp2mjpqgr','8d16e814-984d-4ceb-98fc-5a809f33838e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(9,'7f2dc285-a320-4497-98a3-fae6f320e216','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:47',NULL,'CREATE','COMPLETE','ObjectStorageRoleUserData','27d181a3-f9bf-4e43-b986-980d13b2cba3','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(10,'e996333d-589c-4cd5-921c-d99b142742d2','8d16e814-984d-4ceb-98fc-5a809f33838e','2026-06-13 07:49:47',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-BlockStorageRoleUserData-omqtp2mjpqgr-userdata-y2fcily7esvm','state changed','OS::Heat::MultipartMime',NULL,NULL),(11,'2146d0e0-4588-4232-b845-aafe4d8eda58','8d16e814-984d-4ceb-98fc-5a809f33838e','2026-06-13 07:49:47',NULL,'CREATE','COMPLETE','userdata','644aecc1-3169-438a-9686-09c91ef77d36','state changed','OS::Heat::MultipartMime',NULL,NULL),(12,'fb8e6e6b-7ab1-4ed8-9cd5-9d0ec8ab3cb4','8d16e814-984d-4ceb-98fc-5a809f33838e','2026-06-13 07:49:47',NULL,'CREATE','COMPLETE','overcloud-BlockStorageRoleUserData-omqtp2mjpqgr','8d16e814-984d-4ceb-98fc-5a809f33838e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(13,'d231c273-a9a5-46a5-bcb3-ddc0b5daed04','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:47',NULL,'CREATE','IN_PROGRESS','CellControllerRoleUserData','overcloud-CellControllerRoleUserData-wqdqorxnk7z3','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(14,'56d0bd3c-dca2-4bf0-bb6f-e1ac60a921c8','70bbd0a2-f150-4bfd-ab8f-63e339667831','2026-06-13 07:49:47',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerRoleUserData-wqdqorxnk7z3','70bbd0a2-f150-4bfd-ab8f-63e339667831','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(15,'61918361-7177-4e70-b728-1646b329294e','70bbd0a2-f150-4bfd-ab8f-63e339667831','2026-06-13 07:49:48',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerRoleUserData-wqdqorxnk7z3-userdata-mzirctzonaf4','state changed','OS::Heat::MultipartMime',NULL,NULL),(16,'2b4c248d-fa1a-4e5a-b2b6-d216a3e248a6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:48',NULL,'CREATE','COMPLETE','BlockStorageRoleUserData','8d16e814-984d-4ceb-98fc-5a809f33838e','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(17,'6a8dcc05-0d7b-488c-bf00-120f5fb80cab','70bbd0a2-f150-4bfd-ab8f-63e339667831','2026-06-13 07:49:48',NULL,'CREATE','COMPLETE','userdata','89b7f0eb-3430-4eab-84d0-d2351a122dbd','state changed','OS::Heat::MultipartMime',NULL,NULL),(18,'1903afdc-c42d-496f-af01-0c316be779b0','70bbd0a2-f150-4bfd-ab8f-63e339667831','2026-06-13 07:49:48',NULL,'CREATE','COMPLETE','overcloud-CellControllerRoleUserData-wqdqorxnk7z3','70bbd0a2-f150-4bfd-ab8f-63e339667831','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(19,'a3f4d807-780f-4dbb-88ec-00b617405f6a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:48',NULL,'CREATE','IN_PROGRESS','NetworkerRoleUserData','overcloud-NetworkerRoleUserData-fe3ojtt3qh4i','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(20,'a77f1614-59eb-41bd-a680-9d042cd30088','1dd2a3a0-a356-44ea-9b7e-9375c2a01512','2026-06-13 07:49:48',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerRoleUserData-fe3ojtt3qh4i','1dd2a3a0-a356-44ea-9b7e-9375c2a01512','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(21,'03b476f9-da04-43a8-a3a0-a4435e8f9722','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:48',NULL,'CREATE','COMPLETE','CellControllerRoleUserData','70bbd0a2-f150-4bfd-ab8f-63e339667831','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(22,'16b96cf9-2000-4e56-8462-36dfa60e1f28','1dd2a3a0-a356-44ea-9b7e-9375c2a01512','2026-06-13 07:49:48',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NetworkerRoleUserData-fe3ojtt3qh4i-userdata-en5edncsbf4r','state changed','OS::Heat::MultipartMime',NULL,NULL),(23,'0ad8f333-6751-45d0-b5de-4b1375235f74','1dd2a3a0-a356-44ea-9b7e-9375c2a01512','2026-06-13 07:49:49',NULL,'CREATE','COMPLETE','userdata','202c3d4a-d5ee-45e2-8e52-12182aafc5ea','state changed','OS::Heat::MultipartMime',NULL,NULL),(24,'a13719ba-8c5f-4c6d-bd8e-fa639d90a2cb','1dd2a3a0-a356-44ea-9b7e-9375c2a01512','2026-06-13 07:49:49',NULL,'CREATE','COMPLETE','overcloud-NetworkerRoleUserData-fe3ojtt3qh4i','1dd2a3a0-a356-44ea-9b7e-9375c2a01512','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(25,'c8d50247-43a8-4597-996e-85f95f08ea77','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:49',NULL,'CREATE','IN_PROGRESS','CellControllerComputeRoleUserData','overcloud-CellControllerComputeRoleUserData-a4tsllmayqzi','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(26,'eebb4b61-c56d-4b4b-bd91-24c4b6472aed','1f3b052d-fdce-4f0e-8452-72dc44d8a5d1','2026-06-13 07:49:49',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeRoleUserData-a4tsllmayqzi','1f3b052d-fdce-4f0e-8452-72dc44d8a5d1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(27,'7349b3d3-ccd7-46bb-9956-7c33f8797492','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:49',NULL,'CREATE','COMPLETE','NetworkerRoleUserData','1dd2a3a0-a356-44ea-9b7e-9375c2a01512','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(28,'50aefa9e-685f-46fc-9a7b-38dab92da0bb','1f3b052d-fdce-4f0e-8452-72dc44d8a5d1','2026-06-13 07:49:50',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerComputeRoleUserData-a4tsllmayqzi-userdata-k3bfygdsa5sb','state changed','OS::Heat::MultipartMime',NULL,NULL),(29,'f34b1eb8-c860-41bf-bf29-2954c0916d61','1f3b052d-fdce-4f0e-8452-72dc44d8a5d1','2026-06-13 07:49:50',NULL,'CREATE','COMPLETE','userdata','8e1e6bc5-c572-4b26-96a6-8eca4820b8ff','state changed','OS::Heat::MultipartMime',NULL,NULL),(30,'a165c01b-8514-48b1-b585-e0387584ae66','1f3b052d-fdce-4f0e-8452-72dc44d8a5d1','2026-06-13 07:49:50',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeRoleUserData-a4tsllmayqzi','1f3b052d-fdce-4f0e-8452-72dc44d8a5d1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(31,'65dcb7e7-a5bc-469c-bba3-114f5848c233','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:50',NULL,'CREATE','IN_PROGRESS','CephStorageRoleUserData','overcloud-CephStorageRoleUserData-pvqyxyncyc6p','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(32,'4f7504e2-fb91-4095-8f6e-46130bd2cfa6','700b9af4-34dd-4e08-87e6-9772c8cde2dc','2026-06-13 07:49:50',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageRoleUserData-pvqyxyncyc6p','700b9af4-34dd-4e08-87e6-9772c8cde2dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(33,'54696d3b-9f88-4224-96b6-550ba9482064','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:50',NULL,'CREATE','COMPLETE','CellControllerComputeRoleUserData','1f3b052d-fdce-4f0e-8452-72dc44d8a5d1','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(34,'2811b1e0-d5e6-4442-8c8c-41964291a377','700b9af4-34dd-4e08-87e6-9772c8cde2dc','2026-06-13 07:49:50',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CephStorageRoleUserData-pvqyxyncyc6p-userdata-7ikld62dfk4t','state changed','OS::Heat::MultipartMime',NULL,NULL),(35,'8960865a-214e-4c42-a463-f480691e766e','700b9af4-34dd-4e08-87e6-9772c8cde2dc','2026-06-13 07:49:51',NULL,'CREATE','COMPLETE','userdata','3cd1cb9f-6176-472a-b8a3-e3b288c2c16c','state changed','OS::Heat::MultipartMime',NULL,NULL),(36,'b103e291-6d1a-40bd-b523-a6ea3f8fed40','700b9af4-34dd-4e08-87e6-9772c8cde2dc','2026-06-13 07:49:51',NULL,'CREATE','COMPLETE','overcloud-CephStorageRoleUserData-pvqyxyncyc6p','700b9af4-34dd-4e08-87e6-9772c8cde2dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(37,'de03a6a6-abdd-4686-9e7f-103bcbd34dde','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:51',NULL,'CREATE','IN_PROGRESS','NodeUserData','overcloud-NodeUserData-eeivtllqshcf','state changed','OS::TripleO::NodeUserData',NULL,NULL),(38,'7a8bc22e-d417-4fd6-a385-2dd479f19bcf','cf4edfb1-b629-4b86-8deb-a44b060405f2','2026-06-13 07:49:51',NULL,'CREATE','IN_PROGRESS','overcloud-NodeUserData-eeivtllqshcf','cf4edfb1-b629-4b86-8deb-a44b060405f2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(39,'cbf54358-4773-43ec-a011-581970f2772d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:51',NULL,'CREATE','COMPLETE','CephStorageRoleUserData','700b9af4-34dd-4e08-87e6-9772c8cde2dc','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(40,'f58fab1a-891d-449e-bd9d-53df5e1dd0ad','cf4edfb1-b629-4b86-8deb-a44b060405f2','2026-06-13 07:49:51',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeUserData-eeivtllqshcf-userdata-otymc3uhcr2d','state changed','OS::Heat::MultipartMime',NULL,NULL),(41,'432929e9-d07e-4d91-bb07-05ed75afc708','cf4edfb1-b629-4b86-8deb-a44b060405f2','2026-06-13 07:49:52',NULL,'CREATE','COMPLETE','userdata','b0cef856-0c98-478c-a2cd-61490b9edb5a','state changed','OS::Heat::MultipartMime',NULL,NULL),(42,'ce3f1129-a323-4f3f-b9f9-7a863f28715f','cf4edfb1-b629-4b86-8deb-a44b060405f2','2026-06-13 07:49:52',NULL,'CREATE','COMPLETE','overcloud-NodeUserData-eeivtllqshcf','cf4edfb1-b629-4b86-8deb-a44b060405f2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(43,'9b65ed7e-c519-4918-a460-3a52f5c11101','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:52',NULL,'CREATE','IN_PROGRESS','ComputeHCIRoleUserData','overcloud-ComputeHCIRoleUserData-opqpf6ovuhos','state changed','OS::TripleO::ComputeHCI::NodeUserData',NULL,NULL),(44,'b263afb8-3638-44fd-ba35-c5d05f4da799','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:52',NULL,'CREATE','COMPLETE','NodeUserData','cf4edfb1-b629-4b86-8deb-a44b060405f2','state changed','OS::TripleO::NodeUserData',NULL,NULL),(45,'90543190-7040-4781-a1ed-9b74b6508142','8066708b-1ab1-4ff9-9ca2-701591f1575b','2026-06-13 07:49:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIRoleUserData-opqpf6ovuhos','8066708b-1ab1-4ff9-9ca2-701591f1575b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(46,'5e2459bf-4a03-4370-a3ea-ef71e225de10','8066708b-1ab1-4ff9-9ca2-701591f1575b','2026-06-13 07:49:53',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ComputeHCIRoleUserData-opqpf6ovuhos-userdata-nzlsaotug7me','state changed','OS::Heat::MultipartMime',NULL,NULL),(47,'df2f01eb-bf1f-4909-a024-78e0f9276c4d','8066708b-1ab1-4ff9-9ca2-701591f1575b','2026-06-13 07:49:53',NULL,'CREATE','COMPLETE','userdata','2da24297-08b0-4794-a567-8e005e034c8c','state changed','OS::Heat::MultipartMime',NULL,NULL),(48,'7a648d64-25e8-428c-bd47-e39479385411','8066708b-1ab1-4ff9-9ca2-701591f1575b','2026-06-13 07:49:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIRoleUserData-opqpf6ovuhos','8066708b-1ab1-4ff9-9ca2-701591f1575b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(49,'36f90820-7ecb-49be-9b9d-f158e3b3c6e1','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:53',NULL,'CREATE','IN_PROGRESS','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-upzvgoahxqjo','state changed','OS::Heat::Value',NULL,8),(50,'7baa03e7-5e71-4792-bfbc-0e2d69896bcf','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:53',NULL,'CREATE','COMPLETE','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-upzvgoahxqjo','state changed','OS::Heat::Value',NULL,8),(51,'4d70fe51-48e9-40a0-a14d-dfed5055b9b3','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:53',NULL,'CREATE','COMPLETE','ComputeHCIRoleUserData','8066708b-1ab1-4ff9-9ca2-701591f1575b','state changed','OS::TripleO::ComputeHCI::NodeUserData',NULL,NULL),(52,'4163a3fa-6baa-48a1-a074-d7f883f92249','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:54',NULL,'CREATE','IN_PROGRESS','ComputeRoleUserData','overcloud-ComputeRoleUserData-ffnpdnbj65ep','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(53,'4a58ea71-ca20-413f-a924-037f57b62578','7cc948b3-aff7-41c8-b020-d033d24f124b','2026-06-13 07:49:54',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeRoleUserData-ffnpdnbj65ep','7cc948b3-aff7-41c8-b020-d033d24f124b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(54,'9102723d-7eb6-40b2-a049-38d920acd20f','7cc948b3-aff7-41c8-b020-d033d24f124b','2026-06-13 07:49:55',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ComputeRoleUserData-ffnpdnbj65ep-userdata-cabiy33x4d3z','state changed','OS::Heat::MultipartMime',NULL,NULL),(55,'b221f38a-7c33-46c5-8f8c-b7dfeb935081','7cc948b3-aff7-41c8-b020-d033d24f124b','2026-06-13 07:49:55',NULL,'CREATE','COMPLETE','userdata','f2c078c6-0318-410d-8460-5990c8280ba6','state changed','OS::Heat::MultipartMime',NULL,NULL),(56,'0fcfdbe9-b353-4ea8-8072-f6b9a0fbe761','7cc948b3-aff7-41c8-b020-d033d24f124b','2026-06-13 07:49:55',NULL,'CREATE','COMPLETE','overcloud-ComputeRoleUserData-ffnpdnbj65ep','7cc948b3-aff7-41c8-b020-d033d24f124b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(57,'519978db-d604-472a-a776-26322e10ecad','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:55',NULL,'CREATE','IN_PROGRESS','NodeTimesyncUserData','overcloud-NodeTimesyncUserData-powa4twndp7a','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(58,'94f7c1af-5e88-4c81-84b1-97864e7a8b2a','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:56',NULL,'CREATE','IN_PROGRESS','overcloud-NodeTimesyncUserData-powa4twndp7a','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(59,'d184647e-8092-4bb0-bb77-23efce22382e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:56',NULL,'CREATE','COMPLETE','ComputeRoleUserData','7cc948b3-aff7-41c8-b020-d033d24f124b','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(60,'2c7c1966-e5c9-4505-b80e-c7b9ce9ae70c','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:56',NULL,'CREATE','IN_PROGRESS','timesync_chrony','overcloud-NodeTimesyncUserData-powa4twndp7a-timesync_chrony-fskdwcohk2ip','state changed','OS::Heat::SoftwareConfig',NULL,12),(61,'87f4d905-b1d8-4f4b-9e90-f24acb1b5289','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:56',NULL,'CREATE','COMPLETE','timesync_chrony','a79a06e6-e814-4cb0-a590-91b54dba4954','state changed','OS::Heat::SoftwareConfig',NULL,12),(62,'b5ad2078-e55a-44fe-9809-1631acb948ba','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:56',NULL,'CREATE','IN_PROGRESS','ControllerRoleUserData','overcloud-ControllerRoleUserData-o6a4fmoc6pv7','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(63,'f9542141-cf3d-4851-87ef-14e9f9100474','ee726cf0-8b85-4a12-9bb7-d3bf1d795b52','2026-06-13 07:49:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerRoleUserData-o6a4fmoc6pv7','ee726cf0-8b85-4a12-9bb7-d3bf1d795b52','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(64,'3d734d72-1692-4bca-8afa-d45c6e15686a','ee726cf0-8b85-4a12-9bb7-d3bf1d795b52','2026-06-13 07:49:56',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ControllerRoleUserData-o6a4fmoc6pv7-userdata-m5ljjpbeztgf','state changed','OS::Heat::MultipartMime',NULL,NULL),(65,'e028fa65-8438-41fe-8469-56208139f040','ee726cf0-8b85-4a12-9bb7-d3bf1d795b52','2026-06-13 07:49:57',NULL,'CREATE','COMPLETE','userdata','591ec00b-e5df-4ba3-9c23-ce8db546eccc','state changed','OS::Heat::MultipartMime',NULL,NULL),(66,'11ccf62e-c8e1-4cf0-9006-4c6e83fba865','ee726cf0-8b85-4a12-9bb7-d3bf1d795b52','2026-06-13 07:49:57',NULL,'CREATE','COMPLETE','overcloud-ControllerRoleUserData-o6a4fmoc6pv7','ee726cf0-8b85-4a12-9bb7-d3bf1d795b52','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(67,'ed34a3cf-aeb5-44fb-8267-58aeb1354a25','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:57',NULL,'CREATE','IN_PROGRESS','timesync_sync','overcloud-NodeTimesyncUserData-powa4twndp7a-timesync_sync-ezfbjbouc4y5','state changed','OS::Heat::SoftwareConfig',NULL,13),(68,'cc4c8897-7cd8-4537-8578-ad2c712635d1','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:57',NULL,'CREATE','COMPLETE','timesync_sync','364a9345-b5e0-4a59-936d-f238b6b150c0','state changed','OS::Heat::SoftwareConfig',NULL,13),(69,'b0f17f61-fe5e-4189-bd05-c4c71023dd13','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:57',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeTimesyncUserData-powa4twndp7a-userdata-bjvymcxyuk4g','state changed','OS::Heat::MultipartMime',NULL,14),(70,'c2c736f3-9d8f-4730-9cc9-72064c9ae012','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:57',NULL,'CREATE','COMPLETE','userdata','98e579e9-bcdf-421e-8bc4-103e282aab2a','state changed','OS::Heat::MultipartMime',NULL,14),(71,'7f0a19ca-b702-4d11-9e68-ede5133728e2','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','2026-06-13 07:49:57',NULL,'CREATE','COMPLETE','overcloud-NodeTimesyncUserData-powa4twndp7a','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(72,'c09c7814-8750-4f73-b227-c44a52bcd1e3','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:57',NULL,'CREATE','IN_PROGRESS','ServiceNetMap','overcloud-ServiceNetMap-3b6fv7ata6de','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(73,'1aefb118-98a7-4cca-b17a-ded3109c39f2','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:57',NULL,'CREATE','COMPLETE','ControllerRoleUserData','ee726cf0-8b85-4a12-9bb7-d3bf1d795b52','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(74,'37b87783-d6ab-4bad-b0dd-a56c85f4d235','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:58',NULL,'CREATE','COMPLETE','NodeTimesyncUserData','1ca914e5-344e-447b-8f5b-0b0dc07efe7d','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(75,'398afc13-d57f-4d66-9e40-e5a2e48dc63b','beee342e-1874-4c95-8eac-c04c5f63cebb','2026-06-13 07:49:58',NULL,'CREATE','IN_PROGRESS','overcloud-ServiceNetMap-3b6fv7ata6de','beee342e-1874-4c95-8eac-c04c5f63cebb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(76,'92a69b9f-bb92-47f3-9c9c-c6937f5e5874','beee342e-1874-4c95-8eac-c04c5f63cebb','2026-06-13 07:49:58',NULL,'CREATE','IN_PROGRESS','ServiceNetMapValue','overcloud-ServiceNetMap-3b6fv7ata6de-ServiceNetMapValue-bo3qi2wqhvih','state changed','OS::Heat::Value',NULL,16),(77,'fc51f91b-b305-41b4-8c29-1bbac5d31f4d','beee342e-1874-4c95-8eac-c04c5f63cebb','2026-06-13 07:49:58',NULL,'CREATE','COMPLETE','ServiceNetMapValue','overcloud-ServiceNetMap-3b6fv7ata6de-ServiceNetMapValue-bo3qi2wqhvih','state changed','OS::Heat::Value',NULL,16),(78,'baf65fb8-d992-4fe6-b93c-d232c6132ad4','beee342e-1874-4c95-8eac-c04c5f63cebb','2026-06-13 07:49:58',NULL,'CREATE','COMPLETE','overcloud-ServiceNetMap-3b6fv7ata6de','beee342e-1874-4c95-8eac-c04c5f63cebb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(79,'5660248f-719b-40db-a418-1ac92861a6f3','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:58',NULL,'CREATE','IN_PROGRESS','NodeAdminUserData','overcloud-NodeAdminUserData-ipwbauzhlfyb','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(80,'52ae88f4-391e-4c97-b1ad-ff4a18b38192','0d5f1236-f344-4d47-8250-d06b5cad11e8','2026-06-13 07:49:58',NULL,'CREATE','IN_PROGRESS','overcloud-NodeAdminUserData-ipwbauzhlfyb','0d5f1236-f344-4d47-8250-d06b5cad11e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(81,'d0b96419-8500-4e97-8cf1-676c070860a3','0d5f1236-f344-4d47-8250-d06b5cad11e8','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','user_config','overcloud-NodeAdminUserData-ipwbauzhlfyb-user_config-t4ncebo5xtdw','state changed','OS::Heat::CloudConfig',NULL,18),(82,'37741301-8cc4-4a3c-967f-7d44b7cbb172','0d5f1236-f344-4d47-8250-d06b5cad11e8','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','user_config','e619f868-5f45-48bb-bda7-cb0feb90ec48','state changed','OS::Heat::CloudConfig',NULL,18),(83,'fb5faa34-8c77-431c-9128-114faf443867','0d5f1236-f344-4d47-8250-d06b5cad11e8','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeAdminUserData-ipwbauzhlfyb-userdata-ii3phao4bzuj','state changed','OS::Heat::MultipartMime',NULL,19),(84,'18b0bb5b-ed70-484e-a733-8e55feb8774b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','ServiceNetMap','beee342e-1874-4c95-8eac-c04c5f63cebb','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(85,'aca64d41-49c0-4d41-854a-a9296d90edb1','0d5f1236-f344-4d47-8250-d06b5cad11e8','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','userdata','51f31f09-aff0-4baa-ad24-b3a82642ee08','state changed','OS::Heat::MultipartMime',NULL,19),(86,'6303a194-80d1-40d4-9724-7a3d80bec31b','0d5f1236-f344-4d47-8250-d06b5cad11e8','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','overcloud-NodeAdminUserData-ipwbauzhlfyb','0d5f1236-f344-4d47-8250-d06b5cad11e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(87,'7f53c256-3b00-4d1c-a89f-610e4a144752','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-mi3ewfactc34','state changed','OS::Heat::Value',NULL,21),(88,'0c620bc2-14cd-4af3-b146-592d730ae24c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-mi3ewfactc34','state changed','OS::Heat::Value',NULL,21),(89,'49099a54-9158-4368-93b1-452adb3f6aaa','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-7kk2qka7x4im','state changed','OS::Heat::Value',NULL,22),(90,'3941e971-3938-4b41-ad84-6de37ecf1a13','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-7kk2qka7x4im','state changed','OS::Heat::Value',NULL,22),(91,'01ecdc87-07fe-4f15-9744-e8af15cf6c76','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-u7ugu4gmadun','state changed','OS::Heat::Value',NULL,24),(92,'b6b86c02-7e4a-4363-b9e9-e040596615b0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-u7ugu4gmadun','state changed','OS::Heat::Value',NULL,24),(93,'b83ca551-a2bd-4e41-95f9-9d7878bf83e5','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-moszcwxq6rl6','state changed','OS::Heat::Value',NULL,27),(94,'90f1dc00-f1fa-4120-837a-46354b135752','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-moszcwxq6rl6','state changed','OS::Heat::Value',NULL,27),(95,'154c0608-a0a0-41a7-a102-bc20fe2369c4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','ControlVirtualIP','overcloud-ControlVirtualIP-qypigkinjeh3','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,29),(96,'5a56c909-3caf-43b3-aaa1-a08c44f8167d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','CloudNames','overcloud-CloudNames-2caju5d2rke6','state changed','OS::Heat::Value',NULL,31),(97,'8700e3cc-b3e5-47ce-a22b-898144804ff0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-wc3v34krfkta','state changed','OS::Heat::Value',NULL,30),(98,'d2043405-0d08-4ad7-88a1-b013010f77dd','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:49:59',NULL,'CREATE','COMPLETE','CloudNames','overcloud-CloudNames-2caju5d2rke6','state changed','OS::Heat::Value',NULL,31),(99,'f09b2262-7028-4e81-a8bd-3aed2894242f','1befd5f4-b9ca-489d-98f9-49a17b86da50','2026-06-13 07:49:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControlVirtualIP-qypigkinjeh3','1befd5f4-b9ca-489d-98f9-49a17b86da50','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(100,'720b1f04-5f94-4a89-86cf-8c48191549fe','1befd5f4-b9ca-489d-98f9-49a17b86da50','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','overcloud-ControlVirtualIP-qypigkinjeh3','1befd5f4-b9ca-489d-98f9-49a17b86da50','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(101,'f4a96fd3-18cd-4322-a5f6-0968863ec44c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','NodeAdminUserData','0d5f1236-f344-4d47-8250-d06b5cad11e8','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(102,'dfe0c5da-51af-4855-a0fc-ca549b171dd4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-wc3v34krfkta','state changed','OS::Heat::Value',NULL,30),(103,'136396b3-5154-422b-81b8-958ec7a6afe7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-r6zkrvrnjsvd','state changed','OS::Heat::Value',NULL,32),(104,'bcd294b4-92b8-457a-a61b-2cfead798b29','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-r6zkrvrnjsvd','state changed','OS::Heat::Value',NULL,32),(105,'c479fe98-fd39-4353-9ab1-e8d018eb5643','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-qnulk5vyxrv6','state changed','OS::Heat::Value',NULL,34),(106,'371ba1bf-32e9-4a15-9dc6-72c7188df201','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-qnulk5vyxrv6','state changed','OS::Heat::Value',NULL,34),(107,'41fc7316-84a1-4cfd-9cbe-955b276a4e1c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','NetworkerUserData','overcloud-NetworkerUserData-uifbnwdi3oyz','state changed','OS::Heat::MultipartMime',NULL,38),(108,'a2ab1f52-9454-4620-8ea4-7aa8fb162299','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','CellControllerUserData','overcloud-CellControllerUserData-qqc3s4wrsxvd','state changed','OS::Heat::MultipartMime',NULL,39),(109,'405066ee-67ff-4be5-a76f-70869088ec1d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-weurnuzmqx42','state changed','OS::Heat::Value',NULL,40),(110,'fd2b6364-d8b8-443b-9041-adbb5260216d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-weurnuzmqx42','state changed','OS::Heat::Value',NULL,40),(111,'c324c9d3-bf5c-42ac-aa19-e58079c44874','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','ObjectStorageUserData','overcloud-ObjectStorageUserData-njelllhslrg2','state changed','OS::Heat::MultipartMime',NULL,41),(112,'a113549f-aaf4-496e-b3d8-55896ab4724f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','CephStorageUserData','overcloud-CephStorageUserData-vzzckbo3vyhi','state changed','OS::Heat::MultipartMime',NULL,42),(113,'1861f674-71a0-4100-8318-4e19e0055d4f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','ControllerUserData','overcloud-ControllerUserData-l2ktqzuy6dcx','state changed','OS::Heat::MultipartMime',NULL,44),(114,'39f6c231-2a54-47ee-a977-b5423df250d8','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','ComputeHCIUserData','overcloud-ComputeHCIUserData-scjir7apqyqf','state changed','OS::Heat::MultipartMime',NULL,45),(115,'bbceb059-68c5-48c0-8365-9212a5221aa7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','ComputeHCIServiceNetMapLower','overcloud-ComputeHCIServiceNetMapLower-57iqthkko7a5','state changed','OS::Heat::Value',NULL,43),(116,'612eaaef-be6f-4532-9b0e-6152fe7641ab','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','ComputeUserData','overcloud-ComputeUserData-v3x4vagapya7','state changed','OS::Heat::MultipartMime',NULL,47),(117,'c8ea8941-141d-43e2-b31f-5ede32f3ca33','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','CellControllerComputeUserData','overcloud-CellControllerComputeUserData-cvykfbnasv5s','state changed','OS::Heat::MultipartMime',NULL,48),(118,'41f15b7c-77fe-4439-b960-d0adaece4bd6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','ComputeHCIServiceNetMapLower','overcloud-ComputeHCIServiceNetMapLower-57iqthkko7a5','state changed','OS::Heat::Value',NULL,43),(119,'8e8976a5-31f3-4db0-8f8a-e5ad1be8f6f9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','NetworkerUserData','6791cb1c-dcec-429f-8bec-0b6834d06250','state changed','OS::Heat::MultipartMime',NULL,38),(120,'f0a3930c-9506-4186-bc5e-284c88bac802','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','CellControllerUserData','4d3a995d-a620-4ee4-a312-16c0ad7a119a','state changed','OS::Heat::MultipartMime',NULL,39),(121,'89b6a212-0ae7-4b8c-af97-67ad9bb8542d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','CephStorageUserData','cfe2be45-84ba-4024-9716-1090e22487ee','state changed','OS::Heat::MultipartMime',NULL,42),(122,'937955fc-82d7-47e7-8fca-03e5840c1b65','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','IN_PROGRESS','BlockStorageUserData','overcloud-BlockStorageUserData-cnvippjwikwu','state changed','OS::Heat::MultipartMime',NULL,50),(123,'7c8b5456-1c27-455e-bfe3-3590d47d6be9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','ComputeHCIUserData','d2c646d1-5aad-4d88-b994-6e5921fd3309','state changed','OS::Heat::MultipartMime',NULL,45),(124,'c282f34d-282e-4ef3-bc75-a62b9a346616','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','ControllerUserData','9327d359-1196-4ef7-be77-4dbf2ea0408b','state changed','OS::Heat::MultipartMime',NULL,44),(125,'916eb831-2ef7-4246-80cf-27b9cfda9679','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','ComputeUserData','5d44be84-f4d6-449f-8ddf-7c8a3eaa78db','state changed','OS::Heat::MultipartMime',NULL,47),(126,'16c6deda-0562-454a-bd45-363320af6259','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','ObjectStorageUserData','cced4c02-fe08-4e07-ade1-c8a14ed582c3','state changed','OS::Heat::MultipartMime',NULL,41),(127,'55f62948-8384-4421-b107-ac76d0a2be85','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','CellControllerComputeUserData','765e9b2b-453e-4612-943e-5f643f3bd22c','state changed','OS::Heat::MultipartMime',NULL,48),(128,'2ec717b4-2830-4d6f-b007-2bed1f4928bb','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:00',NULL,'CREATE','COMPLETE','BlockStorageUserData','b0a1c5dd-5234-4c17-bbce-34e4eb1ff747','state changed','OS::Heat::MultipartMime',NULL,50),(129,'1ff84055-d48e-41ac-a718-5a540199ac31','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:01',NULL,'CREATE','COMPLETE','ControlVirtualIP','1befd5f4-b9ca-489d-98f9-49a17b86da50','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,29),(130,'6b443036-789c-4ea8-a36c-4b91a05fb38f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:01',NULL,'CREATE','IN_PROGRESS','Networks','overcloud-Networks-hcjxax5gdsao','state changed','OS::TripleO::Network',NULL,54),(131,'e25cb443-d85b-484f-bd5b-3185f35fac56','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:01',NULL,'CREATE','IN_PROGRESS','overcloud-Networks-hcjxax5gdsao','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(132,'34d29bef-c979-4c29-9508-90420ed3601f','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:01',NULL,'CREATE','IN_PROGRESS','NetworkAttributesMap','overcloud-Networks-hcjxax5gdsao-NetworkAttributesMap-xhxdrzl5zf4a','state changed','OS::Heat::Value',NULL,55),(133,'4931ff57-5505-4ad9-beb9-8ca813212df2','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:01',NULL,'CREATE','COMPLETE','NetworkAttributesMap','overcloud-Networks-hcjxax5gdsao-NetworkAttributesMap-xhxdrzl5zf4a','state changed','OS::Heat::Value',NULL,55),(134,'20e4f313-b2c8-43d2-9be7-0af7790235e6','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:02',NULL,'CREATE','IN_PROGRESS','NetworkCidrMap','overcloud-Networks-hcjxax5gdsao-NetworkCidrMap-dxtkwznjhrji','state changed','OS::Heat::Value',NULL,56),(135,'b2cea456-821c-47ca-a625-f9df0846da77','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:02',NULL,'CREATE','COMPLETE','NetworkCidrMap','overcloud-Networks-hcjxax5gdsao-NetworkCidrMap-dxtkwznjhrji','state changed','OS::Heat::Value',NULL,56),(136,'206ed5c6-e8c9-4e8c-b214-11c67d3dbc08','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:03',NULL,'CREATE','IN_PROGRESS','NetworkIpVersionMap','overcloud-Networks-hcjxax5gdsao-NetworkIpVersionMap-kxfe4tbaygql','state changed','OS::Heat::Value',NULL,57),(137,'93744ff1-f60c-4d82-b426-b7b2684f01b8','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:03',NULL,'CREATE','COMPLETE','NetworkIpVersionMap','overcloud-Networks-hcjxax5gdsao-NetworkIpVersionMap-kxfe4tbaygql','state changed','OS::Heat::Value',NULL,57),(138,'8708f43d-077c-43ce-9eb5-0cb45cb80abd','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:04',NULL,'CREATE','IN_PROGRESS','NetworkExtraConfig','overcloud-Networks-hcjxax5gdsao-NetworkExtraConfig-se43obl7beck','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(139,'9319d624-7752-4e96-9b88-db39d38667a5','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:04',NULL,'CREATE','COMPLETE','NetworkExtraConfig','c93708ac-535d-4f06-bb01-9e66f54affe5','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(140,'31dc9ddb-c5e0-4dea-8b04-1e274167ded7','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','2026-06-13 07:50:04',NULL,'CREATE','COMPLETE','overcloud-Networks-hcjxax5gdsao','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(141,'fb2731b6-b693-44ea-a7a0-f4e919f247fc','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','COMPLETE','Networks','719ecd84-c28c-4e8b-8a35-6fb26dd7185d','state changed','OS::TripleO::Network',NULL,54),(142,'7b8fd56d-cc3a-4658-b3cf-55da2c9467b0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','ComputeHCINetworkConfig','overcloud-ComputeHCINetworkConfig-hdqfrsoekhq5','state changed','OS::TripleO::ComputeHCI::Net::SoftwareConfig',NULL,NULL),(143,'5e988cb4-98f3-4031-8fbd-29d636e19170','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','ControllerNetworkConfig','overcloud-ControllerNetworkConfig-27tnztroyovf','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(144,'917f5c8f-f748-4d30-98a2-8ba8b40bf62b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkConfig','overcloud-NetworkerNetworkConfig-ptwqjj4z32ep','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(145,'13f142de-2722-462d-861d-e8bcceaa560e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','StorageMgmtVirtualIP','overcloud-StorageMgmtVirtualIP-cumzppzdfarz','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,61),(146,'60e1b8a1-71cb-4def-a281-501c7d9afd38','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','COMPLETE','NetworkerNetworkConfig','7a9855a5-e26a-47f6-aacb-93a5ec0fb8b1','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(147,'0046d62f-79ed-4dbe-99db-267054581335','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','COMPLETE','ControllerNetworkConfig','c3bfe5fd-c421-4a6d-8c5b-e6d57f09ebbe','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(148,'42ff568c-4937-446c-8745-3c0cd3aa5f3f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkConfig','overcloud-CellControllerComputeNetworkConfig-abjbsxo24ebb','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(149,'1d24dc93-3039-42b8-b28a-bdcddfe3ba55','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','PublicVirtualIP','overcloud-PublicVirtualIP-b6r53gncpoll','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,62),(150,'320dd127-f3f3-45d3-bb1e-b6e6235f9291','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkConfig','7cd9106a-414f-414c-9f3d-276c248c302f','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(151,'1e1ef3a1-5fb8-4837-8a19-e9dc26eef182','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','ComputeNetworkConfig','overcloud-ComputeNetworkConfig-aonzm7jdulya','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(152,'7eec4be4-bf32-4353-82a6-96896248862a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkConfig','overcloud-BlockStorageNetworkConfig-mtnjgaxxm6bk','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(153,'bdd59767-acf1-4aaa-9754-6c69d417fcaa','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:05',NULL,'CREATE','COMPLETE','BlockStorageNetworkConfig','a83359b1-425f-4030-acc7-e07868ed7e77','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(154,'3e5da3d5-de37-4ccf-bffe-0185816b3462','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ioefy6wzqg4r','state changed','OS::Heat::Value',NULL,63),(155,'d6a03279-1330-4895-9d32-1d2965f49ccc','48ba1e03-42fa-45c3-ad93-1f4274b4d647','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','overcloud-PublicVirtualIP-b6r53gncpoll','48ba1e03-42fa-45c3-ad93-1f4274b4d647','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(156,'20a770dc-b363-475d-b879-f39be22695e5','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','ComputeHCINetworkConfig','6475fb7a-a1dc-4912-a1d9-551a30409303','state changed','OS::TripleO::ComputeHCI::Net::SoftwareConfig',NULL,NULL),(157,'add272e5-e7dd-4185-b04c-8f3772b90252','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','NetCidrMapValue','overcloud-NetCidrMapValue-7ki6zgio25qc','state changed','OS::Heat::Value',NULL,64),(158,'fb1e388a-419f-42d1-bbbe-9d0f3df8f0e2','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ioefy6wzqg4r','state changed','OS::Heat::Value',NULL,63),(159,'258ed738-2173-42a9-b18c-def5dd8e12a9','67571b60-7d3e-40d0-a887-77fc26a10918','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','overcloud-StorageMgmtVirtualIP-cumzppzdfarz','67571b60-7d3e-40d0-a887-77fc26a10918','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(160,'df728a8d-45a7-4c8f-b196-8f0854e560c4','48ba1e03-42fa-45c3-ad93-1f4274b4d647','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','overcloud-PublicVirtualIP-b6r53gncpoll','48ba1e03-42fa-45c3-ad93-1f4274b4d647','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(161,'d0e4ea30-37c0-407b-984a-09f7d3ae54d0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','NetCidrMapValue','overcloud-NetCidrMapValue-7ki6zgio25qc','state changed','OS::Heat::Value',NULL,64),(162,'db0c9feb-30c2-423a-a021-957b7946c200','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','ComputeNetworkConfig','b93cb096-047e-413c-ad3e-ae55990e2538','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(163,'2c517f99-674c-4830-8271-8246ed0fd873','67571b60-7d3e-40d0-a887-77fc26a10918','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','overcloud-StorageMgmtVirtualIP-cumzppzdfarz','67571b60-7d3e-40d0-a887-77fc26a10918','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(164,'f78aee01-9026-42c9-9dfd-7c1ebc5b18a9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','StorageVirtualIP','overcloud-StorageVirtualIP-h4tfhqusfavr','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,65),(165,'95d7dfaf-a99b-43bb-a5e3-91c929ccae12','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','InternalApiVirtualIP','overcloud-InternalApiVirtualIP-vdhnngtvmkid','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,66),(166,'8934db9e-f58d-4b71-9964-75d64b98473b','d0829e0b-565b-4e75-970d-a07acbc206d7','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','overcloud-StorageVirtualIP-h4tfhqusfavr','d0829e0b-565b-4e75-970d-a07acbc206d7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(167,'72c217dc-b913-45a2-849f-4fae5694b120','d0829e0b-565b-4e75-970d-a07acbc206d7','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','overcloud-StorageVirtualIP-h4tfhqusfavr','d0829e0b-565b-4e75-970d-a07acbc206d7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(168,'c57a20d4-32ad-4f83-9a40-c022a1bbd6fa','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkConfig','overcloud-CephStorageNetworkConfig-4gyouo2c3ebs','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(169,'1d25ee24-3cd0-4d74-9363-b4946f8450a4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkConfig','overcloud-CellControllerNetworkConfig-jujddnmcviba','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(170,'74310ed5-255a-42da-89c9-fc7754a1ed87','cccee1ff-eb7f-4dab-a10a-78201437aca6','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','overcloud-InternalApiVirtualIP-vdhnngtvmkid','cccee1ff-eb7f-4dab-a10a-78201437aca6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(171,'5c14d6b1-b29e-4bae-b2ec-9087283f05f8','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkConfig','overcloud-ObjectStorageNetworkConfig-mk3tt4ubmtry','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(172,'9f0ad816-7ecb-49f1-ae78-114611e7c9e0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','CephStorageNetworkConfig','0706eb42-2cea-4ba4-98ca-ddc4e8509142','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(173,'153fe071-ce6a-440e-b65e-5e7c032033e7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','CellControllerNetworkConfig','dd979cad-6b0f-4c56-86f9-f7eb254f29b0','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(174,'4cae3a0c-3e67-4d62-8448-96856f98d6c0','cccee1ff-eb7f-4dab-a10a-78201437aca6','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','overcloud-InternalApiVirtualIP-vdhnngtvmkid','cccee1ff-eb7f-4dab-a10a-78201437aca6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(175,'99d7cfd3-3369-4159-bb68-5ecefefea4f2','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:06',NULL,'CREATE','COMPLETE','ObjectStorageNetworkConfig','340a1cbf-a3c0-48b0-9743-ed72cbffe767','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(176,'72fa6f5d-2a7b-4357-8638-a30790293385','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:07',NULL,'CREATE','COMPLETE','PublicVirtualIP','48ba1e03-42fa-45c3-ad93-1f4274b4d647','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,62),(177,'431aecff-b3b5-4a26-81be-a169938b0aa9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:07',NULL,'CREATE','COMPLETE','StorageMgmtVirtualIP','67571b60-7d3e-40d0-a887-77fc26a10918','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,61),(178,'e682c3d0-d95f-445d-9f17-d4b6ac9a70ad','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:07',NULL,'CREATE','COMPLETE','StorageVirtualIP','d0829e0b-565b-4e75-970d-a07acbc206d7','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,65),(179,'27315514-67c7-4da6-8c62-567ad697415a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:07',NULL,'CREATE','COMPLETE','InternalApiVirtualIP','cccee1ff-eb7f-4dab-a10a-78201437aca6','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,66),(180,'30dc6a6c-4130-4e65-b610-d7dfa219ea8b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:07',NULL,'CREATE','IN_PROGRESS','VipMap','overcloud-VipMap-6jreylszb4k5','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,74),(181,'ba48b2a6-9961-43e0-8ad3-395a4ad64399','274bf042-08f7-43b4-8abc-9ff22c6b02f8','2026-06-13 07:50:07',NULL,'CREATE','IN_PROGRESS','overcloud-VipMap-6jreylszb4k5','274bf042-08f7-43b4-8abc-9ff22c6b02f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(182,'766b4ba1-3525-4d01-b0f8-30d7eece2dc8','274bf042-08f7-43b4-8abc-9ff22c6b02f8','2026-06-13 07:50:07',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-VipMap-6jreylszb4k5-NetIpMapValue-mt5ljsbdxkr4','state changed','OS::Heat::Value',NULL,75),(183,'a26fb37c-0566-4aa4-ad9c-11cc391001e8','274bf042-08f7-43b4-8abc-9ff22c6b02f8','2026-06-13 07:50:07',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-VipMap-6jreylszb4k5-NetIpMapValue-mt5ljsbdxkr4','state changed','OS::Heat::Value',NULL,75),(184,'3189abba-0c2f-4397-9569-a95a968f9320','274bf042-08f7-43b4-8abc-9ff22c6b02f8','2026-06-13 07:50:07',NULL,'CREATE','COMPLETE','overcloud-VipMap-6jreylszb4k5','274bf042-08f7-43b4-8abc-9ff22c6b02f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(185,'995c8820-2ff2-4a03-b50d-6da762d63095','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:08',NULL,'CREATE','COMPLETE','VipMap','274bf042-08f7-43b4-8abc-9ff22c6b02f8','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,74),(186,'60822bdb-3e54-44b7-9b6a-16a4b663e968','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:08',NULL,'CREATE','IN_PROGRESS','EndpointMap','overcloud-EndpointMap-ba77na6h2mul','state changed','OS::TripleO::EndpointMap',NULL,78),(187,'73aaccc6-9680-4aeb-a1d0-2718cc0de18d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:08',NULL,'CREATE','IN_PROGRESS','VipHosts','overcloud-VipHosts-ssfbsmrselgo','state changed','OS::Heat::Value',NULL,79),(188,'0408dec9-1803-4042-88af-41fffbaf3817','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:09',NULL,'CREATE','COMPLETE','VipHosts','overcloud-VipHosts-ssfbsmrselgo','state changed','OS::Heat::Value',NULL,79),(189,'09364b68-6bee-4346-984f-310849b9c8bb','babc0e01-f4b9-44ba-8e6a-99d4af1fba50','2026-06-13 07:50:09',NULL,'CREATE','IN_PROGRESS','overcloud-EndpointMap-ba77na6h2mul','babc0e01-f4b9-44ba-8e6a-99d4af1fba50','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(190,'b9227260-e0b6-455c-ad57-b57d145b4421','babc0e01-f4b9-44ba-8e6a-99d4af1fba50','2026-06-13 07:50:09',NULL,'CREATE','COMPLETE','overcloud-EndpointMap-ba77na6h2mul','babc0e01-f4b9-44ba-8e6a-99d4af1fba50','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(191,'80bac35c-3a09-4e9b-876f-27b7c8bdd674','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','COMPLETE','EndpointMap','babc0e01-f4b9-44ba-8e6a-99d4af1fba50','state changed','OS::TripleO::EndpointMap',NULL,78),(192,'c84af00f-9039-45a6-8bed-e6973d33e321','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','IN_PROGRESS','EndpointMapData','overcloud-EndpointMapData-4bkgndobutkh','state changed','OS::Heat::Value',NULL,82),(193,'da08ffca-aeff-49e1-b23e-4969284b48ef','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','COMPLETE','EndpointMapData','overcloud-EndpointMapData-4bkgndobutkh','state changed','OS::Heat::Value',NULL,82),(194,'57334b86-997e-4cdd-a7c5-c59eee713855','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChain','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5','state changed','OS::TripleO::BlockStorageServices',NULL,83),(195,'226f3f15-136d-4f81-b876-24bd2cf4d58a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChain','overcloud-ObjectStorageServiceChain-t7pdutznvxt6','state changed','OS::TripleO::ObjectStorageServices',NULL,84),(196,'bd5e0d7f-5bf6-4ccc-b07e-a7d04dabd8f9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChain','overcloud-CephStorageServiceChain-uy6sem75csw2','state changed','OS::TripleO::CephStorageServices',NULL,85),(197,'6850a11e-a221-45a5-af8b-ffad86edb5ba','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','IN_PROGRESS','ComputeHCIServiceChain','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f','state changed','OS::TripleO::ComputeHCIServices',NULL,86),(198,'97eedc9d-3dd3-4e1f-8cca-844172b9bd73','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChain','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2','state changed','OS::TripleO::CellControllerComputeServices',NULL,87),(199,'4c98a281-a2b6-4bec-94c0-4d074da3427f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:10',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChain','overcloud-NetworkerServiceChain-wjfsqm5rzut2','state changed','OS::TripleO::NetworkerServices',NULL,88),(200,'a6ea2b47-e93d-4eed-adfe-539dec975568','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-uy6sem75csw2','892287d9-0491-440c-8c76-d0e67519bfc8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(201,'da98f288-0436-4e68-8aaa-57464099be4e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','ControllerServiceChain','overcloud-ControllerServiceChain-vhdt72nhe4ji','state changed','OS::TripleO::ControllerServices',NULL,89),(202,'3e8a1024-ead9-4af7-9ea5-eb1883428255','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','ComputeServiceChain','overcloud-ComputeServiceChain-m7joik7pyldm','state changed','OS::TripleO::ComputeServices',NULL,90),(203,'3345b8c0-a7dc-4f21-8518-94848d3b013b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChain','overcloud-CellControllerServiceChain-jyv42aiisndf','state changed','OS::TripleO::CellControllerServices',NULL,91),(204,'bc27df3c-ed76-4ed4-a158-7efa5b6c77f0','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(205,'1c2b690c-c27d-4c6d-9c45-8c102f363b40','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2','659ecdde-f722-4014-9aee-e116435e07bf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(206,'9d032d6e-cd67-4ee4-b028-00cc270a0ded','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-t7pdutznvxt6','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(207,'e46c125f-49e1-44e0-bbe3-5f313307e7b2','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(208,'37e39355-20b3-4564-b1eb-67a879ec0a30','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-wjfsqm5rzut2','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(209,'a4c915fc-50fc-4cb0-b3a6-2e2dad104c99','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji','6672b166-a959-4a82-90bf-0df8a99740f1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(210,'cdf5fd27-68c7-48f7-8df0-893f0c89c128','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-m7joik7pyldm','1b50a534-e8d6-46fb-ae1f-25609640418e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(211,'1e970a4f-c68f-4aaf-a5dd-e1d48294eaf1','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-jyv42aiisndf','814bc91b-b000-483d-89f3-8fb82be740fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(212,'09550425-611b-4e03-884d-b417b327c07a','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceChain-pqkygpczgsnr','state changed','OS::Heat::ResourceChain',NULL,93),(213,'d30d5b25-db18-4f6a-8f03-248ca77cfefc','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6','state changed','OS::Heat::ResourceChain',NULL,94),(214,'37984a8b-0142-4610-937e-0ee92dae2d22','c2fcac65-57c4-465e-a043-6abb0ef03e45','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceChain-pqkygpczgsnr','c2fcac65-57c4-465e-a043-6abb0ef03e45','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(215,'f08da3b3-558a-48db-afa9-aa953f029feb','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceChain-mo64yll7orfz','state changed','OS::Heat::ResourceChain',NULL,95),(216,'b26b0fb7-ed7b-4715-975c-f421909143f8','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:11',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceChain-xpcaa4ewc44x','state changed','OS::Heat::ResourceChain',NULL,96),(217,'8bcfea44-b94b-464d-a474-1a1328c0f34f','c2fcac65-57c4-465e-a043-6abb0ef03e45','2026-06-13 07:50:11',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceChain-pqkygpczgsnr','c2fcac65-57c4-465e-a043-6abb0ef03e45','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(218,'651bd323-6560-4b44-9a79-6e38d20169e2','2860a3ea-09ac-4659-b056-fead1464be9d','2026-06-13 07:50:12',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceChain-xpcaa4ewc44x','2860a3ea-09ac-4659-b056-fead1464be9d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(219,'d42e7975-f1f4-4043-a4c3-305fcd4be697','2860a3ea-09ac-4659-b056-fead1464be9d','2026-06-13 07:50:12',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceChain-xpcaa4ewc44x','2860a3ea-09ac-4659-b056-fead1464be9d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(220,'4769c96f-ad99-470f-b0ca-77e36afa7670','607af71e-f515-458c-aa6f-e3b617443444','2026-06-13 07:50:12',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceChain-mo64yll7orfz','607af71e-f515-458c-aa6f-e3b617443444','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(221,'08d0d3bd-a69e-4c9e-a577-b05d29ed8341','607af71e-f515-458c-aa6f-e3b617443444','2026-06-13 07:50:12',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceChain-mo64yll7orfz','607af71e-f515-458c-aa6f-e3b617443444','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(222,'2702c34e-60b2-4ccc-9182-024a6b0d7197','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:12',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceChain-b3o44f4mbafq','state changed','OS::Heat::ResourceChain',NULL,98),(223,'720c3e6d-e288-42dc-b111-15a53364f11a','767ee145-4f67-4acb-abfd-63dc14927843','2026-06-13 07:50:12',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceChain-b3o44f4mbafq','767ee145-4f67-4acb-abfd-63dc14927843','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(224,'5c2c5b78-4e94-485c-b4d5-265e25dbff08','767ee145-4f67-4acb-abfd-63dc14927843','2026-06-13 07:50:12',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceChain-b3o44f4mbafq','767ee145-4f67-4acb-abfd-63dc14927843','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(225,'dd2584ef-fd26-4c98-83a2-ae24e07a3932','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:12',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi','state changed','OS::Heat::ResourceChain',NULL,97),(226,'41a67a57-d29d-45cf-8f7b-54ddfb775e02','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceChain','c2fcac65-57c4-465e-a043-6abb0ef03e45','state changed','OS::Heat::ResourceChain',NULL,93),(227,'fbf883f1-675a-4f0e-b852-16b096f1f560','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceChain','2860a3ea-09ac-4659-b056-fead1464be9d','state changed','OS::Heat::ResourceChain',NULL,96),(228,'80d8584e-9396-4b4f-9e65-06f7b0768e90','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-GlobalConfigSettings-wxihfgregt42','state changed','OS::Heat::Value',NULL,99),(229,'b1b123ad-5998-4c6d-9434-c394052a5a4d','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceChain','607af71e-f515-458c-aa6f-e3b617443444','state changed','OS::Heat::ResourceChain',NULL,95),(230,'418b00e7-070b-4e1d-8fe6-b3457117ba0e','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-UpdateTasks-abcz4cqpyuoq','state changed','OS::Heat::Value',NULL,100),(231,'aeecfe77-1e26-404a-96d4-6ec7f5017666','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-GlobalConfigSettings-wxihfgregt42','state changed','OS::Heat::Value',NULL,99),(232,'e099415e-445c-45fa-afe9-6ede4bec7ff6','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CephStorageServiceChain-uy6sem75csw2-FirewallFrontendRules-hijsy54qbk7b','state changed','OS::Heat::Value',NULL,101),(233,'110dbf40-cbcf-44d2-99b1-b1b2e0816858','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-UpdateTasks-abcz4cqpyuoq','state changed','OS::Heat::Value',NULL,100),(234,'87da25af-b661-492a-9d88-51f73d3a6cd8','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-HostPrepTasks-kxk6oh7qhsc5','state changed','OS::Heat::Value',NULL,104),(235,'f8490c5c-272b-4fd1-b343-5e943df34377','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalDeployTasks-hoabwwmbcqp7','state changed','OS::Heat::Value',NULL,103),(236,'c796323e-bd17-46a0-95c0-e02f669242b5','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceServerMetadataHook-uibw6wvx7zlt','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,NULL),(237,'ef18f09a-d52d-4d72-a06c-9a407d1354c2','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-KeystoneResourcesConfigs-t3devvfuh6jq','state changed','OS::Heat::Value',NULL,102),(238,'3d340783-fb44-4c5f-9465-3cc963eec37d','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-HostPrepTasks-kxk6oh7qhsc5','state changed','OS::Heat::Value',NULL,104),(239,'eaf0a5b7-ddde-4b6f-a751-c2572d35045f','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalDeployTasks-hoabwwmbcqp7','state changed','OS::Heat::Value',NULL,103),(240,'7029dbac-55b3-48aa-94f8-6aa25e810d55','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PuppetStepConfig-chbh6bp4xxwy','state changed','OS::Heat::Value',NULL,105),(241,'9623ae43-32da-4dc1-89a8-9938d1f8d915','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CephStorageServiceChain-uy6sem75csw2-FirewallFrontendRules-hijsy54qbk7b','state changed','OS::Heat::Value',NULL,101),(242,'625c80ee-361f-4e94-8f7e-e326a4450f9a','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DockerPuppetTasks-mpj2oobupqep','state changed','OS::Heat::Value',NULL,106),(243,'a87c7e5f-89e4-4f57-88bf-3925cdda753d','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-NetworkerServiceChain-wjfsqm5rzut2-FirewallFrontendRules-bjyar5yfxgc6','state changed','OS::Heat::Value',NULL,107),(244,'66065c06-1540-4276-a014-db8705e78b6f','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','46c18d6c-9a70-4ae6-963d-2a7091c32d7a','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,NULL),(245,'49b53323-737d-42fa-bdcf-e054ac56308e','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalUpdateTasks-dkj6omtkdv42','state changed','OS::Heat::Value',NULL,109),(246,'6c30c230-4886-440f-bb1b-04887ff023af','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DockerPuppetTasks-mpj2oobupqep','state changed','OS::Heat::Value',NULL,106),(247,'b74d251a-74c1-44f2-8c23-7d24aa2cdb96','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-UpgradeBatchTasks-yqjhlv3izhui','state changed','OS::Heat::Value',NULL,110),(248,'bebfd236-d450-466c-9591-85bf78521c54','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceChain','767ee145-4f67-4acb-abfd-63dc14927843','state changed','OS::Heat::ResourceChain',NULL,98),(249,'8c9b0cd5-53be-44bb-a756-e3373e91dd15','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalDeployTasks-eiyk6wjsdeoj','state changed','OS::Heat::Value',NULL,108),(250,'3237eddc-d124-43f1-8f2e-737a48864e05','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-NetworkerServiceChain-wjfsqm5rzut2-FirewallFrontendRules-bjyar5yfxgc6','state changed','OS::Heat::Value',NULL,107),(251,'7ce91f5f-da2d-4ac6-9df4-4e4f113450b6','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalPostDeployTasks-xgs2unoozexy','state changed','OS::Heat::Value',NULL,114),(252,'3c68e86f-14b0-4323-bbe9-ee72a9e751ef','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceServerMetadataHook-uf6kmipq2jzx','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,NULL),(253,'eb7a5f00-bec9-4965-8c94-7f3bf4192a21','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalUpdateTasks-dkj6omtkdv42','state changed','OS::Heat::Value',NULL,109),(254,'8b630287-993e-4ac0-b696-00098351815d','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-UpgradeBatchTasks-yqjhlv3izhui','state changed','OS::Heat::Value',NULL,110),(255,'c806be9f-3d40-409b-a498-81177194c20f','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-KeystoneResourcesConfigs-t3devvfuh6jq','state changed','OS::Heat::Value',NULL,102),(256,'d8b81cba-16ad-4079-bc0a-754f7165ddb1','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalDeployTasks-vpyeu3mehygr','state changed','OS::Heat::Value',NULL,113),(257,'bfb51f48-e5a7-4b46-96fc-962df2bcb47e','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalUpgradeTasks-wbyteq4ljl4f','state changed','OS::Heat::Value',NULL,111),(258,'d3e82830-588e-4a52-aedb-30984e2afc60','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalPostDeployTasks-xgs2unoozexy','state changed','OS::Heat::Value',NULL,114),(259,'fc1c4eae-3486-44af-a75c-4c66c7958d42','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PuppetStepConfig-chbh6bp4xxwy','state changed','OS::Heat::Value',NULL,105),(260,'27c6152f-0daa-4382-9669-92089520acd4','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalUpdateTasks-vcksljvp5c62','state changed','OS::Heat::Value',NULL,117),(261,'fc286c1e-658d-48aa-8acb-bb8f8e731376','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PostUpgradeTasks-krdoqv6t5iat','state changed','OS::Heat::Value',NULL,112),(262,'40f73081-9ec6-404c-8af7-8686ac1f8a69','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-HostFirewallTasks-iyk34uokeqep','state changed','OS::Heat::Value',NULL,116),(263,'5587a7bb-8197-4a1b-938e-fd1e30d7e081','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-wjfsqm5rzut2-KeystoneResourcesConfigs-qroutvvl5aej','state changed','OS::Heat::Value',NULL,118),(264,'341d2e97-1e7f-44c7-ab02-4bc7d252445b','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','35c6f75d-a390-49c5-8454-9ea5df318ef6','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,NULL),(265,'bb260db4-bee8-4bc2-a906-e342192b1282','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(266,'1037f318-2b19-4166-93b3-6d13648d54c9','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-MonitoringSubscriptionsConfig-ejlkkj6hqfgh','state changed','OS::Heat::Value',NULL,120),(267,'0df78d67-a95a-4ba7-8877-a43ed49a2cef','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ScaleTasks-opukkfrtjblz','state changed','OS::Heat::Value',NULL,115),(268,'87c3ce0f-89c1-4131-add2-04f92d5095dc','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DeployStepsTasks-hewdsjknlwzz','state changed','OS::Heat::Value',NULL,122),(269,'e82b5e8e-6376-4bd2-b203-96dc9c70ddda','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ContainerPuppetTasks-v42aec3n2ib2','state changed','OS::Heat::Value',NULL,123),(270,'cb7b50d2-0314-488d-9604-8a55bd514eca','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalDeployTasks-eiyk6wjsdeoj','state changed','OS::Heat::Value',NULL,108),(271,'2b87b4aa-4ffb-40ef-93a8-52010c8b056b','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-PuppetStepConfig-gyplunmnrndb','state changed','OS::Heat::Value',NULL,119),(272,'6d01765b-5919-4571-a820-93c677e713df','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DockerConfigScripts-34np6rwqwaxo','state changed','OS::Heat::Value',NULL,121),(273,'b9035d2b-9d98-4b2f-9941-9e2885d29a5e','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-wjfsqm5rzut2-KeystoneResourcesConfigs-qroutvvl5aej','state changed','OS::Heat::Value',NULL,118),(274,'271e946f-8dd9-42c6-978d-cd89d3675774','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalUpdateTasks-vcksljvp5c62','state changed','OS::Heat::Value',NULL,117),(275,'8c1e5d10-be7a-40c8-8204-db5b5eb003ba','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceConfigSettings-e222ykf4nvgl','state changed','OS::Heat::Value',NULL,125),(276,'f60c6c20-5057-476b-a058-576d4e247913','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DeployStepsTasks-hewdsjknlwzz','state changed','OS::Heat::Value',NULL,122),(277,'5ccaf774-28f5-4368-a8c7-32e8d54f2c83','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ContainerPuppetTasks-v42aec3n2ib2','state changed','OS::Heat::Value',NULL,123),(278,'a352abe6-e39f-433d-8cee-bc8bff1b5b2a','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PreUpgradeRollingTasks-nrmjl6lvlls5','state changed','OS::Heat::Value',NULL,127),(279,'ab8f1fca-1756-4892-a6c0-f32ee62e3725','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceConfigSettings-e222ykf4nvgl','state changed','OS::Heat::Value',NULL,125),(280,'7be2e09a-f989-4eb7-a5a9-32e9f65111a8','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-IpaRegistrationTasks-jf5ws5lknv7g','state changed','OS::Heat::Value',NULL,129),(281,'d78d8a74-14d6-48e5-bec9-803d8e27c1a6','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PreDeployStepTasks-4hqhu5o23lhx','state changed','OS::Heat::Value',NULL,128),(282,'d91c655e-103b-40f4-b0d0-8eb60dc69d13','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PreUpgradeRollingTasks-nrmjl6lvlls5','state changed','OS::Heat::Value',NULL,127),(283,'3b4dce8f-c337-42b0-86c2-805ac439e273','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-UpgradeTasks-7aromu7kryzo','state changed','OS::Heat::Value',NULL,126),(284,'ecb1edb9-b95b-4ad6-8a26-1f69f997adf5','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ExternalUpgradeTasks-wbyteq4ljl4f','state changed','OS::Heat::Value',NULL,111),(285,'b664a155-1c29-469b-aff1-9cb533ea3371','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-UpgradeTasks-biord3q3jpu3','state changed','OS::Heat::Value',NULL,132),(286,'7a5c9b68-b663-4e66-b0d0-8a1777953453','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-KollaConfig-izssy3uevo2y','state changed','OS::Heat::Value',NULL,131),(287,'96b86984-7388-4e8f-b907-59ba28f204e7','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-HostFirewallTasks-jpu2hofgc6fx','state changed','OS::Heat::Value',NULL,124),(288,'957cf353-5f15-4259-87a8-8af45c4eb9ee','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PostUpgradeTasks-krdoqv6t5iat','state changed','OS::Heat::Value',NULL,112),(289,'e1680f48-605c-4454-8fb0-eb46e7585a8f','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalDeployTasks-vpyeu3mehygr','state changed','OS::Heat::Value',NULL,113),(290,'8f900b30-1f3a-42d1-bae3-de8e477cacd2','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PreDeployStepTasks-4hqhu5o23lhx','state changed','OS::Heat::Value',NULL,128),(291,'af72d1ec-117c-41c8-9c62-dd3c216db8f9','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-IpaRegistrationTasks-jf5ws5lknv7g','state changed','OS::Heat::Value',NULL,129),(292,'c7b311f0-9097-424d-9532-ab66609ad31d','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-HostFirewallTasks-oy54qga4wah5','state changed','OS::Heat::Value',NULL,136),(293,'cbec8866-05ff-4a62-9cb3-04ca97566488','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DeployStepsTasks-7rxdh5lsbcec','state changed','OS::Heat::Value',NULL,138),(294,'55733d3a-b3fb-4b40-9593-6e06a78cdf9d','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-KollaConfig-izssy3uevo2y','state changed','OS::Heat::Value',NULL,131),(295,'da52a5ad-cd11-4d7a-8ded-8b106d803058','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-UpgradeTasks-biord3q3jpu3','state changed','OS::Heat::Value',NULL,132),(296,'75363782-a351-4568-a896-80643888fa88','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PreUpgradeRollingTasks-3vjbn4l5uxmk','state changed','OS::Heat::Value',NULL,130),(297,'f8fb1dc1-6ade-47e7-92c4-e943dae7887e','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ScaleTasks-opukkfrtjblz','state changed','OS::Heat::Value',NULL,115),(298,'78a63574-c545-45ef-bfce-2dbe3b5c6ac6','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DockerConfigScripts-34np6rwqwaxo','state changed','OS::Heat::Value',NULL,121),(299,'e983f02c-6a19-487f-8518-cc94ab9a9592','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PostUpdateTasks-kw3iqkipdaau','state changed','OS::Heat::Value',NULL,133),(300,'4c227e3a-2b9c-4891-b30f-dfe761525392','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-PuppetStepConfig-gyplunmnrndb','state changed','OS::Heat::Value',NULL,119),(301,'faade2cf-ec89-4d64-a24b-125ba23ad469','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DockerConfig-zz5nksues2sb','state changed','OS::Heat::Value',NULL,141),(302,'abc7ea4e-ff8f-475d-8313-9f31fd195271','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DeployStepsTasks-7rxdh5lsbcec','state changed','OS::Heat::Value',NULL,138),(303,'60517c7e-320b-44ee-87ef-5ea34074bb2c','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalUpgradeTasks-2gb4mqm2cqu6','state changed','OS::Heat::Value',NULL,140),(304,'2dfdfebf-3c1d-4885-957e-f4fe1e8a1a80','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-HostFirewallTasks-oy54qga4wah5','state changed','OS::Heat::Value',NULL,136),(305,'30130a7c-83e4-42d7-8f5b-f461fd2284ef','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-NetworkerServiceChain-wjfsqm5rzut2-AnsibleGroupVars-tz5j4hsjbzcr','state changed','OS::Heat::Value',NULL,142),(306,'2c9bf809-49ec-4603-ac14-a0fbb1e55437','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-NetworkerServiceChain-wjfsqm5rzut2-GlobalConfigSettings-pdefvfr6dbtc','state changed','OS::Heat::Value',NULL,137),(307,'b6ad4d25-1d2e-489f-895e-6194d46a6404','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-AnsibleGroupVars-2gm5x54lwwoq','state changed','OS::Heat::Value',NULL,143),(308,'3f60b5f4-2036-4099-a6d1-1f1921c19e0f','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(309,'4a4f3dd7-3d26-462c-9e16-b52d9cc06534','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ScaleTasks-jrrarbqcqwjk','state changed','OS::Heat::Value',NULL,139),(310,'288552fa-c4b3-418f-a829-c2cab088ab8a','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-DockerConfig-zz5nksues2sb','state changed','OS::Heat::Value',NULL,141),(311,'0513a5d5-2824-4aa2-9586-a0811a776e4c','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalUpgradeTasks-2gb4mqm2cqu6','state changed','OS::Heat::Value',NULL,140),(312,'02b0bf2e-073b-4e9b-b959-27e1f87f97e5','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PostUpgradeTasks-dblnvz6humep','state changed','OS::Heat::Value',NULL,145),(313,'13feff95-9abe-4576-af59-87354d763ade','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-UpgradeTasks-7aromu7kryzo','state changed','OS::Heat::Value',NULL,126),(314,'b0085efa-700a-4ca9-b8c2-0d9091622515','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-HostFirewallTasks-iyk34uokeqep','state changed','OS::Heat::Value',NULL,116),(315,'2d1c0002-2c17-4a64-8b6e-cfb4c71ff427','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-NetworkerServiceChain-wjfsqm5rzut2-AnsibleGroupVars-tz5j4hsjbzcr','state changed','OS::Heat::Value',NULL,142),(316,'e032f73e-3c30-4350-b5e9-c53dc371a95c','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceNames-con2wqvtkpgj','state changed','OS::Heat::Value',NULL,146),(317,'6e261ef3-522f-46d8-8e33-193473cee3b2','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-AnsibleGroupVars-2gm5x54lwwoq','state changed','OS::Heat::Value',NULL,143),(318,'1c2ecfef-8a45-4820-9654-6c7845ee1949','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DockerPuppetTasks-3m3hs5d7cvku','state changed','OS::Heat::Value',NULL,151),(319,'301ebbb6-48c4-48b4-a73a-f7eb7cebbae3','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PreDeployStepTasks-edg2jlyw5qke','state changed','OS::Heat::Value',NULL,144),(320,'6f38fbf4-e9e3-468a-bcfe-42823cd08ced','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-FirewallFrontendRules-nfef4usa7vkc','state changed','OS::Heat::Value',NULL,134),(321,'6931747d-8231-4464-950a-7467b9ea34ac','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-KollaConfig-nyihpigw54l5','state changed','OS::Heat::Value',NULL,150),(322,'a8b97863-7cf7-439e-830c-564d50184234','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalPostDeployTasks-jn36fwoxjzqa','state changed','OS::Heat::Value',NULL,135),(323,'caf0efdf-42e8-4ce0-8302-3b8e0c74a9bc','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PostUpgradeTasks-dblnvz6humep','state changed','OS::Heat::Value',NULL,145),(324,'7d8b632c-751d-4ffb-a5fe-72b79ec7e0a3','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PostUpdateTasks-kw3iqkipdaau','state changed','OS::Heat::Value',NULL,133),(325,'492f7680-931f-4f95-ba7f-fea80394f56c','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceNames-con2wqvtkpgj','state changed','OS::Heat::Value',NULL,146),(326,'bfd86a7e-19a7-4117-8304-7b705971da2b','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PreUpgradeRollingTasks-zbexk2iz6nld','state changed','OS::Heat::Value',NULL,153),(327,'89538270-168d-44b4-9dca-067321832726','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-IpaRegistrationTasks-esh5up4sc4cd','state changed','OS::Heat::Value',NULL,154),(328,'fa73a2f1-c75e-4e54-968c-e0d1e7024459','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PreUpgradeRollingTasks-3vjbn4l5uxmk','state changed','OS::Heat::Value',NULL,130),(329,'ff0e4eb1-b86f-41e3-9dce-0c99f2ee6a28','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DockerPuppetTasks-3m3hs5d7cvku','state changed','OS::Heat::Value',NULL,151),(330,'a09af683-fa52-49f9-80fb-783c28307edf','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-KollaConfig-nyihpigw54l5','state changed','OS::Heat::Value',NULL,150),(331,'98595de3-f7dd-4128-86fe-bfa21028963b','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ServiceServerMetadataHook-fpltgbkpw4uf','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,NULL),(332,'74302cc4-c5d0-4835-829e-9aad3693a8f5','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-IpaRegistrationTasks-esh5up4sc4cd','state changed','OS::Heat::Value',NULL,154),(333,'0a06e1e1-6c14-48b0-a3af-36b8b9eed269','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PreUpgradeRollingTasks-zbexk2iz6nld','state changed','OS::Heat::Value',NULL,153),(334,'e04ef8ba-f3c4-4f25-81b5-69006ef9a115','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-MonitoringSubscriptionsConfig-zoxhv3fjtzvw','state changed','OS::Heat::Value',NULL,156),(335,'59e0a860-7b75-4aca-a13a-7e478815187b','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-MonitoringSubscriptionsConfig-zoxhv3fjtzvw','state changed','OS::Heat::Value',NULL,156),(336,'09e53677-5f30-445a-888b-27907408f570','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:13',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-MonitoringSubscriptionsConfig-ejlkkj6hqfgh','state changed','OS::Heat::Value',NULL,120),(337,'1f45e239-e4cf-440f-b683-97be6f8286ba','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:13',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CephStorageServiceChain-uy6sem75csw2-GlobalConfigSettings-qfzw2gg2bmyt','state changed','OS::Heat::Value',NULL,148),(338,'19d77ec6-1c0b-45b6-899b-0afcbd3c9c14','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-FirewallRules-xuqs3szprwxt','state changed','OS::Heat::Value',NULL,147),(339,'77e342b2-d4a8-43d6-9d80-b097913bd07f','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PostUpdateTasks-lqrrzsztqlx5','state changed','OS::Heat::Value',NULL,149),(340,'758679e9-3ee4-47f2-a0c5-21973055320a','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-UpdateTasks-dfzabe77qoz2','state changed','OS::Heat::Value',NULL,159),(341,'e5456726-0060-43f4-985c-04851a2aeaf1','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalPostDeployTasks-lkjtoqsse3vn','state changed','OS::Heat::Value',NULL,161),(342,'301cc617-af6d-4d43-bdfd-4a7a2b631ccf','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PostUpgradeTasks-wa7lw5jbdbgh','state changed','OS::Heat::Value',NULL,162),(343,'09c8b790-6d1c-4651-9adb-a7f77a5cc20d','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-UpdateTasks-dfzabe77qoz2','state changed','OS::Heat::Value',NULL,159),(344,'f16f39f1-dea7-4c94-abf0-b9476fddf38b','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PostUpgradeTasks-wa7lw5jbdbgh','state changed','OS::Heat::Value',NULL,162),(345,'632f1c90-cbf5-44b0-af55-753d81aa7d36','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-ScaleTasks-jrrarbqcqwjk','state changed','OS::Heat::Value',NULL,139),(346,'bdab49ef-c8c3-4492-90a5-7f3ffd20e579','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-NetworkerServiceChain-wjfsqm5rzut2-GlobalConfigSettings-pdefvfr6dbtc','state changed','OS::Heat::Value',NULL,137),(347,'d522a4bb-b6e5-4513-a186-e2c38e3682fa','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-HostPrepTasks-umusrhu52yj2','state changed','OS::Heat::Value',NULL,155),(348,'63f970f7-28ae-400a-8aac-d436a1d93793','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ContainerPuppetTasks-uoqzjekyh667','state changed','OS::Heat::Value',NULL,165),(349,'21cd44a6-00b6-423f-b21b-49f0e5bb881d','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ExternalPostDeployTasks-lkjtoqsse3vn','state changed','OS::Heat::Value',NULL,161),(350,'03f9f500-d1fd-4bef-b66a-ce675964d71f','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ContainerPuppetTasks-uoqzjekyh667','state changed','OS::Heat::Value',NULL,165),(351,'1bdbe924-77fb-4541-8706-46ca9cd36972','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceServerMetadataHook-uj5nk33c2ku3','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,NULL),(352,'99f61683-e7dc-4cce-90d2-18ec48aced10','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-HostFirewallTasks-jpu2hofgc6fx','state changed','OS::Heat::Value',NULL,124),(353,'31c107af-6d77-4847-ba64-91aa20aa0dbd','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','155ac6fd-a039-4e46-ba3a-53864a876561','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,NULL),(354,'15998980-b13d-4c7b-bdee-7d1cc260c97d','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PreDeployStepTasks-edg2jlyw5qke','state changed','OS::Heat::Value',NULL,144),(355,'2faf645d-7dcc-4445-bce3-e63d91282bec','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceNames-mmjzzlrfimcb','state changed','OS::Heat::Value',NULL,160),(356,'3904986d-f7cf-4953-829c-51fd0e38d7c5','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DockerConfigScripts-bg24qry75doh','state changed','OS::Heat::Value',NULL,164),(357,'98ed4a62-d955-469d-a6c7-4604e43838f7','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceConfigSettings-gy5y64qppe75','state changed','OS::Heat::Value',NULL,157),(358,'d75ad9d7-c60b-458f-ac8c-fe9375935c83','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-m7joik7pyldm-MonitoringSubscriptionsConfig-ov2czfgqkvvz','state changed','OS::Heat::Value',NULL,158),(359,'11c255a2-cd5c-48b0-8238-89c9175d57f5','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PuppetStepConfig-asvt5bo7bdbx','state changed','OS::Heat::Value',NULL,167),(360,'27903870-62d1-4675-9f51-29d05cd9e39b','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalPostDeployTasks-eqzbaaksjamg','state changed','OS::Heat::Value',NULL,166),(361,'3aedbc09-16fa-4f7b-bcef-eaa38332e6fa','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ComputeServiceChain-m7joik7pyldm-DockerConfigScripts-jmsb3636wx4i','state changed','OS::Heat::Value',NULL,168),(362,'5c2278df-0edb-4687-876a-9d1734e5c017','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceNames-ghp2tnkl57ii','state changed','OS::Heat::Value',NULL,169),(363,'8aae11cd-f682-4de5-bbcc-d41843b6b4e3','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-FirewallFrontendRules-nfef4usa7vkc','state changed','OS::Heat::Value',NULL,134),(364,'e1192831-cd97-43cd-9051-cf75ca84bb44','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PuppetConfig-rrafynpqszv5','state changed','OS::Heat::Value',NULL,170),(365,'0a077e28-98c9-4eba-9b18-3fa820520e86','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalPostDeployTasks-jn36fwoxjzqa','state changed','OS::Heat::Value',NULL,135),(366,'2677b5ad-3664-4708-8745-a2a7a16d20d4','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-FirewallRules-xuqs3szprwxt','state changed','OS::Heat::Value',NULL,147),(367,'c3e20280-de70-476e-8918-2ea130f966a2','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PostUpdateTasks-lqrrzsztqlx5','state changed','OS::Heat::Value',NULL,149),(368,'c42678e8-54e6-42a2-878c-38687698bc25','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-UpgradeBatchTasks-nerpcbuaxar6','state changed','OS::Heat::Value',NULL,171),(369,'fa66494c-14fa-41c3-b2b2-7b2d2b777d0b','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-HostPrepTasks-umusrhu52yj2','state changed','OS::Heat::Value',NULL,155),(370,'46e99771-e2ac-4805-bef8-f2faadcdde20','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PuppetConfig-52kyxspzh7ad','state changed','OS::Heat::Value',NULL,173),(371,'18d8d4f0-4503-4429-84bd-87f1b945a262','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-NetworkerServiceChain-wjfsqm5rzut2-FirewallRules-du4qdak76nmq','state changed','OS::Heat::Value',NULL,172),(372,'8dbc59e6-9dd0-4471-904b-3809f32490b9','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c23f2c06-1e61-45ec-8932-73e698f90e99','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,NULL),(373,'67c67aaa-27e3-4ce7-b614-51d423d03b51','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceNames-mmjzzlrfimcb','state changed','OS::Heat::Value',NULL,160),(374,'4631b555-7827-44f9-bfcf-1a761982c155','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CephStorageServiceChain-uy6sem75csw2-GlobalConfigSettings-qfzw2gg2bmyt','state changed','OS::Heat::Value',NULL,148),(375,'615697a7-35a2-4e12-8b05-a67662dcfd41','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ComputeServiceChain-m7joik7pyldm-FirewallRules-x5s4rduee7z3','state changed','OS::Heat::Value',NULL,174),(376,'276e06d1-fc63-4a11-8c36-2d492f4527ff','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DockerConfigScripts-bg24qry75doh','state changed','OS::Heat::Value',NULL,164),(377,'4f9f0a5f-54b7-46d2-92ff-ff02d1b6d651','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ComputeServiceChain-m7joik7pyldm-GlobalConfigSettings-we36pn4yedoc','state changed','OS::Heat::Value',NULL,177),(378,'cec47170-bc26-4cb5-a3f8-f2a2565a9178','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ComputeServiceChain-m7joik7pyldm-GlobalConfigSettings-we36pn4yedoc','state changed','OS::Heat::Value',NULL,177),(379,'8179982f-077a-40a4-a9bc-46f3319cce8c','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DockerConfig-n7phi2yozgij','state changed','OS::Heat::Value',NULL,175),(380,'55d27929-12ff-4923-bc98-58f896e1969f','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-NetworkerServiceChain-wjfsqm5rzut2-UpgradeBatchTasks-nerpcbuaxar6','state changed','OS::Heat::Value',NULL,171),(381,'837ee498-69ef-442d-b63c-af0acb09afdc','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-NetworkerServiceChain-wjfsqm5rzut2-ServiceConfigSettings-gy5y64qppe75','state changed','OS::Heat::Value',NULL,157),(382,'3e448fd2-9c4b-4b43-a417-1cc4625af833','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PuppetConfig-52kyxspzh7ad','state changed','OS::Heat::Value',NULL,173),(383,'6b2c3bef-f250-492e-8e68-2d82de4bdf6b','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-UpdateTasks-wjq4sorr63il','state changed','OS::Heat::Value',NULL,178),(384,'0b6ab622-c4de-4949-bc1c-0b6cf4399713','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-m7joik7pyldm-MonitoringSubscriptionsConfig-ov2czfgqkvvz','state changed','OS::Heat::Value',NULL,158),(385,'0a4f0a09-b89b-421d-a5ca-5acc7804f0a0','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-HostPrepTasks-x5hn2jdrektc','state changed','OS::Heat::Value',NULL,176),(386,'92cdbdc3-3e78-401b-a209-8053969504df','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-PuppetStepConfig-asvt5bo7bdbx','state changed','OS::Heat::Value',NULL,167),(387,'37c4f916-58ac-4348-ab45-d86acaa24c79','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalPostDeployTasks-eqzbaaksjamg','state changed','OS::Heat::Value',NULL,166),(388,'1410d078-2514-4be1-a525-1769196760df','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-UpdateTasks-wjq4sorr63il','state changed','OS::Heat::Value',NULL,178),(389,'8b81732a-53ed-46c8-a104-a7bf4d92f34b','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ComputeServiceChain-m7joik7pyldm-FirewallRules-x5s4rduee7z3','state changed','OS::Heat::Value',NULL,174),(390,'f2514c31-d7bf-49cd-afae-3d03dce02c0e','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CephStorageServiceChain-uy6sem75csw2-DockerConfigScripts-rsjofjb5of2z','state changed','OS::Heat::Value',NULL,179),(391,'9d17e1e9-dbc3-44d6-b52c-34b99ec6d175','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceNames-ghp2tnkl57ii','state changed','OS::Heat::Value',NULL,169),(392,'66cd09f4-1235-443a-a7f7-1917d07f3172','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ComputeServiceChain-m7joik7pyldm-DockerConfigScripts-jmsb3636wx4i','state changed','OS::Heat::Value',NULL,168),(393,'ff3f5490-1b28-4b1b-bf37-9d987cba8150','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ObjectStorageServiceChain-t7pdutznvxt6-PuppetConfig-rrafynpqszv5','state changed','OS::Heat::Value',NULL,170),(394,'db879a69-b702-49cc-8b60-35ce4f118e22','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CephStorageServiceChain-uy6sem75csw2-DockerConfigScripts-rsjofjb5of2z','state changed','OS::Heat::Value',NULL,179),(395,'b45d895f-3198-4125-9b36-3eaeb0b9768e','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ComputeServiceChain-m7joik7pyldm-PuppetConfig-6gr24ouhu7kp','state changed','OS::Heat::Value',NULL,181),(396,'df942f8f-fa1f-434d-a813-02f1dffc87fc','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ComputeServiceChain-m7joik7pyldm-DeployStepsTasks-2wiebyzopdqp','state changed','OS::Heat::Value',NULL,182),(397,'3354db59-beb9-4571-913b-ac944e009f5b','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-NetworkerServiceChain-wjfsqm5rzut2-FirewallRules-du4qdak76nmq','state changed','OS::Heat::Value',NULL,172),(398,'1d1bdb8a-ecfb-48a8-b37c-12e76c118205','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ComputeServiceChain-m7joik7pyldm-DeployStepsTasks-2wiebyzopdqp','state changed','OS::Heat::Value',NULL,182),(399,'c6a044d1-0902-437b-9a18-470b53d95289','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ComputeServiceChain-m7joik7pyldm-FirewallFrontendRules-iziloek4gon7','state changed','OS::Heat::Value',NULL,180),(400,'a06fb18d-c3de-4eb6-ac47-b7a6d13c1209','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-UpgradeBatchTasks-hhozdugycnrl','state changed','OS::Heat::Value',NULL,183),(401,'5b6d1f76-4648-4b37-85f3-21883d62c6bd','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ComputeServiceChain-m7joik7pyldm-PuppetConfig-6gr24ouhu7kp','state changed','OS::Heat::Value',NULL,181),(402,'c5f0f5e6-b022-4f31-a229-7109c5d1ad2f','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-NetworkerServiceChain-wjfsqm5rzut2-DockerConfig-n7phi2yozgij','state changed','OS::Heat::Value',NULL,175),(403,'e0e46f2c-c26a-4e22-88ff-a49338b0475b','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-UpgradeBatchTasks-hhozdugycnrl','state changed','OS::Heat::Value',NULL,183),(404,'f8202b34-d928-4182-b6d6-20fc20131cca','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ComputeServiceChain-m7joik7pyldm-UpdateTasks-wjjdu4pjuyiv','state changed','OS::Heat::Value',NULL,184),(405,'7be74c4d-f780-4f83-ae6b-bc4daa83ef65','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-m7joik7pyldm-KeystoneResourcesConfigs-4dh4sexyxjzl','state changed','OS::Heat::Value',NULL,186),(406,'b9ca1f31-5a46-441e-ac4e-6324811eeccb','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-HostPrepTasks-x5hn2jdrektc','state changed','OS::Heat::Value',NULL,176),(407,'48398cfd-f0dd-43a0-b8e5-78203b80b258','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-m7joik7pyldm-KeystoneResourcesConfigs-4dh4sexyxjzl','state changed','OS::Heat::Value',NULL,186),(408,'330d322d-1f83-49f8-93a1-2c0380bdde1a','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ComputeServiceChain-m7joik7pyldm-HostFirewallTasks-isfycdtiifp4','state changed','OS::Heat::Value',NULL,185),(409,'612bfa55-0b5d-40ae-9116-61868f5e75cc','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ComputeServiceChain-m7joik7pyldm-UpdateTasks-wjjdu4pjuyiv','state changed','OS::Heat::Value',NULL,184),(410,'ab9ca8d0-dbc3-4492-9ab7-6448cc4216bd','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-UpgradeTasks-3ot73lm7y64m','state changed','OS::Heat::Value',NULL,188),(411,'3b5af2ca-cf2b-4d60-8173-5ef8b117c23c','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceConfigSettings-mob54ka7xxpl','state changed','OS::Heat::Value',NULL,189),(412,'9b478b81-1755-4de3-9087-17ce67146ac9','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ComputeServiceChain-m7joik7pyldm-FirewallFrontendRules-iziloek4gon7','state changed','OS::Heat::Value',NULL,180),(413,'10378436-b7e5-40c1-9fdf-057b6784a14e','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceChain-dzqwp7mcvvbz','state changed','OS::Heat::ResourceChain',NULL,190),(414,'fa60bdaf-1330-4f20-8d83-e984d763a28f','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ComputeServiceChain-m7joik7pyldm-UpgradeTasks-qey436ff42rd','state changed','OS::Heat::Value',NULL,187),(415,'67d2f90b-a187-4875-a78b-3fabf98d8a8b','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PostUpgradeTasks-balagx5glaqc','state changed','OS::Heat::Value',NULL,192),(416,'1d079cee-342b-4966-9f58-7091e2a30b6c','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-KollaConfig-ienkmi5dnnzt','state changed','OS::Heat::Value',NULL,191),(417,'61592bdd-8063-4857-be7a-7a689e420325','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-UpgradeTasks-3ot73lm7y64m','state changed','OS::Heat::Value',NULL,188),(418,'028a72d5-a44e-4956-8635-84c4d70b91b9','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ComputeServiceChain-m7joik7pyldm-ServiceConfigSettings-mob54ka7xxpl','state changed','OS::Heat::Value',NULL,189),(419,'13e28f6d-1222-4d84-88f5-034173e0731f','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PostUpgradeTasks-balagx5glaqc','state changed','OS::Heat::Value',NULL,192),(420,'dc3dc283-0811-4c02-ad66-2f5c439d1e43','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ScaleTasks-euwrjpc5myxs','state changed','OS::Heat::Value',NULL,194),(421,'a03d355e-9f8a-488a-9dd6-e73e014beaf9','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ComputeServiceChain-m7joik7pyldm-HostFirewallTasks-isfycdtiifp4','state changed','OS::Heat::Value',NULL,185),(422,'66e70177-ca6f-4e9e-9d9b-03cf34a9f100','93484ca9-c36e-4e65-9794-d90219b2ab6c','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceChain-dzqwp7mcvvbz','93484ca9-c36e-4e65-9794-d90219b2ab6c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(423,'a4d47503-43a8-4295-a313-0b0ee780f418','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ScaleTasks-euwrjpc5myxs','state changed','OS::Heat::Value',NULL,194),(424,'ede91385-0822-420e-ad9c-7668620288dd','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-KollaConfig-ienkmi5dnnzt','state changed','OS::Heat::Value',NULL,191),(425,'fa4db529-4bb9-4e94-aec9-c6c2f5a68bb0','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalUpgradeTasks-jn5vbwpysbsg','state changed','OS::Heat::Value',NULL,195),(426,'b2d4b960-61e8-4fad-96d7-d17635c3ca48','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PreUpgradeRollingTasks-5su6fn26llg3','state changed','OS::Heat::Value',NULL,196),(427,'b1a9fdca-15e1-44f0-bb57-3f757bb0563a','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PreUpgradeRollingTasks-5su6fn26llg3','state changed','OS::Heat::Value',NULL,196),(428,'4c1cc6bb-7f3b-4252-aed9-b009c581aca1','93484ca9-c36e-4e65-9794-d90219b2ab6c','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceChain-dzqwp7mcvvbz','93484ca9-c36e-4e65-9794-d90219b2ab6c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(429,'f6149956-f624-4907-b9c9-6be2d7047160','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalUpgradeTasks-jn5vbwpysbsg','state changed','OS::Heat::Value',NULL,195),(430,'b0b9180b-0427-4d06-a597-cdc3d7c106fa','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CephStorageServiceChain-uy6sem75csw2-AnsibleGroupVars-7xvhh3y5wgg4','state changed','OS::Heat::Value',NULL,197),(431,'f01ed600-aad6-4774-965c-2b937377e1ce','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CephStorageServiceChain-uy6sem75csw2-AnsibleGroupVars-7xvhh3y5wgg4','state changed','OS::Heat::Value',NULL,197),(432,'5ba51273-563f-486f-9500-7eb87bdce014','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalUpgradeTasks-c6zoqsqdx23i','state changed','OS::Heat::Value',NULL,198),(433,'a4c27f9e-2318-441e-a196-cc986ef38b42','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ComputeServiceChain-m7joik7pyldm-KollaConfig-fgqwmttltynn','state changed','OS::Heat::Value',NULL,193),(434,'6b08d33b-db3d-4a4f-82fc-bf932ea4b41a','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ComputeServiceChain-m7joik7pyldm-HostPrepTasks-2mi2emrhat77','state changed','OS::Heat::Value',NULL,200),(435,'b902decc-6153-4dbe-9d41-67939fcbd02e','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ComputeServiceChain-m7joik7pyldm-UpgradeTasks-qey436ff42rd','state changed','OS::Heat::Value',NULL,187),(436,'c65d7dfd-b98f-443c-a254-787163f895da','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ComputeServiceChain-m7joik7pyldm-IpaRegistrationTasks-a4lpls6ousa7','state changed','OS::Heat::Value',NULL,201),(437,'5b75a79b-076d-437e-89cc-90bab94df967','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ComputeServiceChain-m7joik7pyldm-HostPrepTasks-2mi2emrhat77','state changed','OS::Heat::Value',NULL,200),(438,'741743f6-81cd-416c-b32c-7ad7274ec8c2','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalUpgradeTasks-c6zoqsqdx23i','state changed','OS::Heat::Value',NULL,198),(439,'11734623-18c6-4d75-9000-f2b7e58cd482','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ComputeServiceChain-m7joik7pyldm-IpaRegistrationTasks-a4lpls6ousa7','state changed','OS::Heat::Value',NULL,201),(440,'ba87b010-b541-4842-a88d-7ee59e3b3559','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PreDeployStepTasks-wglorp5jftux','state changed','OS::Heat::Value',NULL,199),(441,'1a324678-b5c3-4848-b0c0-61b0b600a074','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ComputeServiceChain-m7joik7pyldm-DockerPuppetTasks-2cp3buskmyp4','state changed','OS::Heat::Value',NULL,202),(442,'927f53b7-4ea1-487a-883c-41d39dcd1c76','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PostUpdateTasks-k47gjqaw4vez','state changed','OS::Heat::Value',NULL,204),(443,'9ad72bff-5403-4e39-82b1-6bd23ac4f255','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ContainerPuppetTasks-efbyi4yptu3y','state changed','OS::Heat::Value',NULL,203),(444,'6c67552a-ae39-417b-9207-cf9d05275c18','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ComputeServiceChain-m7joik7pyldm-DockerPuppetTasks-2cp3buskmyp4','state changed','OS::Heat::Value',NULL,202),(445,'66b7e1f0-4ece-4d4f-aed3-e754cbe8ccb3','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PostUpdateTasks-k47gjqaw4vez','state changed','OS::Heat::Value',NULL,204),(446,'8f442c6e-3c81-48e4-bff9-75d910ecda81','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-t7pdutznvxt6','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(447,'d7662e02-53c6-4234-bfa1-252e594289e9','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ComputeServiceChain-m7joik7pyldm-PuppetStepConfig-tcbityxk4vjg','state changed','OS::Heat::Value',NULL,207),(448,'95b956a6-a3dc-4e6c-85e8-72b2814cab3e','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ContainerPuppetTasks-efbyi4yptu3y','state changed','OS::Heat::Value',NULL,203),(449,'b2d7aaaa-a1ac-46d1-b230-46a2e76e871d','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ScaleTasks-do3fc7rdtjpo','state changed','OS::Heat::Value',NULL,208),(450,'93073164-e1e0-4ac4-827b-847fdd48bd6f','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalDeployTasks-nmswzqsv2kna','state changed','OS::Heat::Value',NULL,209),(451,'672be03f-dd2c-4a57-be1b-9d2278a5639d','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ComputeServiceChain-m7joik7pyldm-KollaConfig-fgqwmttltynn','state changed','OS::Heat::Value',NULL,193),(452,'84f7f169-b492-491f-9eb6-fca22f36eec2','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ScaleTasks-do3fc7rdtjpo','state changed','OS::Heat::Value',NULL,208),(453,'c859e103-3605-4fdf-a6a9-085e725ed8ea','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ComputeServiceChain-m7joik7pyldm-UpgradeBatchTasks-rlnbbnazhrsv','state changed','OS::Heat::Value',NULL,206),(454,'4929be36-a57a-4d4c-a48b-21f94b82df44','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalUpdateTasks-65l53vclfvzd','state changed','OS::Heat::Value',NULL,205),(455,'426f84c3-0c3e-418f-a209-1f2921a430f6','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ComputeServiceChain-m7joik7pyldm-PuppetStepConfig-tcbityxk4vjg','state changed','OS::Heat::Value',NULL,207),(456,'4569c5e2-0c67-4b71-8355-0adc272a7128','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalDeployTasks-nmswzqsv2kna','state changed','OS::Heat::Value',NULL,209),(457,'0d1df6b3-6204-4440-a2f5-c160a122ccf7','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:14',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PostUpdateTasks-bz74tvwszyru','state changed','OS::Heat::Value',NULL,212),(458,'8b778114-48ff-48c3-a5d0-21b017a54257','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceNames-mahfpikbjnpq','state changed','OS::Heat::Value',NULL,213),(459,'4dc99b40-f773-4f96-b43a-7ed8491ed0ba','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PreDeployStepTasks-wglorp5jftux','state changed','OS::Heat::Value',NULL,199),(460,'695ccee0-951f-49b7-9bc9-ecc3d4b1ff03','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ComputeServiceChain-m7joik7pyldm-PostUpdateTasks-bz74tvwszyru','state changed','OS::Heat::Value',NULL,212),(461,'0a7b5519-bf2d-4096-af44-eb9b8cdbe4da','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceNames-mahfpikbjnpq','state changed','OS::Heat::Value',NULL,213),(462,'ee6c89b8-ead2-4c60-b4a2-f17a2d2b445c','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ComputeServiceChain-m7joik7pyldm-AnsibleGroupVars-kdga5i2gc4cg','state changed','OS::Heat::Value',NULL,210),(463,'33d6fd9f-5fe0-4905-9b82-3cc5ca9b3461','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ComputeServiceChain-m7joik7pyldm-DockerConfig-7tmf5u4cnzxi','state changed','OS::Heat::Value',NULL,214),(464,'49cbdb45-2a7f-41ff-996d-c80edc82df81','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ComputeServiceChain-m7joik7pyldm-UpgradeBatchTasks-rlnbbnazhrsv','state changed','OS::Heat::Value',NULL,206),(465,'693803b3-b18a-4900-925e-be5894737c75','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceChain-6n6n7npyr23b','state changed','OS::Heat::ResourceChain',NULL,215),(466,'b7c3fa42-5300-4b07-bed7-b64be7f13f3b','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ComputeServiceChain-m7joik7pyldm-ExternalUpdateTasks-65l53vclfvzd','state changed','OS::Heat::Value',NULL,205),(467,'b8cf5290-cb55-4e64-82e3-8ba9a3ec6744','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ComputeServiceChain-m7joik7pyldm-AnsibleGroupVars-kdga5i2gc4cg','state changed','OS::Heat::Value',NULL,210),(468,'fe91a383-408d-4a47-9cee-97bd4b5e0eb3','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-wjfsqm5rzut2','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(469,'9d1ea756-2a27-4ea4-8a75-2a6a6fce0b12','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-DeployStepsTasks-nn5ci6edbpfe','state changed','OS::Heat::Value',NULL,216),(470,'c5a2a755-ae2d-4715-bb64-03d057165a8f','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-PuppetConfig-qhmehikilxke','state changed','OS::Heat::Value',NULL,217),(471,'7f848aab-a0fb-480f-afa4-7d70bb9f1b9f','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ComputeServiceChain-m7joik7pyldm-DockerConfig-7tmf5u4cnzxi','state changed','OS::Heat::Value',NULL,214),(472,'758f6c06-67ea-4936-989e-afd4a5e82eda','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-PuppetConfig-qhmehikilxke','state changed','OS::Heat::Value',NULL,217),(473,'17d7f609-144d-4748-a3c1-3d535e47c788','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-MonitoringSubscriptionsConfig-ccw2kcki6ac3','state changed','OS::Heat::Value',NULL,218),(474,'a835e581-6bf3-4f2c-abb4-61c259d976da','e2e9bd77-2c68-4de7-8e33-ab452bea7e45','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceChain-6n6n7npyr23b','e2e9bd77-2c68-4de7-8e33-ab452bea7e45','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(475,'d9946f82-9678-4fda-b2ab-29977cab8c9b','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-DeployStepsTasks-nn5ci6edbpfe','state changed','OS::Heat::Value',NULL,216),(476,'261a068d-ecaa-4660-8ed5-d4f37e43cf89','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-MonitoringSubscriptionsConfig-ccw2kcki6ac3','state changed','OS::Heat::Value',NULL,218),(477,'b2399f4f-ba6e-4a0a-bde7-b8405d29ba7d','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-DockerPuppetTasks-ltmaqfehhude','state changed','OS::Heat::Value',NULL,219),(478,'4c74f3c0-a05d-41ef-bd4a-84ce15a3603f','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-IpaRegistrationTasks-kk7tmxg5jssw','state changed','OS::Heat::Value',NULL,220),(479,'ff7159c3-c4b8-4910-9a84-1704203621a8','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-IpaRegistrationTasks-kk7tmxg5jssw','state changed','OS::Heat::Value',NULL,220),(480,'2b35bf61-7841-47f8-b3ac-a86e2a538d9a','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-DockerPuppetTasks-ltmaqfehhude','state changed','OS::Heat::Value',NULL,219),(481,'179ea95a-0379-4e28-b934-e480b37013ad','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceChain-7mgfkmlgpvdw','state changed','OS::Heat::ResourceChain',NULL,221),(482,'b56194b8-d2a9-45b4-9657-bf912ac748f0','e2e9bd77-2c68-4de7-8e33-ab452bea7e45','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceChain-6n6n7npyr23b','e2e9bd77-2c68-4de7-8e33-ab452bea7e45','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(483,'ebb7de26-b95e-436c-bd56-9f2a934864c3','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceConfigSettings-qbagh5dlwfis','state changed','OS::Heat::Value',NULL,223),(484,'4f3bfc7c-6ec8-44f6-bdf2-823739896072','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ObjectStorageServiceChain','31ae7926-5e46-48be-a6e1-7eea0ad6b7c4','state changed','OS::TripleO::ObjectStorageServices',NULL,84),(485,'ac6ad42f-6aa6-48f7-8faf-a194d0e75a6a','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CephStorageServiceChain-uy6sem75csw2-ServiceConfigSettings-qbagh5dlwfis','state changed','OS::Heat::Value',NULL,223),(486,'53823646-7c67-4d22-833c-78858355c793','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-DockerConfig-pyc4yt2vtmt7','state changed','OS::Heat::Value',NULL,224),(487,'21463791-5d93-4307-8102-46013b30dc76','96e118a2-b0b0-4d93-a0bf-481461a00a27','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceChain-7mgfkmlgpvdw','96e118a2-b0b0-4d93-a0bf-481461a00a27','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(488,'fa233b8c-6f63-400d-9dba-9e5dbadb7811','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','NetworkerServiceChain','a118cedd-4095-46d9-ac6e-87cbd9fb2cc3','state changed','OS::TripleO::NetworkerServices',NULL,88),(489,'d55df1b4-5a40-4c8c-86f4-0d4a3fd57418','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PreDeployStepTasks-vlown2qojhrw','state changed','OS::Heat::Value',NULL,222),(490,'7bad96c6-5a37-427e-b6dd-65be5015d944','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CephStorageServiceChain-uy6sem75csw2-DockerConfig-pyc4yt2vtmt7','state changed','OS::Heat::Value',NULL,224),(491,'9571bfab-bc28-40a3-b849-05b38a44e3d1','96e118a2-b0b0-4d93-a0bf-481461a00a27','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceChain-7mgfkmlgpvdw','96e118a2-b0b0-4d93-a0bf-481461a00a27','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(492,'0adef605-3fa9-4e43-8f44-d1039c32da22','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-PreDeployStepTasks-vlown2qojhrw','state changed','OS::Heat::Value',NULL,222),(493,'5f12cb0b-c877-4e18-be20-b6569220c5f2','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ContainerPuppetTasks-2n2idqbkphxb','state changed','OS::Heat::Value',NULL,230),(494,'d2d7cff8-456b-455e-8752-e447162ed891','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','0','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-0-bgvn75dqkfvn','state changed','OS::TripleO::Services::BootParams',NULL,225),(495,'3c1213ef-f2f6-44a7-b7f4-ca4c66f9c04d','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ContainerPuppetTasks-2n2idqbkphxb','state changed','OS::Heat::Value',NULL,230),(496,'d4af9051-7058-40e3-ba4a-a4a37df312b8','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-uy6sem75csw2-KeystoneResourcesConfigs-vrfq4po4tst7','state changed','OS::Heat::Value',NULL,235),(497,'d94e9bd2-d57f-43c7-a1d2-822d1f7e8e14','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-uy6sem75csw2-KeystoneResourcesConfigs-vrfq4po4tst7','state changed','OS::Heat::Value',NULL,235),(498,'f7f382ea-5404-4997-a1f9-8e0a02b5ce77','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ServiceChain','96e118a2-b0b0-4d93-a0bf-481461a00a27','state changed','OS::Heat::ResourceChain',NULL,221),(499,'ee773eff-e1da-436e-acf0-ef4db43dd011','97584f96-0f43-4a42-8633-c6684dfba84e','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-0-bgvn75dqkfvn','97584f96-0f43-4a42-8633-c6684dfba84e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(500,'bf43fb7c-cb3c-43a7-a0ca-5dc93b24fc97','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalUpdateTasks-7lxnadz2vgnv','state changed','OS::Heat::Value',NULL,251),(501,'30121e3e-f32a-4efe-aefb-601914a70cf4','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CephStorageServiceChain-uy6sem75csw2-FirewallRules-4fcey773z3kg','state changed','OS::Heat::Value',NULL,259),(502,'745cdaff-bb9f-4311-838b-3fb49a30813e','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CephStorageServiceChain-uy6sem75csw2-FirewallRules-4fcey773z3kg','state changed','OS::Heat::Value',NULL,259),(503,'cbed1a4e-85f1-4365-84c2-77a9a4959844','97584f96-0f43-4a42-8633-c6684dfba84e','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-0-bgvn75dqkfvn-RoleParametersValue-gncjjwlvsw4d','state changed','OS::Heat::Value',NULL,265),(504,'49d6c155-d0ff-4991-8d52-18d1cbc5a4d7','97584f96-0f43-4a42-8633-c6684dfba84e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-0-bgvn75dqkfvn-RoleParametersValue-gncjjwlvsw4d','state changed','OS::Heat::Value',NULL,265),(505,'76d1f498-2211-4092-aaa4-a2886f31c4ca','97584f96-0f43-4a42-8633-c6684dfba84e','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-0-bgvn75dqkfvn','97584f96-0f43-4a42-8633-c6684dfba84e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(506,'82d38d3e-42a7-41d3-97ed-39ab966cfd46','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CephStorageServiceChain-uy6sem75csw2-ExternalUpdateTasks-7lxnadz2vgnv','state changed','OS::Heat::Value',NULL,251),(507,'90b7c437-ce7d-4530-a1a7-abec2b046790','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','0','97584f96-0f43-4a42-8633-c6684dfba84e','state changed','OS::TripleO::Services::BootParams',NULL,225),(508,'e9b57352-d383-42fd-9171-c93599ded697','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-KollaConfig-o6kdk4ovkbmt','state changed','OS::Heat::Value',NULL,271),(509,'79a12198-3013-4bb0-9bed-0baaca1fbbcf','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-jyv42aiisndf-KeystoneResourcesConfigs-kau7by4bdiwo','state changed','OS::Heat::Value',NULL,270),(510,'e043aafe-0864-461d-a5ba-a37cb4c3c867','892287d9-0491-440c-8c76-d0e67519bfc8','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-uy6sem75csw2','892287d9-0491-440c-8c76-d0e67519bfc8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(511,'d11c268c-7cc5-4971-838f-59440dd12a46','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-KollaConfig-o6kdk4ovkbmt','state changed','OS::Heat::Value',NULL,271),(512,'3984c61c-8c37-48c9-8317-d60e5af25786','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ServiceChain','93484ca9-c36e-4e65-9794-d90219b2ab6c','state changed','OS::Heat::ResourceChain',NULL,190),(513,'9bd60b22-7380-4def-897d-307f9f8d8bba','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-jhmbhoc2sris','state changed','OS::Heat::Value',NULL,272),(514,'815adbc4-0e49-4be0-9962-f14988a0bba7','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PostUpgradeTasks-pts2g67w7vyh','state changed','OS::Heat::Value',NULL,276),(515,'b48a10b4-019d-466b-9515-61cb57d24158','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-jyv42aiisndf-KeystoneResourcesConfigs-kau7by4bdiwo','state changed','OS::Heat::Value',NULL,270),(516,'a119e63a-1a0d-4f74-9f4a-4861678d29c1','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PostUpgradeTasks-pts2g67w7vyh','state changed','OS::Heat::Value',NULL,276),(517,'767f9c4e-64bd-4d0c-aa97-aad6de8018fe','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalPostDeployTasks-6usduzfx7zbb','state changed','OS::Heat::Value',NULL,278),(518,'2b52053e-4227-4e00-957c-595a172deca5','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-jhmbhoc2sris','state changed','OS::Heat::Value',NULL,272),(519,'3af2b981-bcb8-4b9e-82e0-14edb74be65a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalPostDeployTasks-6usduzfx7zbb','state changed','OS::Heat::Value',NULL,278),(520,'5bad9f4d-327b-46c6-a8d6-61939cf2828e','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PreDeployStepTasks-e4dtfwirlqpb','state changed','OS::Heat::Value',NULL,281),(521,'2b8b8d19-c6a3-4512-b325-b6686dbb739a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PreDeployStepTasks-e4dtfwirlqpb','state changed','OS::Heat::Value',NULL,281),(522,'50c7fc1d-32f7-4455-807b-2260c64af81a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:15',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-DockerConfig-vjlgftekkfkh','state changed','OS::Heat::Value',NULL,279),(523,'328eac79-28a8-48c3-a9b4-849b0ead1723','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalUpdateTasks-tfkh46kxh5ad','state changed','OS::Heat::Value',NULL,284),(524,'38d5c6d4-9a27-47c3-836c-aecc681e9c33','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceConfigSettings-jeilcilpxzrk','state changed','OS::Heat::Value',NULL,286),(525,'17f7d817-f4ea-47cb-83e1-499316d42cec','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceConfigSettings-jeilcilpxzrk','state changed','OS::Heat::Value',NULL,286),(526,'d9b69378-7349-4546-beba-65eb2c1e2217','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalUpgradeTasks-xejhuudntuou','state changed','OS::Heat::Value',NULL,287),(527,'02611f94-9278-4229-9f02-e51399d0c9ee','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalUpdateTasks-tfkh46kxh5ad','state changed','OS::Heat::Value',NULL,284),(528,'db54a6ba-65b3-472a-a406-03059852d508','1b50a534-e8d6-46fb-ae1f-25609640418e','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-m7joik7pyldm','1b50a534-e8d6-46fb-ae1f-25609640418e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(529,'6b7deaca-aba7-472c-b11d-a26d4a12c3cd','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PuppetStepConfig-lxq2yyyq5ji6','state changed','OS::Heat::Value',NULL,289),(530,'1d1689f7-418d-4ef3-b878-837d45f5c0f5','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalUpgradeTasks-xejhuudntuou','state changed','OS::Heat::Value',NULL,287),(531,'18f8acdb-d189-4209-ba48-2bd86875900f','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PuppetStepConfig-lxq2yyyq5ji6','state changed','OS::Heat::Value',NULL,289),(532,'77592b3a-869f-4b55-8ec8-e36ab619c427','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-qiit6hjhvac2','state changed','OS::Heat::Value',NULL,290),(533,'a3825279-d7d0-453a-852f-eb19b6c5df54','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ScaleTasks-bkd4jaanvoww','state changed','OS::Heat::Value',NULL,291),(534,'2a387c3a-0621-4a4e-a2d1-a7362d6f0a4b','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-DockerConfig-vjlgftekkfkh','state changed','OS::Heat::Value',NULL,279),(535,'c156586a-2c98-4bd8-9703-6ce9d55aa0db','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','4','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w','state changed','OS::TripleO::Services::Collectd',NULL,288),(536,'522f19be-256b-4286-8794-262bad560bb2','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-MonitoringSubscriptionsConfig-woqa6rfyfp53','state changed','OS::Heat::Value',NULL,293),(537,'f10273a2-3704-4be4-bb60-76e39e8a116a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-MonitoringSubscriptionsConfig-kx5dxyi7ksb7','state changed','OS::Heat::Value',NULL,292),(538,'ce664cf3-dc1d-4a9b-8dee-e5c44356aabe','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-FirewallFrontendRules-ysahamczthb6','state changed','OS::Heat::Value',NULL,296),(539,'f2e21e40-97be-4340-8811-624bf73b4d30','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ScaleTasks-bkd4jaanvoww','state changed','OS::Heat::Value',NULL,291),(540,'e86b7db6-e961-4994-90bb-c8ed54050f5e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-qiit6hjhvac2','state changed','OS::Heat::Value',NULL,290),(541,'637beca2-087a-4bea-bd99-11979665b5eb','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalUpdateTasks-jajuqpbboeql','state changed','OS::Heat::Value',NULL,298),(542,'84917eff-c808-4426-8a12-0f12d496a83a','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-KeystoneResourcesConfigs-kgcvjnjgcy74','state changed','OS::Heat::Value',NULL,299),(543,'6ea7eb9c-587e-47b4-918b-17cb751ff72d','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-FirewallFrontendRules-ysahamczthb6','state changed','OS::Heat::Value',NULL,296),(544,'ba5e67e5-fc93-43d9-b217-2e0304ba28b8','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-UpgradeTasks-77i4mq5ot5qo','state changed','OS::Heat::Value',NULL,294),(545,'ab9cb927-9b13-4f69-9a88-88450499c255','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-UpdateTasks-ugn43qa3sfgk','state changed','OS::Heat::Value',NULL,300),(546,'b5efe88c-2644-4063-a276-c38e2127954a','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-MonitoringSubscriptionsConfig-woqa6rfyfp53','state changed','OS::Heat::Value',NULL,293),(547,'c9f3750b-5491-47f0-ac9a-4afe8e780764','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-UpdateTasks-ugn43qa3sfgk','state changed','OS::Heat::Value',NULL,300),(548,'7dc20332-2a87-4428-bbcc-502e2eab4c44','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerServiceChain-jyv42aiisndf-GlobalConfigSettings-54kkp7vjgwcb','state changed','OS::Heat::Value',NULL,297),(549,'55181921-d1ce-45e4-8c8c-14a1906d84ed','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-KeystoneResourcesConfigs-kgcvjnjgcy74','state changed','OS::Heat::Value',NULL,299),(550,'10a0423c-10eb-4ceb-84ef-f6d521712834','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-MonitoringSubscriptionsConfig-kx5dxyi7ksb7','state changed','OS::Heat::Value',NULL,292),(551,'30b7cf54-8dc2-42fb-ab40-862dcd27fe69','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-HostPrepTasks-62hf63any2tb','state changed','OS::Heat::Value',NULL,304),(552,'0d9ba0a6-87e4-4229-b1de-b22b27ca94ca','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalUpgradeTasks-4cbwgxwvqack','state changed','OS::Heat::Value',NULL,303),(553,'9e952c6a-cd2b-4c33-ad56-08a8abea26cc','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','CephStorageServiceChain','892287d9-0491-440c-8c76-d0e67519bfc8','state changed','OS::TripleO::CephStorageServices',NULL,85),(554,'74655556-e875-4b82-8c49-df5348727c6e','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-UpgradeTasks-77i4mq5ot5qo','state changed','OS::Heat::Value',NULL,294),(555,'cbfcbef4-4646-4e81-af0f-dc02d55496b3','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalPostDeployTasks-twljpleulm6b','state changed','OS::Heat::Value',NULL,306),(556,'e421c639-f9e6-4bd9-960b-944d70ba5b0b','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ScaleTasks-hyfmck4gcnmf','state changed','OS::Heat::Value',NULL,307),(557,'0c5e6d11-6731-41de-825d-05b7d89873e5','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerServiceChain-jyv42aiisndf-GlobalConfigSettings-54kkp7vjgwcb','state changed','OS::Heat::Value',NULL,297),(558,'613434ac-6929-4c48-ad56-4af0191981e3','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-HostPrepTasks-62hf63any2tb','state changed','OS::Heat::Value',NULL,304),(559,'015543b8-8ed0-4b20-9169-7c4a021ab526','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalUpdateTasks-jajuqpbboeql','state changed','OS::Heat::Value',NULL,298),(560,'5b2da5c3-2e38-49dd-96c5-4eb9ff3802c9','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-KollaConfig-7535pdxyqka5','state changed','OS::Heat::Value',NULL,309),(561,'b8b5616e-f070-48f2-9be8-b231146fbd36','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalUpgradeTasks-4cbwgxwvqack','state changed','OS::Heat::Value',NULL,303),(562,'2c64dd8f-2676-4708-a4bf-b9c4836c0a26','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-HostFirewallTasks-jinrfmrz4sv6','state changed','OS::Heat::Value',NULL,310),(563,'ab35e644-c84b-4443-9e99-a8d31d1aae8f','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceChain','e2e9bd77-2c68-4de7-8e33-ab452bea7e45','state changed','OS::Heat::ResourceChain',NULL,215),(564,'a6b9d7bd-08c0-4242-8a2e-c0e2b866fe21','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerServiceChain-jyv42aiisndf-FirewallRules-nil2lvo4ewd2','state changed','OS::Heat::Value',NULL,311),(565,'a0b61a4a-651a-4995-9ce7-0a4d890183be','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-KollaConfig-7535pdxyqka5','state changed','OS::Heat::Value',NULL,309),(566,'202f630d-20bc-4a24-9a52-0e3038dcf6c0','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DockerConfigScripts-u6xzdfbxjtj4','state changed','OS::Heat::Value',NULL,315),(567,'a6b90655-64da-4c57-b06e-406e57138913','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalPostDeployTasks-twljpleulm6b','state changed','OS::Heat::Value',NULL,306),(568,'d4b1c8ab-d59f-4a29-8f31-23658bc671e3','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PuppetConfig-4stlgdbhlqku','state changed','OS::Heat::Value',NULL,314),(569,'c2addfad-1eee-4059-9c4b-c5935a9db7eb','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ScaleTasks-hyfmck4gcnmf','state changed','OS::Heat::Value',NULL,307),(570,'0250305b-f86d-4bea-8271-8ff05e05b8b6','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-IpaRegistrationTasks-6oi2pvxaailw','state changed','OS::Heat::Value',NULL,312),(571,'712bcbbc-7bc1-45ef-a391-6cb5f89cbaed','0754b6e3-97af-4875-b088-19fcab688ed3','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w','0754b6e3-97af-4875-b088-19fcab688ed3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(572,'9b3ebcc9-c04e-4a3f-9c5a-e4406a496ea6','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-HostFirewallTasks-2t4uu5io6x5q','state changed','OS::Heat::Value',NULL,317),(573,'92549766-edc5-4c90-902e-fe3764f7967f','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerServiceChain-jyv42aiisndf-FirewallFrontendRules-hjtk6c6hgthu','state changed','OS::Heat::Value',NULL,320),(574,'8a13dc13-2f00-456e-8ede-7a3c0b1be14a','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PreUpgradeRollingTasks-ntlqpygkg2mn','state changed','OS::Heat::Value',NULL,319),(575,'2c758108-c344-4ddd-900d-ad744b32c532','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerServiceChain-jyv42aiisndf-FirewallRules-nil2lvo4ewd2','state changed','OS::Heat::Value',NULL,311),(576,'30ae0ac6-73c7-4fa1-8de1-7d843101cfff','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PuppetConfig-4stlgdbhlqku','state changed','OS::Heat::Value',NULL,314),(577,'3428fedf-7f4d-4dd8-b717-26dff878a979','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ContainerPuppetTasks-52436emhcovc','state changed','OS::Heat::Value',NULL,323),(578,'e675546d-e8e8-44d1-a6f6-d05ad6f0910f','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ContainerPuppetTasks-6xlhgyiw2cwk','state changed','OS::Heat::Value',NULL,324),(579,'fd9371a2-14cf-4b46-b0f0-17acf2db93a3','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerServiceChain-jyv42aiisndf-FirewallFrontendRules-hjtk6c6hgthu','state changed','OS::Heat::Value',NULL,320),(580,'34a8d5a4-cf88-4193-aa26-2135cc02dad3','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ContainerPuppetTasks-52436emhcovc','state changed','OS::Heat::Value',NULL,323),(581,'971d84f2-9537-4436-afd5-c2e4dcc0b3ed','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PreUpgradeRollingTasks-ntlqpygkg2mn','state changed','OS::Heat::Value',NULL,319),(582,'ac5aa22f-fe53-4781-b1fd-ee79a734e956','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DockerConfigScripts-u6xzdfbxjtj4','state changed','OS::Heat::Value',NULL,315),(583,'ac7bbbba-7ed7-41c5-938d-86bef3c92382','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-HostFirewallTasks-jinrfmrz4sv6','state changed','OS::Heat::Value',NULL,310),(584,'b635e459-86e9-43c7-83a9-5bf50a058c3b','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-UpgradeBatchTasks-olhvjseol572','state changed','OS::Heat::Value',NULL,322),(585,'fddfeae6-cca1-4996-9cd5-6a5fb1e057a9','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-FirewallRules-qpr3vo44mvoz','state changed','OS::Heat::Value',NULL,336),(586,'87fa2d87-b543-4087-9a88-8210607e08dd','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-IpaRegistrationTasks-6oi2pvxaailw','state changed','OS::Heat::Value',NULL,312),(587,'61fe7393-b3db-4b99-b922-d6f7866c290c','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ContainerPuppetTasks-6xlhgyiw2cwk','state changed','OS::Heat::Value',NULL,324),(588,'bdf33b24-dc65-43f2-a3f0-5d8ff2d2bc3b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ObjectStorage','overcloud-ObjectStorage-vocupf72jybb','state changed','OS::Heat::ResourceGroup',NULL,332),(589,'9a50bac1-5a5d-4b57-9040-b5bbbf5dd575','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-UpgradeTasks-abdwnwzqwwhe','state changed','OS::Heat::Value',NULL,335),(590,'1f42e787-9650-4f29-9f63-fe41e296755d','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','2','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea','state changed','OS::TripleO::Services::CephClient',NULL,334),(591,'297e7846-d5d0-474c-9898-8ba5bd2ac547','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ComputeServiceChain','1b50a534-e8d6-46fb-ae1f-25609640418e','state changed','OS::TripleO::ComputeServices',NULL,90),(592,'9af9e036-6719-4e3e-a88c-e71760b0bc68','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-FirewallRules-qpr3vo44mvoz','state changed','OS::Heat::Value',NULL,336),(593,'ec370717-3501-4ae0-b4dd-8df05f0579c7','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PostUpgradeTasks-3wmald64zo3v','state changed','OS::Heat::Value',NULL,342),(594,'b9ed1d29-6980-4fd9-9d0b-efe3d5cbf2be','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceNames-sdv6v4r3xnby','state changed','OS::Heat::Value',NULL,344),(595,'c0d9e61f-980c-471f-be1e-11b0d13bb4e1','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceConfigSettings-mzt2iadr5o46','state changed','OS::Heat::Value',NULL,340),(596,'4da1a85c-d64e-4042-81ab-124f99212e26','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-UpgradeTasks-abdwnwzqwwhe','state changed','OS::Heat::Value',NULL,335),(597,'cb4b388d-087a-4564-bb42-95f1f70c4229','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PostUpgradeTasks-3wmald64zo3v','state changed','OS::Heat::Value',NULL,342),(598,'7419f06e-af0a-4f7e-8d48-6568655d68b9','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-HostFirewallTasks-2t4uu5io6x5q','state changed','OS::Heat::Value',NULL,317),(599,'f7dcc939-2b32-495d-bc08-e27626008d6b','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-IpaRegistrationTasks-avoo6dljzgue','state changed','OS::Heat::Value',NULL,351),(600,'8b6d481a-2b74-4942-8bff-0e62028d5974','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-PuppetStepConfig-a5x23vyzmoaw','state changed','OS::Heat::Value',NULL,349),(601,'12f192e7-1a7d-49a2-adad-7efeff4f8156','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-IpaRegistrationTasks-avoo6dljzgue','state changed','OS::Heat::Value',NULL,351),(602,'230041bb-1860-49fd-9879-3d2437b01e6a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceServerMetadataHook-rm6jth45qdts','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,NULL),(603,'6cc1e4c6-c207-470a-b0a2-1d4f1617b9bf','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-DeployStepsTasks-jhew5hxbueh5','state changed','OS::Heat::Value',NULL,353),(604,'a52a0496-7679-4fde-aef1-958cce223d9b','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceNames-sdv6v4r3xnby','state changed','OS::Heat::Value',NULL,344),(605,'6273dd3a-ed32-4522-954b-d6bc6e203ee1','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceConfigSettings-mzt2iadr5o46','state changed','OS::Heat::Value',NULL,340),(606,'a23b0dc6-fbe7-481e-b803-504bc011e522','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-UpgradeBatchTasks-olhvjseol572','state changed','OS::Heat::Value',NULL,322),(607,'ab3da118-9163-4be9-a017-663901f2e279','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-FirewallFrontendRules-flr2kepua3ch','state changed','OS::Heat::Value',NULL,346),(608,'ef2e3326-c4a4-42a2-a3eb-b93b5a38da0a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceNames-k3rtcj3zikom','state changed','OS::Heat::Value',NULL,358),(609,'1544970a-2003-46e9-bd1b-b0e0dc5e802b','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PostUpdateTasks-3ciysvvqfzk3','state changed','OS::Heat::Value',NULL,357),(610,'dabd3539-2989-402a-8b50-8791acc32690','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-PuppetStepConfig-a5x23vyzmoaw','state changed','OS::Heat::Value',NULL,349),(611,'d974231c-48c4-449b-888e-692076575781','15fd7abd-deef-46fe-812d-8fb602e61c75','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea','15fd7abd-deef-46fe-812d-8fb602e61c75','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(612,'6394c29a-389a-493b-b8f9-dc5864fd4191','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerServiceChain-jyv42aiisndf-ServiceNames-k3rtcj3zikom','state changed','OS::Heat::Value',NULL,358),(613,'e5351e06-b7db-4479-8941-8741e119c9f7','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-DeployStepsTasks-jhew5hxbueh5','state changed','OS::Heat::Value',NULL,353),(614,'d3ded9b5-9ebe-4346-b868-54d154c1fa5f','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PreDeployStepTasks-dbddd6pqcsrg','state changed','OS::Heat::Value',NULL,365),(615,'b38e48d2-8956-426a-b13d-27e83b030200','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DockerPuppetTasks-lfz7sqhbshmq','state changed','OS::Heat::Value',NULL,366),(616,'1fe8dcee-9e1e-4271-ba7b-5225b4f0c331','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DeployStepsTasks-5ljmcn7lfuj7','state changed','OS::Heat::Value',NULL,362),(617,'1d0c4a8e-2a72-4c5c-b531-88e65bdc55e6','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerServiceChain-jyv42aiisndf-DockerConfigScripts-tojdzrfgplqg','state changed','OS::Heat::Value',NULL,359),(618,'916a06bb-9a52-4f24-b92a-103eaabbdb27','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceServerMetadataHook-xayvie5gnfi5','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,NULL),(619,'fde13358-e6ae-49fc-b745-af6cb0525cd7','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PostUpdateTasks-3ciysvvqfzk3','state changed','OS::Heat::Value',NULL,357),(620,'d8528c87-890a-4de1-8045-84f34b9de651','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalDeployTasks-u7vyatoz4nzr','state changed','OS::Heat::Value',NULL,370),(621,'2c6e6c73-3025-4f11-aba7-2bad5f892efb','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-FirewallFrontendRules-flr2kepua3ch','state changed','OS::Heat::Value',NULL,346),(622,'edabe403-91ed-4cec-a8c7-4a2ecb735630','54128122-491c-4791-bb6e-aefc6146fc37','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorage-vocupf72jybb','54128122-491c-4791-bb6e-aefc6146fc37','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(623,'b64b7bcb-18c2-40f2-9509-8bdc5c2fc23b','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PreDeployStepTasks-u4pmainyb25y','state changed','OS::Heat::Value',NULL,372),(624,'21d19a26-4aa6-4eaf-ad6e-2efc7f90e6a8','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c0206fa0-ee2b-4398-9bed-67491a782da8','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,NULL),(625,'bc76e625-1d05-444f-ba08-7d50e1838a49','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-FirewallRules-kh6idhko5xky','state changed','OS::Heat::Value',NULL,375),(626,'fb3820a1-b956-42e8-8aea-60149feb3383','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DockerPuppetTasks-lfz7sqhbshmq','state changed','OS::Heat::Value',NULL,366),(627,'e3694447-2399-4754-94db-1379b6278120','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DeployStepsTasks-5ljmcn7lfuj7','state changed','OS::Heat::Value',NULL,362),(628,'871796fc-4074-4735-85ad-f5893edc1026','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DockerConfig-ajh5izl4qan7','state changed','OS::Heat::Value',NULL,376),(629,'32246a54-1ea4-4cb0-9337-aa2ad24a75d4','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerServiceChain-jyv42aiisndf-DockerConfigScripts-tojdzrfgplqg','state changed','OS::Heat::Value',NULL,359),(630,'c2b9cfef-4961-4cb1-b061-b7aa1806bb36','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PreDeployStepTasks-dbddd6pqcsrg','state changed','OS::Heat::Value',NULL,365),(631,'38a2ccda-72e5-46d6-a46c-08ff9b8f966d','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-DockerPuppetTasks-ld7godiwo67l','state changed','OS::Heat::Value',NULL,378),(632,'a947f006-53ab-4fef-91af-6a7b7befb3a2','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalUpgradeTasks-yvuyxl2s2spu','state changed','OS::Heat::Value',NULL,380),(633,'c1758107-3f21-407b-b345-06bf0082bb51','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-AnsibleGroupVars-lf5gjckbeij6','state changed','OS::Heat::Value',NULL,382),(634,'e8db9308-cef9-4c56-bbc5-40d6f2c0aa95','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PostUpdateTasks-d57arzppjcyp','state changed','OS::Heat::Value',NULL,379),(635,'8cc8da03-87bb-4ad0-94d5-c9c8de33a442','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-ExternalDeployTasks-u7vyatoz4nzr','state changed','OS::Heat::Value',NULL,370),(636,'33a09d53-b461-4c04-b8e6-c570d2ab4928','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerServiceChain-jyv42aiisndf-AnsibleGroupVars-qky63mlsddke','state changed','OS::Heat::Value',NULL,386),(637,'809eafed-7e56-4449-9dc3-0346b6019510','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-MonitoringSubscriptionsConfig-c75ctfpoufvc','state changed','OS::Heat::Value',NULL,383),(638,'223e04d2-399d-46cb-8439-48d56169a17e','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-FirewallRules-kh6idhko5xky','state changed','OS::Heat::Value',NULL,375),(639,'d942ae60-d2d8-4d3a-9243-51213a0e2437','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','52c6e493-dbaa-4076-9704-b26dc368c8e1','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,NULL),(640,'4e2b5cd0-208b-4cc4-9cd8-8581913ae6cb','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-HostFirewallTasks-nzq2pliq6swz','state changed','OS::Heat::Value',NULL,389),(641,'49416190-ace8-4b80-bc90-1f681cad10a4','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-PostUpdateTasks-d57arzppjcyp','state changed','OS::Heat::Value',NULL,379),(642,'cf1da341-b767-4d6e-af9b-7d1f280cf13f','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-AnsibleGroupVars-lf5gjckbeij6','state changed','OS::Heat::Value',NULL,382),(643,'1b2cdcf6-4d6f-4578-9502-86ace56ad2f1','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalDeployTasks-36ofvtimcxmr','state changed','OS::Heat::Value',NULL,391),(644,'45cbecf5-6544-4877-8f64-9be80802d71a','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-DockerConfig-ajh5izl4qan7','state changed','OS::Heat::Value',NULL,376),(645,'00ab8038-e08c-4342-b48f-121aac84a965','54128122-491c-4791-bb6e-aefc6146fc37','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','overcloud-ObjectStorage-vocupf72jybb','54128122-491c-4791-bb6e-aefc6146fc37','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(646,'7bb0a23c-239b-4e11-b9c0-d4e0bc22e16a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PostUpdateTasks-uzyv3q72p3al','state changed','OS::Heat::Value',NULL,393),(647,'54b30a51-9d02-4b00-ae0f-56e972adb6fd','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerServiceChain-jyv42aiisndf-AnsibleGroupVars-qky63mlsddke','state changed','OS::Heat::Value',NULL,386),(648,'031062ef-1c79-491b-824c-c2091fcffeeb','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalUpgradeTasks-yvuyxl2s2spu','state changed','OS::Heat::Value',NULL,380),(649,'038e6f17-044b-41e0-a34b-c79cb5fd1781','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PreDeployStepTasks-u4pmainyb25y','state changed','OS::Heat::Value',NULL,372),(650,'f3d56d18-3a03-43dd-9482-fd79b307f2a3','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-IpaRegistrationTasks-2a3c5mxw3put','state changed','OS::Heat::Value',NULL,395),(651,'b3b02cca-70dd-4aa0-b2c0-5c05ff6698bb','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceServerMetadataHook-fzw6uoif2m6n','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,NULL),(652,'a257ea31-f0c5-4227-82e3-563d55b1e0d7','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PostUpgradeTasks-ayrvy6bxfocg','state changed','OS::Heat::Value',NULL,396),(653,'183448a5-9d4d-4b97-b4a9-8126c6e196f0','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-HostFirewallTasks-nzq2pliq6swz','state changed','OS::Heat::Value',NULL,389),(654,'668bee5f-654a-468e-a323-f3225124264c','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PostUpdateTasks-uzyv3q72p3al','state changed','OS::Heat::Value',NULL,393),(655,'cbf72d0f-205a-4dc3-9184-d358de3aeee7','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-DockerPuppetTasks-ld7godiwo67l','state changed','OS::Heat::Value',NULL,378),(656,'62ea595c-ab4e-4c1f-866b-14098aa03b2a','0754b6e3-97af-4875-b088-19fcab688ed3','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w-RoleParametersValue-fru5cvvt6o4d','state changed','OS::Heat::Value',NULL,401),(657,'55c7f6d7-5efc-49cf-9f77-9ee6dbf68532','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-GlobalConfigSettings-xsucbcw4sd46','state changed','OS::Heat::Value',NULL,403),(658,'19bf2700-08d6-47af-9a4d-37176d52b6a6','15fd7abd-deef-46fe-812d-8fb602e61c75','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','CephBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,400),(659,'2d1a7660-8f75-455e-b6ef-2fbe457451bc','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-IpaRegistrationTasks-2a3c5mxw3put','state changed','OS::Heat::Value',NULL,395),(660,'c8fc5480-956d-4f6c-a01b-7c8df4b6256f','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceNames-4jkzaw4gvilz','state changed','OS::Heat::Value',NULL,392),(661,'551de642-1db0-4b1a-88de-b3f2299afb21','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ExternalDeployTasks-36ofvtimcxmr','state changed','OS::Heat::Value',NULL,391),(662,'e0efc756-63d5-4308-bb25-a7b4acc03500','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-GlobalConfigSettings-xsucbcw4sd46','state changed','OS::Heat::Value',NULL,403),(663,'ac9ff468-6032-48e6-aa40-f08d24c80904','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','fcba6af8-1b14-465b-8147-68edb844b7e0','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,NULL),(664,'e7d07620-57a8-4fb4-8bb5-cf51bf50e3dd','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PostUpgradeTasks-ayrvy6bxfocg','state changed','OS::Heat::Value',NULL,396),(665,'f0b35173-1ad5-4a63-9a81-3b92b80a670d','0754b6e3-97af-4875-b088-19fcab688ed3','2026-06-13 07:50:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w-RoleParametersValue-fru5cvvt6o4d','state changed','OS::Heat::Value',NULL,401),(666,'17cf2d3e-8c01-45ad-b951-d4f4f4151d9a','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-UpgradeBatchTasks-aukt2tja5f3q','state changed','OS::Heat::Value',NULL,410),(667,'57600019-f737-44f5-9bd0-306cc20e0127','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-MonitoringSubscriptionsConfig-c75ctfpoufvc','state changed','OS::Heat::Value',NULL,383),(668,'6e5f9bcd-7030-4cf2-8e76-e835ca130f92','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DockerConfig-45grq5sieyci','state changed','OS::Heat::Value',NULL,409),(669,'f2f5745d-e1b7-47a3-8aae-9a69fd3bef0d','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PuppetStepConfig-myixbsxjukuy','state changed','OS::Heat::Value',NULL,414),(670,'2cc0aca2-c4c1-401d-a455-25a7e5f58185','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PuppetConfig-76rhqlhajqyk','state changed','OS::Heat::Value',NULL,405),(671,'c7814db5-a1a4-408e-859a-5aaf76648df5','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceConfigSettings-6wauytja5b24','state changed','OS::Heat::Value',NULL,420),(672,'79d07887-d630-4d16-bed3-df5e18de74c6','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PuppetStepConfig-myixbsxjukuy','state changed','OS::Heat::Value',NULL,414),(673,'0ea04396-2bc7-400c-a915-fa4327dabd61','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-GlobalConfigSettings-gqm6vogdqjz7','state changed','OS::Heat::Value',NULL,412),(674,'f50310ce-7628-41ce-8f73-dd44fe89bdf4','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DockerConfig-45grq5sieyci','state changed','OS::Heat::Value',NULL,409),(675,'8d4be531-b336-472d-beb8-5aab87cc30be','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-ServiceNames-4jkzaw4gvilz','state changed','OS::Heat::Value',NULL,392),(676,'255f0e88-4265-439f-9cf3-4ce67933c563','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-UpgradeBatchTasks-aukt2tja5f3q','state changed','OS::Heat::Value',NULL,410),(677,'3bfe8afe-a5e7-463d-84c7-2913a494b07a','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ServiceConfigSettings-6wauytja5b24','state changed','OS::Heat::Value',NULL,420),(678,'b3a679cc-da20-41a8-a6f2-cb4dce0c23f1','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalDeployTasks-ni2cbtw47jjy','state changed','OS::Heat::Value',NULL,417),(679,'21556552-4d92-43a5-8edd-a56b8b4c4480','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-HostPrepTasks-3jhfpkf2xxye','state changed','OS::Heat::Value',NULL,426),(680,'81cd0aea-28a5-407a-b44b-b5dec142f87f','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PuppetConfig-76rhqlhajqyk','state changed','OS::Heat::Value',NULL,405),(681,'830524af-f597-4d93-acc5-943f3aed60a4','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DockerPuppetTasks-3sndmbbd4tfz','state changed','OS::Heat::Value',NULL,424),(682,'8b5e1d26-966e-4ad8-ad65-96c3c53569e4','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v','72bc937a-7885-4887-9e56-f6ccb11e6372','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(683,'9e16e010-870f-4de2-8fa5-0826b183dac2','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-HostPrepTasks-3jhfpkf2xxye','state changed','OS::Heat::Value',NULL,426),(684,'56b223ce-7126-41c4-bc41-ad8cff6e8905','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-PuppetConfig-ijaz5j2grlis','state changed','OS::Heat::Value',NULL,423),(685,'2252aacf-f7f5-4ab3-b5d9-1ff3750a2271','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PreUpgradeRollingTasks-f7ry33bd5d4m','state changed','OS::Heat::Value',NULL,427),(686,'19e9898c-c9ee-4608-b02c-fc06828098c3','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5-GlobalConfigSettings-gqm6vogdqjz7','state changed','OS::Heat::Value',NULL,412),(687,'31ce16ab-8f13-4224-872c-869ddf3341a8','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DockerPuppetTasks-3sndmbbd4tfz','state changed','OS::Heat::Value',NULL,424),(688,'5955c61f-6145-476b-adf3-7d18713529ee','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalUpdateTasks-oiy3w4elmpns','state changed','OS::Heat::Value',NULL,429),(689,'9b9b5a4c-c4b8-407f-ae5d-abdd83448630','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalDeployTasks-ni2cbtw47jjy','state changed','OS::Heat::Value',NULL,417),(690,'2f2fa99a-8681-4db6-86bd-c76e06332f34','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalUpdateTasks-oiy3w4elmpns','state changed','OS::Heat::Value',NULL,429),(691,'099803ec-1474-42bb-a98d-c75d00484021','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-v4idsatqnmvg','state changed','OS::Heat::Value',NULL,430),(692,'e7687067-85f7-4a92-a4dc-f4196ed8150d','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-PreUpgradeRollingTasks-f7ry33bd5d4m','state changed','OS::Heat::Value',NULL,427),(693,'bfed0f56-14fb-4e5a-84e3-0dbb408d3def','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-UpgradeBatchTasks-j56y6lxvvfbl','state changed','OS::Heat::Value',NULL,431),(694,'d2fb8a48-4327-42fd-9e90-dc140bb4c449','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-KollaConfig-udbmahvfrzal','state changed','OS::Heat::Value',NULL,436),(695,'6de7807e-e7e7-4ffc-b5c2-71e34d54d3d0','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PreUpgradeRollingTasks-xpn3qow7ixuj','state changed','OS::Heat::Value',NULL,435),(696,'52e658e4-e383-411a-9be7-13dc1da2a6dd','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerServiceChain-jyv42aiisndf-PuppetConfig-ijaz5j2grlis','state changed','OS::Heat::Value',NULL,423),(697,'4cf870c7-4015-421b-8a91-f46edfd6a7f4','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-UpdateTasks-7btndrxqhtoy','state changed','OS::Heat::Value',NULL,437),(698,'3ac235d6-ef6d-43f6-a209-a35a20d1c4ad','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DeployStepsTasks-5luooc7jk3xi','state changed','OS::Heat::Value',NULL,439),(699,'d89c3287-e6b2-487a-84b2-c5e4bd0da2ef','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-KollaConfig-udbmahvfrzal','state changed','OS::Heat::Value',NULL,436),(700,'ba6321b4-888b-4d60-b53a-782029a0ab80','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DeployStepsTasks-5luooc7jk3xi','state changed','OS::Heat::Value',NULL,439),(701,'b6bad7ad-e827-489e-939d-aef6a0e7edcf','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ScaleTasks-rnwf75is7ar7','state changed','OS::Heat::Value',NULL,441),(702,'395122dd-3374-4821-9b1a-84f0f6519c87','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-UpgradeBatchTasks-j56y6lxvvfbl','state changed','OS::Heat::Value',NULL,431),(703,'2209b286-5c96-4025-a300-27596ea88854','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ScaleTasks-rnwf75is7ar7','state changed','OS::Heat::Value',NULL,441),(704,'a8ddcc94-2a59-4097-9edc-b6f5d6dc584a','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DockerConfigScripts-46qcprsldu6q','state changed','OS::Heat::Value',NULL,444),(705,'a7847f06-01b0-4c37-86bc-7ffacf6440fd','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-UpdateTasks-7btndrxqhtoy','state changed','OS::Heat::Value',NULL,437),(706,'ce5617da-d3ed-44c4-a4d3-d041e0430df0','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-vnuyn5qjjhq5','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(707,'44c6ed01-e4ce-4ddf-af11-336d5f5f5a0e','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ContainerPuppetTasks-ejn76gzhulgq','state changed','OS::Heat::Value',NULL,443),(708,'52c219d1-c195-41f7-82d8-b98c11b3ad3c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-v4idsatqnmvg','state changed','OS::Heat::Value',NULL,430),(709,'d50f579e-c764-4834-9b39-1b572baca109','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-DockerConfigScripts-46qcprsldu6q','state changed','OS::Heat::Value',NULL,444),(710,'e2f52647-53f8-464a-afa6-992e16c46d37','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-HostPrepTasks-gwgj5cfu7xpv','state changed','OS::Heat::Value',NULL,448),(711,'2fed15d9-18ad-42fc-80d7-1faff2b02674','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-ynygkt6dkkor','state changed','OS::Heat::Value',NULL,445),(712,'c20daf27-5316-4c2f-8d00-7d9159dc8ef0','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-HostPrepTasks-gwgj5cfu7xpv','state changed','OS::Heat::Value',NULL,448),(713,'1e92c522-cb89-499e-bd00-0589075aee1b','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-AnsibleGroupVars-ye2tngxlrwkk','state changed','OS::Heat::Value',NULL,453),(714,'e82e3303-51af-4405-83c3-8f8a2bb8042a','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-UpgradeTasks-lfma4zi24y2f','state changed','OS::Heat::Value',NULL,449),(715,'68585ff4-1288-4cbd-8fb2-4954b17aa30d','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-jyv42aiisndf-PreUpgradeRollingTasks-xpn3qow7ixuj','state changed','OS::Heat::Value',NULL,435),(716,'b8cd4b09-9b77-45f1-bcde-24d0bcdbdb7e','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-UpdateTasks-dphq4xpiurrg','state changed','OS::Heat::Value',NULL,455),(717,'6f72f958-e075-4181-9206-2e73ffe2b5f7','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-AnsibleGroupVars-ye2tngxlrwkk','state changed','OS::Heat::Value',NULL,453),(718,'b5d9947e-ce6a-487c-bae0-ea9518185f99','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ContainerPuppetTasks-ejn76gzhulgq','state changed','OS::Heat::Value',NULL,443),(719,'0bd9ace4-2489-41f2-ba0d-456362d6fe69','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalPostDeployTasks-hfdrjfte44sb','state changed','OS::Heat::Value',NULL,451),(720,'38337011-f747-42b5-9da7-0a6797853a65','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-UpdateTasks-dphq4xpiurrg','state changed','OS::Heat::Value',NULL,455),(721,'87c478f5-4d64-4694-bbc5-f4dc3514797b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-ynygkt6dkkor','state changed','OS::Heat::Value',NULL,445),(722,'36fccf7c-7cb2-4b19-a1f7-7e27d3361af7','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ContainerImageUrlParts','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v-ContainerImageUrlParts-2mijs4qudpod','state changed','OS::Heat::Value',NULL,457),(723,'441f9f4c-239f-45bc-8833-628649363885','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-ExternalPostDeployTasks-hfdrjfte44sb','state changed','OS::Heat::Value',NULL,451),(724,'051d234b-1975-48a8-9dc6-8e1d181f83d5','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ContainerImageUrlParts','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v-ContainerImageUrlParts-2mijs4qudpod','state changed','OS::Heat::Value',NULL,457),(725,'2f347784-b445-410b-afe4-ce2d2c302d2c','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-KeystoneResourcesConfigs-gakijsw6l65x','state changed','OS::Heat::Value',NULL,456),(726,'fa7f9627-d7e9-43d3-9e9f-06a924c955f1','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-UpgradeTasks-lfma4zi24y2f','state changed','OS::Heat::Value',NULL,449),(727,'0a119a35-752d-4e2e-a05b-e0ad287f588f','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','1','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-1-pmkfpda3lvv7','state changed','OS::TripleO::Services::CACerts',NULL,463),(728,'13e6fffb-dc20-4e27-9e60-91005a1a23ab','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','CephAdmVars','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v-CephAdmVars-xwyms3bhnwud','state changed','OS::Heat::Value',NULL,468),(729,'93ea46c1-5d78-477e-8b78-2fc7aa8ca5d2','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','CephAdmVars','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v-CephAdmVars-xwyms3bhnwud','state changed','OS::Heat::Value',NULL,468),(730,'aa7c71ef-5e9c-4c0f-9f35-b6ec7dce9668','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2-KeystoneResourcesConfigs-gakijsw6l65x','state changed','OS::Heat::Value',NULL,456),(731,'9141c297-a738-4d0d-9fa2-9fdcf4e19cfb','814bc91b-b000-483d-89f3-8fb82be740fe','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-jyv42aiisndf','814bc91b-b000-483d-89f3-8fb82be740fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(732,'9da98338-6422-4990-89d2-10d97eb7e345','659ecdde-f722-4014-9aee-e116435e07bf','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-yj6oxnp4s5k2','659ecdde-f722-4014-9aee-e116435e07bf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(733,'4ae0d024-451f-45d7-ba39-56f4f4be15b2','a5355cab-eb3e-461a-84ea-539ab787c885','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-1-pmkfpda3lvv7','a5355cab-eb3e-461a-84ea-539ab787c885','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(734,'f306f94f-2f9b-47de-af83-cfb8d61ba341','a5355cab-eb3e-461a-84ea-539ab787c885','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-1-pmkfpda3lvv7','a5355cab-eb3e-461a-84ea-539ab787c885','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(735,'fdd6c21d-68c5-458f-8651-0ed74a0b8dc3','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-xdau4rhbxe6a','state changed','OS::Heat::Value',NULL,479),(736,'8d33df1c-3f67-4a04-8fa2-da1ed2c63f66','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-xdau4rhbxe6a','state changed','OS::Heat::Value',NULL,479),(737,'b9abc898-dbf4-4264-91a1-1aa3fc7c6963','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNames','overcloud-CephStorageServiceNames-qid4hfghjqxi','state changed','OS::Heat::Value',NULL,480),(738,'76fb931a-a84d-4634-b69a-38bbc5d15dff','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNames','overcloud-NetworkerServiceNames-azf5iaebrfvc','state changed','OS::Heat::Value',NULL,481),(739,'a1285d74-a81a-44ef-9f28-1ad090229153','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ObjectStorage','54128122-491c-4791-bb6e-aefc6146fc37','state changed','OS::Heat::ResourceGroup',NULL,332),(740,'be7a51ca-ff32-4315-aeb4-3388815e73f3','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','CephStorageServiceNames','overcloud-CephStorageServiceNames-qid4hfghjqxi','state changed','OS::Heat::Value',NULL,480),(741,'22b71030-be6a-4b84-9725-f693a6a7605b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','NetworkerServiceNames','overcloud-NetworkerServiceNames-azf5iaebrfvc','state changed','OS::Heat::Value',NULL,481),(742,'c3ff44e3-2f4a-4345-a87d-b94bd719196e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ComputeServiceNames','overcloud-ComputeServiceNames-ohzyeetv564p','state changed','OS::Heat::Value',NULL,483),(743,'b3f39c93-6f52-4855-ab34-0505c380d77e','0754b6e3-97af-4875-b088-19fcab688ed3','2026-06-13 07:50:17',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w-ContainersCommon-kegah5bjavg6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(744,'c1478e56-296b-4d80-b3fd-30f9cb295b5a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:17',NULL,'CREATE','COMPLETE','ComputeServiceNames','overcloud-ComputeServiceNames-ohzyeetv564p','state changed','OS::Heat::Value',NULL,483),(745,'d79d563d-a634-478e-9215-042516597617','1c289367-c68c-45a8-a426-9ab94659a0ca','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w-ContainersCommon-kegah5bjavg6','1c289367-c68c-45a8-a426-9ab94659a0ca','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(746,'3172886e-ad58-4a37-865a-581447bc055c','1c289367-c68c-45a8-a426-9ab94659a0ca','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w-ContainersCommon-kegah5bjavg6','1c289367-c68c-45a8-a426-9ab94659a0ca','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(747,'dede7bed-b59a-4f79-b7b8-0b54a0510e96','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','Networker','overcloud-Networker-lv3m33foitn3','state changed','OS::Heat::ResourceGroup',NULL,484),(748,'a004af11-bbc0-4e8f-8972-711bd9e05785','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','CephStorage','overcloud-CephStorage-ntshkcrmzi6p','state changed','OS::Heat::ResourceGroup',NULL,485),(749,'d8e229a3-a8f9-4464-811f-dd69e51eab4e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','Compute','overcloud-Compute-uhmhzfrtcqcf','state changed','OS::Heat::ResourceGroup',NULL,487),(750,'6fa68b90-abb5-4345-b08e-57baf742e80f','2e58c7ca-e1bd-469a-a7c7-feecefb734d5','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorage-ntshkcrmzi6p','2e58c7ca-e1bd-469a-a7c7-feecefb734d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(751,'6520ca46-0439-4b48-9d6f-e07e78e72000','2e58c7ca-e1bd-469a-a7c7-feecefb734d5','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','overcloud-CephStorage-ntshkcrmzi6p','2e58c7ca-e1bd-469a-a7c7-feecefb734d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(752,'568e9cca-367a-4ab2-a194-319ac5b5ef92','504e140c-1e9c-4f44-9a93-32b64bb43125','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-uhmhzfrtcqcf','504e140c-1e9c-4f44-9a93-32b64bb43125','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(753,'bd9add56-7c7e-4a23-ae99-c89ec3c634af','9077b6c6-f768-4e9c-9949-5904c4b801d2','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-Networker-lv3m33foitn3','9077b6c6-f768-4e9c-9949-5904c4b801d2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(754,'c0f84bdb-61ed-4b67-9bb2-2c2b9d412139','504e140c-1e9c-4f44-9a93-32b64bb43125','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','overcloud-Compute-uhmhzfrtcqcf','504e140c-1e9c-4f44-9a93-32b64bb43125','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(755,'59cd4195-3b49-47b2-b05c-c01f0eebc691','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','BlockStorageServiceChain','2fb7d9b7-804f-449f-8aea-d4c75de57ea9','state changed','OS::TripleO::BlockStorageServices',NULL,83),(756,'471c5387-e5c0-45c0-aa6b-c11fa592741d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-yweyrnecuhwi','state changed','OS::Heat::Value',NULL,490),(757,'2b8107e7-4a1e-4cd6-90d4-fd490104bf85','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','CephStorage','2e58c7ca-e1bd-469a-a7c7-feecefb734d5','state changed','OS::Heat::ResourceGroup',NULL,485),(758,'11607036-eecd-4754-a8fa-dcb527da9de0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-yweyrnecuhwi','state changed','OS::Heat::Value',NULL,490),(759,'a5a5c22b-5dc4-4081-ac9a-1bfc2e79a09e','9077b6c6-f768-4e9c-9949-5904c4b801d2','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','overcloud-Networker-lv3m33foitn3','9077b6c6-f768-4e9c-9949-5904c4b801d2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(760,'1ae653f4-3e0b-4875-8beb-aac6560b7f2d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChain','659ecdde-f722-4014-9aee-e116435e07bf','state changed','OS::TripleO::CellControllerComputeServices',NULL,87),(761,'100343a7-f452-4497-8a55-f3141609a850','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','DefaultCephConfigOverrides','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v-DefaultCephConfigOverrides-eukilvzswife','state changed','OS::Heat::Value',NULL,494),(762,'d4ff6418-6313-4510-b808-57e20a767665','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','DefaultCephConfigOverrides','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v-DefaultCephConfigOverrides-eukilvzswife','state changed','OS::Heat::Value',NULL,494),(763,'ade4c98b-0da7-42ed-a63a-0211eeef29c2','72bc937a-7885-4887-9e56-f6ccb11e6372','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea-CephBase-26y4bz42ax4v','72bc937a-7885-4887-9e56-f6ccb11e6372','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(764,'f981b97d-7acf-4aca-b4b0-b1ba0c848b6a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','CephStorageServers','overcloud-CephStorageServers-kspik4jpxlzb','state changed','OS::Heat::Value',NULL,499),(765,'aed24299-58ee-4f6b-b430-d7c7b6d2b591','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','CephStorageServers','overcloud-CephStorageServers-kspik4jpxlzb','state changed','OS::Heat::Value',NULL,499),(766,'0eb449aa-2fd2-4764-8ad3-6517f3792f8a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','ObjectStorageIpListMap','overcloud-ObjectStorageIpListMap-2dprr3kuzqst','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,497),(767,'f293baa7-4385-42a0-b474-f5358ffbd045','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','3','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k','state changed','OS::TripleO::Services::CephOSD',NULL,501),(768,'12828fd8-91f0-4b90-bf21-9ac86fb1d827','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','ObjectStorageServers','overcloud-ObjectStorageServers-y2q2iujnb2vp','state changed','OS::Heat::Value',NULL,495),(769,'d408a598-b7d6-419d-b3c4-683985443093','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','Networker','9077b6c6-f768-4e9c-9949-5904c4b801d2','state changed','OS::Heat::ResourceGroup',NULL,484),(770,'059b2b02-6513-4b4e-bc6b-cfa395ff01b4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-5kxapxnoo7pc','state changed','OS::Heat::Value',NULL,504),(771,'bcf6af14-a428-45c9-a39e-d9cf7c4f01d9','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageIpListMap-2dprr3kuzqst','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(772,'523369a8-698e-4718-a0a5-97f908cba684','a223cbea-f1ba-4d99-80e7-4f99889aac7c','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k','a223cbea-f1ba-4d99-80e7-4f99889aac7c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(773,'92360460-9846-40ee-8402-a79890a29555','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','ObjectStorageServers','overcloud-ObjectStorageServers-y2q2iujnb2vp','state changed','OS::Heat::Value',NULL,495),(774,'578e96fd-748a-43f9-ba5a-190204c57183','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','CellControllerServiceChain','814bc91b-b000-483d-89f3-8fb82be740fe','state changed','OS::TripleO::CellControllerServices',NULL,91),(775,'b71de475-0b1a-4e8b-be68-39129c37b463','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','1','a5355cab-eb3e-461a-84ea-539ab787c885','state changed','OS::TripleO::Services::CACerts',NULL,463),(776,'8c28be69-92fa-42a6-9c3a-bca34d3b49ee','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-5kxapxnoo7pc','state changed','OS::Heat::Value',NULL,504),(777,'534f91df-46bd-4e12-b76f-366d907ebf5a','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ObjectStorageIpListMap-2dprr3kuzqst-NetIpMapValue-nl5nco6bnwcl','state changed','OS::Heat::Value',NULL,517),(778,'766532a4-a719-4fc3-919b-b88986fb90f6','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ObjectStorageIpListMap-2dprr3kuzqst-NetIpMapValue-nl5nco6bnwcl','state changed','OS::Heat::Value',NULL,517),(779,'007166d2-1537-4645-8687-4825be00afce','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','NetworkerServers','overcloud-NetworkerServers-d76342kdchnt','state changed','OS::Heat::Value',NULL,530),(780,'19de69ee-5a4f-49ff-9f2d-a5a55a1c0916','a223cbea-f1ba-4d99-80e7-4f99889aac7c','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','CephBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,529),(781,'a046532c-e883-4190-a465-8fb1927bc084','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','COMPLETE','NetworkerServers','overcloud-NetworkerServers-d76342kdchnt','state changed','OS::Heat::Value',NULL,530),(782,'0304df1e-3ce6-4a5c-ae24-a1b21d874e5d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','CephStorageIpListMap','overcloud-CephStorageIpListMap-x5tpr2dtzkcc','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,535),(783,'a942a749-3f45-4441-98d8-e6225d4195fb','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','5','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,536),(784,'6f1ca4ca-ffd4-40b8-90ac-1db8214ba65b','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx','fbdddd9d-e306-489c-8d01-11fd00ede79c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(785,'68c025a5-1ae3-4661-bfa8-c8e627b45ae0','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw','d599361a-59f3-45c6-a56b-a2e55f02cbef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(786,'4bd40f3d-4679-4702-8baa-eb7080110092','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:18',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-mzusbx6jnift','state changed','OS::Heat::Value',NULL,561),(787,'8007e454-0f29-4fa6-9999-f7e123207290','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageIpListMap-x5tpr2dtzkcc','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(788,'f65707e5-b570-4947-baaa-5ef16a812cd9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-mzusbx6jnift','state changed','OS::Heat::Value',NULL,561),(789,'7523f9c6-118d-447d-8f5e-2e0e951d4876','0754b6e3-97af-4875-b088-19fcab688ed3','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','ContainersCommon','1c289367-c68c-45a8-a426-9ab94659a0ca','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(790,'9a072b93-ba23-49cc-bd11-78ccacc56215','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','DefaultCephConfigOverrides','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx-DefaultCephConfigOverrides-4vvcrwmfe3pi','state changed','OS::Heat::Value',NULL,584),(791,'8fc47fdd-8627-4b5a-b82f-ebb552cf586e','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','DefaultCephConfigOverrides','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx-DefaultCephConfigOverrides-4vvcrwmfe3pi','state changed','OS::Heat::Value',NULL,584),(792,'eb854e4d-3323-495d-b1c5-f32e59bf3caa','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CephStorageIpListMap-x5tpr2dtzkcc-NetIpMapValue-tgluqcf5npqz','state changed','OS::Heat::Value',NULL,590),(793,'96a3af5c-cbf1-4d40-9da2-5fe198377a02','0754b6e3-97af-4875-b088-19fcab688ed3','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-4-npdmvase6x5w','0754b6e3-97af-4875-b088-19fcab688ed3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(794,'eb191c62-30a1-4bfc-aaee-2c24f9d6bacd','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','NetworkerIpListMap','overcloud-NetworkerIpListMap-burty4ajw2xp','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,595),(795,'d3d8748e-2d50-4d86-8553-3c68ddee0bbd','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CephStorageIpListMap-x5tpr2dtzkcc-NetIpMapValue-tgluqcf5npqz','state changed','OS::Heat::Value',NULL,590),(796,'c376f253-933a-4c91-9023-bb61764d853d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-4ovwtukxadq4','state changed','OS::Heat::Value',NULL,602),(797,'61b5e752-ead7-4180-81bf-e067219db549','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-CeilometerServiceBase-3w4axnedunkh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,601),(798,'6d799895-998f-40e0-9e96-5cf1aad1aac7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-4ovwtukxadq4','state changed','OS::Heat::Value',NULL,602),(799,'65c2f9d4-07d8-4b1e-ac0d-6f3fca9b5505','15fd7abd-deef-46fe-812d-8fb602e61c75','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','CephBase','72bc937a-7885-4887-9e56-f6ccb11e6372','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,400),(800,'34067783-3c8d-44b8-b8b2-f9907b3ba34c','976a8cbd-0a03-4d60-821c-438aeb855f0c','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerIpListMap-burty4ajw2xp','976a8cbd-0a03-4d60-821c-438aeb855f0c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(801,'1f30cbdb-a30d-41a4-a40a-50e5e2a98c19','15fd7abd-deef-46fe-812d-8fb602e61c75','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-2-i6av7gxiu7ea','15fd7abd-deef-46fe-812d-8fb602e61c75','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(802,'3d9d0cf0-7626-4dd9-acd9-88913cc41f9e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','Compute','504e140c-1e9c-4f44-9a93-32b64bb43125','state changed','OS::Heat::ResourceGroup',NULL,487),(803,'b53722d9-1f1e-4f6c-949c-6da7aff7677d','e04d0d2c-4d68-4054-9673-278596d12ddc','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-CeilometerServiceBase-3w4axnedunkh','e04d0d2c-4d68-4054-9673-278596d12ddc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(804,'7bca4a44-4868-4172-b394-e33599cdc0ed','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-aupfgbpvu2ir','state changed','OS::Heat::Value',NULL,616),(805,'0b672290-a4df-4f8e-986f-dfe4253d84f7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-eqorv54dks63','state changed','OS::Heat::Value',NULL,617),(806,'8b11892e-a10e-4d67-a47e-e1324c55c8a0','e04d0d2c-4d68-4054-9673-278596d12ddc','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-CeilometerServiceBase-3w4axnedunkh','e04d0d2c-4d68-4054-9673-278596d12ddc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(807,'ff7449a3-abf7-4bdd-a356-86bdc14b1743','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-eqorv54dks63','state changed','OS::Heat::Value',NULL,617),(808,'c82f57a7-70bc-4af0-b5ce-0fdfea704d28','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-muejxw77bahn','state changed','OS::Heat::Value',NULL,618),(809,'5b3a8024-480e-414e-b48f-63aee4f52130','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-muejxw77bahn','state changed','OS::Heat::Value',NULL,618),(810,'c84f632a-78ce-4467-8d68-1c845d2bcef1','976a8cbd-0a03-4d60-821c-438aeb855f0c','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-NetworkerIpListMap-burty4ajw2xp-NetIpMapValue-5xr3jlrntnxv','state changed','OS::Heat::Value',NULL,620),(811,'6636a22c-1e32-457e-a4f3-27c9dd367e52','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','ComputeServers','overcloud-ComputeServers-fzbivr7nx7ct','state changed','OS::Heat::Value',NULL,622),(812,'1d4adbdd-9491-413f-8cab-92326ae2996e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-aupfgbpvu2ir','state changed','OS::Heat::Value',NULL,616),(813,'2728dc57-5b83-4978-ac02-ca935d853ab7','976a8cbd-0a03-4d60-821c-438aeb855f0c','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-NetworkerIpListMap-burty4ajw2xp-NetIpMapValue-5xr3jlrntnxv','state changed','OS::Heat::Value',NULL,620),(814,'52630ac8-099c-4631-966a-939a678ee858','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','ComputeServers','overcloud-ComputeServers-fzbivr7nx7ct','state changed','OS::Heat::Value',NULL,622),(815,'18630c7e-55d4-43a3-9550-493a62bc3bf8','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','3','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha','state changed','OS::TripleO::Services::AodhNotifier',NULL,619),(816,'01d22450-5c38-4f9d-b5d2-bd5a21bc700a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-yubqovsw4nuw','state changed','OS::Heat::Value',NULL,624),(817,'950abd9b-6bc9-4e63-875d-bf39572909e4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-yubqovsw4nuw','state changed','OS::Heat::Value',NULL,624),(818,'60b9b535-7e27-4689-acec-b801071a58d3','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','4','0754b6e3-97af-4875-b088-19fcab688ed3','state changed','OS::TripleO::Services::Collectd',NULL,288),(819,'bc25fa21-d656-483f-aedf-7f04f8f16f8f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-efllcttifaky','state changed','OS::Heat::Value',NULL,625),(820,'7452f82c-26f2-4512-9b12-2f4f055e2eb2','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha','162cf7cb-fcfd-40c6-b946-79baebf95d90','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(821,'79b0c64e-4665-44cf-91df-bcbb72d39d90','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-efllcttifaky','state changed','OS::Heat::Value',NULL,625),(822,'2eb5754c-9a73-4b02-ab62-297bedac41fd','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','BlockStorage','overcloud-BlockStorage-525kxhdgad5y','state changed','OS::Heat::ResourceGroup',NULL,629),(823,'ca2fed36-fb04-47ad-90ca-de4d0ab1c91c','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ObjectStorageIpListMap-2dprr3kuzqst-EnabledServicesValue-zo3wur57irz3','state changed','OS::Heat::Value',NULL,630),(824,'e4586a3c-4b19-4f04-bda3-5e46237d3db3','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ObjectStorageIpListMap-2dprr3kuzqst-EnabledServicesValue-zo3wur57irz3','state changed','OS::Heat::Value',NULL,630),(825,'fca571fc-0139-4f6b-abd1-fda3030a5c0b','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageIpListMap-2dprr3kuzqst','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(826,'aa74b530-ca27-4e86-930c-67698753f0b3','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','ComputeIpListMap','overcloud-ComputeIpListMap-xnbhc2znkdn5','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,632),(827,'19421e52-1b30-40d0-a58a-ed608258073c','670975f0-0e2c-4022-b04b-3760932fb913','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorage-525kxhdgad5y','670975f0-0e2c-4022-b04b-3760932fb913','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(828,'db216ca5-4bb7-4a09-823f-5de6f8b8e60d','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','2','15fd7abd-deef-46fe-812d-8fb602e61c75','state changed','OS::TripleO::Services::CephClient',NULL,334),(829,'459d9509-fc13-4d77-8c31-a6486b2236fd','670975f0-0e2c-4022-b04b-3760932fb913','2026-06-13 07:50:19',NULL,'CREATE','COMPLETE','overcloud-BlockStorage-525kxhdgad5y','670975f0-0e2c-4022-b04b-3760932fb913','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(830,'6fb5b5ce-4a86-47e5-989e-e01778c5e5d6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:19',NULL,'CREATE','IN_PROGRESS','CellControllerCompute','overcloud-CellControllerCompute-o5c4enxccelp','state changed','OS::Heat::ResourceGroup',NULL,636),(831,'8edbbd4f-b4cd-4bbb-bc50-7932337a305d','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','8','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-8-ylc4dr326jxm','state changed','OS::TripleO::Services::Kernel',NULL,640),(832,'630fcaf3-5c2d-4fbd-b8dd-e0cab67ba481','c0839afb-27bb-406a-8f7c-891e3582bf77','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeIpListMap-xnbhc2znkdn5','c0839afb-27bb-406a-8f7c-891e3582bf77','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(833,'952c6a8a-6f6e-4da4-8556-91ff71a0feb5','832c141d-769e-4708-aa35-9afb17b0e087','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerCompute-o5c4enxccelp','832c141d-769e-4708-aa35-9afb17b0e087','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(834,'40122322-6252-40cd-abdf-e2c5a07decf5','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','ContainerImageUrlParts','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx-ContainerImageUrlParts-3a6jfabz6r2p','state changed','OS::Heat::Value',NULL,643),(835,'60cba4ce-d71a-49ad-b5c3-befc73796661','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CephStorageIpListMap-x5tpr2dtzkcc-EnabledServicesValue-q3y5d2fnywqu','state changed','OS::Heat::Value',NULL,644),(836,'f3b14d95-f345-4756-8b21-4e2fbd8d6e1f','d2dbf4eb-3909-43fd-9767-2265c5dcc158','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-8-ylc4dr326jxm','d2dbf4eb-3909-43fd-9767-2265c5dcc158','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(837,'290614b9-26d9-4b20-995c-1c2e7673cc19','832c141d-769e-4708-aa35-9afb17b0e087','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-CellControllerCompute-o5c4enxccelp','832c141d-769e-4708-aa35-9afb17b0e087','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(838,'22e29897-0cf9-40d0-8b8f-1dcea924ce72','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','ContainerImageUrlParts','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx-ContainerImageUrlParts-3a6jfabz6r2p','state changed','OS::Heat::Value',NULL,643),(839,'282f4bb3-3083-46c4-a48e-ac030cd6680b','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CephStorageIpListMap-x5tpr2dtzkcc-EnabledServicesValue-q3y5d2fnywqu','state changed','OS::Heat::Value',NULL,644),(840,'b8113817-9a19-472d-80f1-820e91798799','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-CephStorageIpListMap-x5tpr2dtzkcc','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(841,'35da3aee-927a-45c4-8eb3-92263a562ba1','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','CephAdmVars','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx-CephAdmVars-wotte4mtvuzy','state changed','OS::Heat::Value',NULL,647),(842,'4bf41173-73b8-48cb-9eb0-48919b26779d','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','CephAdmVars','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx-CephAdmVars-wotte4mtvuzy','state changed','OS::Heat::Value',NULL,647),(843,'b015253c-c2c1-4bda-b74c-88b419de8da8','fbdddd9d-e306-489c-8d01-11fd00ede79c','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k-CephBase-wnvxlupgespx','fbdddd9d-e306-489c-8d01-11fd00ede79c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(844,'b241588f-1f7f-490b-b52f-4fbdf9ee2f6a','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','6','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,649),(845,'9f265839-6e27-4492-8484-29733773f712','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-ContainersCommon-7kokn7mbkwrh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(846,'fbcfea1c-a6fb-47d3-b5b4-fdb610b7f358','c0839afb-27bb-406a-8f7c-891e3582bf77','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ComputeIpListMap-xnbhc2znkdn5-EnabledServicesValue-q7t4zjfp7kwy','state changed','OS::Heat::Value',NULL,650),(847,'c4d619b9-a4f5-40d4-a591-7b8699e46a33','c0839afb-27bb-406a-8f7c-891e3582bf77','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ComputeIpListMap-xnbhc2znkdn5-EnabledServicesValue-q7t4zjfp7kwy','state changed','OS::Heat::Value',NULL,650),(848,'139e6cdd-b6e8-493f-8071-e088b4587204','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNames','overcloud-CellControllerServiceNames-b2wlflj4lbyg','state changed','OS::Heat::Value',NULL,651),(849,'b1eb35ff-30c7-40ba-ae65-9ec75e48c71f','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(850,'043d6729-63c9-482e-a91c-8fe7585e45ae','d2dbf4eb-3909-43fd-9767-2265c5dcc158','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-8-ylc4dr326jxm-RoleParametersValue-v6toy5ig6zwe','state changed','OS::Heat::Value',NULL,653),(851,'80d8208c-1a68-44fc-bcab-997a17286647','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','AodhBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-AodhBase-maesy4hr2obs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,652),(852,'37bf15f3-13d7-4015-8e4d-8ef4944f7fc5','a6b317fd-00ac-4766-9666-645b5134e1a2','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-ContainersCommon-7kokn7mbkwrh','a6b317fd-00ac-4766-9666-645b5134e1a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(853,'8fcb1fd7-cf52-4f7a-b880-0f2def5b0a31','d2dbf4eb-3909-43fd-9767-2265c5dcc158','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-8-ylc4dr326jxm-RoleParametersValue-v6toy5ig6zwe','state changed','OS::Heat::Value',NULL,653),(854,'5767e82c-39e1-4ad1-8dfb-0b02fc30616a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','CellControllerServiceNames','overcloud-CellControllerServiceNames-b2wlflj4lbyg','state changed','OS::Heat::Value',NULL,651),(855,'8632c683-83fe-4826-9c81-b0b25fd41ffd','d2dbf4eb-3909-43fd-9767-2265c5dcc158','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-8-ylc4dr326jxm','d2dbf4eb-3909-43fd-9767-2265c5dcc158','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(856,'710c7e23-ab32-4075-a1f2-ffc0426412c2','a6b317fd-00ac-4766-9666-645b5134e1a2','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-ContainersCommon-7kokn7mbkwrh','a6b317fd-00ac-4766-9666-645b5134e1a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(857,'43c88803-ce37-4711-a7cc-e09d1b8c1384','976a8cbd-0a03-4d60-821c-438aeb855f0c','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-NetworkerIpListMap-burty4ajw2xp-EnabledServicesValue-stlfz5otabce','state changed','OS::Heat::Value',NULL,655),(858,'fb0b1afa-568b-40d2-872e-6bf9b2f5c675','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerServiceBase-3v4ljgwq6ubo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,656),(859,'f0e7b532-a2fa-4de6-8a19-7889ab614caf','976a8cbd-0a03-4d60-821c-438aeb855f0c','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-NetworkerIpListMap-burty4ajw2xp-EnabledServicesValue-stlfz5otabce','state changed','OS::Heat::Value',NULL,655),(860,'991bb840-fda4-4725-9830-e351ae8d4c00','976a8cbd-0a03-4d60-821c-438aeb855f0c','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-NetworkerIpListMap-burty4ajw2xp','976a8cbd-0a03-4d60-821c-438aeb855f0c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(861,'b436bd57-2292-4b3a-8376-59fe0c00db3f','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','0','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof','state changed','OS::TripleO::Services::AodhApi',NULL,657),(862,'d1110593-96fd-46cc-8f25-83962e3d43cb','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','ContainersCommon','a6b317fd-00ac-4766-9666-645b5134e1a2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(863,'34b70e08-4b8e-4858-b7de-7f0db42d9244','661ac34a-3d5b-4f0f-aab6-ba35239228c8','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-AodhBase-maesy4hr2obs','661ac34a-3d5b-4f0f-aab6-ba35239228c8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(864,'6b96ff32-b5d7-4e6b-b761-c44a0af109d5','661ac34a-3d5b-4f0f-aab6-ba35239228c8','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-AodhBase-maesy4hr2obs','661ac34a-3d5b-4f0f-aab6-ba35239228c8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(865,'f37ca85f-50ef-4885-9552-acbe6109819e','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(866,'f328340a-a2f6-4af8-930b-0c4cfd8fbd62','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','CellController','overcloud-CellController-qawci6lc2jyv','state changed','OS::Heat::ResourceGroup',NULL,658),(867,'3fd3d240-8e1f-4417-9d3f-fe73c93ca0ef','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','CeilometerServiceBase','e04d0d2c-4d68-4054-9673-278596d12ddc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,601),(868,'44ac2e23-4556-48b6-81f6-8aa096b20dc3','b8eed62f-af01-40a6-8330-b9aac611dfde','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerServiceBase-3v4ljgwq6ubo','b8eed62f-af01-40a6-8330-b9aac611dfde','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(869,'d3c5dc8e-a21c-4589-88cc-ac262708879d','b8eed62f-af01-40a6-8330-b9aac611dfde','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerServiceBase-3v4ljgwq6ubo','b8eed62f-af01-40a6-8330-b9aac611dfde','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(870,'89c1e796-87a4-4b0d-bf47-f0447efa44b5','4a983258-b736-415b-b6a4-74fd18bab80b','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-CellController-qawci6lc2jyv','4a983258-b736-415b-b6a4-74fd18bab80b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(871,'c251e24e-ea9d-4a77-9083-bbf64109faa6','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','AodhBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-AodhBase-zcxgkl3tdfbf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,659),(872,'ee30326d-8598-4238-b88b-5615f5e4e59c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','ObjectStorageIpListMap','0f0a2af7-ef2e-4a8b-9392-26ae56af01f4','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,497),(873,'22850174-2c3a-494d-87de-7fceb6c0a06c','4a983258-b736-415b-b6a4-74fd18bab80b','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-CellController-qawci6lc2jyv','4a983258-b736-415b-b6a4-74fd18bab80b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(874,'decb72d6-65a3-4f82-831e-19a1948aefbe','70c4c6da-52a3-4bb7-8e35-2ceaff2bb5d4','2026-06-13 07:50:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-AodhBase-zcxgkl3tdfbf','70c4c6da-52a3-4bb7-8e35-2ceaff2bb5d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(875,'7aeb54c7-35b2-4cec-9558-84aa0d9d3ef5','70c4c6da-52a3-4bb7-8e35-2ceaff2bb5d4','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-AodhBase-zcxgkl3tdfbf','70c4c6da-52a3-4bb7-8e35-2ceaff2bb5d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(876,'3eb51f9f-b352-406c-a4c7-12e5d26a1295','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:20',NULL,'CREATE','COMPLETE','BlockStorage','670975f0-0e2c-4022-b04b-3760932fb913','state changed','OS::Heat::ResourceGroup',NULL,629),(877,'6992734c-d284-4e19-b13a-c898e0b33e35','a223cbea-f1ba-4d99-80e7-4f99889aac7c','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','CephBase','fbdddd9d-e306-489c-8d01-11fd00ede79c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,529),(878,'09984340-5dc6-4048-ac77-167a0a05872a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-3m3zc72htnqy','state changed','OS::Heat::Value',NULL,660),(879,'f16e1621-e1e6-4487-8d36-cf9ba07deb40','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','CephStorageIpListMap','24cccbbc-5b4a-4a19-be66-ce6490ef3c97','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,535),(880,'9b2989c1-8570-4e51-bf38-857adddbd13a','a223cbea-f1ba-4d99-80e7-4f99889aac7c','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-3-hzc7ozv4my2k','a223cbea-f1ba-4d99-80e7-4f99889aac7c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(881,'5736c2a2-4b0c-4040-bc07-cda87e65a763','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-3m3zc72htnqy','state changed','OS::Heat::Value',NULL,660),(882,'e09cb758-1def-4d59-bc25-64e882abe4d5','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','BlockStorageServers','overcloud-BlockStorageServers-ksrkhmxk37g3','state changed','OS::Heat::Value',NULL,661),(883,'54e9f8cc-106b-4549-8d5c-248a11ed55cc','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','BlockStorageServers','overcloud-BlockStorageServers-ksrkhmxk37g3','state changed','OS::Heat::Value',NULL,661),(884,'4ac3506a-5ef0-44f4-aa75-e7af3dd68057','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','CellControllerCompute','832c141d-769e-4708-aa35-9afb17b0e087','state changed','OS::Heat::ResourceGroup',NULL,636),(885,'ab227cb2-a6d3-42c4-8420-eb954b4f28d2','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','BlockStorageIpListMap','overcloud-BlockStorageIpListMap-7mguggnpzaka','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,665),(886,'677e4ca0-591c-464a-a529-cd11f3d94a25','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-RoleParametersValue-tuexe24hxifb','state changed','OS::Heat::Value',NULL,667),(887,'391c9237-ed0d-433d-a33a-ee1578859d1a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','NetworkerIpListMap','976a8cbd-0a03-4d60-821c-438aeb855f0c','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,595),(888,'5b187c42-4a85-4f4a-889f-dedb7b583f8f','c0839afb-27bb-406a-8f7c-891e3582bf77','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeIpListMap-xnbhc2znkdn5-NetIpMapValue-oy6yjo3bj5uu','state changed','OS::Heat::Value',NULL,668),(889,'b3b3d7f3-c9d7-42aa-b9a1-26aaf298f4c5','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-RoleParametersValue-tuexe24hxifb','state changed','OS::Heat::Value',NULL,667),(890,'46b2339a-17b4-47c0-a83d-911754b4b59b','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-RoleParametersValue-dt6khck6qbex','state changed','OS::Heat::Value',NULL,666),(891,'82ab43fe-8ad1-4818-920d-bb64b3156c0f','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','8','d2dbf4eb-3909-43fd-9767-2265c5dcc158','state changed','OS::TripleO::Services::Kernel',NULL,640),(892,'4aab558a-820f-4f34-8634-31d4bb570b21','c0839afb-27bb-406a-8f7c-891e3582bf77','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeIpListMap-xnbhc2znkdn5-NetIpMapValue-oy6yjo3bj5uu','state changed','OS::Heat::Value',NULL,668),(893,'c457f26a-48af-43fd-a851-c5a9e0a29519','c0839afb-27bb-406a-8f7c-891e3582bf77','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','overcloud-ComputeIpListMap-xnbhc2znkdn5','c0839afb-27bb-406a-8f7c-891e3582bf77','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(894,'51c20e91-ab40-4c1e-ac82-b4e45f49807e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServers','overcloud-CellControllerComputeServers-bjdw3nj5d5pt','state changed','OS::Heat::Value',NULL,669),(895,'d13c46eb-3fdf-4dc4-a341-850c49024378','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw-RoleParametersValue-dt6khck6qbex','state changed','OS::Heat::Value',NULL,666),(896,'446c1ba1-31e8-4e5e-bc92-f2885be2f576','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageIpListMap-7mguggnpzaka','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(897,'11cc69d8-3e0c-4c27-a517-c354ff06be47','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','CellControllerComputeServers','overcloud-CellControllerComputeServers-bjdw3nj5d5pt','state changed','OS::Heat::Value',NULL,669),(898,'ad76e5dc-c0a2-444b-833d-1dcde6e9deeb','d599361a-59f3-45c6-a56b-a2e55f02cbef','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-5-xmslyf4s3sdw','d599361a-59f3-45c6-a56b-a2e55f02cbef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(899,'cc018a71-954f-4d96-a323-c40af09edb62','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-6nbycjeaacoj','state changed','OS::Heat::Value',NULL,670),(900,'b14ae8ae-2e2e-45df-a7cd-a5539233f0bf','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','CeilometerAgentCentralBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,673),(901,'98dc7a6a-6cb3-4563-92c3-c38c34e1c73d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-6nbycjeaacoj','state changed','OS::Heat::Value',NULL,670),(902,'e94f76a7-1415-4250-a794-90d769f67e34','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-BlockStorageIpListMap-7mguggnpzaka-NetIpMapValue-pe4llnoui5zp','state changed','OS::Heat::Value',NULL,674),(903,'23c55b09-bf03-4635-bcef-604c94675e98','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-BlockStorageIpListMap-7mguggnpzaka-NetIpMapValue-pe4llnoui5zp','state changed','OS::Heat::Value',NULL,674),(904,'8e64d0e5-dd48-4a96-8760-bf2d2f3d850c','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4','06209a8f-9603-4ed4-a230-8445f1559643','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(905,'1b715397-5fbb-4bb6-a584-80d2d3ead168','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-RoleParametersValue-g66jqcivrjic','state changed','OS::Heat::Value',NULL,676),(906,'acda8b1d-5bf8-4576-aac5-b2e8e9c1b85d','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-RoleParametersValue-g66jqcivrjic','state changed','OS::Heat::Value',NULL,676),(907,'20e3c219-c7ae-40c2-b1da-9eb7fabb73c8','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','AodhBase','661ac34a-3d5b-4f0f-aab6-ba35239228c8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,652),(908,'ea575e66-17dd-4256-822d-c4249eacba3b','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','2','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd','state changed','OS::TripleO::Services::AodhListener',NULL,678),(909,'67cb3533-4cc6-48a6-9d4e-4bc93ac62f1f','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','CeilometerServiceBase','b8eed62f-af01-40a6-8330-b9aac611dfde','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,656),(910,'86f81992-6629-40bb-8054-b9a1bf12a28d','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','3','a223cbea-f1ba-4d99-80e7-4f99889aac7c','state changed','OS::TripleO::Services::CephOSD',NULL,501),(911,'8a53e039-3342-4864-9d46-991ae674b62d','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','AodhBase','70c4c6da-52a3-4bb7-8e35-2ceaff2bb5d4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,659),(912,'ac82a58d-6005-4edd-b1d6-0ea3634fbf21','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','CellController','4a983258-b736-415b-b6a4-74fd18bab80b','state changed','OS::Heat::ResourceGroup',NULL,658),(913,'1a42c6d7-45c8-4d28-9562-a002f838945d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','CellControllerComputeIpListMap','overcloud-CellControllerComputeIpListMap-d63bkgphlfn2','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,680),(914,'78ce6342-9bcc-4afd-9601-e360ceabe875','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-CeilometerServiceBase-ypd2j7vwtgfa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,681),(915,'5c0ad95c-710b-4ded-8a8a-af44d1d7aa41','69633f88-d269-489f-8331-cf514c94ddc8','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-CeilometerServiceBase-ypd2j7vwtgfa','69633f88-d269-489f-8331-cf514c94ddc8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(916,'82cc0a08-97fe-4bfe-a219-20691fabb127','aa3b19cd-61ae-432c-8c83-860723e511c1','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeIpListMap-d63bkgphlfn2','aa3b19cd-61ae-432c-8c83-860723e511c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(917,'c7bd3266-ab57-4e89-91ab-04d0a2d694f3','69633f88-d269-489f-8331-cf514c94ddc8','2026-06-13 07:50:21',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-CeilometerServiceBase-ypd2j7vwtgfa','69633f88-d269-489f-8331-cf514c94ddc8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(918,'d98101b4-58a9-446e-8c6c-8f4d223ad8fc','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:21',NULL,'CREATE','IN_PROGRESS','12','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy','state changed','OS::TripleO::Services::NovaLibvirt',NULL,682),(919,'29fa5cf9-a78a-45c8-99f5-b5730bc3263e','aa3b19cd-61ae-432c-8c83-860723e511c1','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-d63bkgphlfn2-EnabledServicesValue-lgm536qva7y5','state changed','OS::Heat::Value',NULL,683),(920,'be24d67d-4ae0-49b8-89dc-cc5ba209eac2','aa3b19cd-61ae-432c-8c83-860723e511c1','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-d63bkgphlfn2-EnabledServicesValue-lgm536qva7y5','state changed','OS::Heat::Value',NULL,683),(921,'cbb71861-88a8-4f09-a77c-8966cfe3c78b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','CellControllerServers','overcloud-CellControllerServers-xjq535xch4mu','state changed','OS::Heat::Value',NULL,685),(922,'07e04660-4230-47e4-ae24-f7279a57e023','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','CellControllerServers','overcloud-CellControllerServers-xjq535xch4mu','state changed','OS::Heat::Value',NULL,685),(923,'ee6397f4-0787-44ef-8e14-e1598787b721','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(924,'97ef4ae1-d392-4362-bac8-032672432c37','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-smu5l3vwuaha','state changed','OS::Heat::Value',NULL,688),(925,'4465ff38-234b-4d51-b4db-4155f94eecc3','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','5','d599361a-59f3-45c6-a56b-a2e55f02cbef','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,536),(926,'0f0d205b-367c-4beb-8611-83fce0586026','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','ComputeIpListMap','c0839afb-27bb-406a-8f7c-891e3582bf77','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,632),(927,'244fc782-964b-4c86-86f6-05a4bbb76954','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(928,'11a90323-609b-4864-8551-dacda9069f0c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-smu5l3vwuaha','state changed','OS::Heat::Value',NULL,688),(929,'b240645a-0655-4774-a397-743dffd43ca9','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-MySQLClient-hzsofazdj54r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(930,'954ba665-66d4-440a-8d80-b2c312c7c127','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-RoleParametersValue-klnw6fo32ots','state changed','OS::Heat::Value',NULL,694),(931,'f5474dc1-c9fc-4d31-a944-af3f3883d266','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-RoleParametersValue-klnw6fo32ots','state changed','OS::Heat::Value',NULL,694),(932,'f2b964ff-5bc6-4d91-8c8d-d71f9b3e2156','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','7','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam','state changed','OS::TripleO::Services::Iscsid',NULL,695),(933,'416dec9d-d281-4b55-81cf-ea8862ae0b31','afa95458-f97f-41da-8212-6eb29622ff0b','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-MySQLClient-hzsofazdj54r','afa95458-f97f-41da-8212-6eb29622ff0b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(934,'6a512c82-06d4-4658-9c3f-f130034f1712','afa95458-f97f-41da-8212-6eb29622ff0b','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-MySQLClient-hzsofazdj54r','afa95458-f97f-41da-8212-6eb29622ff0b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(935,'a7fd398f-7b30-48ac-aa52-9cad216ac897','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','CellControllerIpListMap','overcloud-CellControllerIpListMap-2kj2byd6seg2','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,698),(936,'4d860c55-5b22-4b8b-89aa-9a529f88ebaa','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-RoleParametersValue-gqagxof647dm','state changed','OS::Heat::Value',NULL,700),(937,'b8494008-eccc-4ff0-a28f-e30e80385ed7','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-RoleParametersValue-gqagxof647dm','state changed','OS::Heat::Value',NULL,700),(938,'06d6676b-7b6d-481e-8970-8a21ce79adfb','2bd430d1-a63b-4cb6-aab1-680222462a3a','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerIpListMap-2kj2byd6seg2','2bd430d1-a63b-4cb6-aab1-680222462a3a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(939,'c90cedb6-6a0e-4e76-8a10-36cbef9b52da','eca4a402-6023-4e07-a3e1-f4649dd0e175','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam','eca4a402-6023-4e07-a3e1-f4649dd0e175','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(940,'3da602d3-0134-4d12-a6c5-8d26afb6d15a','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','9','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt','state changed','OS::TripleO::Services::MetricsQdr',NULL,701),(941,'6bbd5eb9-8b15-45b0-bf19-db40aaa61ddf','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','AodhBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-AodhBase-vfzysaauzam5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,702),(942,'b399391c-f6d8-4f7a-adea-691d28b6cd41','12fd75bc-b8b0-4425-b5b8-1856dcc79554','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt','12fd75bc-b8b0-4425-b5b8-1856dcc79554','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(943,'c28791cb-c81b-4724-bb82-b358ff12f803','2bd430d1-a63b-4cb6-aab1-680222462a3a','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerIpListMap-2kj2byd6seg2-EnabledServicesValue-txjcv3usbtds','state changed','OS::Heat::Value',NULL,703),(944,'f47fe44d-7718-45da-a431-c702b3c3864b','2bd430d1-a63b-4cb6-aab1-680222462a3a','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerIpListMap-2kj2byd6seg2-EnabledServicesValue-txjcv3usbtds','state changed','OS::Heat::Value',NULL,703),(945,'af8a7df7-3105-4cbe-8b7c-8c2f2e0e7a90','941bfcd0-1e49-458d-83b0-7f6306ad91e4','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-AodhBase-vfzysaauzam5','941bfcd0-1e49-458d-83b0-7f6306ad91e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(946,'a198861e-f913-4319-9c76-9e8dee6a05f1','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-BlockStorageIpListMap-7mguggnpzaka-EnabledServicesValue-vmytzolx6tth','state changed','OS::Heat::Value',NULL,704),(947,'49982eab-90a9-4624-80d4-1fa3b9c85c8b','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-BlockStorageIpListMap-7mguggnpzaka-EnabledServicesValue-vmytzolx6tth','state changed','OS::Heat::Value',NULL,704),(948,'c3ce7549-d965-4cf6-8b8d-76f7c5b727c7','941bfcd0-1e49-458d-83b0-7f6306ad91e4','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-AodhBase-vfzysaauzam5','941bfcd0-1e49-458d-83b0-7f6306ad91e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(949,'72fec297-6b47-41d4-a5ec-db51592e4caa','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','overcloud-BlockStorageIpListMap-7mguggnpzaka','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(950,'c9695e95-be1f-44b9-9cb4-e181f9fcadcc','12fd75bc-b8b0-4425-b5b8-1856dcc79554','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt-RoleParametersValue-m7wopy345bu4','state changed','OS::Heat::Value',NULL,705),(951,'d7b678de-97ee-46c7-a3c4-4d54e76beb3d','12fd75bc-b8b0-4425-b5b8-1856dcc79554','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt-RoleParametersValue-m7wopy345bu4','state changed','OS::Heat::Value',NULL,705),(952,'fa8de944-dcb2-4576-8bff-01de7796cfba','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','1','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn','state changed','OS::TripleO::Services::AodhEvaluator',NULL,706),(953,'347a4248-e97e-4ac8-b7d3-20d03b04fc03','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ApacheServiceBase-x3wchm55vfbb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,707),(954,'cb121756-20aa-4cb2-b90e-535f4e050645','eca4a402-6023-4e07-a3e1-f4649dd0e175','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam-RoleParametersValue-jxofvi2uzdfs','state changed','OS::Heat::Value',NULL,708),(955,'39268a89-0a0d-4f8e-97e1-19f6a03b892c','eca4a402-6023-4e07-a3e1-f4649dd0e175','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam-RoleParametersValue-jxofvi2uzdfs','state changed','OS::Heat::Value',NULL,708),(956,'5edc0cc2-f8a2-4ef7-9c3d-85c979a37cfb','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn','c1a4e430-bcd3-4771-a656-0247a708ddbe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(957,'b9b0884f-5353-47d1-9a3d-a562e87ea3c9','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-ContainersCommon-jprfakvi3qlz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(958,'3492eff6-aff4-40f6-ab81-893714f3c021','78f82608-72d8-4fc0-b792-18a497bdc59a','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ApacheServiceBase-x3wchm55vfbb','78f82608-72d8-4fc0-b792-18a497bdc59a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(959,'82cc5ae0-c321-4015-a222-d11cf3688b2f','4b995138-b9c9-4b5f-b2f4-dbdf39938a42','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-ContainersCommon-jprfakvi3qlz','4b995138-b9c9-4b5f-b2f4-dbdf39938a42','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(960,'2555308d-a891-44ff-8bf8-73de92e0254a','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','CeilometerServiceBase','69633f88-d269-489f-8331-cf514c94ddc8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,681),(961,'71f0c599-47b6-4259-ac4a-d254bbdee49a','4b995138-b9c9-4b5f-b2f4-dbdf39938a42','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-ContainersCommon-jprfakvi3qlz','4b995138-b9c9-4b5f-b2f4-dbdf39938a42','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(962,'8ae825ac-f2e1-442e-9606-ff06672b17c3','78f82608-72d8-4fc0-b792-18a497bdc59a','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ApacheServiceBase-x3wchm55vfbb-ApacheNetworks-hpllqaotqua3','state changed','OS::Heat::Value',NULL,709),(963,'eb2381e7-4f21-4f62-b13b-5ab33906a9b0','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:22',NULL,'CREATE','IN_PROGRESS','AodhBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-AodhBase-ty345mqcmset','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,710),(964,'a68edbf4-6266-418e-8d66-01671c99fcbe','78f82608-72d8-4fc0-b792-18a497bdc59a','2026-06-13 07:50:22',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ApacheServiceBase-x3wchm55vfbb-ApacheNetworks-hpllqaotqua3','state changed','OS::Heat::Value',NULL,709),(965,'64594d23-45c7-48a5-b9e2-28099aa25560','78f82608-72d8-4fc0-b792-18a497bdc59a','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ApacheServiceBase-x3wchm55vfbb','78f82608-72d8-4fc0-b792-18a497bdc59a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(966,'806dd1df-846f-4259-923e-450b12f5ad55','aa3b19cd-61ae-432c-8c83-860723e511c1','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerComputeIpListMap-d63bkgphlfn2-NetIpMapValue-mdwx7i3xz7be','state changed','OS::Heat::Value',NULL,711),(967,'bc5b425d-6180-4e12-9588-6e84573a52d9','1fff1cdc-a816-485c-803a-bc9b8901da86','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-AodhBase-ty345mqcmset','1fff1cdc-a816-485c-803a-bc9b8901da86','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(968,'6863a51d-d38c-4bbe-ae7a-e9f2b3895820','1fff1cdc-a816-485c-803a-bc9b8901da86','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-AodhBase-ty345mqcmset','1fff1cdc-a816-485c-803a-bc9b8901da86','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(969,'994c0bb5-1b91-451d-9034-28944fe71501','aa3b19cd-61ae-432c-8c83-860723e511c1','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerComputeIpListMap-d63bkgphlfn2-NetIpMapValue-mdwx7i3xz7be','state changed','OS::Heat::Value',NULL,711),(970,'2f8e342c-f1b9-422e-9367-e27718be1207','aa3b19cd-61ae-432c-8c83-860723e511c1','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeIpListMap-d63bkgphlfn2','aa3b19cd-61ae-432c-8c83-860723e511c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(971,'d2758325-2ab0-4398-8e6d-255e9d0a2395','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-ContainersCommon-okexcaqmhhxb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(972,'5c1a74d1-5483-4891-a3f9-46f203584447','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','NovaLibvirtCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtCommon-xdpqqk3fpwx4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(973,'19cb7cbd-6df5-4ada-b85b-9060d1d6fe41','6ca1bac1-5185-4387-bbfc-98ed0ae00151','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-ContainersCommon-okexcaqmhhxb','6ca1bac1-5185-4387-bbfc-98ed0ae00151','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(974,'5317a2ae-eaf3-478e-90fa-438e9f741613','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','MySQLClient','afa95458-f97f-41da-8212-6eb29622ff0b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(975,'3ac15873-c811-4e6f-ab64-dd4fe489ccfe','2aee2c7f-a49f-4e5e-9ec5-deaadab04bb6','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtCommon-xdpqqk3fpwx4','2aee2c7f-a49f-4e5e-9ec5-deaadab04bb6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(976,'e4be3c8d-1ecd-405e-a2d6-6d0168d8e46e','6ca1bac1-5185-4387-bbfc-98ed0ae00151','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha-ContainersCommon-okexcaqmhhxb','6ca1bac1-5185-4387-bbfc-98ed0ae00151','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(977,'208f43c4-9137-454a-afee-4e613775daa9','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-ContainersCommon-pdk7ihzgnje5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(978,'70c4f4d2-3bb8-4e36-ac20-72974c3ce080','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','BlockStorageIpListMap','55caf7a3-ebae-41a6-aa3f-4dcd5f8876c3','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,665),(979,'285e3d3f-1fc6-4ea1-b437-fa98fc1921c7','2aee2c7f-a49f-4e5e-9ec5-deaadab04bb6','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtCommon-xdpqqk3fpwx4-RoleParametersValue-lhrfb6ksoav3','state changed','OS::Heat::Value',NULL,713),(980,'fda579c6-e09f-45ef-8d2e-93e4c5ae6d8a','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-RoleParametersValue-3sqi3kyl4a6x','state changed','OS::Heat::Value',NULL,712),(981,'3141f153-aee1-4bcc-86c1-99084806afc7','496d011a-99b0-4b8e-b11a-6100fe3739e5','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-ContainersCommon-pdk7ihzgnje5','496d011a-99b0-4b8e-b11a-6100fe3739e5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(982,'1c2d5ae5-18fe-4832-98d5-11c976e0c062','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-RoleParametersValue-3sqi3kyl4a6x','state changed','OS::Heat::Value',NULL,712),(983,'ebf4f4e2-436f-4bba-bc56-9861fc3bffce','2aee2c7f-a49f-4e5e-9ec5-deaadab04bb6','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtCommon-xdpqqk3fpwx4-RoleParametersValue-lhrfb6ksoav3','state changed','OS::Heat::Value',NULL,713),(984,'47754ad3-fddc-4a50-a61d-a7fc9139631b','2aee2c7f-a49f-4e5e-9ec5-deaadab04bb6','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtCommon-xdpqqk3fpwx4','2aee2c7f-a49f-4e5e-9ec5-deaadab04bb6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(985,'618e070f-3516-49ab-8d2a-70a65f4ed2e5','496d011a-99b0-4b8e-b11a-6100fe3739e5','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-ContainersCommon-pdk7ihzgnje5','496d011a-99b0-4b8e-b11a-6100fe3739e5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(986,'4f06275c-55a0-46b6-be5c-a0a9bb7ea7d4','2bd430d1-a63b-4cb6-aab1-680222462a3a','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerIpListMap-2kj2byd6seg2-NetIpMapValue-gzopc3rqqrwc','state changed','OS::Heat::Value',NULL,714),(987,'3107839d-d651-47bc-a3dc-9ce25b4d4b75','2bd430d1-a63b-4cb6-aab1-680222462a3a','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerIpListMap-2kj2byd6seg2-NetIpMapValue-gzopc3rqqrwc','state changed','OS::Heat::Value',NULL,714),(988,'2116a53a-09fb-43d8-b49a-71a2dbbaa43e','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','AodhBase','941bfcd0-1e49-458d-83b0-7f6306ad91e4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,702),(989,'7722a1f2-0819-4f07-8330-57f6b57f9855','2bd430d1-a63b-4cb6-aab1-680222462a3a','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-CellControllerIpListMap-2kj2byd6seg2','2bd430d1-a63b-4cb6-aab1-680222462a3a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(990,'d53a0396-0d2a-4a88-8099-8d67d6d6a636','12fd75bc-b8b0-4425-b5b8-1856dcc79554','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt-ContainersCommon-w4mwuxmoeb36','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(991,'ed6a9660-0c7c-419c-b0de-36185cc6c2da','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ContainersCommon-yu5p6javff3k','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(992,'db90193c-a3d7-413f-954e-da53e0a89aec','0061ae7a-aefd-4563-8aa5-daa3f2dba389','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt-ContainersCommon-w4mwuxmoeb36','0061ae7a-aefd-4563-8aa5-daa3f2dba389','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(993,'111002c8-6529-42bc-8a8e-f3a726178c3d','eca4a402-6023-4e07-a3e1-f4649dd0e175','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam-ContainersCommon-qecgfhur3cp6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(994,'e092f099-1f6d-4fce-ad06-b5d870c97176','0061ae7a-aefd-4563-8aa5-daa3f2dba389','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt-ContainersCommon-w4mwuxmoeb36','0061ae7a-aefd-4563-8aa5-daa3f2dba389','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(995,'f39c1ac9-7c39-483f-9fe2-2ecc4f01b83d','5dfec7ac-f5fc-4a31-9920-b5b8394f5d33','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ContainersCommon-yu5p6javff3k','5dfec7ac-f5fc-4a31-9920-b5b8394f5d33','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(996,'0cb0a40a-caef-4127-9bb8-c0aceceed49e','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','ApacheServiceBase','78f82608-72d8-4fc0-b792-18a497bdc59a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,707),(997,'044c234b-c678-4c88-b1df-b8c057ee8c46','5dfec7ac-f5fc-4a31-9920-b5b8394f5d33','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-ContainersCommon-yu5p6javff3k','5dfec7ac-f5fc-4a31-9920-b5b8394f5d33','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(998,'84af81d9-be70-4284-a29b-3717c34c7b69','d8a34d6c-8c87-41b9-a17d-0bee670e34d3','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam-ContainersCommon-qecgfhur3cp6','d8a34d6c-8c87-41b9-a17d-0bee670e34d3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(999,'3cdc3410-021f-4ef8-b722-aea7813acb1e','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-RoleParametersValue-pqwbaibj6qvd','state changed','OS::Heat::Value',NULL,715),(1000,'9ff0b669-4453-40db-8909-1b16d12d1ae0','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','ContainersCommon','5dfec7ac-f5fc-4a31-9920-b5b8394f5d33','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1001,'0aa57dfc-0fa6-4edd-96d5-7679f7a4847f','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4-RoleParametersValue-pqwbaibj6qvd','state changed','OS::Heat::Value',NULL,715),(1002,'29532560-b289-41a7-8116-e3ceb2b376db','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','ContainersCommon','4b995138-b9c9-4b5f-b2f4-dbdf39938a42','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1003,'15ea3773-3d60-4560-83a9-142315da4d16','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-RoleParametersValue-uqmm6s3ev75c','state changed','OS::Heat::Value',NULL,716),(1004,'62edf664-e97c-4f6c-a6a2-ce3ecf151bec','d8a34d6c-8c87-41b9-a17d-0bee670e34d3','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam-ContainersCommon-qecgfhur3cp6','d8a34d6c-8c87-41b9-a17d-0bee670e34d3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1005,'0ad9ab39-0db4-4e5e-90be-508256ccdedd','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','CellControllerComputeIpListMap','aa3b19cd-61ae-432c-8c83-860723e511c1','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,680),(1006,'4b1ae678-3ac3-425b-93c8-0ee1562dabae','06209a8f-9603-4ed4-a230-8445f1559643','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap-CeilometerAgentCentralBase-lbpi45nh7te4','06209a8f-9603-4ed4-a230-8445f1559643','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1007,'d7b6abce-ec64-45b2-8e3a-093f5b0323c0','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-RoleParametersValue-uqmm6s3ev75c','state changed','OS::Heat::Value',NULL,716),(1008,'324b51f1-3627-4be5-95a0-b8dae24ae3de','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','AodhBase','1fff1cdc-a816-485c-803a-bc9b8901da86','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml',NULL,710),(1009,'0774ed13-b888-4ee0-ba58-5cc984d6f43d','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:24',NULL,'CREATE','IN_PROGRESS','NovaLibvirtLogging','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtLogging-twyfif6awam6','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1010,'fa1d9e81-2346-4f9a-a254-ff3a910d3fce','ee9644ca-7c89-4ee1-bb31-400bd487b924','2026-06-13 07:50:24',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtLogging-twyfif6awam6','ee9644ca-7c89-4ee1-bb31-400bd487b924','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1011,'a4bda4bb-af47-48f1-8541-199bdd3d10ce','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','ContainersCommon','6ca1bac1-5185-4387-bbfc-98ed0ae00151','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1012,'408c9c1d-c431-4513-8efe-5b88103e9fa5','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','NovaLibvirtCommon','2aee2c7f-a49f-4e5e-9ec5-deaadab04bb6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1013,'dcc9ec42-8742-4fc9-861c-44f9312e2afb','ee9644ca-7c89-4ee1-bb31-400bd487b924','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaLibvirtLogging-twyfif6awam6','ee9644ca-7c89-4ee1-bb31-400bd487b924','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1014,'2eafe905-161c-4fa3-b7ea-bda3f4e01637','162cf7cb-fcfd-40c6-b946-79baebf95d90','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-3-ao3bsavnxmha','162cf7cb-fcfd-40c6-b946-79baebf95d90','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1015,'566a899e-a737-4797-8b09-c86a72bc55c1','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','CellControllerIpListMap','2bd430d1-a63b-4cb6-aab1-680222462a3a','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,698),(1016,'473c63b1-10cf-4127-91eb-5673c5fd33a3','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-ContainersCommon-wppwd4lgv4i7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1017,'39934a25-36bc-4997-82fc-3f45d576cd20','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','ContainersCommon','496d011a-99b0-4b8e-b11a-6100fe3739e5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1018,'0ceda44e-54b6-4ea3-a322-434425a60a96','fe92743f-895b-4dab-a149-f3ac2a6f5837','2026-06-13 07:50:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-ContainersCommon-wppwd4lgv4i7','fe92743f-895b-4dab-a149-f3ac2a6f5837','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1019,'e6132583-022e-43f2-808c-72d4e641fd9a','fe92743f-895b-4dab-a149-f3ac2a6f5837','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-ContainersCommon-wppwd4lgv4i7','fe92743f-895b-4dab-a149-f3ac2a6f5837','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1020,'05e96c37-c050-4c88-829a-2dae1a5c8ca9','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:24',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-MySQLClient-ibscgf7goqxs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1021,'9a075b17-9bc9-44ad-b806-ee7969430239','12fd75bc-b8b0-4425-b5b8-1856dcc79554','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','ContainersCommon','0061ae7a-aefd-4563-8aa5-daa3f2dba389','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1022,'2821a145-f124-4187-9e83-2ac614d5ec67','12fd75bc-b8b0-4425-b5b8-1856dcc79554','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-9-mfunz6gvbsvt','12fd75bc-b8b0-4425-b5b8-1856dcc79554','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1023,'24683aff-428e-49b2-bdfd-e5e2db9773b2','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','3','162cf7cb-fcfd-40c6-b946-79baebf95d90','state changed','OS::TripleO::Services::AodhNotifier',NULL,619),(1024,'09b0f157-9061-42bb-9ba8-65593dafaa64','9ace71a2-67f1-4a49-b984-afcce3efbb61','2026-06-13 07:50:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-MySQLClient-ibscgf7goqxs','9ace71a2-67f1-4a49-b984-afcce3efbb61','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1025,'69d45778-bdbf-422f-8449-fe85081e780e','9ace71a2-67f1-4a49-b984-afcce3efbb61','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof-MySQLClient-ibscgf7goqxs','9ace71a2-67f1-4a49-b984-afcce3efbb61','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1026,'71e2167a-feb7-4cbe-8ea0-925e2fc8b13d','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','CeilometerAgentCentralBase','06209a8f-9603-4ed4-a230-8445f1559643','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,673),(1027,'a2f18afc-1020-4681-bca1-61b4ec40e52c','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-6-g426vhfuqmap','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1028,'c08dcbfc-d4ff-4bbc-936b-0aaec5aeef0a','eca4a402-6023-4e07-a3e1-f4649dd0e175','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','ContainersCommon','d8a34d6c-8c87-41b9-a17d-0bee670e34d3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1029,'0d186a33-75f7-42c8-935e-ae8dad27d550','eca4a402-6023-4e07-a3e1-f4649dd0e175','2026-06-13 07:50:24',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-7-v5qcnc7xzsam','eca4a402-6023-4e07-a3e1-f4649dd0e175','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1030,'8b3330d5-a710-4a16-a38a-1a7edfb24bef','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-MySQLClient-udumqurberia','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1031,'4fb4625f-0de1-4375-b380-71500bada26a','23b5bfa9-9a3f-46ca-bfc7-cc755936c9ae','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-MySQLClient-udumqurberia','23b5bfa9-9a3f-46ca-bfc7-cc755936c9ae','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1032,'2813a913-f510-412d-b424-74e03ae9de48','23b5bfa9-9a3f-46ca-bfc7-cc755936c9ae','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-MySQLClient-udumqurberia','23b5bfa9-9a3f-46ca-bfc7-cc755936c9ae','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1033,'6e389793-9e83-4cff-81b1-6073141a42f9','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaBase-fr2ee3ik2dn4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,722),(1034,'8e69f7bb-9dcc-4a5d-bb6e-ac5252855f56','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','7','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,723),(1035,'79509af8-b246-46e8-b05a-418508176e66','bc09e31c-7792-44a8-bc2c-556f0ecb3374','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaBase-fr2ee3ik2dn4','bc09e31c-7792-44a8-bc2c-556f0ecb3374','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1036,'e0cdf2b3-8247-4a2a-9abb-b64c2ef25f57','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','NovaLibvirtLogging','ee9644ca-7c89-4ee1-bb31-400bd487b924','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1037,'914e3cac-1c6e-448c-9e57-9d0f1ff9d2d9','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y','0a1876ee-7c54-4289-87ce-2df6b8d811d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1038,'e88de70b-ce26-4669-b556-6999b7f9a82d','bc09e31c-7792-44a8-bc2c-556f0ecb3374','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaBase-fr2ee3ik2dn4-RoleParametersValue-a6ronaqx5mvz','state changed','OS::Heat::Value',NULL,724),(1039,'57ff10d3-6e0d-48c7-abce-2ded1e0ca127','bc09e31c-7792-44a8-bc2c-556f0ecb3374','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaBase-fr2ee3ik2dn4-RoleParametersValue-a6ronaqx5mvz','state changed','OS::Heat::Value',NULL,724),(1040,'6f291eb9-19be-4a4d-88e5-482f0960e646','bc09e31c-7792-44a8-bc2c-556f0ecb3374','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-NovaBase-fr2ee3ik2dn4','bc09e31c-7792-44a8-bc2c-556f0ecb3374','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1041,'24729c8e-cdc4-4e95-88c9-89356bb60e3f','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-MySQLClient-c2slyk7p74f3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1042,'9eccd9ef-b293-4e04-836c-20db7c7705cd','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','7','eca4a402-6023-4e07-a3e1-f4649dd0e175','state changed','OS::TripleO::Services::Iscsid',NULL,695),(1043,'fef85ddc-265c-4bc9-b4c1-7fa643a8d030','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','6','8ab5509c-888c-4a18-b78e-6c8ba27a09dc','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,649),(1044,'83190ce8-9e57-463f-aa03-308127f3de2e','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','ContainersCommon','fe92743f-895b-4dab-a149-f3ac2a6f5837','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1045,'dff790e1-c202-4f1e-924c-0dfc4e295205','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-CeilometerServiceBase-fkp3sr53bkhb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,725),(1046,'5e1ff4fc-2092-4937-957b-e89cbc373925','f7b11142-8cb4-4db2-a3e9-f76a64ca8667','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-MySQLClient-c2slyk7p74f3','f7b11142-8cb4-4db2-a3e9-f76a64ca8667','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1047,'34facab7-e3e6-4024-a8d5-9e33d6440be2','f7b11142-8cb4-4db2-a3e9-f76a64ca8667','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd-MySQLClient-c2slyk7p74f3','f7b11142-8cb4-4db2-a3e9-f76a64ca8667','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1048,'15e980f1-ae8a-4764-80aa-f1504c97c873','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','9','12fd75bc-b8b0-4425-b5b8-1856dcc79554','state changed','OS::TripleO::Services::MetricsQdr',NULL,701),(1049,'2e2f31d4-150d-4d2d-9ff6-12e8cc54c68d','3196db81-225c-4151-9bf8-8c8771d56eac','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-CeilometerServiceBase-fkp3sr53bkhb','3196db81-225c-4151-9bf8-8c8771d56eac','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1050,'b2cbcaf1-1770-4ccc-afc8-55be03dcd3a0','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','MySQLClient','9ace71a2-67f1-4a49-b984-afcce3efbb61','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1051,'ae966644-ee5e-4dee-9279-8bdb358f35c8','3196db81-225c-4151-9bf8-8c8771d56eac','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-CeilometerServiceBase-fkp3sr53bkhb','3196db81-225c-4151-9bf8-8c8771d56eac','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1052,'669ae965-c096-4588-902c-f358ae811307','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','2026-06-13 07:50:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-0-tk4oibzouwof','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1053,'a7f3b800-c8c8-4de5-9d52-344cc7072b7c','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:25',NULL,'CREATE','IN_PROGRESS','11','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6','state changed','OS::TripleO::Services::NovaCompute',NULL,733),(1054,'4c289aff-fd26-441d-b3bc-641e81ca81a0','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-ContainersCommon-wcf676ms2vdf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1055,'e497010e-7c19-4502-9dd3-97e9071aee9a','30a98839-647f-4776-97d8-2df4fe344026','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-ContainersCommon-wcf676ms2vdf','30a98839-647f-4776-97d8-2df4fe344026','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1056,'871c261f-f98f-4351-aae1-5617e9b1b5d7','30a98839-647f-4776-97d8-2df4fe344026','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn-ContainersCommon-wcf676ms2vdf','30a98839-647f-4776-97d8-2df4fe344026','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1057,'50fe125f-193c-434b-a106-909241557bb1','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','10','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-10-yldcom3mksf3','state changed','OS::TripleO::Services::MySQLClient',NULL,738),(1058,'0e6f4869-66ae-4464-ad7e-5de3bce8c328','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6','27d95331-c3f0-49f5-a7da-924505151e57','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1059,'547dfb51-78e5-4dc9-87df-13d776aa4ca2','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','13','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-13-tbhs3avssdmz','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,739),(1060,'b46e5de5-19f0-47fa-a400-de74b43ff02d','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','MySQLClient','23b5bfa9-9a3f-46ca-bfc7-cc755936c9ae','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1061,'da6017a0-f79a-4b9c-a69e-9f85a077b7c9','9055dbcc-6d49-466d-8644-cb1fd875881c','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-10-yldcom3mksf3','9055dbcc-6d49-466d-8644-cb1fd875881c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1062,'2c9092ef-c979-4920-8b18-1239140689c5','b2cfda17-1e62-4740-a93b-c78de3005cf0','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-13-tbhs3avssdmz','b2cfda17-1e62-4740-a93b-c78de3005cf0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1063,'e59786ec-b5e8-401a-a3a9-44ce05cb7a54','9055dbcc-6d49-466d-8644-cb1fd875881c','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-10-yldcom3mksf3','9055dbcc-6d49-466d-8644-cb1fd875881c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1064,'bd198293-22de-4f3c-a36a-274b6cf3e55d','b2cfda17-1e62-4740-a93b-c78de3005cf0','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-13-tbhs3avssdmz-RoleParametersValue-lehs4jsofxll','state changed','OS::Heat::Value',NULL,740),(1065,'226ab69b-101b-4643-9532-6f55a9d834b2','b2cfda17-1e62-4740-a93b-c78de3005cf0','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-13-tbhs3avssdmz-RoleParametersValue-lehs4jsofxll','state changed','OS::Heat::Value',NULL,740),(1066,'44a7bb21-ab3b-43a4-9834-fbc56d8e9604','b2cfda17-1e62-4740-a93b-c78de3005cf0','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-13-tbhs3avssdmz','b2cfda17-1e62-4740-a93b-c78de3005cf0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1067,'f642268e-4f5e-4701-9b16-8fda5b3b4fb5','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-ContainersCommon-fu7hsjduqrby','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1068,'6bd84cab-0a07-4b3b-8007-ab18383a8448','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-ContainersCommon-f6ywwiltbtu4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1069,'91db5ed0-3dcb-466e-bd0a-324f18d9cde8','bfee92e3-c641-44b5-9783-c647d9b11b4e','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-ContainersCommon-fu7hsjduqrby','bfee92e3-c641-44b5-9783-c647d9b11b4e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1070,'2186a597-1c52-4052-adfb-b3cfd595b7f7','0fa52620-a5ac-499d-a5d5-71fbe1fc3d96','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-ContainersCommon-f6ywwiltbtu4','0fa52620-a5ac-499d-a5d5-71fbe1fc3d96','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1071,'c903e969-9039-43b1-92eb-a6890ca39abb','bfee92e3-c641-44b5-9783-c647d9b11b4e','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy-ContainersCommon-fu7hsjduqrby','bfee92e3-c641-44b5-9783-c647d9b11b4e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1072,'5e999747-c2c3-4143-8b48-2ced11f65b75','0fa52620-a5ac-499d-a5d5-71fbe1fc3d96','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-ContainersCommon-f6ywwiltbtu4','0fa52620-a5ac-499d-a5d5-71fbe1fc3d96','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1073,'6cc39bf8-9ba3-4482-8a13-3fe30a11792c','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','NovaBase','bc09e31c-7792-44a8-bc2c-556f0ecb3374','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,722),(1074,'a486b5f5-e600-46b1-a97f-654f1ecebdf2','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','0','10c5e6cf-ca1d-4860-a680-cb3028c3f8f7','state changed','OS::TripleO::Services::AodhApi',NULL,657),(1075,'a822fc15-f497-4213-90b1-d1417a809b75','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-ContainersCommon-lye6otuajnkw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1076,'8c0432cb-0051-4677-b299-d6949622aad6','54a85304-5aeb-4cd6-855a-d90ac5082265','2026-06-13 07:50:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-ContainersCommon-lye6otuajnkw','54a85304-5aeb-4cd6-855a-d90ac5082265','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1077,'08800984-3f75-411a-875f-3ef560e2f262','54a85304-5aeb-4cd6-855a-d90ac5082265','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-ContainersCommon-lye6otuajnkw','54a85304-5aeb-4cd6-855a-d90ac5082265','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1078,'1c9db930-7062-4a42-8964-8a1c6486aa0d','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','MySQLClient','f7b11142-8cb4-4db2-a3e9-f76a64ca8667','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1079,'170f6568-f076-4d2e-8ba9-b96bf69ae4bd','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-2-tlzewppg4ztd','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1080,'50d20ac3-4bb4-4400-9b12-71552ff445f4','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:26',NULL,'CREATE','COMPLETE','CeilometerServiceBase','3196db81-225c-4151-9bf8-8c8771d56eac','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,725),(1081,'46ccec53-b232-48a0-92f4-5ad35ab8a24c','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','ContainersCommon','30a98839-647f-4776-97d8-2df4fe344026','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1082,'1cca32db-1a96-485c-a4f3-2ea18bcb3613','c1a4e430-bcd3-4771-a656-0247a708ddbe','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-1-y7na43iv4zxn','c1a4e430-bcd3-4771-a656-0247a708ddbe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1083,'a72731ff-539b-4cf0-824d-f5d43fe12c02','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','13','b2cfda17-1e62-4740-a93b-c78de3005cf0','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,739),(1084,'610e2b16-9ee8-4918-967d-353197ecd48b','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','10','9055dbcc-6d49-466d-8644-cb1fd875881c','state changed','OS::TripleO::Services::MySQLClient',NULL,738),(1085,'a3a025fd-900c-4b37-960d-b3ea3904c42a','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','4','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-4-qa2yjyl6bolk','state changed','OS::TripleO::Services::BootParams',NULL,748),(1086,'0ac41d26-4747-4a0a-bff7-5aaae04a3517','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','2','a57d7449-b62c-4d79-a7bf-d2679ae36f8a','state changed','OS::TripleO::Services::AodhListener',NULL,678),(1087,'b0da79dd-06c5-498c-b337-c35ac0632517','d9cf8f5e-fa5d-47ff-997e-1b7360da008a','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-4-qa2yjyl6bolk','d9cf8f5e-fa5d-47ff-997e-1b7360da008a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1088,'04bf9420-60cc-4f51-ae0f-357a5e5b410c','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','NovaComputeCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaComputeCommon-zhkkmlh2253g','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,751),(1089,'cf2c96e7-2ef8-406e-b77e-ae394431c25f','d9cf8f5e-fa5d-47ff-997e-1b7360da008a','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-4-qa2yjyl6bolk-RoleParametersValue-trcitctqs6su','state changed','OS::Heat::Value',NULL,752),(1090,'445db1ca-380c-4b5b-9f1c-50eec6cfd345','d9cf8f5e-fa5d-47ff-997e-1b7360da008a','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-4-qa2yjyl6bolk-RoleParametersValue-trcitctqs6su','state changed','OS::Heat::Value',NULL,752),(1091,'9a6b7a38-8759-4a63-b025-17246bad045d','d9cf8f5e-fa5d-47ff-997e-1b7360da008a','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-4-qa2yjyl6bolk','d9cf8f5e-fa5d-47ff-997e-1b7360da008a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1092,'c6d3af7e-447d-4ccf-ac39-7f531fa7ffa3','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','ContainersCommon','bfee92e3-c641-44b5-9783-c647d9b11b4e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1093,'9d7dc34c-f86e-46c6-8620-dcd218fc6dbe','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','ContainersCommon','0fa52620-a5ac-499d-a5d5-71fbe1fc3d96','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1094,'4e0748e2-ce49-42f7-b088-41a3502062f1','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-12-bwgrh4aqruhy','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1095,'179ba40d-7245-4776-9c30-055ca8aca196','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','17','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig','state changed','OS::TripleO::Services::Rsyslog',NULL,754),(1096,'81ded509-6dc8-4af9-a414-d8706ec377a1','ef193751-3a28-410f-9f3e-8ce2212a1f0f','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaComputeCommon-zhkkmlh2253g','ef193751-3a28-410f-9f3e-8ce2212a1f0f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1097,'90cd1c1c-eb54-408c-9015-1700b90da058','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','14','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,756),(1098,'0c2b9779-9b14-402b-8a20-94ad8930315a','ef193751-3a28-410f-9f3e-8ce2212a1f0f','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaComputeCommon-zhkkmlh2253g','ef193751-3a28-410f-9f3e-8ce2212a1f0f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1099,'9f5b32cb-5a2a-4366-8af2-3c3ab01ca2dc','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','NovaComputeCommon','ef193751-3a28-410f-9f3e-8ce2212a1f0f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,751),(1100,'5e2fefc5-5265-4e4f-810e-dd8defc1d2a6','1c569793-808e-4b92-b958-1fa44cbb969e','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig','1c569793-808e-4b92-b958-1fa44cbb969e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1101,'6b3e8069-1c8b-4cb2-8678-253b6e966b01','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1102,'33a0155f-a9e1-47b7-9f47-e3fc97858312','1c569793-808e-4b92-b958-1fa44cbb969e','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig-ContainersCommon-sk5kstuhk6sr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1103,'4f088152-9257-44e5-9912-8e44d99faff5','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-RoleParametersValue-bqm4475iqgrf','state changed','OS::Heat::Value',NULL,760),(1104,'4d6b9362-61c1-4b43-84ad-190ce0d7f155','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y-RoleParametersValue-bqm4475iqgrf','state changed','OS::Heat::Value',NULL,760),(1105,'bacbca02-ed9d-4511-88cc-88478183b2d8','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-RoleParametersValue-76mzyst5okyo','state changed','OS::Heat::Value',NULL,762),(1106,'d42decb8-14a1-425f-8f00-20179577a218','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-RoleParametersValue-76mzyst5okyo','state changed','OS::Heat::Value',NULL,762),(1107,'1ef0914c-c211-46e0-9c28-4cb4635d6326','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','ContainersCommon','54a85304-5aeb-4cd6-855a-d90ac5082265','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1108,'05f80b39-6b92-4fa7-bf66-0f4165996b95','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','6','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,763),(1109,'8eaa57f4-efa7-438c-8b5e-bf265c9dc247','0a1876ee-7c54-4289-87ce-2df6b8d811d5','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-7-il6hdza4wz6y','0a1876ee-7c54-4289-87ce-2df6b8d811d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1110,'7ab489d3-7fa8-4621-81ec-efea831db3fb','7c26f37c-92fe-4dc0-913c-23c04bc68f3e','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig-ContainersCommon-sk5kstuhk6sr','7c26f37c-92fe-4dc0-913c-23c04bc68f3e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1111,'8e50d25c-9ef6-4132-bf96-c25a95209cf7','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:27',NULL,'CREATE','COMPLETE','1','c1a4e430-bcd3-4771-a656-0247a708ddbe','state changed','OS::TripleO::Services::AodhEvaluator',NULL,706),(1112,'26dcb015-c03a-4e58-bc25-2e82abb7c7dc','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1113,'8c416ab3-d039-4742-b88b-09afee36cb95','7c26f37c-92fe-4dc0-913c-23c04bc68f3e','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig-ContainersCommon-sk5kstuhk6sr','7c26f37c-92fe-4dc0-913c-23c04bc68f3e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1114,'7ad4e6de-500f-4fe3-a472-58d7eecf0087','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-CeilometerServiceBase-yylgox5gehir','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,766),(1115,'386f4e24-42cb-4e3a-8c2d-962664bfc2b3','962df6a5-5b06-49ae-85b7-723adde33935','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-CeilometerServiceBase-yylgox5gehir','962df6a5-5b06-49ae-85b7-723adde33935','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1116,'ce894d40-68ad-4436-8139-65ec5ffe879a','962df6a5-5b06-49ae-85b7-723adde33935','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-CeilometerServiceBase-yylgox5gehir','962df6a5-5b06-49ae-85b7-723adde33935','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1117,'243c4f56-7a93-41a2-b6f7-f4363c0723fd','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-RoleParametersValue-yvt5einy3s4d','state changed','OS::Heat::Value',NULL,770),(1118,'2f1b3e54-26f8-44a9-80f5-d06ff23a123d','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','4','d9cf8f5e-fa5d-47ff-997e-1b7360da008a','state changed','OS::TripleO::Services::BootParams',NULL,748),(1119,'34f71587-f8c0-4b6d-b2f3-f9208349934f','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-RoleParametersValue-yvt5einy3s4d','state changed','OS::Heat::Value',NULL,770),(1120,'9a58f57e-5543-47bb-82d1-92bc80d416f2','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','12','dc12b4e0-235f-40e0-912e-40e8cab1a3dd','state changed','OS::TripleO::Services::NovaLibvirt',NULL,682),(1121,'e9703e56-2762-4475-b1f6-466fe3308cb5','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaLogging-bf2h7mvsbtu2','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,773),(1122,'ab279b31-c2ce-4ec0-ade4-e87c636f1b09','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','5','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-5-avv57x5alpny','state changed','OS::TripleO::Services::CACerts',NULL,772),(1123,'849af289-72f3-4eb1-bfc7-91f61cf8063f','7af76ec7-9ae2-40fe-b230-68e241a1cc47','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaLogging-bf2h7mvsbtu2','7af76ec7-9ae2-40fe-b230-68e241a1cc47','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1124,'e5590b02-8e76-4179-bd05-726f3ca64011','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','7','0a1876ee-7c54-4289-87ce-2df6b8d811d5','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,723),(1125,'1818c7dc-485d-44f9-b6ff-14194a653b34','30271a3d-683c-4b6c-ba50-6d3d47b7cb38','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-5-avv57x5alpny','30271a3d-683c-4b6c-ba50-6d3d47b7cb38','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1126,'2a94afa2-4d69-4a08-a33a-d79d47601412','30271a3d-683c-4b6c-ba50-6d3d47b7cb38','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-5-avv57x5alpny','30271a3d-683c-4b6c-ba50-6d3d47b7cb38','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1127,'a3cb173d-81c4-476d-8259-610ea77b9905','7af76ec7-9ae2-40fe-b230-68e241a1cc47','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaLogging-bf2h7mvsbtu2-InitLogContainerName-7v56ca6aou6d','state changed','OS::Heat::Value',NULL,777),(1128,'bcd5529e-472e-4ccb-9a4b-dd9405b85beb','1c569793-808e-4b92-b958-1fa44cbb969e','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig-RoleParametersValue-zq2dhmau2rnb','state changed','OS::Heat::Value',NULL,778),(1129,'2c70579d-3a88-4865-8669-efd1d7aaffaa','7af76ec7-9ae2-40fe-b230-68e241a1cc47','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaLogging-bf2h7mvsbtu2-InitLogContainerName-7v56ca6aou6d','state changed','OS::Heat::Value',NULL,777),(1130,'0d4d463f-114e-4137-826f-be728e12cdeb','1c569793-808e-4b92-b958-1fa44cbb969e','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig-RoleParametersValue-zq2dhmau2rnb','state changed','OS::Heat::Value',NULL,778),(1131,'44c71b0c-40c7-4e98-b643-cfb6762fbff6','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','8','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47','state changed','OS::TripleO::Services::CephClient',NULL,780),(1132,'79847d39-6ae0-4e84-877a-01e3077be58b','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','SshdBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-SshdBase-ol75wtyl7ar2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,784),(1133,'4819537c-549f-4e7f-af70-4ae9cb869830','a8a7782e-d990-4e37-9d50-f828dc0b185c','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-SshdBase-ol75wtyl7ar2','a8a7782e-d990-4e37-9d50-f828dc0b185c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1134,'4ab45f86-4f4d-49fc-b626-38ca572554d7','a8a7782e-d990-4e37-9d50-f828dc0b185c','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-SshdBase-ol75wtyl7ar2','a8a7782e-d990-4e37-9d50-f828dc0b185c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1135,'f2683db2-9633-45ec-8787-7ae3140196f2','1c569793-808e-4b92-b958-1fa44cbb969e','2026-06-13 07:50:28',NULL,'CREATE','COMPLETE','ContainersCommon','7c26f37c-92fe-4dc0-913c-23c04bc68f3e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1136,'878dbfad-8b33-46ee-8bdc-121386f9af1d','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','11','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr','state changed','OS::TripleO::Services::CephMon',NULL,789),(1137,'386a55de-6999-418b-84b7-7e2bc544f2e5','09037b2f-81db-46da-88da-3438a9dfd152','2026-06-13 07:50:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47','09037b2f-81db-46da-88da-3438a9dfd152','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1138,'fa9b3058-1bcd-4b56-99a4-da5a71eca563','1c569793-808e-4b92-b958-1fa44cbb969e','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-17-lja76gjn4iig','1c569793-808e-4b92-b958-1fa44cbb969e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1139,'b7b4c714-5abb-4055-821f-2080d6321ed1','09037b2f-81db-46da-88da-3438a9dfd152','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','CephBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,792),(1140,'4d5b2403-b5ed-4d71-a965-87d6fb182a85','078d2954-17c6-4c08-bc34-0f3c01292827','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr','078d2954-17c6-4c08-bc34-0f3c01292827','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1141,'55c65198-525e-433c-8843-91ee1b239bfb','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-ContainersCommon-doylrcrf43e3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1142,'ba9b29b6-bddb-4d2c-9edf-025841be2d74','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','CeilometerServiceBase','962df6a5-5b06-49ae-85b7-723adde33935','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,766),(1143,'ed387f12-abc3-4d50-8a6d-8f71417f4f1c','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','16','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-16-uoqm5qeh5bmo','state changed','OS::TripleO::Services::Podman',NULL,794),(1144,'bd95280a-9901-4e1e-ad6d-435a77b2fc15','078d2954-17c6-4c08-bc34-0f3c01292827','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','CephBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,795),(1145,'673e0265-4658-4581-8c75-d803bff59a01','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7','79f7372c-0338-4d99-aa93-81d43334a84b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1146,'c09b132d-04c3-4385-9ad9-958f14591cc2','ef4d8c48-a6ef-4ce1-b754-5eca814e485b','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-ContainersCommon-doylrcrf43e3','ef4d8c48-a6ef-4ce1-b754-5eca814e485b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1147,'1af186c3-d7b7-4282-ae0f-47e3389a3b24','ef4d8c48-a6ef-4ce1-b754-5eca814e485b','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-ContainersCommon-doylrcrf43e3','ef4d8c48-a6ef-4ce1-b754-5eca814e485b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1148,'0f1f2336-da08-474e-991f-5081040150d3','a9ee68dc-884a-4fd9-bd1f-6e8f7b63f307','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-16-uoqm5qeh5bmo','a9ee68dc-884a-4fd9-bd1f-6e8f7b63f307','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1149,'46f653a9-e12b-4bac-b89c-647799eff91a','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-CinderNVMeOF-taayj65ipjnz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1150,'fd26e352-ca03-4574-b1e6-5faf41f05812','a9ee68dc-884a-4fd9-bd1f-6e8f7b63f307','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-16-uoqm5qeh5bmo','a9ee68dc-884a-4fd9-bd1f-6e8f7b63f307','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1151,'0834c96f-d48b-4618-8f88-981e46e31174','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','ContainersCommon','ef4d8c48-a6ef-4ce1-b754-5eca814e485b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1152,'e8ecd2d4-8691-4988-98ac-5d819bf87428','5b45d687-a4af-438f-9c61-64b105521571','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-CinderNVMeOF-taayj65ipjnz','5b45d687-a4af-438f-9c61-64b105521571','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1153,'26e50cbf-e032-4904-8d67-8806f53f2b26','5b45d687-a4af-438f-9c61-64b105521571','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-CinderNVMeOF-taayj65ipjnz','5b45d687-a4af-438f-9c61-64b105521571','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1154,'a82cc2ab-d1ee-4de3-b993-c023388b6933','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1155,'bc5902df-0228-4753-8f9b-45370df1f26c','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','ContainerImageUrlParts','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7-ContainerImageUrlParts-hpnn3oid6lvf','state changed','OS::Heat::Value',NULL,796),(1156,'5c361974-5db4-4e4f-83cf-05539891b53e','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','ContainerImageUrlParts','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7-ContainerImageUrlParts-hpnn3oid6lvf','state changed','OS::Heat::Value',NULL,796),(1157,'19c9b520-f3be-4931-81a8-a7abd394549d','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','CephAdmVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7-CephAdmVars-g77fitefbu7w','state changed','OS::Heat::Value',NULL,798),(1158,'b01cff87-247e-42c2-add5-4a12a630e425','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','DefaultCephConfigOverrides','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae-DefaultCephConfigOverrides-asrtak2esfrh','state changed','OS::Heat::Value',NULL,799),(1159,'32b043f0-eb2d-4fea-b73d-5f2e0e7eadc1','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','5','30271a3d-683c-4b6c-ba50-6d3d47b7cb38','state changed','OS::TripleO::Services::CACerts',NULL,772),(1160,'36318023-8d7e-430b-9b55-b45762262b3e','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','DefaultCephConfigOverrides','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae-DefaultCephConfigOverrides-asrtak2esfrh','state changed','OS::Heat::Value',NULL,799),(1161,'6c60522b-ad9e-40f8-a7c6-8b24700a6fe8','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','CephAdmVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7-CephAdmVars-g77fitefbu7w','state changed','OS::Heat::Value',NULL,798),(1162,'1445ec97-be35-40a5-84e4-77cc5ca78b37','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','17','1c569793-808e-4b92-b958-1fa44cbb969e','state changed','OS::TripleO::Services::Rsyslog',NULL,754),(1163,'bc07bce3-1877-4e72-99d3-2824eeaed9d0','7af76ec7-9ae2-40fe-b230-68e241a1cc47','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaLogging-bf2h7mvsbtu2-RoleParametersValue-dvibgfhynppl','state changed','OS::Heat::Value',NULL,800),(1164,'3a3a56bf-abbf-490e-9eee-f98c39cf3ec6','7af76ec7-9ae2-40fe-b230-68e241a1cc47','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaLogging-bf2h7mvsbtu2-RoleParametersValue-dvibgfhynppl','state changed','OS::Heat::Value',NULL,800),(1165,'691d60f9-bd65-4122-b314-c824074d515c','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-ContainersCommon-f7otjswcx5gy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1166,'a43e8e36-dcd0-4b6d-a117-5a6c09b8ab33','7af76ec7-9ae2-40fe-b230-68e241a1cc47','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaLogging-bf2h7mvsbtu2','7af76ec7-9ae2-40fe-b230-68e241a1cc47','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1167,'483b60dd-3bee-4fb7-8dd6-0e4634e5dfc0','aa99114a-4964-45e3-9a01-1016c9f55af9','2026-06-13 07:50:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-ContainersCommon-f7otjswcx5gy','aa99114a-4964-45e3-9a01-1016c9f55af9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1168,'f401d105-f87e-4ac1-b397-68daa02c66d9','aa99114a-4964-45e3-9a01-1016c9f55af9','2026-06-13 07:50:29',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck-ContainersCommon-f7otjswcx5gy','aa99114a-4964-45e3-9a01-1016c9f55af9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1169,'110930db-7c59-4778-a3c1-cf3d9879c627','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','SshdBase','a8a7782e-d990-4e37-9d50-f828dc0b185c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,784),(1170,'4f53c4a6-0bdd-4d4a-a605-8be038e979fd','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','9','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-9-4sshstuzcpxc','state changed','OS::TripleO::Services::CephMds',NULL,805),(1171,'86905fcc-30ce-4303-90c7-bea2327b3090','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','21','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-21-cxlmghjsdgha','state changed','OS::TripleO::Services::Timezone',NULL,806),(1172,'426e53ba-409c-434a-bb40-bdfcfe6051bb','0bdc2e3e-bbe6-4876-a6fa-6db3eee92331','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-9-4sshstuzcpxc','0bdc2e3e-bbe6-4876-a6fa-6db3eee92331','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1173,'28181030-0a76-4e57-810b-211cfe29974c','93bb5e2c-b473-486d-bad7-0e955f12715c','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-21-cxlmghjsdgha','93bb5e2c-b473-486d-bad7-0e955f12715c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1174,'8c6e2bd2-ae15-4cf6-8296-9f4401aed802','0bdc2e3e-bbe6-4876-a6fa-6db3eee92331','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-9-4sshstuzcpxc','0bdc2e3e-bbe6-4876-a6fa-6db3eee92331','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1175,'d2b663ff-2253-4248-b191-444283c4c6e8','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-RoleParametersValue-vwklf63mifxv','state changed','OS::Heat::Value',NULL,807),(1176,'a231abd0-83ba-440a-8814-21e25d9ae3da','93bb5e2c-b473-486d-bad7-0e955f12715c','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-21-cxlmghjsdgha','93bb5e2c-b473-486d-bad7-0e955f12715c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1177,'c3317e37-506f-4ae1-95ac-a6ae51aae7c6','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm-RoleParametersValue-vwklf63mifxv','state changed','OS::Heat::Value',NULL,807),(1178,'0b385d72-41bf-40b3-b85f-87cfe43cec81','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-6-bols7m2dqfdm','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1179,'57d992fd-2589-457e-a5d0-7e6be971f736','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','16','a9ee68dc-884a-4fd9-bd1f-6e8f7b63f307','state changed','OS::TripleO::Services::Podman',NULL,794),(1180,'5fa54180-58a8-407a-b63d-2215c617f48e','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaBase-oyzxqci6c63e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,808),(1181,'c4cf8139-4a64-4a20-b327-8b71f70f8f48','251b8b75-bacc-4d37-9b22-441917375905','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaBase-oyzxqci6c63e','251b8b75-bacc-4d37-9b22-441917375905','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1182,'17ab4994-7394-45a0-878b-e8898ba48df7','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','DefaultCephConfigOverrides','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7-DefaultCephConfigOverrides-5ilwtwp7aao7','state changed','OS::Heat::Value',NULL,809),(1183,'18572aee-8be0-44ad-acb4-5aff1c335788','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','CinderNVMeOF','5b45d687-a4af-438f-9c61-64b105521571','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1184,'a9e4ce88-795a-49a6-8ea6-8cd036e1fd77','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','DefaultCephConfigOverrides','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7-DefaultCephConfigOverrides-5ilwtwp7aao7','state changed','OS::Heat::Value',NULL,809),(1185,'6b373f59-3445-4983-8e87-03d1970d3f11','79f7372c-0338-4d99-aa93-81d43334a84b','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47-CephBase-g4gepxqvslr7','79f7372c-0338-4d99-aa93-81d43334a84b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1186,'631f1bb9-823e-4ae0-8e04-a6990629d854','251b8b75-bacc-4d37-9b22-441917375905','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaBase-oyzxqci6c63e-RoleParametersValue-jgqsbixr4tcm','state changed','OS::Heat::Value',NULL,811),(1187,'a41d2a69-fde3-44f9-b1e4-d3cae4c81a34','251b8b75-bacc-4d37-9b22-441917375905','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaBase-oyzxqci6c63e-RoleParametersValue-jgqsbixr4tcm','state changed','OS::Heat::Value',NULL,811),(1188,'53eb6559-aa6a-48fa-87ef-331f62a4664b','251b8b75-bacc-4d37-9b22-441917375905','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6-NovaBase-oyzxqci6c63e','251b8b75-bacc-4d37-9b22-441917375905','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1189,'9f2216e3-5bba-4bbb-8a5f-7e82e74b7bda','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','NovaLogging','7af76ec7-9ae2-40fe-b230-68e241a1cc47','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,773),(1190,'2399345e-b27a-4d62-bfbc-c338eadda8dc','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','20','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-20-7mt6b7zuupev','state changed','OS::TripleO::Services::Timesync',NULL,812),(1191,'79bb0373-85ff-407f-adda-ca7cdd767aa0','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','ContainerImageUrlParts','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae-ContainerImageUrlParts-5vfonrmzbcvc','state changed','OS::Heat::Value',NULL,813),(1192,'469ed33f-2b7e-4fa2-8045-ead441cf66ae','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','ContainerImageUrlParts','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae-ContainerImageUrlParts-5vfonrmzbcvc','state changed','OS::Heat::Value',NULL,813),(1193,'a8daae70-7aa9-43fe-a469-c2b020903713','1195630b-a142-4a85-99de-6fc89e2ff742','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-20-7mt6b7zuupev','1195630b-a142-4a85-99de-6fc89e2ff742','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1194,'5b9cfce4-a234-4957-b66e-97cfdb302bc5','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:30',NULL,'CREATE','IN_PROGRESS','CephAdmVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae-CephAdmVars-fze365vvju6a','state changed','OS::Heat::Value',NULL,815),(1195,'5dc47f77-93a3-4622-9d4d-804073fcc45b','1195630b-a142-4a85-99de-6fc89e2ff742','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-20-7mt6b7zuupev','1195630b-a142-4a85-99de-6fc89e2ff742','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1196,'03c98bfc-b29e-4a08-b39a-0840097a6f9f','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','CephAdmVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae-CephAdmVars-fze365vvju6a','state changed','OS::Heat::Value',NULL,815),(1197,'2144f1cf-3eed-4ad8-9d43-77d141dd6b0e','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr-CephBase-j2cdfqn4l5ae','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1198,'365606f8-c11d-4f68-a6b4-c9dc96af756a','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:30',NULL,'CREATE','COMPLETE','ContainersCommon','aa99114a-4964-45e3-9a01-1016c9f55af9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1199,'63ff1e1f-cca3-4dc4-af32-eddff79423ae','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-14-x7uz4cvawxck','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1200,'92765a17-757c-41f0-ac8f-796bc501b578','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','6','1cb3bb35-8311-4f89-8922-ca5b0a1709a3','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,763),(1201,'a0cf24b0-022f-441b-824e-a1bd939d6429','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','9','0bdc2e3e-bbe6-4876-a6fa-6db3eee92331','state changed','OS::TripleO::Services::CephMds',NULL,805),(1202,'6337ea51-8a1e-42fc-8d01-ee17d54ea475','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','21','93bb5e2c-b473-486d-bad7-0e955f12715c','state changed','OS::TripleO::Services::Timezone',NULL,806),(1203,'3751916e-2f8d-4909-9cd1-2bab954eade2','09037b2f-81db-46da-88da-3438a9dfd152','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','CephBase','79f7372c-0338-4d99-aa93-81d43334a84b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,792),(1204,'5428581d-ac04-43cc-a59c-cd27397c4084','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','25','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur','state changed','OS::TripleO::Services::OVNController',NULL,819),(1205,'b34d2c90-b4e1-4202-b0a3-62da2f894fe9','09037b2f-81db-46da-88da-3438a9dfd152','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-8-wgwcblg6dl47','09037b2f-81db-46da-88da-3438a9dfd152','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1206,'36d18428-aa48-46c9-9216-7346ce3f246d','078d2954-17c6-4c08-bc34-0f3c01292827','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','CephBase','c0d9f01c-6aaa-4bbd-879c-a2c344d14634','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,795),(1207,'68e27448-fed0-4ecb-b1bc-692ae67693bd','078d2954-17c6-4c08-bc34-0f3c01292827','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-11-n5j7jwlg7ehr','078d2954-17c6-4c08-bc34-0f3c01292827','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1208,'aa1062cb-7a4a-4934-8f99-a3cf6dd823a7','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','NovaBase','251b8b75-bacc-4d37-9b22-441917375905','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,808),(1209,'296b684d-13c9-4524-a295-e978d5ad5008','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','13','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72','state changed','OS::TripleO::Services::CinderBackup',NULL,823),(1210,'0fea0f7c-0175-425e-a1b3-7a4d33dabda0','27d95331-c3f0-49f5-a7da-924505151e57','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-11-wistlnxhkql6','27d95331-c3f0-49f5-a7da-924505151e57','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1211,'895f2394-1ca5-4de1-8128-28164494fc71','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','10','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2','state changed','OS::TripleO::Services::CephMgr',NULL,824),(1212,'98aacd66-2728-4168-aa0e-2a72110abe3d','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur','c8526a80-b607-43f9-8f67-9f10e47df795','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1213,'c879c8a7-968d-48d5-ab05-a5fd2257d1f9','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72','2f17ddc6-eb78-40ab-8074-582f6d03073c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1214,'3bb7959c-adab-4574-bab7-e63c22040f08','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','14','ff97ab56-7218-478c-afa8-1cc7b1b91ab3','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,756),(1215,'2f36e328-18b0-4880-ad87-d7b774c3aa47','1d400a96-494c-41ef-9d4f-07bd019419ec','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2','1d400a96-494c-41ef-9d4f-07bd019419ec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1216,'1a2da281-3e1c-4ab5-ae11-cc1011886d46','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur-RoleParametersValue-rbn6syvlpchr','state changed','OS::Heat::Value',NULL,825),(1217,'ca9bd2db-b612-4a60-881e-5f39e730ff8f','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','20','1195630b-a142-4a85-99de-6fc89e2ff742','state changed','OS::TripleO::Services::Timesync',NULL,812),(1218,'be43050c-a09e-4d3f-901b-60f6961a8185','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur-RoleParametersValue-rbn6syvlpchr','state changed','OS::Heat::Value',NULL,825),(1219,'3cca64ea-7f6b-49c4-8753-98cab83a927b','1d400a96-494c-41ef-9d4f-07bd019419ec','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','CephBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,830),(1220,'bbccc6f9-c1c0-45a4-b8ca-39ef06852c43','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-MySQLClient-mmzad3dw6ocm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1221,'9e91d4f0-6b71-4650-8e78-e8034464039b','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','24','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-24-gt2q3bbft3cq','state changed','OS::TripleO::Services::Tuned',NULL,833),(1222,'32b96607-b89e-43bd-92c2-8d2799ee3d1e','50dfbe1f-e2fa-4e79-98da-c1f4dff8f419','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-MySQLClient-mmzad3dw6ocm','50dfbe1f-e2fa-4e79-98da-c1f4dff8f419','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1223,'37c201d1-4777-40bd-bd04-5d0d03671adf','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','18','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-18-ku3mquqglnkc','state changed','OS::TripleO::Services::Snmp',NULL,832),(1224,'fdfce08e-c055-4e47-965c-ef405d465bf5','470eb082-1378-45cc-a1a2-19596906600d','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-24-gt2q3bbft3cq','470eb082-1378-45cc-a1a2-19596906600d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1225,'e615824e-33da-46dd-8340-11f5b9a0579e','50dfbe1f-e2fa-4e79-98da-c1f4dff8f419','2026-06-13 07:50:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-MySQLClient-mmzad3dw6ocm','50dfbe1f-e2fa-4e79-98da-c1f4dff8f419','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1226,'3ec2f807-d7d2-4f56-95b3-c2b9110be47f','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us','e6078b83-4788-49c1-8a79-05d6db6b2a43','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1227,'eb2cb791-26fe-4cf3-8273-1ff9b3c867a1','470eb082-1378-45cc-a1a2-19596906600d','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-24-gt2q3bbft3cq-RoleParametersValue-6k54hwggmy3f','state changed','OS::Heat::Value',NULL,834),(1228,'6d7e42fc-4050-4914-a531-fb40881bf488','2421fce4-65ec-429a-aeda-10f6009db1d5','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-18-ku3mquqglnkc','2421fce4-65ec-429a-aeda-10f6009db1d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1229,'4d3bb986-8111-46f8-99db-95644174b249','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','8','09037b2f-81db-46da-88da-3438a9dfd152','state changed','OS::TripleO::Services::CephClient',NULL,780),(1230,'39867f44-95fb-4934-92f2-be21146c3ec7','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','ContainerImageUrlParts','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us-ContainerImageUrlParts-6nyce3awy7eq','state changed','OS::Heat::Value',NULL,835),(1231,'f73cf3c4-a8ad-4973-970b-fe3fee6c6daf','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','ContainerImageUrlParts','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us-ContainerImageUrlParts-6nyce3awy7eq','state changed','OS::Heat::Value',NULL,835),(1232,'df22e636-0ea4-4fa3-b43e-fc9434514ea2','470eb082-1378-45cc-a1a2-19596906600d','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-24-gt2q3bbft3cq-RoleParametersValue-6k54hwggmy3f','state changed','OS::Heat::Value',NULL,834),(1233,'3badbddc-29f8-4a7f-b135-57de5944c3ea','2421fce4-65ec-429a-aeda-10f6009db1d5','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-18-ku3mquqglnkc','2421fce4-65ec-429a-aeda-10f6009db1d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1234,'06f1d582-e691-4c36-9c27-835c438c2699','470eb082-1378-45cc-a1a2-19596906600d','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-24-gt2q3bbft3cq','470eb082-1378-45cc-a1a2-19596906600d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1235,'76e12d9d-e931-4489-b9a3-f4550aadafe0','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','CephAdmVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us-CephAdmVars-riqx2htjega4','state changed','OS::Heat::Value',NULL,837),(1236,'10e792bd-38a4-47bd-b20f-5121774a6f58','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','CephAdmVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us-CephAdmVars-riqx2htjega4','state changed','OS::Heat::Value',NULL,837),(1237,'e623f167-8575-4216-9179-0f9d20d0f0c6','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','11','078d2954-17c6-4c08-bc34-0f3c01292827','state changed','OS::TripleO::Services::CephMon',NULL,789),(1238,'436e6ca1-4826-4386-b211-ecc543c44554','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','11','27d95331-c3f0-49f5-a7da-924505151e57','state changed','OS::TripleO::Services::NovaCompute',NULL,733),(1239,'14dd782c-4627-42e4-b1c7-781513e3f8b8','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','12','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie','state changed','OS::TripleO::Services::CinderApi',NULL,846),(1240,'aab96cf2-67f3-47b0-a1c3-bc0d3c53e8f9','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur-ContainersCommon-xzx35ghactsx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1241,'f22138f9-9402-469d-b2cf-ad3073323e15','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','15','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke','state changed','OS::TripleO::Services::CinderVolume',NULL,854),(1242,'9710ac52-3b3d-4ce6-823a-3a96912f0284','b1e28847-1f57-47f8-8c75-d08745d95dbe','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur-ContainersCommon-xzx35ghactsx','b1e28847-1f57-47f8-8c75-d08745d95dbe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1243,'d81bd480-34e6-4d5a-9022-ef6ec4c65355','1d400a96-494c-41ef-9d4f-07bd019419ec','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','CephMgrAnsibleVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephMgrAnsibleVars-4ume2rtphcbn','state changed','OS::Heat::Value',NULL,855),(1244,'11c9429f-b616-4528-bdfd-eb4306565311','1d400a96-494c-41ef-9d4f-07bd019419ec','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','CephMgrAnsibleVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephMgrAnsibleVars-4ume2rtphcbn','state changed','OS::Heat::Value',NULL,855),(1245,'c96af822-ae92-498b-9a8c-b88131658f39','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie','8459f208-d30e-4fd2-93a6-73c52bdd81a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1246,'f026cb8f-0dac-4d1a-9fa2-62f18eff48c4','b1e28847-1f57-47f8-8c75-d08745d95dbe','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur-ContainersCommon-xzx35ghactsx','b1e28847-1f57-47f8-8c75-d08745d95dbe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1247,'67963f47-3753-47a9-8bc7-acb331c3c65a','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','CinderBackupBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,857),(1248,'19e5bb9d-648e-4f36-a793-c897e2639843','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:32',NULL,'CREATE','COMPLETE','MySQLClient','50dfbe1f-e2fa-4e79-98da-c1f4dff8f419','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1249,'6c48b8a7-8891-4a00-bbc1-f04e3956e433','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1250,'7043f55e-868f-45ed-8d75-6dfe95c717b6','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','24','470eb082-1378-45cc-a1a2-19596906600d','state changed','OS::TripleO::Services::Tuned',NULL,833),(1251,'86ee0bec-cba3-4cdf-926a-37c82a22df4d','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','15','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,859),(1252,'8df2fcb6-a203-4935-84a6-cb03b33cae7d','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','18','2421fce4-65ec-429a-aeda-10f6009db1d5','state changed','OS::TripleO::Services::Snmp',NULL,832),(1253,'e6f33c2a-e840-475a-a411-7f8bcced30d1','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3','7e909790-fb81-4dde-83c6-4afea667e4d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1254,'a29e1fa7-afa1-48e6-b404-6b75c2c09de0','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','DefaultCephConfigOverrides','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us-DefaultCephConfigOverrides-7aflb23o4fci','state changed','OS::Heat::Value',NULL,860),(1255,'cfea7ecd-b6b7-4229-bc1f-027dd8549c66','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ApacheServiceBase-dkvq3pjedlmk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,861),(1256,'7711452d-24cf-4e04-91bb-e4f74ad1b05b','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','DefaultCephConfigOverrides','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us-DefaultCephConfigOverrides-7aflb23o4fci','state changed','OS::Heat::Value',NULL,860),(1257,'fc93a499-5a1a-4009-bb3a-f989e9d553b9','800f4e7b-c78d-43b6-be87-24a7fb6c5ec9','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ApacheServiceBase-dkvq3pjedlmk','800f4e7b-c78d-43b6-be87-24a7fb6c5ec9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1258,'b80708ff-9442-439b-be15-1304b630269d','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-RoleParametersValue-bozvolwrutpm','state changed','OS::Heat::Value',NULL,862),(1259,'ccca2901-6869-45c6-a3bf-a1e076704526','3eabf901-e0cf-4235-8779-1b3227701e33','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52','3eabf901-e0cf-4235-8779-1b3227701e33','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1260,'4d94803b-328f-40da-81a1-db7215df42c1','e6078b83-4788-49c1-8a79-05d6db6b2a43','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2-CephBase-uzcsv27oi5us','e6078b83-4788-49c1-8a79-05d6db6b2a43','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1261,'1bc8b608-6b27-4edf-b92c-5075da3a92a7','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-RoleParametersValue-bozvolwrutpm','state changed','OS::Heat::Value',NULL,862),(1262,'d542fca9-dc7f-4951-be77-e9f68ed9339e','800f4e7b-c78d-43b6-be87-24a7fb6c5ec9','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ApacheServiceBase-dkvq3pjedlmk-ApacheNetworks-biojkjbfxizf','state changed','OS::Heat::Value',NULL,864),(1263,'20beb355-19e1-4751-8be1-1d963102d69a','800f4e7b-c78d-43b6-be87-24a7fb6c5ec9','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ApacheServiceBase-dkvq3pjedlmk-ApacheNetworks-biojkjbfxizf','state changed','OS::Heat::Value',NULL,864),(1264,'6441b383-9ba1-45ba-87b4-77d4c47f1b05','3eabf901-e0cf-4235-8779-1b3227701e33','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52-ContainersCommon-gas2ytpyxy2a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1265,'ce656865-f187-4cb0-8e8b-ab66c52620fc','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','22','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-22-petpbbfucmgr','state changed','OS::TripleO::Services::TripleoFirewall',NULL,865),(1266,'d9b67885-c3d2-46ea-96f9-12b3a7e45493','800f4e7b-c78d-43b6-be87-24a7fb6c5ec9','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ApacheServiceBase-dkvq3pjedlmk','800f4e7b-c78d-43b6-be87-24a7fb6c5ec9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1267,'2582550b-d431-4700-9483-61677c4bc534','1ad66a2c-250d-479d-a38a-36372ac33e23','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52-ContainersCommon-gas2ytpyxy2a','1ad66a2c-250d-479d-a38a-36372ac33e23','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1268,'749cc2a5-0735-46ef-bbcc-f2ecf9602b76','2e714555-253e-4b5d-9ba2-3437dc936f66','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-22-petpbbfucmgr','2e714555-253e-4b5d-9ba2-3437dc936f66','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1269,'06f627cb-654f-4dd7-97fb-e01819bef648','1ad66a2c-250d-479d-a38a-36372ac33e23','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52-ContainersCommon-gas2ytpyxy2a','1ad66a2c-250d-479d-a38a-36372ac33e23','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1270,'7c408727-0008-43f6-aed3-9ac55449ffe9','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-RoleParametersValue-c6cayngxygkm','state changed','OS::Heat::Value',NULL,866),(1271,'16ef7ca4-76ae-4397-8bbf-f19a74c47178','2e714555-253e-4b5d-9ba2-3437dc936f66','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-22-petpbbfucmgr-RoleParametersValue-wo2c4gkc5jdj','state changed','OS::Heat::Value',NULL,867),(1272,'9bec7b42-5990-45aa-be0b-c56961444d76','2e714555-253e-4b5d-9ba2-3437dc936f66','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-22-petpbbfucmgr-RoleParametersValue-wo2c4gkc5jdj','state changed','OS::Heat::Value',NULL,867),(1273,'c47498b0-b38b-474b-ad81-a3f95bf41dd9','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-RoleParametersValue-c6cayngxygkm','state changed','OS::Heat::Value',NULL,866),(1274,'cab20f05-d211-46ea-a4cc-d609edb6a033','2e714555-253e-4b5d-9ba2-3437dc936f66','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-22-petpbbfucmgr','2e714555-253e-4b5d-9ba2-3437dc936f66','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1275,'5753d613-734c-4d18-8117-445985ab70fc','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur-OVNBridgeMappingsValue-7zzkpq3gbexu','state changed','OS::Heat::Value',NULL,868),(1276,'b1712274-5d97-40a6-8676-d5fe9c84a55d','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur-OVNBridgeMappingsValue-7zzkpq3gbexu','state changed','OS::Heat::Value',NULL,868),(1277,'f8edb27a-29ea-4b65-8435-989ab2c8b7b3','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','ContainersCommon','b1e28847-1f57-47f8-8c75-d08745d95dbe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1278,'03095828-a209-4ac6-8760-26b8fd0985e3','c8526a80-b607-43f9-8f67-9f10e47df795','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-25-auq7ttaigjur','c8526a80-b607-43f9-8f67-9f10e47df795','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1279,'28987bba-6434-435b-b65e-8787fbe6964a','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-RoleParametersValue-dyd3hcxwkfpe','state changed','OS::Heat::Value',NULL,869),(1280,'b316f73b-27f7-458b-8a33-47058f0195e8','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-RoleParametersValue-dyd3hcxwkfpe','state changed','OS::Heat::Value',NULL,869),(1281,'df2e08e0-cbee-47de-9f9a-e2c81d8c753d','1d400a96-494c-41ef-9d4f-07bd019419ec','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','CephBase','e6078b83-4788-49c1-8a79-05d6db6b2a43','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml',NULL,830),(1282,'1a9ddf72-8716-45a4-821f-0200dff03549','1d400a96-494c-41ef-9d4f-07bd019419ec','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-10-bdnvvioio2x2','1d400a96-494c-41ef-9d4f-07bd019419ec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1283,'19e382ec-1a23-4dc9-a04b-d36cc9bcf668','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-ContainersCommon-l3orardcuj2o','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1284,'c423b799-3b97-4ed5-af2d-dd774da87376','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ContainersCommon-sid6gzsimrvq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1285,'1b46cf60-f516-415b-9b96-2027a772be34','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','ApacheServiceBase','800f4e7b-c78d-43b6-be87-24a7fb6c5ec9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,861),(1286,'6d07ec75-49a9-47a6-8133-30cea6fed326','0161d780-6240-48ff-8bf2-8e26b0d9e770','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ContainersCommon-sid6gzsimrvq','0161d780-6240-48ff-8bf2-8e26b0d9e770','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1287,'e47f63ce-5fb8-4612-aa16-12070d6c8c9f','66a42b64-1d2f-405c-98db-6751e06a9aca','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-ContainersCommon-l3orardcuj2o','66a42b64-1d2f-405c-98db-6751e06a9aca','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1288,'c66fb444-4ec9-4fa6-88b9-6522bd79a6f8','0161d780-6240-48ff-8bf2-8e26b0d9e770','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-ContainersCommon-sid6gzsimrvq','0161d780-6240-48ff-8bf2-8e26b0d9e770','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1289,'2577a13c-f207-46f4-a263-26effe5d1017','66a42b64-1d2f-405c-98db-6751e06a9aca','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-ContainersCommon-l3orardcuj2o','66a42b64-1d2f-405c-98db-6751e06a9aca','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1290,'e047e601-ab8a-4330-b5ff-488adfae1659','3eabf901-e0cf-4235-8779-1b3227701e33','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52-RoleParametersValue-v4en5kyssnyn','state changed','OS::Heat::Value',NULL,870),(1291,'350fd56d-d203-428f-8d70-d6faf76c8127','3eabf901-e0cf-4235-8779-1b3227701e33','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52-RoleParametersValue-v4en5kyssnyn','state changed','OS::Heat::Value',NULL,870),(1292,'c7c68a6b-a4e5-4d19-bf3b-f07d5319df55','3eabf901-e0cf-4235-8779-1b3227701e33','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','ContainersCommon','1ad66a2c-250d-479d-a38a-36372ac33e23','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1293,'b254b353-c7c4-40a0-bb80-33a438616bbc','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','22','2e714555-253e-4b5d-9ba2-3437dc936f66','state changed','OS::TripleO::Services::TripleoFirewall',NULL,865),(1294,'0ce26d5b-8294-4ead-a26d-098a0d65073a','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-ContainersCommon-hazqsdhfy37k','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1295,'4da00de5-d134-4624-b166-a867929bdfdf','3eabf901-e0cf-4235-8779-1b3227701e33','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-15-jdzhomxxbx52','3eabf901-e0cf-4235-8779-1b3227701e33','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1296,'0a630a29-8549-499a-aa5b-85fc45e034f9','3f877527-da43-4c00-9896-961d6e709f28','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-ContainersCommon-hazqsdhfy37k','3f877527-da43-4c00-9896-961d6e709f28','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1297,'cb23fc41-d3a8-4e57-8f78-e0c62f08a034','3f877527-da43-4c00-9896-961d6e709f28','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-ContainersCommon-hazqsdhfy37k','3f877527-da43-4c00-9896-961d6e709f28','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1298,'879fec61-898b-420d-ae10-cfbb94397506','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','26','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,873),(1299,'1a09ff18-99c3-46ad-b9ad-5a4028e0e442','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','10','1d400a96-494c-41ef-9d4f-07bd019419ec','state changed','OS::TripleO::Services::CephMgr',NULL,824),(1300,'ff9223d5-4d57-4402-9e8d-ff9a47c3d281','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf','6e84056d-4aca-4e66-8311-33da24378074','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1301,'9e99680a-be60-4885-aca0-48c306077115','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:34',NULL,'CREATE','COMPLETE','25','c8526a80-b607-43f9-8f67-9f10e47df795','state changed','OS::TripleO::Services::OVNController',NULL,819),(1302,'f9ca5dac-58b5-4705-9d79-11322d96f06b','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-NeutronBase-lj6mu5nrqazh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,874),(1303,'1764cd64-2400-44e5-876d-8eeb2ccad517','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-ContainersCommon-cifofto5qwny','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1304,'44a60ded-6bd3-4589-89e8-0176367d61ee','5607d17b-1df2-4580-b13e-fc6ccc5df562','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-NeutronBase-lj6mu5nrqazh','5607d17b-1df2-4580-b13e-fc6ccc5df562','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1305,'19e32e84-8a07-40d3-8888-c00b06e0ff8e','6edf4a51-1dae-4065-8f07-98be2d1842b5','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-ContainersCommon-cifofto5qwny','6edf4a51-1dae-4065-8f07-98be2d1842b5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1306,'f9548231-9b52-4eef-8ad2-7b2c05115f9c','6edf4a51-1dae-4065-8f07-98be2d1842b5','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-ContainersCommon-cifofto5qwny','6edf4a51-1dae-4065-8f07-98be2d1842b5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1307,'5be1e067-921d-4f4d-bca2-0c0fd4c7e9a2','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1308,'e63d42b8-07ae-43d6-a960-1fd4bb0bf8a0','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-RoleParametersValue-n774zo3gghf3','state changed','OS::Heat::Value',NULL,879),(1309,'8d292a08-0035-4389-a306-04ebaab4975a','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-RoleParametersValue-n774zo3gghf3','state changed','OS::Heat::Value',NULL,879),(1310,'a190f495-4bb4-4cd6-ba92-1f5481f27219','5607d17b-1df2-4580-b13e-fc6ccc5df562','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-NeutronBase-lj6mu5nrqazh','5607d17b-1df2-4580-b13e-fc6ccc5df562','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1311,'202a3314-59e5-4270-af13-0e8ccbc83a17','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','14','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq','state changed','OS::TripleO::Services::CinderScheduler',NULL,880),(1312,'cbea0d5a-afd4-4522-a03d-0846cadf8f6a','f96fe81e-8e03-4d80-becd-3bec817dc1e4','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m','f96fe81e-8e03-4d80-becd-3bec817dc1e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1313,'17e0b18a-66f6-479a-b202-fd88ba573c05','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','ContainersCommon','66a42b64-1d2f-405c-98db-6751e06a9aca','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1314,'4b0c3c0b-6af0-422e-b025-989165813ed4','f96fe81e-8e03-4d80-becd-3bec817dc1e4','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m-ContainersCommon-cik5iq44ndzx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1315,'fdeee409-1e0c-4d65-baa1-5732802fce86','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','ContainersCommon','0161d780-6240-48ff-8bf2-8e26b0d9e770','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1316,'115a2afb-bb01-41af-ab20-40000c7fe1e9','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','15','3eabf901-e0cf-4235-8779-1b3227701e33','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,859),(1317,'0910f87c-85f7-4bdc-9eda-ef06343014c0','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq','53f3f851-1080-44ad-a64c-1e3f6a24cc60','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1318,'727f6718-c601-460c-99a1-a6131be6a76a','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-MySQLClient-pxwsqx6usrf5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1319,'70ae5344-e690-40bf-921a-3192cae9d360','e5690426-63f5-44d2-8c48-7d4ee21c68c6','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m-ContainersCommon-cik5iq44ndzx','e5690426-63f5-44d2-8c48-7d4ee21c68c6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1320,'e4374b43-e29d-4b87-acd5-7b51e03911c9','e5690426-63f5-44d2-8c48-7d4ee21c68c6','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m-ContainersCommon-cik5iq44ndzx','e5690426-63f5-44d2-8c48-7d4ee21c68c6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1321,'503ebdb4-3ddd-45a1-8aea-811b2e9d450f','8f442fda-c794-4166-932c-66dc1ec8b9cc','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-MySQLClient-pxwsqx6usrf5','8f442fda-c794-4166-932c-66dc1ec8b9cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1322,'8f1491ae-a8d0-4920-b188-cfb14a63109e','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','ContainersCommon','3f877527-da43-4c00-9896-961d6e709f28','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1323,'6b580944-84b7-4362-be28-44439e1b386e','8f442fda-c794-4166-932c-66dc1ec8b9cc','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-MySQLClient-pxwsqx6usrf5','8f442fda-c794-4166-932c-66dc1ec8b9cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1324,'5a0c04bd-122c-4480-b902-0f16414a055d','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1325,'f4d18bb9-3c27-4639-9653-630940676b90','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','19','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-19-zslxaeoqtv72','state changed','OS::TripleO::Services::Sshd',NULL,884),(1326,'20233854-bd5b-4b00-8a28-a0e27429b47f','2fc83b15-f93b-43a5-8c38-865d79756136','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf','2fc83b15-f93b-43a5-8c38-865d79756136','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1327,'ea820570-0eae-4bee-8f44-6ffe76512d4e','51a99c71-11e7-4c02-ac57-bbbb48439720','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-19-zslxaeoqtv72','51a99c71-11e7-4c02-ac57-bbbb48439720','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1328,'00403f89-7ad0-4567-aa67-83f85f365240','51a99c71-11e7-4c02-ac57-bbbb48439720','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-19-zslxaeoqtv72','51a99c71-11e7-4c02-ac57-bbbb48439720','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1329,'446b5e89-6634-49a7-bea3-663ac2375b3c','2fc83b15-f93b-43a5-8c38-865d79756136','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf-CinderNVMeOF-oetaqu3yrngd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1330,'3c1a6029-2bc1-4d44-9879-c3743f2c48d3','c4f491c8-8d2c-46ef-a00b-65210eb9a202','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf-CinderNVMeOF-oetaqu3yrngd','c4f491c8-8d2c-46ef-a00b-65210eb9a202','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1331,'7974d807-79b4-4953-83d9-56fb3d83d50b','c4f491c8-8d2c-46ef-a00b-65210eb9a202','2026-06-13 07:50:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf-CinderNVMeOF-oetaqu3yrngd','c4f491c8-8d2c-46ef-a00b-65210eb9a202','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1332,'8b8c78ab-d5c7-4d76-99af-1c2f2de2efa9','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1333,'f02ad7ed-762f-4d6e-9cef-f2fa652108d9','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:35',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-NeutronLogging-5c4rxotwhktp','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,885),(1334,'7ab9b2ad-8885-401a-a65f-cfa2a0f1e7c4','f76ca782-3e5f-4558-ba7d-bd2ba254040d','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-NeutronLogging-5c4rxotwhktp','f76ca782-3e5f-4558-ba7d-bd2ba254040d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1335,'9a62d450-f3af-41c1-89f0-0c985bfeb759','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','NeutronBase','5607d17b-1df2-4580-b13e-fc6ccc5df562','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,874),(1336,'635a5f3e-3a43-44f0-aac9-cb3dbf6472a1','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1337,'b275da75-6c92-4db4-b065-880eb3495d13','f76ca782-3e5f-4558-ba7d-bd2ba254040d','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-NeutronLogging-5c4rxotwhktp','f76ca782-3e5f-4558-ba7d-bd2ba254040d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1338,'9bf562b5-63a8-44c2-9ce5-6c20a8aa9610','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','ContainersCommon','6edf4a51-1dae-4065-8f07-98be2d1842b5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1339,'f29efae2-eaa2-4dd4-afcd-00f1021460b5','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1340,'e665aad2-53a3-4f5e-b664-658964ac0fff','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,886),(1341,'02d0e440-270a-498a-abf3-a2fe447006d4','eff0056a-5db2-4c02-96eb-ddd346f45cdf','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck','eff0056a-5db2-4c02-96eb-ddd346f45cdf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1342,'d1545095-d023-49d3-b24a-1d271820f199','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw-CinderNVMeOF-wv5v53k3cjv2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1343,'a456ae3b-bb9e-4a17-b842-e059ae1c3fa3','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw','18ffdaee-cdb2-4c68-a3e1-551765a84f05','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1344,'1d296006-9993-4ebc-b232-31ef368940b4','3cd9d652-b1b5-43ba-bfbc-df33b7136d92','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw-CinderNVMeOF-wv5v53k3cjv2','3cd9d652-b1b5-43ba-bfbc-df33b7136d92','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1345,'373eff20-9d39-4e85-912a-e4064cc19a7d','eff0056a-5db2-4c02-96eb-ddd346f45cdf','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck-ContainersCommon-qaifbkje3bul','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1346,'db8023b2-726a-4ecb-b97a-0e2715ccec17','f96fe81e-8e03-4d80-becd-3bec817dc1e4','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m-CinderNVMeOF-ms3hsydvi6oq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1347,'461d6c69-4ffb-4bc8-a902-9a0df5f82c98','3cd9d652-b1b5-43ba-bfbc-df33b7136d92','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw-CinderNVMeOF-wv5v53k3cjv2','3cd9d652-b1b5-43ba-bfbc-df33b7136d92','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1348,'3d079792-47fb-44d6-97bf-cdc3099a5ced','d59750b6-5e5e-4086-a85f-a4e20f7de366','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck-ContainersCommon-qaifbkje3bul','d59750b6-5e5e-4086-a85f-a4e20f7de366','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1349,'6530079a-7f33-4b13-84bb-9560fa839108','59376ec2-60c8-4dc2-80d1-ae6e9dea8b88','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m-CinderNVMeOF-ms3hsydvi6oq','59376ec2-60c8-4dc2-80d1-ae6e9dea8b88','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1350,'2a9059e6-a146-4cb3-80b0-16ec8cd406ab','d59750b6-5e5e-4086-a85f-a4e20f7de366','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck-ContainersCommon-qaifbkje3bul','d59750b6-5e5e-4086-a85f-a4e20f7de366','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1351,'fd0e2ca1-fdd2-49f0-b98f-e8cc64ea4367','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderBase-h4dj4gda2iem','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,887),(1352,'55926dc8-9004-4fc1-8cba-d178104a044f','59376ec2-60c8-4dc2-80d1-ae6e9dea8b88','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m-CinderNVMeOF-ms3hsydvi6oq','59376ec2-60c8-4dc2-80d1-ae6e9dea8b88','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1353,'c73036aa-4908-4c7b-92a6-ad4483ee4e52','79c6fdbb-f028-424f-a0a7-6e581c59b55e','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderBase-h4dj4gda2iem','79c6fdbb-f028-424f-a0a7-6e581c59b55e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1354,'75acbc24-669a-488b-967e-eb7dc231df96','f96fe81e-8e03-4d80-becd-3bec817dc1e4','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','ContainersCommon','e5690426-63f5-44d2-8c48-7d4ee21c68c6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1355,'d77eb34c-fef2-4764-b3d2-d834ad08ac7b','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-ContainersCommon-lfse3fes557i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1356,'5c088fed-6c54-4429-92ac-8a38c2c73633','79c6fdbb-f028-424f-a0a7-6e581c59b55e','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderBase-h4dj4gda2iem','79c6fdbb-f028-424f-a0a7-6e581c59b55e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1357,'6ae79db2-eda3-4253-89c1-56cbe154b137','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','MySQLClient','8f442fda-c794-4166-932c-66dc1ec8b9cc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1358,'7dadf113-4edc-4cfa-b355-3f61f70d05b8','6a5e1a8a-947f-4ca6-82c8-cd63e032acd1','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-ContainersCommon-lfse3fes557i','6a5e1a8a-947f-4ca6-82c8-cd63e032acd1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1359,'238e8675-87f3-42a6-aaef-f49b692d9335','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderBase-q2os4bddhqzx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,888),(1360,'f8648bcd-8281-4718-b3fc-5da77d025233','6a5e1a8a-947f-4ca6-82c8-cd63e032acd1','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-ContainersCommon-lfse3fes557i','6a5e1a8a-947f-4ca6-82c8-cd63e032acd1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1361,'d5330250-8985-4765-bf66-22db1d23881b','0417e0e6-2f3d-4b20-8c28-47e668450f58','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderBase-q2os4bddhqzx','0417e0e6-2f3d-4b20-8c28-47e668450f58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1362,'93277402-4f07-4576-8788-a21c13ea3281','0417e0e6-2f3d-4b20-8c28-47e668450f58','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderBase-q2os4bddhqzx','0417e0e6-2f3d-4b20-8c28-47e668450f58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1363,'60a58e27-9179-4426-90e7-fb860b0030d1','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','19','51a99c71-11e7-4c02-ac57-bbbb48439720','state changed','OS::TripleO::Services::Sshd',NULL,884),(1364,'9fbfe1a9-a635-47e8-8de0-fff8b6e82a77','2fc83b15-f93b-43a5-8c38-865d79756136','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf-ContainersCommon-showt34lkmgq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1365,'06c85f7f-1534-4444-a582-3f4a079666c0','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','CinderBase','0417e0e6-2f3d-4b20-8c28-47e668450f58','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,888),(1366,'36e60c09-7b8c-49db-9bc5-3df17ae2dd49','1eb67e25-57ee-483e-a1a1-06b434b47f49','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf-ContainersCommon-showt34lkmgq','1eb67e25-57ee-483e-a1a1-06b434b47f49','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1367,'0af1264a-1dd2-4023-bd88-5e596192441d','1eb67e25-57ee-483e-a1a1-06b434b47f49','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf-ContainersCommon-showt34lkmgq','1eb67e25-57ee-483e-a1a1-06b434b47f49','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1368,'b8214b4c-1abe-4e48-a82e-97f665c260a0','2fc83b15-f93b-43a5-8c38-865d79756136','2026-06-13 07:50:36',NULL,'CREATE','COMPLETE','CinderNVMeOF','c4f491c8-8d2c-46ef-a00b-65210eb9a202','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1369,'b5d27bea-f783-4022-96a1-525523ea2750','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','23','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay','state changed','OS::TripleO::Services::TripleoPackages',NULL,890),(1370,'bd18ad13-0363-4c9e-b737-cb50089d99f6','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-ContainersCommon-rizijmsjmpjo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1371,'282bd1e5-397e-4dc8-9e0c-ab53d77ce606','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','2026-06-13 07:50:36',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1372,'256216c7-b9f3-4834-a495-6e9cebad3208','d947b8db-f01f-41b0-bd1e-c2f26ef23581','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-ContainersCommon-rizijmsjmpjo','d947b8db-f01f-41b0-bd1e-c2f26ef23581','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1373,'ac16a3bb-f6a0-47a3-9235-878125cd71a5','d947b8db-f01f-41b0-bd1e-c2f26ef23581','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-ContainersCommon-rizijmsjmpjo','d947b8db-f01f-41b0-bd1e-c2f26ef23581','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1374,'39e882c6-ddf2-4d4a-905b-36fa82df25ed','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','NeutronLogging','f76ca782-3e5f-4558-ba7d-bd2ba254040d','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,885),(1375,'c94d03fe-58fd-47b7-ab3d-51ba2b3ebff1','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay-Podman-tbvryejbuh5p','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,891),(1376,'b17b4ff5-0733-4674-8026-5d1e4923f27c','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-MySQLClient-4acrp5j5rqqc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1377,'bcc01f42-78d0-4abc-a69b-a65a7d9a1754','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderBase-jzy7sa2wbrtk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,892),(1378,'d4b454cb-3833-43c3-b477-7005225c53c9','ea564934-cca0-4060-ae7b-1ac6daadc3a0','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay-Podman-tbvryejbuh5p','ea564934-cca0-4060-ae7b-1ac6daadc3a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1379,'30244e12-50c7-4928-b9fb-212aae07581f','ea564934-cca0-4060-ae7b-1ac6daadc3a0','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay-Podman-tbvryejbuh5p','ea564934-cca0-4060-ae7b-1ac6daadc3a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1380,'2d7f112c-c975-4cfe-94b0-4b610ec1ebf3','13dbda95-bf5d-420d-897e-5ea4fac917f0','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-MySQLClient-4acrp5j5rqqc','13dbda95-bf5d-420d-897e-5ea4fac917f0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1381,'2190b3ec-fbe7-480e-813e-fdb0868edc42','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw-ContainersCommon-f4nhshgkqke4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1382,'4b85e22e-df7d-44e4-9bfd-4a31c082acca','13dbda95-bf5d-420d-897e-5ea4fac917f0','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-MySQLClient-4acrp5j5rqqc','13dbda95-bf5d-420d-897e-5ea4fac917f0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1383,'8dd6be2b-5abc-4b0b-8305-ea4df409ebab','e6353109-fbe0-4d31-83fc-39feab69ea49','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderBase-jzy7sa2wbrtk','e6353109-fbe0-4d31-83fc-39feab69ea49','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1384,'8f2d5fa7-aff0-4933-98dd-8e1057f0170a','e6353109-fbe0-4d31-83fc-39feab69ea49','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderBase-jzy7sa2wbrtk','e6353109-fbe0-4d31-83fc-39feab69ea49','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1385,'bf859fbc-da11-49ef-8461-8a6f001e20ab','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','CinderBase','e6353109-fbe0-4d31-83fc-39feab69ea49','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,892),(1386,'29a21abd-2d39-4ca4-97cc-2458129c8b5e','9f58979d-30e3-42b8-993d-ccb3671b29a8','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw-ContainersCommon-f4nhshgkqke4','9f58979d-30e3-42b8-993d-ccb3671b29a8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1387,'41bc29f4-8b10-4f69-8a9f-d53c2d6bf5ce','eff0056a-5db2-4c02-96eb-ddd346f45cdf','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck-CinderNVMeOF-y7soxbttkkgg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1388,'430b4be8-2a4b-40fb-bcce-952446005f6f','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','CinderNVMeOF','3cd9d652-b1b5-43ba-bfbc-df33b7136d92','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1389,'70643cd8-759c-42a4-9865-fa1510d458c9','9f58979d-30e3-42b8-993d-ccb3671b29a8','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw-ContainersCommon-f4nhshgkqke4','9f58979d-30e3-42b8-993d-ccb3671b29a8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1390,'3cf2232a-f4d1-496b-a0a0-dfc5fb0b34ac','0ba30607-ed29-41a4-bdf4-909e58b5059b','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck-CinderNVMeOF-y7soxbttkkgg','0ba30607-ed29-41a4-bdf4-909e58b5059b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1391,'098a4359-e2ff-4d5f-ac38-f3839fb8e092','eff0056a-5db2-4c02-96eb-ddd346f45cdf','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','ContainersCommon','d59750b6-5e5e-4086-a85f-a4e20f7de366','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1392,'c3759d4f-3a19-4013-a3fd-05d102622e6a','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1393,'857c0ecd-82c0-43f3-a0eb-b147b3bf19ba','f96fe81e-8e03-4d80-becd-3bec817dc1e4','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','CinderNVMeOF','59376ec2-60c8-4dc2-80d1-ae6e9dea8b88','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1394,'89aaac39-70ed-4763-b26e-912d129741ba','0ba30607-ed29-41a4-bdf4-909e58b5059b','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck-CinderNVMeOF-y7soxbttkkgg','0ba30607-ed29-41a4-bdf4-909e58b5059b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1395,'cb8fd7de-dc03-434a-add8-40bf70b50dc9','f96fe81e-8e03-4d80-becd-3bec817dc1e4','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderCommon-2ie7qme7pf2m','f96fe81e-8e03-4d80-becd-3bec817dc1e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1396,'7a412c73-be2e-4762-8ce6-f7db4dfa200b','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1397,'83215463-0221-4d5e-bacc-7e6370c8926d','765470a8-83e5-4732-85c7-dae5eeb50cf5','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj','765470a8-83e5-4732-85c7-dae5eeb50cf5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1398,'ee007518-608c-49cc-a03d-f327cc18235d','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','CinderBase','79c6fdbb-f028-424f-a0a7-6e581c59b55e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,887),(1399,'f5aeaab4-56ac-4f7f-9ff4-9d243cf65596','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-MySQLClient-psvihncayccn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1400,'d621efb7-7b60-4ea5-9622-386f288c4507','bc503738-5a0c-49ff-9638-d651f888d9ab','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub','bc503738-5a0c-49ff-9638-d651f888d9ab','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1401,'c80d08f5-f9da-4f01-8c9c-7e5a3c67c495','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','ContainersCommon','6a5e1a8a-947f-4ca6-82c8-cd63e032acd1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1402,'5e942fb5-c0d1-4403-a3a0-22913456dcb6','77655fc2-ad92-4e5d-8669-198886608ed1','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-MySQLClient-psvihncayccn','77655fc2-ad92-4e5d-8669-198886608ed1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1403,'a733ccaf-8e3d-45a8-873a-e8ce4a799821','765470a8-83e5-4732-85c7-dae5eeb50cf5','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj-CinderNVMeOF-ooiisfestnk7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1404,'83c513f4-f788-4e72-8081-3013b8f2784e','77655fc2-ad92-4e5d-8669-198886608ed1','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-MySQLClient-psvihncayccn','77655fc2-ad92-4e5d-8669-198886608ed1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1405,'5a6c4c2a-24bd-45c4-b96e-295e9dba3e42','bc503738-5a0c-49ff-9638-d651f888d9ab','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub-CinderNVMeOF-r6itiigo25nm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1406,'f1517f0a-e63f-4430-a0a7-1cbabe014139','f9d37753-476c-4ad2-b6fe-eb53dca23487','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj-CinderNVMeOF-ooiisfestnk7','f9d37753-476c-4ad2-b6fe-eb53dca23487','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1407,'36b69bc8-f391-4b37-b8c9-a8631149fb23','f9d37753-476c-4ad2-b6fe-eb53dca23487','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj-CinderNVMeOF-ooiisfestnk7','f9d37753-476c-4ad2-b6fe-eb53dca23487','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1408,'8b8249da-657a-4070-8f2a-9ce073586e15','912b0708-0efa-4af3-8740-7805b5585ad7','2026-06-13 07:50:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub-CinderNVMeOF-r6itiigo25nm','912b0708-0efa-4af3-8740-7805b5585ad7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1409,'8edc738d-5a85-4337-b81d-0bc834b8daa7','912b0708-0efa-4af3-8740-7805b5585ad7','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub-CinderNVMeOF-r6itiigo25nm','912b0708-0efa-4af3-8740-7805b5585ad7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1410,'7cb65e48-0e0a-43fa-ad3e-31ff7bea1139','2fc83b15-f93b-43a5-8c38-865d79756136','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','ContainersCommon','1eb67e25-57ee-483e-a1a1-06b434b47f49','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1411,'c7a436d1-3917-4035-a226-6def5ad31ead','2fc83b15-f93b-43a5-8c38-865d79756136','2026-06-13 07:50:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-CinderCommon-pdfm2ryvrzlf','2fc83b15-f93b-43a5-8c38-865d79756136','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1412,'dfe0d18a-263d-4097-8b9a-e2167c3bb2d9','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-RoleParametersValue-47z3pcrf77rj','state changed','OS::Heat::Value',NULL,893),(1413,'4d3d79c6-2ce4-40d6-a13b-462271b0dea0','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf-RoleParametersValue-47z3pcrf77rj','state changed','OS::Heat::Value',NULL,893),(1414,'3865cb7d-31fa-4eed-886c-49e39ed7e1c2','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','ContainersCommon','d947b8db-f01f-41b0-bd1e-c2f26ef23581','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1415,'8d1811a9-3cef-472f-9d8c-d0cefa72c5fd','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay-RoleParametersValue-nhi2xmol3wim','state changed','OS::Heat::Value',NULL,894),(1416,'d0a57fff-78d0-413d-8000-5f118ee36620','6e84056d-4aca-4e66-8311-33da24378074','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-26-jquhjzrq6rwf','6e84056d-4aca-4e66-8311-33da24378074','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1417,'bd47bdfe-08ff-4245-9a4b-078400081b5f','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay-RoleParametersValue-nhi2xmol3wim','state changed','OS::Heat::Value',NULL,894),(1418,'636cdd40-10e9-4239-9352-3ee1ce1aa4b7','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-MySQLClient-tgatn6awudlj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1419,'683ac685-cb53-495e-8ff9-2fe058c7566d','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','Podman','ea564934-cca0-4060-ae7b-1ac6daadc3a0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,891),(1420,'9b2de823-459b-49c3-94b8-a8073c750f38','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi-23-xq7bo3k3tsay','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1421,'3cd77692-b7cd-429a-95f1-0c0e99ad23c0','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','MySQLClient','13dbda95-bf5d-420d-897e-5ea4fac917f0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1422,'9641ba06-4fea-4b5d-b33e-888998ad6707','a471a284-907f-455e-8c7c-3b097a139925','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-MySQLClient-tgatn6awudlj','a471a284-907f-455e-8c7c-3b097a139925','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1423,'91e13e82-8ccc-408a-8be8-2498a9d170f3','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','CinderCommon','f96fe81e-8e03-4d80-becd-3bec817dc1e4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1424,'f1f33c4c-a055-42f1-bec1-410bb170e0b9','a471a284-907f-455e-8c7c-3b097a139925','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-MySQLClient-tgatn6awudlj','a471a284-907f-455e-8c7c-3b097a139925','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1425,'3a5bdc25-76f0-417b-8fec-ef318edc8f04','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','ContainersCommon','9f58979d-30e3-42b8-993d-ccb3671b29a8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1426,'986fd616-9a0b-4760-9cd8-d36ce25e19b2','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderCommon-g3vkgbrgu5hw','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1427,'a8eca257-83d8-47a4-a976-cfe2189d2acc','eff0056a-5db2-4c02-96eb-ddd346f45cdf','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','CinderNVMeOF','0ba30607-ed29-41a4-bdf4-909e58b5059b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1428,'a56f4e9b-5b5e-45b4-923d-f2e538d4809f','eff0056a-5db2-4c02-96eb-ddd346f45cdf','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie-CinderCommon-3ceqqxaow5ck','eff0056a-5db2-4c02-96eb-ddd346f45cdf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1429,'837a5809-db68-4af8-9271-eaf28c21fe51','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderBase-adibefa24mgz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,895),(1430,'a0c21fd5-83c3-4c15-9731-e41001e996f9','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-RoleParametersValue-cvoewv757zoi','state changed','OS::Heat::Value',NULL,896),(1431,'23a759a2-d439-44dc-9a40-7cc1deef801f','6906d4b4-a885-4835-820c-713a968073bd','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderBase-adibefa24mgz','6906d4b4-a885-4835-820c-713a968073bd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1432,'6e99e3a4-b6ac-4ad5-a8c7-dae04ca5d7e4','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-RoleParametersValue-cvoewv757zoi','state changed','OS::Heat::Value',NULL,896),(1433,'e3b56fbe-11b5-4704-88ee-bc61e59ab2d4','6906d4b4-a885-4835-820c-713a968073bd','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderBase-adibefa24mgz','6906d4b4-a885-4835-820c-713a968073bd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1434,'25dde7d5-e4f8-44b1-84c8-00c60213267e','765470a8-83e5-4732-85c7-dae5eeb50cf5','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj-ContainersCommon-7qsyskwnkklv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1435,'74250351-569c-4ca3-8fb1-cf91f62e0c6a','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','CinderCommon','2fc83b15-f93b-43a5-8c38-865d79756136','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1436,'b9637cd9-3871-4720-9528-b0834e151ed2','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','MySQLClient','77655fc2-ad92-4e5d-8669-198886608ed1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1437,'94cdadeb-afbf-4b56-813f-4894a1435012','bc503738-5a0c-49ff-9638-d651f888d9ab','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub-ContainersCommon-yujo6nsxqdg3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1438,'51a22130-ce6a-4e11-b58a-4ec06c216610','b1b83712-bec9-44a6-a0b3-fd596443f232','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj-ContainersCommon-7qsyskwnkklv','b1b83712-bec9-44a6-a0b3-fd596443f232','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1439,'b40a4cb8-08e0-4395-a177-e2a5e08d38b2','765470a8-83e5-4732-85c7-dae5eeb50cf5','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','CinderNVMeOF','f9d37753-476c-4ad2-b6fe-eb53dca23487','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1440,'3f3325b7-d9e6-45ac-8285-96b8c5e1b6be','b1b83712-bec9-44a6-a0b3-fd596443f232','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj-ContainersCommon-7qsyskwnkklv','b1b83712-bec9-44a6-a0b3-fd596443f232','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1441,'2a0d1b99-d8a9-4f3e-97cc-61d08300f4cf','cd2ce10e-e2e2-480f-8fa8-61f89c3601b8','2026-06-13 07:50:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub-ContainersCommon-yujo6nsxqdg3','cd2ce10e-e2e2-480f-8fa8-61f89c3601b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1442,'92ff90c6-c220-414e-b063-5af5607a0c09','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','26','6e84056d-4aca-4e66-8311-33da24378074','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,873),(1443,'c2bf0228-e2f0-4492-9772-2ceeb1e09366','bc503738-5a0c-49ff-9638-d651f888d9ab','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','CinderNVMeOF','912b0708-0efa-4af3-8740-7805b5585ad7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1444,'743e0fed-4d22-4cb5-803c-30e3f5d635d4','cd2ce10e-e2e2-480f-8fa8-61f89c3601b8','2026-06-13 07:50:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub-ContainersCommon-yujo6nsxqdg3','cd2ce10e-e2e2-480f-8fa8-61f89c3601b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1445,'9531a35e-28ba-4e8f-aa07-3f94b2f024e6','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','23','cfc468a2-47c4-4c67-945b-e5eb51b0e2aa','state changed','OS::TripleO::Services::TripleoPackages',NULL,890),(1446,'87b43590-a233-41ed-b6d8-b07d2015d078','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceChain-veamxexntfbi','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1447,'e5f154a5-61fc-432e-9328-647feb0e91d4','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','CinderCommon','ac52e7c8-5e2e-46fe-918e-a9d7063760f4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1448,'aea231e8-0742-4206-98c5-9e1df6f637d2','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','CinderCommon','eff0056a-5db2-4c02-96eb-ddd346f45cdf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1449,'efc7001d-c4e4-4619-a546-6ebc3da3bf54','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','MySQLClient','a471a284-907f-455e-8c7c-3b097a139925','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1450,'cdc14d82-ac35-46c3-b738-5aa1883b3e49','8459f208-d30e-4fd2-93a6-73c52bdd81a2','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-12-qu76sdlxxzie','8459f208-d30e-4fd2-93a6-73c52bdd81a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1451,'5d16fb48-9437-4ee7-a9b1-7ce8fe9dae24','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:39',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-MySQLClient-ilhbpkoo7yhr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1452,'c866df97-3eb5-490e-9746-976cede97af8','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:39',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-ContainersCommon-cettisumsw52','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1453,'b61eb8ef-3fdf-4c39-a921-15b49a6ad09a','54a43f25-5265-4fd9-aa66-d63bea9cc954','2026-06-13 07:50:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-MySQLClient-ilhbpkoo7yhr','54a43f25-5265-4fd9-aa66-d63bea9cc954','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1454,'e7e1d703-bd2c-4d5f-9365-abe4fe242a50','54a43f25-5265-4fd9-aa66-d63bea9cc954','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-MySQLClient-ilhbpkoo7yhr','54a43f25-5265-4fd9-aa66-d63bea9cc954','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1455,'aaf18eee-d2c4-4f2e-a801-62b39a7f1f95','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','CinderBase','6906d4b4-a885-4835-820c-713a968073bd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,895),(1456,'5171c250-4e39-49f9-bae0-5b046acaf8c2','1b60ea76-e9ad-4526-a2b2-ff5e871af8f2','2026-06-13 07:50:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-ContainersCommon-cettisumsw52','1b60ea76-e9ad-4526-a2b2-ff5e871af8f2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1457,'6a733cda-ec69-43ca-bfb6-05e53acfae2c','1b60ea76-e9ad-4526-a2b2-ff5e871af8f2','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq-ContainersCommon-cettisumsw52','1b60ea76-e9ad-4526-a2b2-ff5e871af8f2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1458,'c0af9028-6fc5-49f9-ac03-00b9b8cb7633','765470a8-83e5-4732-85c7-dae5eeb50cf5','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','ContainersCommon','b1b83712-bec9-44a6-a0b3-fd596443f232','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1459,'23ee4d41-5b65-4e6e-8766-34f2d6b6fe87','765470a8-83e5-4732-85c7-dae5eeb50cf5','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3-CinderCommon-zx2k5adi7xrj','765470a8-83e5-4732-85c7-dae5eeb50cf5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1460,'7c3dab92-63df-4753-afb9-4c597d7aeb71','bc503738-5a0c-49ff-9638-d651f888d9ab','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','ContainersCommon','cd2ce10e-e2e2-480f-8fa8-61f89c3601b8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1461,'69d67202-a437-4464-b022-4c36416be339','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:39',NULL,'CREATE','COMPLETE','ServiceChain','b77c5c57-9cf1-4e4b-8d87-3bbaaecebea3','state changed','OS::Heat::ResourceChain',NULL,97),(1462,'7240353b-54e5-4fe9-aec1-6f6fce190f37','bc503738-5a0c-49ff-9638-d651f888d9ab','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-CinderCommon-nufft5frrcub','bc503738-5a0c-49ff-9638-d651f888d9ab','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1463,'73c6c717-dae6-4506-9011-488c7146f784','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','12','8459f208-d30e-4fd2-93a6-73c52bdd81a2','state changed','OS::TripleO::Services::CinderApi',NULL,846),(1464,'3d615b70-52ff-4096-b37d-1269a8fe71a3','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:40',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-RoleParametersValue-hyltbr66iofi','state changed','OS::Heat::Value',NULL,914),(1465,'d345ef47-c3c5-4c5d-afea-361705315b19','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw-RoleParametersValue-hyltbr66iofi','state changed','OS::Heat::Value',NULL,914),(1466,'7297a2d4-dbf7-4bc1-bd03-a741c6719846','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:40',NULL,'CREATE','IN_PROGRESS','16','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4','state changed','OS::TripleO::Services::Clustercheck',NULL,915),(1467,'f5490020-71d9-4a2d-a168-f40eb88c796b','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','CinderCommon','765470a8-83e5-4732-85c7-dae5eeb50cf5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1468,'4b1fd742-0ac9-4f10-b59f-f75d36d171b1','7e909790-fb81-4dde-83c6-4afea667e4d4','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72-CinderBackupBase-xp6t7w3igtg3','7e909790-fb81-4dde-83c6-4afea667e4d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1469,'facd8e5d-baca-4bc8-826c-2f01f58bf983','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','MySQLClient','54a43f25-5265-4fd9-aa66-d63bea9cc954','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1470,'94dc5990-6787-4090-9448-785b7d136fe0','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4','f706a375-02c4-43eb-9789-df5d5b831164','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1471,'ba60cf89-0020-4a85-9410-7f9134e75830','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','CinderCommon','bc503738-5a0c-49ff-9638-d651f888d9ab','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1472,'85124a80-4b73-4fab-be86-c6cc2610c4d9','18ffdaee-cdb2-4c68-a3e1-551765a84f05','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke-CinderBase-qa3tncxt2nmw','18ffdaee-cdb2-4c68-a3e1-551765a84f05','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1473,'9bc46834-9faa-4457-9303-a9a790beb95b','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','ContainersCommon','1b60ea76-e9ad-4526-a2b2-ff5e871af8f2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1474,'19aba02d-a861-4572-8ee3-c6e1d5f8d5de','53f3f851-1080-44ad-a64c-1e3f6a24cc60','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-14-oonqxhchfuxq','53f3f851-1080-44ad-a64c-1e3f6a24cc60','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1475,'de17f12a-b9a8-48d4-a919-7fb83c457347','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:40',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-RoleParametersValue-7pnstwjrsogw','state changed','OS::Heat::Value',NULL,920),(1476,'5f548364-5fde-479f-bb4c-2fcc7b43dd43','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:40',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-RoleParametersValue-7pnstwjrsogw','state changed','OS::Heat::Value',NULL,920),(1477,'80912b80-fd47-4dfa-bfb6-bc845d7d9d78','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-IpaRegistrationTasks-yu6puthr44m6','state changed','OS::Heat::Value',NULL,922),(1478,'bf198496-f90f-40a7-98ac-d98015e83b70','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-IpaRegistrationTasks-yu6puthr44m6','state changed','OS::Heat::Value',NULL,922),(1479,'1cb0dc88-4723-4e5a-bae4-ef382c612392','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-MonitoringSubscriptionsConfig-kmwwk3lrj5ia','state changed','OS::Heat::Value',NULL,923),(1480,'c149e5a5-7ab5-4b77-a71a-662252f87be2','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-MonitoringSubscriptionsConfig-kmwwk3lrj5ia','state changed','OS::Heat::Value',NULL,923),(1481,'e7696254-4ca5-4405-8ab1-edc888fdba71','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','CinderBackupBase','7e909790-fb81-4dde-83c6-4afea667e4d4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,857),(1482,'fab1f611-0e66-40fc-9164-636284c51cfb','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DockerConfig-fx5fynp7cimg','state changed','OS::Heat::Value',NULL,924),(1483,'fa3edc14-ea11-45f3-99dd-982541499162','2f17ddc6-eb78-40ab-8074-582f6d03073c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-13-my2onsyocf72','2f17ddc6-eb78-40ab-8074-582f6d03073c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1484,'1e120867-d7e9-4dbc-b5fb-396a395d0029','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DockerConfig-fx5fynp7cimg','state changed','OS::Heat::Value',NULL,924),(1485,'32555389-eb77-4413-b9e7-5980ed6cda75','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PuppetConfig-67thzfo6v2nx','state changed','OS::Heat::Value',NULL,925),(1486,'7aa51398-c198-4113-b9ea-39913714b1f0','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','CinderBase','18ffdaee-cdb2-4c68-a3e1-551765a84f05','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,886),(1487,'0e1a6ffd-9f3c-490a-92f3-e523240a3ccc','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-GlobalConfigSettings-w2tnf4w5lqc7','state changed','OS::Heat::Value',NULL,926),(1488,'dffe3ed2-e917-4739-84b6-ba88755fe420','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PuppetConfig-67thzfo6v2nx','state changed','OS::Heat::Value',NULL,925),(1489,'6073704a-7911-4c4b-b69b-25aae00ebd94','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-15-b6lz7xrotzke','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1490,'5bdfcca7-cd9f-4b2b-9496-a8f8082065c5','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-GlobalConfigSettings-w2tnf4w5lqc7','state changed','OS::Heat::Value',NULL,926),(1491,'bf97bb6f-9999-4bfd-a7a4-ba858ee489d5','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','14','53f3f851-1080-44ad-a64c-1e3f6a24cc60','state changed','OS::TripleO::Services::CinderScheduler',NULL,880),(1492,'6dc470fb-11ed-470d-8bf8-b5b8d79fad6d','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalPostDeployTasks-2nbyws7xe7o3','state changed','OS::Heat::Value',NULL,927),(1493,'2da0fdcb-3771-48ee-b82a-dce575c1d04d','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-HostFirewallTasks-nf3jfnt43ol4','state changed','OS::Heat::Value',NULL,928),(1494,'a4f371b1-b0f9-451d-9a9e-684f59740551','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-HostFirewallTasks-nf3jfnt43ol4','state changed','OS::Heat::Value',NULL,928),(1495,'d40dcd70-9bb0-42f0-9e87-846b5861450c','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ContainerPuppetTasks-43ak3mpzbppr','state changed','OS::Heat::Value',NULL,929),(1496,'dc38e9a4-13c1-4445-8cb1-5913ebcdc914','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','13','2f17ddc6-eb78-40ab-8074-582f6d03073c','state changed','OS::TripleO::Services::CinderBackup',NULL,823),(1497,'1bf3a3b4-dd60-4069-9689-469eb5cdc2ac','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalPostDeployTasks-2nbyws7xe7o3','state changed','OS::Heat::Value',NULL,927),(1498,'75b3ec63-1435-477c-b4a3-32db2e21b393','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-AnsibleGroupVars-apnk52yaqzad','state changed','OS::Heat::Value',NULL,930),(1499,'f2292f67-8ea7-4888-ba2f-d43d283fd1d6','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-AnsibleGroupVars-apnk52yaqzad','state changed','OS::Heat::Value',NULL,930),(1500,'2e1158c4-bf30-4cd2-be5e-1d420bcddc13','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ContainerPuppetTasks-43ak3mpzbppr','state changed','OS::Heat::Value',NULL,929),(1501,'d8c6b8e9-9175-4913-aec2-17d11a073130','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-ContainersCommon-ae7rfhkqcews','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1502,'2a836a9a-c19e-4d72-8d16-41501af209c7','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-UpgradeBatchTasks-xdhb3zmafbuh','state changed','OS::Heat::Value',NULL,934),(1503,'8a71dac9-c0ed-4b44-b7eb-7082088cd353','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-UpgradeBatchTasks-xdhb3zmafbuh','state changed','OS::Heat::Value',NULL,934),(1504,'690a9056-657c-4e0d-b222-39c71947e1cb','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:41',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceServerMetadataHook-otdmfek73kr2','state changed','OS::TripleO::ComputeHCIServiceServerMetadataHook',NULL,NULL),(1505,'55d9af46-cd51-4d27-917c-48e203895734','4709fe60-7976-41aa-b7f0-3a5c9c55bded','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-ContainersCommon-ae7rfhkqcews','4709fe60-7976-41aa-b7f0-3a5c9c55bded','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1506,'390671f7-c165-4087-b910-9747f48ef5e7','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c00bb7c5-fc04-4860-963d-8ab78a700ac1','state changed','OS::TripleO::ComputeHCIServiceServerMetadataHook',NULL,NULL),(1507,'2a29ccf2-c487-4d58-8d8f-112189227bd4','4709fe60-7976-41aa-b7f0-3a5c9c55bded','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-ContainersCommon-ae7rfhkqcews','4709fe60-7976-41aa-b7f0-3a5c9c55bded','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1508,'3576dff7-9853-4695-948b-fee0ff5017b8','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-UpgradeTasks-bwfivsuz4d24','state changed','OS::Heat::Value',NULL,941),(1509,'85ecf6c9-302e-425f-805c-5b52cf744281','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ScaleTasks-cy7vu5fcsb3t','state changed','OS::Heat::Value',NULL,943),(1510,'607295e5-06d8-48b8-baa1-4481d28acaae','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','15','a2245379-84a3-4fd2-ae29-b55f1e71f1aa','state changed','OS::TripleO::Services::CinderVolume',NULL,854),(1511,'afdea334-3688-4ea3-983b-885336936a2d','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-UpgradeTasks-bwfivsuz4d24','state changed','OS::Heat::Value',NULL,941),(1512,'16766cdf-cc42-454a-96d4-be7581f97b4b','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ScaleTasks-cy7vu5fcsb3t','state changed','OS::Heat::Value',NULL,943),(1513,'5e8e17ce-bb41-464c-ac01-a9c181c89745','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceConfigSettings-4c73iwnwgjyg','state changed','OS::Heat::Value',NULL,945),(1514,'34ea7eeb-be1c-4732-a946-229406308252','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceConfigSettings-4c73iwnwgjyg','state changed','OS::Heat::Value',NULL,945),(1515,'5dc6f488-5b38-4a93-a0cf-6e568343f89e','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DockerPuppetTasks-4old64uyiv2q','state changed','OS::Heat::Value',NULL,952),(1516,'683487b7-0306-4949-ac52-5797fb8aa37c','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceNames-aguyolm44rcj','state changed','OS::Heat::Value',NULL,955),(1517,'04e71a44-e5ba-42b0-b6d5-4727386148f1','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ServiceNames-aguyolm44rcj','state changed','OS::Heat::Value',NULL,955),(1518,'b87eed68-9bff-43c1-89c6-466f3d24b956','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DockerPuppetTasks-4old64uyiv2q','state changed','OS::Heat::Value',NULL,952),(1519,'6de51c42-4508-4e75-932d-6831ae0603d0','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalUpdateTasks-7m6mslcrboup','state changed','OS::Heat::Value',NULL,959),(1520,'f8fa1e41-0796-4ba1-993d-7d6a267c7654','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','18','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-18-js7bq2an24hr','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,958),(1521,'c0f133fd-2051-4df3-9ee7-430b0d513618','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalUpdateTasks-7m6mslcrboup','state changed','OS::Heat::Value',NULL,959),(1522,'af0f4585-6776-4004-a967-8f7bc6b03d7a','81c3a574-2542-43cf-886f-97badfe20dfb','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-18-js7bq2an24hr','81c3a574-2542-43cf-886f-97badfe20dfb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1523,'8c0c3fe4-68fd-44fe-8245-3d48b91cf7eb','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PostUpdateTasks-lc4psdohknce','state changed','OS::Heat::Value',NULL,963),(1524,'fe6623af-2782-4cf6-bfb0-b426dc036952','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DockerConfigScripts-pixwni5mppqv','state changed','OS::Heat::Value',NULL,965),(1525,'d51e92cd-34f4-422e-8824-ab1f2bf4255b','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','MysqlPuppetBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,966),(1526,'93cd597c-05a3-49c5-8af0-369e87be1ae7','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DockerConfigScripts-pixwni5mppqv','state changed','OS::Heat::Value',NULL,965),(1527,'a05417a6-ce2a-4102-bda3-78d7bae52396','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PostUpdateTasks-lc4psdohknce','state changed','OS::Heat::Value',NULL,963),(1528,'167fcf31-02e3-4e14-946c-a3a470dcec2d','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:42',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-UpdateTasks-bengovy32gvo','state changed','OS::Heat::Value',NULL,967),(1529,'56a7fa63-5805-456f-89fa-a2e3f766c2f4','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','17','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl','state changed','OS::TripleO::Services::Collectd',NULL,968),(1530,'05f188b7-3974-4095-802e-1169ec122317','81c3a574-2542-43cf-886f-97badfe20dfb','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-18-js7bq2an24hr','81c3a574-2542-43cf-886f-97badfe20dfb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1531,'d582e956-f97d-4f17-b5e4-5157df1e13fd','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1532,'bae551e0-87a9-41a3-ac80-fc7238cd446a','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-UpdateTasks-bengovy32gvo','state changed','OS::Heat::Value',NULL,967),(1533,'abd132b0-298d-453e-aaba-44071243db87','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-FirewallFrontendRules-7y73rcfcntzp','state changed','OS::Heat::Value',NULL,970),(1534,'bf8ce0a1-cbee-4b15-8b34-2559226da8a5','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','ContainersCommon','4709fe60-7976-41aa-b7f0-3a5c9c55bded','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1535,'5aeda7d5-83f5-4ea3-b62f-21fdcc75ee24','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalUpgradeTasks-t3y7yvniso6b','state changed','OS::Heat::Value',NULL,971),(1536,'d09d536e-406d-4073-b11c-528e1264e6e0','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalUpgradeTasks-t3y7yvniso6b','state changed','OS::Heat::Value',NULL,971),(1537,'dfe9f0f1-ef4b-4df0-adfc-cbe21c71f5e6','d1e131dc-f489-4377-8e87-fdce1882ef2b','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl','d1e131dc-f489-4377-8e87-fdce1882ef2b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1538,'385409f9-e254-4a41-88f1-b98a0abd1ee6','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-FirewallFrontendRules-7y73rcfcntzp','state changed','OS::Heat::Value',NULL,970),(1539,'27c836fc-0468-4349-869d-23e8371a78eb','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-MysqlBase-zzevlaax5b4p','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,974),(1540,'415a95a1-4d62-4e6e-acb3-0cb940d6e05a','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DeployStepsTasks-53b62soshyn5','state changed','OS::Heat::Value',NULL,973),(1541,'43b7470a-0305-4c13-bcf9-a7d146804118','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-DeployStepsTasks-53b62soshyn5','state changed','OS::Heat::Value',NULL,973),(1542,'3656400c-2586-4fd0-9a05-a8324ea5e91b','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-FirewallRules-aaqw3ojfi5ox','state changed','OS::Heat::Value',NULL,975),(1543,'faa73c74-e038-49e5-84c9-e675d87f93bf','d1e131dc-f489-4377-8e87-fdce1882ef2b','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl-ContainersCommon-n7cslqyrmirq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1544,'dfe7cf8e-52f5-44e4-9890-6394f144dfb3','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PuppetStepConfig-t2oftnuwvlmg','state changed','OS::Heat::Value',NULL,977),(1545,'f55005e4-7e8a-4327-b19c-9e741e865ace','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PuppetStepConfig-t2oftnuwvlmg','state changed','OS::Heat::Value',NULL,977),(1546,'776780e2-29cb-404e-ad51-1b7cbc2df249','3ac6e8ca-fb84-466a-8036-7e8886aac0bd','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl-ContainersCommon-n7cslqyrmirq','3ac6e8ca-fb84-466a-8036-7e8886aac0bd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1547,'114a45fd-800f-4b2d-b301-cc807a5ed95d','3ac6e8ca-fb84-466a-8036-7e8886aac0bd','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl-ContainersCommon-n7cslqyrmirq','3ac6e8ca-fb84-466a-8036-7e8886aac0bd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1548,'1ad5a178-fa9f-499d-9250-378092b182d3','94748eb9-f73f-4452-a271-e8f0690bc898','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-MysqlBase-zzevlaax5b4p','94748eb9-f73f-4452-a271-e8f0690bc898','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1549,'75b396d1-ed07-4ffd-88cd-a2184e61240d','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-FirewallRules-aaqw3ojfi5ox','state changed','OS::Heat::Value',NULL,975),(1550,'1fe25a2f-5280-49f1-8c3b-510df8f65d5f','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PreDeployStepTasks-qnfhfhl5h36s','state changed','OS::Heat::Value',NULL,980),(1551,'3abdd445-371c-48e3-9b07-89bf4efa5338','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-KeystoneResourcesConfigs-rfing56lmeub','state changed','OS::Heat::Value',NULL,982),(1552,'db11ca05-8737-4a0e-9f39-1d67ed1789e3','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PreDeployStepTasks-qnfhfhl5h36s','state changed','OS::Heat::Value',NULL,980),(1553,'094f1286-207b-49e4-9a9f-2ed79b89ac2e','94748eb9-f73f-4452-a271-e8f0690bc898','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-MysqlBase-zzevlaax5b4p','94748eb9-f73f-4452-a271-e8f0690bc898','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1554,'50ba3fba-aa1d-4cab-8400-5f88eca5b0b5','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-KeystoneResourcesConfigs-rfing56lmeub','state changed','OS::Heat::Value',NULL,982),(1555,'d0db6065-e32a-46ed-a43a-fe759ed44c22','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-HostPrepTasks-w5lknqlowxco','state changed','OS::Heat::Value',NULL,984),(1556,'f46d0fcb-912b-46c2-98b5-ee3f51950bd8','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-KollaConfig-nqx3sixhmvdr','state changed','OS::Heat::Value',NULL,986),(1557,'d200238f-fdb1-4675-8f3b-356624cd70fd','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-HostPrepTasks-w5lknqlowxco','state changed','OS::Heat::Value',NULL,984),(1558,'cf676486-49f2-4ceb-8e3e-163d5484bb62','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','18','81c3a574-2542-43cf-886f-97badfe20dfb','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,958),(1559,'736cd767-40c6-4ecc-8b5d-13fc76d776e3','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:43',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-KollaConfig-nqx3sixhmvdr','state changed','OS::Heat::Value',NULL,986),(1560,'3bca4090-8fdb-42d1-95cf-49f9a1651285','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PostUpgradeTasks-3jgdhzkcle3g','state changed','OS::Heat::Value',NULL,987),(1561,'31b02a23-f217-4860-8c76-47d3dd5e4d41','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PreUpgradeRollingTasks-o3ogabmsbghf','state changed','OS::Heat::Value',NULL,989),(1562,'b5f367b9-3383-44d2-b99d-b9f228491875','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PreUpgradeRollingTasks-o3ogabmsbghf','state changed','OS::Heat::Value',NULL,989),(1563,'baa1b367-e874-4c70-b772-10566aa7e031','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-PostUpgradeTasks-3jgdhzkcle3g','state changed','OS::Heat::Value',NULL,987),(1564,'4ad5e174-f606-44b6-af1f-9e1392bf2706','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalDeployTasks-qfsk32both55','state changed','OS::Heat::Value',NULL,993),(1565,'bd622569-1757-4bc2-bb41-4c8003b49763','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','22','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6','state changed','OS::TripleO::Services::GnocchiMetricd',NULL,994),(1566,'bb01ae84-3f4f-442a-b895-8f0e4999d547','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f-ExternalDeployTasks-qfsk32both55','state changed','OS::Heat::Value',NULL,993),(1567,'e6a65148-8ab5-47f1-837a-a0a5eec572c2','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIServiceChain-skrj7ap5gd5f','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1568,'43d7d949-9a0e-4dee-b907-c43424dce5ee','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-ContainersCommon-idcktv3vky63','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1569,'4aa8c301-b23d-49b0-8d4b-9008bf9c76eb','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6','403da2dd-4c0f-44f8-b992-e93bb61466ba','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1570,'0ebce161-03bf-4f7d-bf61-670b915d24b4','d1e131dc-f489-4377-8e87-fdce1882ef2b','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl-RoleParametersValue-2z3iorp7fsaj','state changed','OS::Heat::Value',NULL,997),(1571,'66c96b4e-767b-4c3b-801c-bb4b8c39473d','691853f1-f4e7-4b36-88d4-51c5531bd9df','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-ContainersCommon-idcktv3vky63','691853f1-f4e7-4b36-88d4-51c5531bd9df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1572,'f41e62e0-c425-4bcb-bdba-b9ff8bc6e9ea','d1e131dc-f489-4377-8e87-fdce1882ef2b','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl-RoleParametersValue-2z3iorp7fsaj','state changed','OS::Heat::Value',NULL,997),(1573,'5c466719-7846-45fb-9b4a-27442998890e','d1e131dc-f489-4377-8e87-fdce1882ef2b','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','ContainersCommon','3ac6e8ca-fb84-466a-8036-7e8886aac0bd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1574,'91defa1b-f03e-41e4-bfeb-044acd2b539d','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','GnocchiServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-GnocchiServiceBase-tnpp3ooupuvi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml',NULL,999),(1575,'1b6522f0-ae22-4eda-a6e3-847bd5943745','d1e131dc-f489-4377-8e87-fdce1882ef2b','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-17-qbvxd4ifo7vl','d1e131dc-f489-4377-8e87-fdce1882ef2b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1576,'e521d5df-036b-4f94-a962-485ba40a5344','7ae08f6d-6b13-48e9-89a5-0465e72bf245','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-GnocchiServiceBase-tnpp3ooupuvi','7ae08f6d-6b13-48e9-89a5-0465e72bf245','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1577,'deeff2c4-893b-4720-b07e-a5630334355e','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','19','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz','state changed','OS::TripleO::Services::GlanceApi',NULL,1000),(1578,'cf579a78-ae11-477e-bfe6-8736aac17087','691853f1-f4e7-4b36-88d4-51c5531bd9df','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-ContainersCommon-idcktv3vky63','691853f1-f4e7-4b36-88d4-51c5531bd9df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1579,'ae798434-a85a-4aef-99c4-a78911dd3c6a','7ae08f6d-6b13-48e9-89a5-0465e72bf245','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-GnocchiServiceBase-tnpp3ooupuvi','7ae08f6d-6b13-48e9-89a5-0465e72bf245','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1580,'e361ba60-c136-484a-b155-35a1040d928f','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz','1094dd60-c5f6-455f-9e26-318ec8842a8d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1581,'56b4f551-492f-4bd3-985d-664d74713810','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','MysqlBase','94748eb9-f73f-4452-a271-e8f0690bc898','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,974),(1582,'b67a63b8-4afa-468e-b198-042cad93103d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','ComputeHCIServiceChain','1cf7ac34-7387-48c7-8b6f-46a8a3f5ba9c','state changed','OS::TripleO::ComputeHCIServices',NULL,86),(1583,'5159810e-7f62-4a1a-8fcd-6ffb0f0dc3a5','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:44',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-RoleParametersValue-47gl2jbdchgn','state changed','OS::Heat::Value',NULL,1002),(1584,'189acfd5-915b-4f93-825f-258bbbbd0c61','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:44',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-RoleParametersValue-47gl2jbdchgn','state changed','OS::Heat::Value',NULL,1002),(1585,'ceb7c52e-5c0c-4996-840f-197cb97726ec','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:45',NULL,'CREATE','COMPLETE','17','d1e131dc-f489-4377-8e87-fdce1882ef2b','state changed','OS::TripleO::Services::Collectd',NULL,968),(1586,'91d3ff69-d174-46ce-a25c-cb40fe0b3132','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-RoleParametersValue-c4vxip3tcjuv','state changed','OS::Heat::Value',NULL,1034),(1587,'10178daa-0794-4a32-b4c9-7efa3a4b5d99','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn-RoleParametersValue-c4vxip3tcjuv','state changed','OS::Heat::Value',NULL,1034),(1588,'a69c08dc-ebb1-4978-8b1e-0ce8925fcd75','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:45',NULL,'CREATE','COMPLETE','ContainersCommon','691853f1-f4e7-4b36-88d4-51c5531bd9df','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1589,'ea3ae1d6-543c-4e02-9ffa-c42bd57c99da','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','2026-06-13 07:50:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4-MysqlPuppetBase-mbpnkjw3rcmn','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1590,'85c9aa1b-bd3a-4a6f-9eb5-ced67e05d785','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-RoleParametersValue-6utaq3zfwu3t','state changed','OS::Heat::Value',NULL,1036),(1591,'679bea04-f4ef-4a34-9088-13e6a8b86c1e','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-RoleParametersValue-6utaq3zfwu3t','state changed','OS::Heat::Value',NULL,1036),(1592,'a028eeb1-17f5-411d-9b68-819fd3ea719b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:45',NULL,'CREATE','IN_PROGRESS','ComputeHCIServiceChainRoleData','overcloud-ComputeHCIServiceChainRoleData-2uu32sfvogqa','state changed','OS::Heat::Value',NULL,1038),(1593,'3a66765b-eaed-4212-ab7e-26c8a43823ac','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:45',NULL,'CREATE','COMPLETE','ComputeHCIServiceChainRoleData','overcloud-ComputeHCIServiceChainRoleData-2uu32sfvogqa','state changed','OS::Heat::Value',NULL,1038),(1594,'c4285ed9-7fe0-41ba-a4e5-bda19daa95ce','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:45',NULL,'CREATE','COMPLETE','GnocchiServiceBase','7ae08f6d-6b13-48e9-89a5-0465e72bf245','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml',NULL,999),(1595,'1ae7e600-943e-41b6-9be3-f4dd43b045c1','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:45',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-ContainersCommon-kbjgfxhfftne','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1596,'bc2863ac-2523-4f66-894d-116e1e848f17','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:45',NULL,'CREATE','IN_PROGRESS','21','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx','state changed','OS::TripleO::Services::GnocchiApi',NULL,1041),(1597,'df01b173-514a-4d31-8065-f290f9c4492b','47c86305-8dbe-4229-9b6b-eb6c20e16c31','2026-06-13 07:50:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-ContainersCommon-kbjgfxhfftne','47c86305-8dbe-4229-9b6b-eb6c20e16c31','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1598,'8b1583b9-4169-4ff5-af59-5d22f1097ea0','47c86305-8dbe-4229-9b6b-eb6c20e16c31','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-ContainersCommon-kbjgfxhfftne','47c86305-8dbe-4229-9b6b-eb6c20e16c31','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1599,'5616f513-29cc-4998-8dd4-9c81972b28ee','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1600,'ac4056d1-d764-4b7e-977a-012babbd2979','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','MysqlPuppetBase','8e6e6ca2-0cde-4fc2-9ccb-eb90a7655580','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,966),(1601,'5bf6f884-e818-4562-bc90-53f50bce31e5','f706a375-02c4-43eb-9789-df5d5b831164','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-16-rdlhkhwvt5i4','f706a375-02c4-43eb-9789-df5d5b831164','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1602,'72d5d7a5-9b1b-42dd-bb28-e9f6b77af0cc','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ApacheServiceBase-uks3lnbakcm2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1042),(1603,'b0e8833a-fad3-4a3f-8a94-2a555e5c01de','089e5437-fc6d-47e9-9d62-fd56b50c9dff','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ApacheServiceBase-uks3lnbakcm2','089e5437-fc6d-47e9-9d62-fd56b50c9dff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1604,'aa5eac8c-4ec2-4474-bb9b-7a03d424a7d0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','ComputeHCIServiceNames','overcloud-ComputeHCIServiceNames-e3wnv22za5z5','state changed','OS::Heat::Value',NULL,1043),(1605,'6e1b5c16-3fc5-4de2-96be-95ca33f4ded2','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','ComputeHCIServiceNames','overcloud-ComputeHCIServiceNames-e3wnv22za5z5','state changed','OS::Heat::Value',NULL,1043),(1606,'c818889c-aed0-4394-ad3c-e83a6c19152e','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-ContainersCommon-jcb2o2xudjr5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1607,'eb8232c9-117d-4698-b8ff-3f11545a806f','089e5437-fc6d-47e9-9d62-fd56b50c9dff','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ApacheServiceBase-uks3lnbakcm2-ApacheNetworks-r3b7utxw6tht','state changed','OS::Heat::Value',NULL,1045),(1608,'0eed7f19-4485-48be-987a-e6292f5d30df','089e5437-fc6d-47e9-9d62-fd56b50c9dff','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ApacheServiceBase-uks3lnbakcm2-ApacheNetworks-r3b7utxw6tht','state changed','OS::Heat::Value',NULL,1045),(1609,'96b14848-a985-4f7e-9eac-c4e974fc6212','089e5437-fc6d-47e9-9d62-fd56b50c9dff','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ApacheServiceBase-uks3lnbakcm2','089e5437-fc6d-47e9-9d62-fd56b50c9dff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1610,'f4298e80-de09-46d3-a704-af7f33391bec','ac17a942-c923-41c4-95f8-7e0a0466aecf','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-ContainersCommon-jcb2o2xudjr5','ac17a942-c923-41c4-95f8-7e0a0466aecf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1611,'dd055632-b83c-472e-b075-2e91ed5ba94c','ac17a942-c923-41c4-95f8-7e0a0466aecf','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-ContainersCommon-jcb2o2xudjr5','ac17a942-c923-41c4-95f8-7e0a0466aecf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1612,'b95dd058-7c6c-401b-977e-fa8753c1a035','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-TLSProxyBase-52sjspxa7wqz','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1613,'6c679a29-cfe6-4bba-8613-29dc55925e97','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','TLSProxyBase','562db0b4-fc8d-48a5-866d-0632e8159db8','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1614,'598ba1a3-1df9-4244-b728-35eb99a75483','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:46',NULL,'CREATE','COMPLETE','16','f706a375-02c4-43eb-9789-df5d5b831164','state changed','OS::TripleO::Services::Clustercheck',NULL,915),(1615,'ecb34407-84b4-470b-a8e4-005bcab67356','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:46',NULL,'CREATE','IN_PROGRESS','ComputeHCI','overcloud-ComputeHCI-n2ieafyllwee','state changed','OS::Heat::ResourceGroup',NULL,1047),(1616,'6fdc01d0-99df-4766-89fd-cde7495d0594','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1617,'9d298dd8-9c21-4607-812d-c64a0da48649','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','ContainersCommon','47c86305-8dbe-4229-9b6b-eb6c20e16c31','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1618,'53bb053a-2cb9-4f1a-b71e-a068d7708735','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1619,'3f06aea6-ccc9-49f2-add9-d5afa2ca4742','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','GnocchiServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-GnocchiServiceBase-w5j3jvvo22j3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml',NULL,1052),(1620,'397f7add-bf9c-4a85-94f0-4948e470d31f','644be819-b474-4f1d-800c-ef8d19108f3c','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-GnocchiServiceBase-w5j3jvvo22j3','644be819-b474-4f1d-800c-ef8d19108f3c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1621,'4344ef75-fd30-4fcd-9082-00230a867cab','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','20','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,1056),(1622,'80e07e92-d016-4215-a560-b59a1afb47c3','644be819-b474-4f1d-800c-ef8d19108f3c','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-GnocchiServiceBase-w5j3jvvo22j3','644be819-b474-4f1d-800c-ef8d19108f3c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1623,'55076dd1-40df-4322-b476-3ea803225728','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-MySQLClient-7g2lj2ib7yjr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1624,'13604e23-96c3-4acf-a923-7f4a1e953c02','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','ApacheServiceBase','089e5437-fc6d-47e9-9d62-fd56b50c9dff','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1042),(1625,'f7394cb1-06bb-4059-b3ad-c74e0079be71','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5','e62d45af-4dc6-4341-88d8-699facae4fab','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1626,'0f034a8b-bac7-4103-be05-594f5ab7bcc2','26d41551-3252-4af7-8f09-2ff030d3a7b1','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-MySQLClient-7g2lj2ib7yjr','26d41551-3252-4af7-8f09-2ff030d3a7b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1627,'353bf065-3d72-431f-aad3-01be6040e1f5','26d41551-3252-4af7-8f09-2ff030d3a7b1','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6-MySQLClient-7g2lj2ib7yjr','26d41551-3252-4af7-8f09-2ff030d3a7b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1628,'4c1b78e3-de2c-469c-bc96-316302ec6f2c','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','ContainersCommon','ac17a942-c923-41c4-95f8-7e0a0466aecf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1629,'13f84487-2992-4e82-a288-afa3c8811fe2','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-MySQLClient-ey2bvykk4rau','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1630,'84b8bf60-a2cb-4093-a07b-7fb6cdf23f8f','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-CinderNVMeOF-tjor4dxb7bkz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1631,'a3fc6579-6846-47a2-8b82-96696899a998','6b7083b9-b940-4208-9e9d-037bd19fa6d0','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-MySQLClient-ey2bvykk4rau','6b7083b9-b940-4208-9e9d-037bd19fa6d0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1632,'b4005588-3245-4d7e-ba39-27ac81eb504b','6b7083b9-b940-4208-9e9d-037bd19fa6d0','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-MySQLClient-ey2bvykk4rau','6b7083b9-b940-4208-9e9d-037bd19fa6d0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1633,'b88b5be8-6ed7-4425-b303-3e68e06f0bc2','083460dd-72b5-4bcc-865c-fc1deefee41d','2026-06-13 07:50:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-CinderNVMeOF-tjor4dxb7bkz','083460dd-72b5-4bcc-865c-fc1deefee41d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1634,'c06d2863-85c6-46ba-b9f1-acad7659031d','083460dd-72b5-4bcc-865c-fc1deefee41d','2026-06-13 07:50:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-CinderNVMeOF-tjor4dxb7bkz','083460dd-72b5-4bcc-865c-fc1deefee41d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1635,'3754a51e-c200-4fdd-a5e4-8a5e5faf91ba','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:48',NULL,'UPDATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1636,'3674987f-db84-4a8c-a677-f378a0b13fc1','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ContainersCommon-pcecb5ehnivm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1637,'c0c6a9e1-4c98-41af-a6e0-17f1a48a037c','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','2','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w','state changed','OS::TripleO::ComputeHCI',NULL,1057),(1638,'0b5b9ae2-259f-485d-a0d3-ddfc9771e259','f4e05165-4aae-43bb-8cd3-6771ec4deb27','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ContainersCommon-pcecb5ehnivm','f4e05165-4aae-43bb-8cd3-6771ec4deb27','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1639,'4034b23d-2fe5-4ac1-9bd6-a32be9eabc64','f4e05165-4aae-43bb-8cd3-6771ec4deb27','2026-06-13 07:50:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-ContainersCommon-pcecb5ehnivm','f4e05165-4aae-43bb-8cd3-6771ec4deb27','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1640,'51107beb-9cf6-4022-9ece-121752e99563','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1641,'479b63f8-d251-431f-84f7-71090c721aee','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:48',NULL,'CREATE','COMPLETE','GnocchiServiceBase','644be819-b474-4f1d-800c-ef8d19108f3c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml',NULL,1052),(1642,'e698e2d0-8380-434a-bd87-e6dcbc1dae23','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:48',NULL,'CREATE','COMPLETE','MySQLClient','26d41551-3252-4af7-8f09-2ff030d3a7b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1643,'8f55ac8d-3dbb-4692-8bb4-944c39f0e137','403da2dd-4c0f-44f8-b992-e93bb61466ba','2026-06-13 07:50:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-22-wpbwzprnyod6','403da2dd-4c0f-44f8-b992-e93bb61466ba','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1644,'6a6777d1-6311-4bde-91af-945f5f3a63a1','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','ComputeHCI','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCI-3vzalbsrl3uk','state changed','OS::TripleO::ComputeHCIServer',NULL,1058),(1645,'89a10b96-51a4-4f9d-a015-4cfb0945cfe7','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceLogging-n7tmwdzywdrc','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1646,'09a8076f-1a01-44a7-a7ef-0c590313eb4f','73350c14-3f67-41a0-9b0c-2d098a4f886f','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCI-3vzalbsrl3uk','73350c14-3f67-41a0-9b0c-2d098a4f886f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1647,'0463c7be-dc20-4d2f-a42c-09d5fbbf41e0','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-GlanceLogging-42bf2excufw5','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1648,'9165c1ae-27de-476d-81aa-5884d07d3568','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:48',NULL,'CREATE','COMPLETE','MySQLClient','6b7083b9-b940-4208-9e9d-037bd19fa6d0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1649,'47b7a120-d52f-4fc1-83e1-7628710fccfb','6a505f69-2031-49ab-8194-9f280e89898f','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceLogging-n7tmwdzywdrc','6a505f69-2031-49ab-8194-9f280e89898f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1650,'d0b67462-11d4-4e03-9856-e7241d4d4cd9','7eb2e81e-995d-4b38-98ee-f90f05ec1a94','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-GlanceLogging-42bf2excufw5','7eb2e81e-995d-4b38-98ee-f90f05ec1a94','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1651,'da530173-92c0-4d9f-97b6-171e687e5068','73350c14-3f67-41a0-9b0c-2d098a4f886f','2026-06-13 07:50:48',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-mputeHCI-3vzalbsrl3uk-deployed-server-ej6feydhvf34','state changed','OS::Heat::DeployedServer',NULL,1059),(1652,'dd958fe1-f5d8-4b3d-8e06-21451840a47d','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:48',NULL,'CREATE','COMPLETE','CinderNVMeOF','083460dd-72b5-4bcc-865c-fc1deefee41d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1653,'321361f0-518b-42ca-920d-53120634d606','6a505f69-2031-49ab-8194-9f280e89898f','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceLogging-n7tmwdzywdrc-RoleParametersValue-zqfxyp2qkzu6','state changed','OS::Heat::Value',NULL,1060),(1654,'f3c54b38-ee0f-45de-84f2-a63b48501bdf','7eb2e81e-995d-4b38-98ee-f90f05ec1a94','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-GlanceLogging-42bf2excufw5-RoleParametersValue-bpzr3txokjzb','state changed','OS::Heat::Value',NULL,1061),(1655,'0f542729-f0eb-4082-b934-eed51b3f9af9','73350c14-3f67-41a0-9b0c-2d098a4f886f','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','deployed-server','067a977c-c526-4227-9e18-7618974b60ad','state changed','OS::Heat::DeployedServer',NULL,1059),(1656,'2babedcb-ef60-4e0a-a8a5-1a3693f1a08d','6a505f69-2031-49ab-8194-9f280e89898f','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceLogging-n7tmwdzywdrc-RoleParametersValue-zqfxyp2qkzu6','state changed','OS::Heat::Value',NULL,1060),(1657,'46f48927-35d7-4ee3-8e3d-ce5b9ae51782','7eb2e81e-995d-4b38-98ee-f90f05ec1a94','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-GlanceLogging-42bf2excufw5-RoleParametersValue-bpzr3txokjzb','state changed','OS::Heat::Value',NULL,1061),(1658,'b11818c6-faba-4d81-94c9-a68abbab1233','7eb2e81e-995d-4b38-98ee-f90f05ec1a94','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-GlanceLogging-42bf2excufw5','7eb2e81e-995d-4b38-98ee-f90f05ec1a94','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1659,'782c6732-5f0d-4fd4-a33b-2a1063ba5064','6a505f69-2031-49ab-8194-9f280e89898f','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceLogging-n7tmwdzywdrc','6a505f69-2031-49ab-8194-9f280e89898f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1660,'0bab881f-5597-47dc-84ab-7be7f6d17be3','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-RoleParametersValue-gzibl3ngt63k','state changed','OS::Heat::Value',NULL,1062),(1661,'f21b79bd-d393-4674-991c-6319e3460587','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-RoleParametersValue-gzibl3ngt63k','state changed','OS::Heat::Value',NULL,1062),(1662,'e6606294-363b-4237-adc5-9691943ef590','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','1','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm','state changed','OS::TripleO::ComputeHCI',NULL,1063),(1663,'f2f9141a-59de-454c-8714-7d3b270d014e','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','ContainersCommon','f4e05165-4aae-43bb-8cd3-6771ec4deb27','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1664,'8996da1e-e018-4fbe-bd15-d2d5a6ab138e','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm','80455355-b7ed-4eb3-9e4e-5322701c9e41','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1665,'3b8ee4eb-af88-46ae-95da-9c922af425f2','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','22','403da2dd-4c0f-44f8-b992-e93bb61466ba','state changed','OS::TripleO::Services::GnocchiMetricd',NULL,994),(1666,'89c946fc-b8b5-4c31-b37b-02009c26e0cd','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-DeploymentActions-vcg5uldxjbnv','state changed','OS::Heat::Value',NULL,1068),(1667,'10cec7ae-6f96-40d6-9db2-43385a4b786c','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-DeploymentActions-vcg5uldxjbnv','state changed','OS::Heat::Value',NULL,1068),(1668,'68f0c8b2-6478-47e3-bae9-b35b80391aff','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-MySQLClient-gijga4md2ecv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1669,'669bf8a0-dbb5-4408-9fb1-b0a3f40cd594','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','GlanceApi','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,1071),(1670,'bea863ad-6861-4705-ab7d-e62593d4f22c','52fd448b-b7f2-4ada-b0ac-888e05726a62','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-MySQLClient-gijga4md2ecv','52fd448b-b7f2-4ada-b0ac-888e05726a62','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1671,'1988a634-11f9-454c-a49f-1b3f24f4b914','52fd448b-b7f2-4ada-b0ac-888e05726a62','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz-MySQLClient-gijga4md2ecv','52fd448b-b7f2-4ada-b0ac-888e05726a62','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1672,'f64927cd-ecf1-4714-ad05-ea9b4b7cc059','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','GlanceLogging','7eb2e81e-995d-4b38-98ee-f90f05ec1a94','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1673,'5488ab16-f0ce-44d5-9aab-14c54cd5b292','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','26','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-26-kwu733gpdmrd','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,1072),(1674,'a73c6aa5-c16a-489f-85c8-adbfc9710ef5','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:49',NULL,'CREATE','COMPLETE','GlanceLogging','6a505f69-2031-49ab-8194-9f280e89898f','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1675,'0eb21415-a1e8-4457-8549-7d9072892a0f','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','ComputeHCI','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCI-iai7d327svop','state changed','OS::TripleO::ComputeHCIServer',NULL,1074),(1676,'b0ee962d-637f-4225-8a3d-471756d20645','73350c14-3f67-41a0-9b0c-2d098a4f886f','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCI-3vzalbsrl3uk-ControlPlanePort-4x2qsip2tpux','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1073),(1677,'3d1f2a2c-b6b8-48d7-98f7-9537214dc11b','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r','5b68e65a-a37e-4f80-a5b0-f4693d93a087','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1678,'caa99733-6f43-4c58-b3a8-abcd504a7175','dd39e8eb-f166-494a-88a0-75ad176c564d','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-26-kwu733gpdmrd','dd39e8eb-f166-494a-88a0-75ad176c564d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1679,'aa416863-8619-429b-97d1-76dbe7c4fdd6','dd39e8eb-f166-494a-88a0-75ad176c564d','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-26-kwu733gpdmrd','dd39e8eb-f166-494a-88a0-75ad176c564d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1680,'252b9372-b598-4d76-ae9e-540bab5f8e80','f1e49968-6579-498d-8c62-1375dabaf5ab','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCI-3vzalbsrl3uk-ControlPlanePort-4x2qsip2tpux','f1e49968-6579-498d-8c62-1375dabaf5ab','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1681,'ee17dbb8-e668-4eb7-a569-c0dae545ef6a','475bb4dd-4463-4547-acda-580eedc1f64a','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCI-iai7d327svop','475bb4dd-4463-4547-acda-580eedc1f64a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1682,'c5c1da8c-1fe5-4c81-8ef5-33c687a6dd46','f1e49968-6579-498d-8c62-1375dabaf5ab','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCI-3vzalbsrl3uk-ControlPlanePort-4x2qsip2tpux','f1e49968-6579-498d-8c62-1375dabaf5ab','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1683,'d4ea4769-9e4a-48a6-9cc6-ff502fb48212','475bb4dd-4463-4547-acda-580eedc1f64a','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCI-iai7d327svop-ControlPlanePort-4w2ka35roj43','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1075),(1684,'34f64768-9327-497e-98a4-87abccd937c0','4506121f-7a69-41f0-a0d3-cd86dd2a4655','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCI-iai7d327svop-ControlPlanePort-4w2ka35roj43','4506121f-7a69-41f0-a0d3-cd86dd2a4655','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1685,'743691a7-d984-4e19-bf87-4a5281e7270f','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-MySQLClient-kthdvoga3jg4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1686,'5aaf5195-833c-4e20-b187-0f6164d8fe86','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-TLSProxyBase-xw7vcrsn7ymc','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1687,'ab45e04e-29b4-4441-9810-55a6b65f70b5','4506121f-7a69-41f0-a0d3-cd86dd2a4655','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCI-iai7d327svop-ControlPlanePort-4w2ka35roj43','4506121f-7a69-41f0-a0d3-cd86dd2a4655','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1688,'13139a64-49f0-4071-93a7-b19b30319724','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','TLSProxyBase','40aa9623-2f59-4f67-b894-705f4c820813','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1689,'471dd739-410d-4c29-ad37-aadb4c11a51e','85097662-1676-4489-844a-a01239a74f79','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-MySQLClient-kthdvoga3jg4','85097662-1676-4489-844a-a01239a74f79','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1690,'48278959-5a0c-455a-8ad0-94d9e89aa3db','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','0','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l','state changed','OS::TripleO::ComputeHCI',NULL,1076),(1691,'c026b16a-9303-4925-bac7-75650c7b2d11','85097662-1676-4489-844a-a01239a74f79','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx-MySQLClient-kthdvoga3jg4','85097662-1676-4489-844a-a01239a74f79','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1692,'e60c37ff-f397-4558-bee3-1a5ccd3d7d2f','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l','55821e71-bee4-4a56-891a-37d4116380a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1693,'8d8e6bf9-8404-4222-b64f-f41a8ce84c2f','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','ComputeHCI','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCI-smzehhqbdlrx','state changed','OS::TripleO::ComputeHCIServer',NULL,1077),(1694,'38d9c55f-f221-4095-b2a0-570232d88db5','4a7d774b-4be6-466c-baea-4aabdab60b5c','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCI-smzehhqbdlrx','4a7d774b-4be6-466c-baea-4aabdab60b5c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1695,'a5466f8b-0925-4b76-8629-7dcbfcb82b53','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-RoleParametersValue-6ky6nxvwcv2p','state changed','OS::Heat::Value',NULL,1078),(1696,'fe3db23a-5fcb-434b-b57e-071a3b1ce569','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-RoleParametersValue-6ky6nxvwcv2p','state changed','OS::Heat::Value',NULL,1078),(1697,'0fd349ff-e43a-4f7a-b755-80550b36a413','4a7d774b-4be6-466c-baea-4aabdab60b5c','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-mputeHCI-smzehhqbdlrx-deployed-server-5o3vtlj5xye4','state changed','OS::Heat::DeployedServer',NULL,1079),(1698,'2db464e0-abb8-4b4f-869c-d0425d9ac931','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','MySQLClient','52fd448b-b7f2-4ada-b0ac-888e05726a62','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1699,'5f74b85c-f844-42c1-b430-19ad430bbdf2','1094dd60-c5f6-455f-9e26-318ec8842a8d','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-19-33gkaze6jhlz','1094dd60-c5f6-455f-9e26-318ec8842a8d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1700,'fdfaff01-37d1-4287-b33a-cd12cc87baec','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:50',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-DeploymentActions-6mwam3yl4rkl','state changed','OS::Heat::Value',NULL,1080),(1701,'49bd969e-477d-4b8c-ab6b-035653445997','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-DeploymentActions-6mwam3yl4rkl','state changed','OS::Heat::Value',NULL,1080),(1702,'bff5e668-2d1a-4bfc-867a-7e45e2f4495d','4a7d774b-4be6-466c-baea-4aabdab60b5c','2026-06-13 07:50:50',NULL,'CREATE','COMPLETE','deployed-server','d3dbe09c-759a-4ebb-8c79-6bd0e98787e1','state changed','OS::Heat::DeployedServer',NULL,1079),(1703,'afccea29-e7af-41a4-9e11-dc8d16f95bf5','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','26','dd39e8eb-f166-494a-88a0-75ad176c564d','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,1072),(1704,'52487098-5f24-4a11-ac9b-6bc707ccb770','73350c14-3f67-41a0-9b0c-2d098a4f886f','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','ControlPlanePort','f1e49968-6579-498d-8c62-1375dabaf5ab','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1073),(1705,'7bf5495c-472e-4cf0-97ea-b81c1c5bcb72','73350c14-3f67-41a0-9b0c-2d098a4f886f','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCI-3vzalbsrl3uk','73350c14-3f67-41a0-9b0c-2d098a4f886f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1706,'e583bc1c-7dcf-42ca-9d08-0be3950fc647','475bb4dd-4463-4547-acda-580eedc1f64a','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-mputeHCI-iai7d327svop-deployed-server-t6yh2dydeu3w','state changed','OS::Heat::DeployedServer',NULL,1082),(1707,'ab8fd987-b43a-4bd7-a8cf-4885f2d3099c','475bb4dd-4463-4547-acda-580eedc1f64a','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','deployed-server','f0325376-07d0-49fb-9625-1dad8a0cec75','state changed','OS::Heat::DeployedServer',NULL,1082),(1708,'15990aec-6322-4f9a-a289-7f258b9f59b0','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-RoleParametersValue-n4yvkqprpxj7','state changed','OS::Heat::Value',NULL,1084),(1709,'8b9b7441-0b90-477d-8fa9-3865768c7159','475bb4dd-4463-4547-acda-580eedc1f64a','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','ControlPlanePort','4506121f-7a69-41f0-a0d3-cd86dd2a4655','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1075),(1710,'05db3a66-60fd-451c-8f40-256d018c096d','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-RoleParametersValue-n4yvkqprpxj7','state changed','OS::Heat::Value',NULL,1084),(1711,'a0077f8e-92ee-4213-94e2-8968abe8e194','475bb4dd-4463-4547-acda-580eedc1f64a','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCI-iai7d327svop','475bb4dd-4463-4547-acda-580eedc1f64a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1712,'d65eb893-996f-4c36-9db0-ebf14dc1b5e9','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','MySQLClient','85097662-1676-4489-844a-a01239a74f79','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1713,'f70ccd05-abc9-4819-8a8c-0d97944b7c8c','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-21-ohdvbvpzxvdx','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1714,'a83b7a09-0ba3-4404-b9cc-af67a1b4a4fc','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','30','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5','state changed','OS::TripleO::Services::Iscsid',NULL,1085),(1715,'a9d39783-3577-4112-81d9-be927a7d6e3d','c9b0a31c-5803-4337-b605-37b7dfaddaa2','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5','c9b0a31c-5803-4337-b605-37b7dfaddaa2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1716,'3d9be32b-6ef5-4d3c-966c-a4a325f71695','c9b0a31c-5803-4337-b605-37b7dfaddaa2','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5-ContainersCommon-js4e75v27ddq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1717,'b382a40c-e2b2-444d-945d-3541437efd8d','d0d869ff-e741-47e8-af79-49d4b70a9043','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5-ContainersCommon-js4e75v27ddq','d0d869ff-e741-47e8-af79-49d4b70a9043','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1718,'948e0bdc-17ea-4530-a82b-00cf8e9df0f3','d0d869ff-e741-47e8-af79-49d4b70a9043','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5-ContainersCommon-js4e75v27ddq','d0d869ff-e741-47e8-af79-49d4b70a9043','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1719,'4eeca115-3f64-4e70-a984-3abc53854b3e','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','19','1094dd60-c5f6-455f-9e26-318ec8842a8d','state changed','OS::TripleO::Services::GlanceApi',NULL,1000),(1720,'cba5f91b-b8e9-48fa-b61d-8b263428fa7d','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-DeploymentActions-qus4jyj2qy5x','state changed','OS::Heat::Value',NULL,1086),(1721,'3012485b-12db-4cb4-9b2f-42f6d1e2fff0','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-DeploymentActions-qus4jyj2qy5x','state changed','OS::Heat::Value',NULL,1086),(1722,'abcd3169-8c10-4a61-aac8-c30f575f291c','4a7d774b-4be6-466c-baea-4aabdab60b5c','2026-06-13 07:50:51',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCI-smzehhqbdlrx-ControlPlanePort-6u4tl5g3l76f','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1091),(1723,'10dd5b59-ebea-43dc-922a-003521762759','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:51',NULL,'CREATE','COMPLETE','ComputeHCI','73350c14-3f67-41a0-9b0c-2d098a4f886f','state changed','OS::TripleO::ComputeHCIServer',NULL,1058),(1724,'c97b0d5d-2ac2-43f0-b6df-a4615a5a01f0','e1d221f6-96f0-4e15-921e-bb69069af691','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCI-smzehhqbdlrx-ControlPlanePort-6u4tl5g3l76f','e1d221f6-96f0-4e15-921e-bb69069af691','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1725,'c19eb87a-ffb9-46ba-8bfd-00084d316cfd','e1d221f6-96f0-4e15-921e-bb69069af691','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCI-smzehhqbdlrx-ControlPlanePort-6u4tl5g3l76f','e1d221f6-96f0-4e15-921e-bb69069af691','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1726,'8a836132-89f3-4e6e-b8f6-095d6c81fd9c','4a7d774b-4be6-466c-baea-4aabdab60b5c','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','ControlPlanePort','e1d221f6-96f0-4e15-921e-bb69069af691','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1091),(1727,'c75faac0-992e-4cb8-ad48-c9dfe84fef5c','4a7d774b-4be6-466c-baea-4aabdab60b5c','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCI-smzehhqbdlrx','4a7d774b-4be6-466c-baea-4aabdab60b5c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1728,'b8241680-e568-43eb-bd6a-9f8903e73be3','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','21','8dceda4f-8dce-4f97-9cc0-9ecb2bb40263','state changed','OS::TripleO::Services::GnocchiApi',NULL,1041),(1729,'8a31a017-6b8b-4871-8ba1-c57d0dfd4727','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','ComputeHCI','475bb4dd-4463-4547-acda-580eedc1f64a','state changed','OS::TripleO::ComputeHCIServer',NULL,1074),(1730,'3ed40a2c-a59d-4604-9b82-fdae152e1b1d','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-MySQLClient-w5pyfhv4zbhe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1731,'c35c4fdb-04f4-4768-a45f-51b23f402906','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','23','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q','state changed','OS::TripleO::Services::GnocchiStatsd',NULL,1098),(1732,'e70038cb-26b1-4723-9b14-911881b6258f','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','ComputeHCIExtraConfigPre','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCIExtraConfigPre-j5oyofvgcvw3','state changed','OS::TripleO::ComputeHCIExtraConfigPre',NULL,1099),(1733,'afa8ec74-0ceb-444f-b55e-c7e0fbbfb545','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StoragePort-a5rt52lutrfx','state changed','OS::TripleO::ComputeHCI::Ports::StoragePort',NULL,1102),(1734,'16dba047-ce90-4656-8dcf-3618a4599d45','174f3a12-7189-4de6-afdf-c90114a63864','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-MySQLClient-w5pyfhv4zbhe','174f3a12-7189-4de6-afdf-c90114a63864','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1735,'2a41e83c-61a9-47ae-8e07-ad97512cfd38','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1736,'5cd51155-b67f-4571-a6fc-baeff335cfca','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-PreNetworkConfig-7lwkptes53dw','state changed','OS::TripleO::ComputeHCI::PreNetworkConfig',NULL,NULL),(1737,'1f11c8c8-0209-40a2-9cd2-843c8cfef786','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NetHostMap-bm4x7aww52u5','state changed','OS::Heat::Value',NULL,1104),(1738,'16497b5b-869c-4c3e-ba3e-4b81583b2656','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StorageMgmtPort-fcflrduh3oi6','state changed','OS::TripleO::ComputeHCI::Ports::StorageMgmtPort',NULL,1103),(1739,'616a5296-dfe7-4fb4-8b3b-88a421522326','174f3a12-7189-4de6-afdf-c90114a63864','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-MySQLClient-w5pyfhv4zbhe','174f3a12-7189-4de6-afdf-c90114a63864','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1740,'4c707eec-04fa-4fd6-bfd8-02370fe6efb8','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NodeTLSCAData-ad3ngqyls3ir','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1741,'a360834b-f9df-425f-b90a-e9e375365233','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-TenantPort-7vsakyddz3ck','state changed','OS::TripleO::ComputeHCI::Ports::TenantPort',NULL,1106),(1742,'ff5b462c-9486-42b8-9337-4b5506d0d318','2685db09-72de-450d-87f0-b43c731cc8fb','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StoragePort-a5rt52lutrfx','2685db09-72de-450d-87f0-b43c731cc8fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1743,'05c0b6f8-d7fc-4ee1-bb29-c02aab15c96c','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NetHostMap-bm4x7aww52u5','state changed','OS::Heat::Value',NULL,1104),(1744,'c03720a8-8c6f-461d-a656-b76e43f5cce1','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-InternalApiPort-7ia25snwl2pe','state changed','OS::TripleO::ComputeHCI::Ports::InternalApiPort',NULL,1108),(1745,'5f04ea14-4d75-440c-8b1b-58ba0b7b294c','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StorageMgmtPort-3oqxj23p66t2','state changed','OS::TripleO::ComputeHCI::Ports::StorageMgmtPort',NULL,1109),(1746,'a8a061b1-7e60-4542-8882-e5453865b233','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','PreNetworkConfig','40fc5970-7fb0-4c92-a6b4-9d8bb4491826','state changed','OS::TripleO::ComputeHCI::PreNetworkConfig',NULL,NULL),(1747,'4f41473c-d198-41be-b00d-95f178807e02','b60d753c-1f48-4e82-a666-7bdd454a0625','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCIExtraConfigPre-j5oyofvgcvw3','b60d753c-1f48-4e82-a666-7bdd454a0625','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1748,'dc385f67-b0ac-4716-9682-548c47e22d9b','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','ComputeHCIExtraConfigPre','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCIExtraConfigPre-2xhpy4nqtjjs','state changed','OS::TripleO::ComputeHCIExtraConfigPre',NULL,1110),(1749,'587ae4b6-81a8-4c1e-99c3-8f42ab5c7f95','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NetHostMap-lnzw2fy66jzx','state changed','OS::Heat::Value',NULL,1112),(1750,'53b550ee-d801-4698-912d-fda057784307','3b2f15c0-d03b-404e-a133-aafb0aa05002','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-InternalApiPort-7ia25snwl2pe','3b2f15c0-d03b-404e-a133-aafb0aa05002','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1751,'0bf0bde3-4779-49aa-90d7-9f4c90ff022a','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-PreNetworkConfig-r3nckq42upsc','state changed','OS::TripleO::ComputeHCI::PreNetworkConfig',NULL,NULL),(1752,'9b1451d3-8430-42d5-809b-6a6ba82257b0','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','ComputeHCIAnsibleHostVars','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCIAnsibleHostVars-nbqgdtlkfqzv','state changed','OS::Heat::Value',NULL,1113),(1753,'b90fcddc-4667-4d64-bcb1-2f67070810c1','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','NodeTLSCAData','c2e9e281-6d9c-445f-baaa-ec01acf1c3b2','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1754,'e656b9e5-8b72-4cb0-9c91-2a990b9cf93c','ae7fc3c5-1c8a-45b8-82f2-5cb86122682e','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StorageMgmtPort-fcflrduh3oi6','ae7fc3c5-1c8a-45b8-82f2-5cb86122682e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1755,'d37a8385-0dbd-41a1-9e0e-28df6dd9daf1','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NetHostMap-lnzw2fy66jzx','state changed','OS::Heat::Value',NULL,1112),(1756,'41c8d5f0-972f-4691-88b5-4da2e7bfa6b7','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NodeTLSCAData-5weuuznqlpg2','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1757,'742666e4-8d73-42c1-b9c5-386d4aeec3d3','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-TenantPort-jy2g4h4xd4vo','state changed','OS::TripleO::ComputeHCI::Ports::TenantPort',NULL,1116),(1758,'2bd1a4b8-457d-47ab-ad91-75e711572e66','2685db09-72de-450d-87f0-b43c731cc8fb','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StoragePort-a5rt52lutrfx-StorageDeployedPort-mkwai35ukxjh','state changed','OS::Heat::Value',NULL,1117),(1759,'d85ba350-8935-4772-9b16-d5669389307a','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','ComputeHCIAnsibleHostVars','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCIAnsibleHostVars-nbqgdtlkfqzv','state changed','OS::Heat::Value',NULL,1113),(1760,'ed319a72-b16a-4fb7-9f1a-51fbbc54f662','2685db09-72de-450d-87f0-b43c731cc8fb','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StoragePort-a5rt52lutrfx-StorageDeployedPort-mkwai35ukxjh','state changed','OS::Heat::Value',NULL,1117),(1761,'363714df-6d86-416d-8913-a44c1dbccc08','c9b0a31c-5803-4337-b605-37b7dfaddaa2','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5-RoleParametersValue-olvwjvv5buc6','state changed','OS::Heat::Value',NULL,1120),(1762,'dcaf236c-da54-4d4b-9d82-1226b378859a','b60d753c-1f48-4e82-a666-7bdd454a0625','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-ComputeHCIExtraConfigPre-j5oyofvgcvw3','b60d753c-1f48-4e82-a666-7bdd454a0625','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1763,'7c20905a-d2ae-4282-aacd-a05cdfa3ba0f','a26b4cd3-8bf5-41f0-b00f-b1a3d2158b34','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-TenantPort-7vsakyddz3ck','a26b4cd3-8bf5-41f0-b00f-b1a3d2158b34','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1764,'97c80bad-cb94-4cce-88d0-38c87ed8b1b5','c514c79c-4fc6-461c-8d19-40363fdfbd55','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCIExtraConfigPre-2xhpy4nqtjjs','c514c79c-4fc6-461c-8d19-40363fdfbd55','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1765,'4629a639-60f2-42b6-ae9a-386aef1a894b','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StoragePort-oc5j5shgsepc','state changed','OS::TripleO::ComputeHCI::Ports::StoragePort',NULL,1118),(1766,'0ac82d13-2c1d-4ef0-a239-233ad3d23a27','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','NodeTLSCAData','bfb0eabb-2795-409a-88c4-a29dc21a2c8a','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1767,'104252ee-2ca7-48ff-b893-a6cdc2b11d0e','e45d54ec-aa84-49ee-9481-e34454f26d1b','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StorageMgmtPort-3oqxj23p66t2','e45d54ec-aa84-49ee-9481-e34454f26d1b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1768,'18378687-ef2d-45de-9279-935bcb2c3a42','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','ComputeHCIAnsibleHostVars','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCIAnsibleHostVars-ykns4k4iqwpy','state changed','OS::Heat::Value',NULL,1123),(1769,'cbdf5f74-349a-4e53-ae52-7b7e426281ed','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-InternalApiPort-uhh4neoepl7t','state changed','OS::TripleO::ComputeHCI::Ports::InternalApiPort',NULL,1121),(1770,'8582988e-3284-4a7d-b8e6-43074d20a7bf','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','PreNetworkConfig','752374f1-0c6a-4cd9-acd5-533e2f971640','state changed','OS::TripleO::ComputeHCI::PreNetworkConfig',NULL,NULL),(1771,'928f0d1e-2275-41e9-9d40-3528798ff98e','c9b0a31c-5803-4337-b605-37b7dfaddaa2','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5-RoleParametersValue-olvwjvv5buc6','state changed','OS::Heat::Value',NULL,1120),(1772,'ba56aac0-4cc3-4c0f-9c27-aca4503aeb76','2685db09-72de-450d-87f0-b43c731cc8fb','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StoragePort-a5rt52lutrfx','2685db09-72de-450d-87f0-b43c731cc8fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1773,'933eb75c-8a08-46c2-83e7-17d01b00423c','3b2f15c0-d03b-404e-a133-aafb0aa05002','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-InternalApiPort-7ia25snwl2pe-InternalApiDeployedPort-duf5e7ndpfef','state changed','OS::Heat::Value',NULL,1125),(1774,'3119f99f-f256-4808-80c2-f10529f83cdd','c9b0a31c-5803-4337-b605-37b7dfaddaa2','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','ContainersCommon','d0d869ff-e741-47e8-af79-49d4b70a9043','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1775,'4174e477-b689-4ed8-b967-0a2b400118c9','0514db89-0176-4067-a65c-d0e8405656ed','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-TenantPort-jy2g4h4xd4vo','0514db89-0176-4067-a65c-d0e8405656ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1776,'d0df1734-0eed-452e-ac16-bac376749ad1','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','ComputeHCIAnsibleHostVars','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCIAnsibleHostVars-ykns4k4iqwpy','state changed','OS::Heat::Value',NULL,1123),(1777,'974f40d8-2316-4175-9f2e-3f610252a2b6','c514c79c-4fc6-461c-8d19-40363fdfbd55','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-ComputeHCIExtraConfigPre-2xhpy4nqtjjs','c514c79c-4fc6-461c-8d19-40363fdfbd55','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1778,'bb4dfc3c-3cf7-4e3e-a042-ea2b7efeb373','3b2f15c0-d03b-404e-a133-aafb0aa05002','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-InternalApiPort-7ia25snwl2pe-InternalApiDeployedPort-duf5e7ndpfef','state changed','OS::Heat::Value',NULL,1125),(1779,'c27fe5b1-34c0-4770-82fb-139b1c82fca1','a26b4cd3-8bf5-41f0-b00f-b1a3d2158b34','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-TenantPort-7vsakyddz3ck-TenantDeployedPort-ggieqavaomtw','state changed','OS::Heat::Value',NULL,1126),(1780,'75293d1a-218a-4c97-af77-bb88fbf5c6f8','3b2f15c0-d03b-404e-a133-aafb0aa05002','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-InternalApiPort-7ia25snwl2pe','3b2f15c0-d03b-404e-a133-aafb0aa05002','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1781,'5ebf54c0-a41d-4d4a-85da-87439323684e','c9b0a31c-5803-4337-b605-37b7dfaddaa2','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-30-s5gx5w5nmmx5','c9b0a31c-5803-4337-b605-37b7dfaddaa2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1782,'c3652207-9761-4f0c-91e5-c808ec7de70e','13756d74-83bb-420c-b582-7b33c35c99e3','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StoragePort-oc5j5shgsepc','13756d74-83bb-420c-b582-7b33c35c99e3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1783,'9dd29ec6-c9ea-4302-a890-0d80a6d23793','a26b4cd3-8bf5-41f0-b00f-b1a3d2158b34','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-TenantPort-7vsakyddz3ck-TenantDeployedPort-ggieqavaomtw','state changed','OS::Heat::Value',NULL,1126),(1784,'92ec4a5f-1463-4f87-9b3f-cde1093e65e1','a26b4cd3-8bf5-41f0-b00f-b1a3d2158b34','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-TenantPort-7vsakyddz3ck','a26b4cd3-8bf5-41f0-b00f-b1a3d2158b34','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1785,'06285ab6-1d5a-4661-93c6-29628c837044','814ecf15-13bb-4c3b-a05e-a780bc4d450b','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-InternalApiPort-uhh4neoepl7t','814ecf15-13bb-4c3b-a05e-a780bc4d450b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1786,'a68a5984-0d48-47b2-888d-cc331f3a0ed7','0514db89-0176-4067-a65c-d0e8405656ed','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-TenantPort-jy2g4h4xd4vo-TenantDeployedPort-4qmajazan4o5','state changed','OS::Heat::Value',NULL,1128),(1787,'e53128b0-2668-41ae-987e-a1e97e0848cb','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-MySQLClient-qfwphc5h7sds','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1788,'d2bf00b5-1604-4a09-bfd0-e58d4d64a26b','0514db89-0176-4067-a65c-d0e8405656ed','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-TenantPort-jy2g4h4xd4vo-TenantDeployedPort-4qmajazan4o5','state changed','OS::Heat::Value',NULL,1128),(1789,'8eda70b9-193f-4148-becc-a61f81be5418','814ecf15-13bb-4c3b-a05e-a780bc4d450b','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-InternalApiPort-uhh4neoepl7t-InternalApiDeployedPort-hhb6yecmr6fb','state changed','OS::Heat::Value',NULL,1130),(1790,'3bf74a0c-7b5a-4cc1-81cb-7f78d3497c9d','814ecf15-13bb-4c3b-a05e-a780bc4d450b','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-InternalApiPort-uhh4neoepl7t-InternalApiDeployedPort-hhb6yecmr6fb','state changed','OS::Heat::Value',NULL,1130),(1791,'6ff20e5f-995b-4a0c-927b-3839cf1581b7','0514db89-0176-4067-a65c-d0e8405656ed','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-TenantPort-jy2g4h4xd4vo','0514db89-0176-4067-a65c-d0e8405656ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1792,'bbbba6b3-3b91-4059-a3d9-72abd97cb022','814ecf15-13bb-4c3b-a05e-a780bc4d450b','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-InternalApiPort-uhh4neoepl7t','814ecf15-13bb-4c3b-a05e-a780bc4d450b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1793,'c8b44355-371e-4787-bffa-bf6b0c771d38','13756d74-83bb-420c-b582-7b33c35c99e3','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StoragePort-oc5j5shgsepc-StorageDeployedPort-q5ijt33t3asn','state changed','OS::Heat::Value',NULL,1132),(1794,'187e73b7-9787-4422-b9ed-eaa1a77d89bf','ae7fc3c5-1c8a-45b8-82f2-5cb86122682e','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StorageMgmtPort-fcflrduh3oi6-StorageMgmtDeployedPort-y3pgmxgkc7lr','state changed','OS::Heat::Value',NULL,1131),(1795,'36493d37-3eca-44ff-968f-a05caf278cd2','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','ComputeHCI','4a7d774b-4be6-466c-baea-4aabdab60b5c','state changed','OS::TripleO::ComputeHCIServer',NULL,1077),(1796,'c11423bc-5bbe-438e-af03-7c98806f95f9','13756d74-83bb-420c-b582-7b33c35c99e3','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StoragePort-oc5j5shgsepc-StorageDeployedPort-q5ijt33t3asn','state changed','OS::Heat::Value',NULL,1132),(1797,'f0c206a0-4e63-48ea-a532-8df915d1fe7f','18463d3f-1821-4329-88e6-f5513e4a81ee','2026-06-13 07:50:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-MySQLClient-qfwphc5h7sds','18463d3f-1821-4329-88e6-f5513e4a81ee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1798,'ddbc2c73-d6af-4f87-9d88-ad3079fd42ff','ae7fc3c5-1c8a-45b8-82f2-5cb86122682e','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StorageMgmtPort-fcflrduh3oi6-StorageMgmtDeployedPort-y3pgmxgkc7lr','state changed','OS::Heat::Value',NULL,1131),(1799,'93b687da-24c2-4504-9bff-ef4c89588294','13756d74-83bb-420c-b582-7b33c35c99e3','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StoragePort-oc5j5shgsepc','13756d74-83bb-420c-b582-7b33c35c99e3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1800,'fe1215a6-9e76-416d-a197-45c8c3b9c05b','18463d3f-1821-4329-88e6-f5513e4a81ee','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-MySQLClient-qfwphc5h7sds','18463d3f-1821-4329-88e6-f5513e4a81ee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1801,'beb1cab6-9eb5-40fe-9e87-ab6d483cad9e','ae7fc3c5-1c8a-45b8-82f2-5cb86122682e','2026-06-13 07:50:52',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-StorageMgmtPort-fcflrduh3oi6','ae7fc3c5-1c8a-45b8-82f2-5cb86122682e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1802,'fd376927-7d3c-47b8-9feb-20f5fc0032e2','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','25','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj','state changed','OS::TripleO::Services::HeatApi',NULL,1133),(1803,'1f5e0fef-c2e5-4aa5-abc6-d25853ae0968','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','MySQLClient','18463d3f-1821-4329-88e6-f5513e4a81ee','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1804,'4d580e97-f4a0-486f-be19-ad23157b4a2c','e45d54ec-aa84-49ee-9481-e34454f26d1b','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StorageMgmtPort-3oqxj23p66t2-StorageMgmtDeployedPort-74catd57eycq','state changed','OS::Heat::Value',NULL,1134),(1805,'eb130c4f-938c-474d-b3a0-3ed106fca5d2','e45d54ec-aa84-49ee-9481-e34454f26d1b','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StorageMgmtPort-3oqxj23p66t2-StorageMgmtDeployedPort-74catd57eycq','state changed','OS::Heat::Value',NULL,1134),(1806,'d9636962-fc77-4977-b4cb-58b65d02fe9e','e45d54ec-aa84-49ee-9481-e34454f26d1b','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-StorageMgmtPort-3oqxj23p66t2','e45d54ec-aa84-49ee-9481-e34454f26d1b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1807,'4f427436-a1f0-4f8c-b0cd-612e7ff4222e','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StoragePort-ebyq5flyzkhc','state changed','OS::TripleO::ComputeHCI::Ports::StoragePort',NULL,1136),(1808,'01499944-61c1-4640-bf0f-925fb943dba5','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-PreNetworkConfig-etwtrjjsjlgv','state changed','OS::TripleO::ComputeHCI::PreNetworkConfig',NULL,NULL),(1809,'da2f2bf1-6d0d-4e07-8a90-4b6a9f157d94','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NodeTLSCAData-2ty77aywsccz','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1810,'edf0bb9a-9989-4c10-9dbb-530046f25fc3','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StorageMgmtPort-pqv2e5bsu3ro','state changed','OS::TripleO::ComputeHCI::Ports::StorageMgmtPort',NULL,1137),(1811,'8fcfe8cf-1f0c-4e0f-b66b-f4c44483c008','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','PreNetworkConfig','fdde2ccc-adc7-43dd-9b5c-ce9ea30692d9','state changed','OS::TripleO::ComputeHCI::PreNetworkConfig',NULL,NULL),(1812,'82d082a4-02cb-42d9-984f-06fc35ab0137','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-InternalApiPort-ktncbpz6rywy','state changed','OS::TripleO::ComputeHCI::Ports::InternalApiPort',NULL,1138),(1813,'e367caaf-cf27-4c94-bb42-14acd5e14586','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','NodeTLSCAData','141018c5-0668-456a-a6c7-7aa15557a598','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1814,'2d5cfce6-185b-4636-ae77-90c8128481f4','afb8f543-28f8-420c-9cbb-b2387815a289','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StoragePort-ebyq5flyzkhc','afb8f543-28f8-420c-9cbb-b2387815a289','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1815,'0c40a51f-c1f7-4cc6-b9cc-7f0a8526decb','5e4e0c83-8d8b-4db3-97c2-8e66134158b6','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StorageMgmtPort-pqv2e5bsu3ro','5e4e0c83-8d8b-4db3-97c2-8e66134158b6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1816,'44b67a4e-2bab-4097-94fe-298b8f2eb8e4','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','ComputeHCIExtraConfigPre','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCIExtraConfigPre-54h66e636fof','state changed','OS::TripleO::ComputeHCIExtraConfigPre',NULL,1139),(1817,'77774420-6d5c-460c-a2d6-9740a9c0482a','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NetHostMap-kaiijtrj24j2','state changed','OS::Heat::Value',NULL,1141),(1818,'84aa7a74-6fe0-4f53-96b7-78203012aae4','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1819,'c3d45d5e-c353-4a11-bf9f-e92c690a09f6','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-TenantPort-zuim3belqkwq','state changed','OS::TripleO::ComputeHCI::Ports::TenantPort',NULL,1142),(1820,'7a40cc0e-dc59-4f24-8dd4-e88259d580b7','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NetHostMap-kaiijtrj24j2','state changed','OS::Heat::Value',NULL,1141),(1821,'2b74cf98-59c8-4b40-9c38-3f39f360c962','e4b54ec6-26b0-4bd9-ba4e-b9d6a6889b02','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-InternalApiPort-ktncbpz6rywy','e4b54ec6-26b0-4bd9-ba4e-b9d6a6889b02','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1822,'29ca5b09-ea98-4269-a0b4-735b2b102173','46d05787-a1ca-4ff4-aad5-ca56d6fad29c','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-TenantPort-zuim3belqkwq','46d05787-a1ca-4ff4-aad5-ca56d6fad29c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1823,'72543eb1-a733-4ffd-ad07-d14120cac288','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-GlanceLogging-yijg2ws35pqr','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1824,'000082bb-b89c-45d7-80c1-67b1a44b751c','8ec2e545-af51-4eae-bb77-f936c37151ea','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCIExtraConfigPre-54h66e636fof','8ec2e545-af51-4eae-bb77-f936c37151ea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1825,'83aa8874-bd5c-4015-9e57-a19029670ea7','5e4e0c83-8d8b-4db3-97c2-8e66134158b6','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StorageMgmtPort-pqv2e5bsu3ro-StorageMgmtDeployedPort-nk5ggpq5rcbb','state changed','OS::Heat::Value',NULL,1143),(1826,'b0aa30b4-444d-4ff6-b670-9d225f2b907c','afb8f543-28f8-420c-9cbb-b2387815a289','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StoragePort-ebyq5flyzkhc-StorageDeployedPort-iead5575dmpn','state changed','OS::Heat::Value',NULL,1145),(1827,'48f963bf-6848-4571-8f33-d0bf835b682d','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','ComputeHCIAnsibleHostVars','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCIAnsibleHostVars-su5lt4zperwh','state changed','OS::Heat::Value',NULL,1146),(1828,'8265172e-61c9-4f76-b0e3-370c5a5cd684','afb8f543-28f8-420c-9cbb-b2387815a289','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StoragePort-ebyq5flyzkhc-StorageDeployedPort-iead5575dmpn','state changed','OS::Heat::Value',NULL,1145),(1829,'a379df8d-c666-41bf-8ecf-9e90b247805c','5e4e0c83-8d8b-4db3-97c2-8e66134158b6','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StorageMgmtPort-pqv2e5bsu3ro-StorageMgmtDeployedPort-nk5ggpq5rcbb','state changed','OS::Heat::Value',NULL,1143),(1830,'2dd61dde-ea3c-4648-85b3-a3d4e9f1ec58','99e5c2cf-8d87-4bf4-9df9-99b86e546179','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-GlanceLogging-yijg2ws35pqr','99e5c2cf-8d87-4bf4-9df9-99b86e546179','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1831,'132ba978-0933-439d-a155-a031b7ca4028','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','ComputeHCIAnsibleHostVars','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCIAnsibleHostVars-su5lt4zperwh','state changed','OS::Heat::Value',NULL,1146),(1832,'8fc7e86e-99ba-4506-8539-598f4323fce5','afb8f543-28f8-420c-9cbb-b2387815a289','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StoragePort-ebyq5flyzkhc','afb8f543-28f8-420c-9cbb-b2387815a289','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1833,'de157edf-603e-46a1-822a-cf7796bba9c0','8ec2e545-af51-4eae-bb77-f936c37151ea','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-ComputeHCIExtraConfigPre-54h66e636fof','8ec2e545-af51-4eae-bb77-f936c37151ea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1834,'865c0d66-42ad-4e0b-a6b9-a517cbadf7f3','e4b54ec6-26b0-4bd9-ba4e-b9d6a6889b02','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-InternalApiPort-ktncbpz6rywy-InternalApiDeployedPort-5sltelxu3zwe','state changed','OS::Heat::Value',NULL,1147),(1835,'9c213baa-5d66-4402-be93-13044075864d','5e4e0c83-8d8b-4db3-97c2-8e66134158b6','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-StorageMgmtPort-pqv2e5bsu3ro','5e4e0c83-8d8b-4db3-97c2-8e66134158b6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1836,'c37c32e5-a7bc-4193-bde7-3865ddec1e0a','46d05787-a1ca-4ff4-aad5-ca56d6fad29c','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-TenantPort-zuim3belqkwq-TenantDeployedPort-3ob547dpg5e5','state changed','OS::Heat::Value',NULL,1148),(1837,'f13f358b-c4ef-474a-820f-7f0d776fe59a','46d05787-a1ca-4ff4-aad5-ca56d6fad29c','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-TenantPort-zuim3belqkwq-TenantDeployedPort-3ob547dpg5e5','state changed','OS::Heat::Value',NULL,1148),(1838,'c2c8f02b-d12b-46a8-9bfd-3b921d13893e','e4b54ec6-26b0-4bd9-ba4e-b9d6a6889b02','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-InternalApiPort-ktncbpz6rywy-InternalApiDeployedPort-5sltelxu3zwe','state changed','OS::Heat::Value',NULL,1147),(1839,'7cff463b-ffa7-44aa-89a1-9bff38a67c83','46d05787-a1ca-4ff4-aad5-ca56d6fad29c','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-TenantPort-zuim3belqkwq','46d05787-a1ca-4ff4-aad5-ca56d6fad29c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1840,'10d5454b-dca6-4052-9f29-e92578887da1','e4b54ec6-26b0-4bd9-ba4e-b9d6a6889b02','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-InternalApiPort-ktncbpz6rywy','e4b54ec6-26b0-4bd9-ba4e-b9d6a6889b02','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1841,'98e022db-bc61-4d18-894e-c9f8c5d8b9fa','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','MySQLClient','174f3a12-7189-4de6-afdf-c90114a63864','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1842,'d2c6dff8-3ac0-43e3-a172-180f151ba69c','99e5c2cf-8d87-4bf4-9df9-99b86e546179','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-GlanceLogging-yijg2ws35pqr-RoleParametersValue-3bsp4mwjw22c','state changed','OS::Heat::Value',NULL,1149),(1843,'3f86759f-81c8-4ae4-89cc-7f7c8d551aaf','99e5c2cf-8d87-4bf4-9df9-99b86e546179','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-GlanceLogging-yijg2ws35pqr-RoleParametersValue-3bsp4mwjw22c','state changed','OS::Heat::Value',NULL,1149),(1844,'23d00257-8d44-43d9-bed1-88c63537cc9c','99e5c2cf-8d87-4bf4-9df9-99b86e546179','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-GlanceLogging-yijg2ws35pqr','99e5c2cf-8d87-4bf4-9df9-99b86e546179','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1845,'cb7ee793-5047-45f1-bd6e-bf0c7c85a523','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-HeatBase-n2ku3yxeqzbj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1150),(1846,'f41406ac-f077-4287-a58d-886c166072a8','6040c7b7-b6d6-4cbf-b350-63773ca60dcc','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-HeatBase-n2ku3yxeqzbj','6040c7b7-b6d6-4cbf-b350-63773ca60dcc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1847,'fe0588a8-3b64-438a-b8c3-a47ea7752643','6040c7b7-b6d6-4cbf-b350-63773ca60dcc','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-HeatBase-n2ku3yxeqzbj','6040c7b7-b6d6-4cbf-b350-63773ca60dcc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1848,'7c027e11-15d7-45d6-ac17-850780e9f494','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','StoragePort','2685db09-72de-450d-87f0-b43c731cc8fb','state changed','OS::TripleO::ComputeHCI::Ports::StoragePort',NULL,1102),(1849,'0b3abf4e-9293-450b-bcce-8c7ef3789f1b','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','InternalApiPort','3b2f15c0-d03b-404e-a133-aafb0aa05002','state changed','OS::TripleO::ComputeHCI::Ports::InternalApiPort',NULL,1108),(1850,'c46fc31b-b6b1-4823-839b-f9acc7b0bad0','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','30','c9b0a31c-5803-4337-b605-37b7dfaddaa2','state changed','OS::TripleO::Services::Iscsid',NULL,1085),(1851,'16dcc1e8-a8cb-4970-a545-189c3259c4ab','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','ComputeHCIExtraConfigPre','b60d753c-1f48-4e82-a666-7bdd454a0625','state changed','OS::TripleO::ComputeHCIExtraConfigPre',NULL,1099),(1852,'5692ddf8-7dbc-4977-9ddb-80dedc84f5ed','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','ComputeHCIExtraConfigPre','c514c79c-4fc6-461c-8d19-40363fdfbd55','state changed','OS::TripleO::ComputeHCIExtraConfigPre',NULL,1110),(1853,'d7c7c5b3-266a-41a0-8621-afd54d1a28f2','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','StorageMgmtPort','ae7fc3c5-1c8a-45b8-82f2-5cb86122682e','state changed','OS::TripleO::ComputeHCI::Ports::StorageMgmtPort',NULL,1103),(1854,'d3e480d0-d178-4222-adc1-a59b62cea5bd','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NodeExtraConfig-apey5jell5eb','state changed','OS::TripleO::NodeExtraConfig',NULL,1156),(1855,'ea5e4a45-afa8-4758-8d6a-bad0a5514bc8','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','StorageMgmtPort','e45d54ec-aa84-49ee-9481-e34454f26d1b','state changed','OS::TripleO::ComputeHCI::Ports::StorageMgmtPort',NULL,1109),(1856,'637f9229-d43a-43ca-a403-c8a55bb4885b','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','TenantPort','0514db89-0176-4067-a65c-d0e8405656ed','state changed','OS::TripleO::ComputeHCI::Ports::TenantPort',NULL,1116),(1857,'717a73dd-bae8-4878-a39a-c9beb9c2c3e2','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NodeExtraConfig-mqzdro5h4k3y','state changed','OS::TripleO::NodeExtraConfig',NULL,1158),(1858,'b9574190-5552-48ea-be01-a309a571e19d','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-RoleParametersValue-75kbpxszshr6','state changed','OS::Heat::Value',NULL,1162),(1859,'154b7dbf-9762-4137-bd3a-b1f5927fdb3e','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','TenantPort','a26b4cd3-8bf5-41f0-b00f-b1a3d2158b34','state changed','OS::TripleO::ComputeHCI::Ports::TenantPort',NULL,1106),(1860,'69f92576-77dd-4db5-aa99-eae35a56cbac','cde1b08f-ca39-488b-a04d-1c05d2ab8660','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NodeExtraConfig-apey5jell5eb','cde1b08f-ca39-488b-a04d-1c05d2ab8660','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1861,'0be04379-67ce-4579-95bf-9ca08aba924d','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-RoleParametersValue-75kbpxszshr6','state changed','OS::Heat::Value',NULL,1162),(1862,'0fb7645e-4ee7-4d2e-8bcb-d30d82b915c7','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','StoragePort','13756d74-83bb-420c-b582-7b33c35c99e3','state changed','OS::TripleO::ComputeHCI::Ports::StoragePort',NULL,1118),(1863,'6671d625-ef9d-4719-9d83-6dfb8c9cb53a','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','InternalApiPort','814ecf15-13bb-4c3b-a05e-a780bc4d450b','state changed','OS::TripleO::ComputeHCI::Ports::InternalApiPort',NULL,1121),(1864,'3a497bad-10a9-4a7f-9636-9ba048d0f97e','cde1b08f-ca39-488b-a04d-1c05d2ab8660','2026-06-13 07:50:53',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NodeExtraConfig-apey5jell5eb','cde1b08f-ca39-488b-a04d-1c05d2ab8660','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1865,'ea9bdbdd-7d7a-46bd-89dd-a8ab1a547890','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NetIpMap-ehz4c4m2bqfo','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1175),(1866,'5e171b1e-3df0-4090-a7cf-87e9fd6f9eef','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:53',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NetIpMap-e6fr7ywk3ppo','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1176),(1867,'5c4da5c1-fb56-4509-ada7-2042656c5a94','b35ca9c7-ce2f-41ef-96f8-c709748b522b','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NetIpMap-ehz4c4m2bqfo','b35ca9c7-ce2f-41ef-96f8-c709748b522b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1868,'7ed8060b-df6a-4ba2-be12-949b4b8734d5','b35ca9c7-ce2f-41ef-96f8-c709748b522b','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NetIpMap-ehz4c4m2bqfo-NetIpMapValue-6ofeqjo5uftx','state changed','OS::Heat::Value',NULL,1177),(1869,'6bb98971-13c2-4919-a777-9be607efd611','b35ca9c7-ce2f-41ef-96f8-c709748b522b','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NetIpMap-ehz4c4m2bqfo-NetIpMapValue-6ofeqjo5uftx','state changed','OS::Heat::Value',NULL,1177),(1870,'a72e8481-550f-4aae-ad8c-0d42c4cdac8d','b35ca9c7-ce2f-41ef-96f8-c709748b522b','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NetIpMap-ehz4c4m2bqfo','b35ca9c7-ce2f-41ef-96f8-c709748b522b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1871,'af404089-fe76-4331-ba03-a52033d991bf','2c0d5447-031a-46a4-b44d-05487edcb700','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NodeExtraConfig-mqzdro5h4k3y','2c0d5447-031a-46a4-b44d-05487edcb700','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1872,'a1ae4657-b520-4139-9689-8c4299113979','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','34','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-34-rxzsrz45ruxr','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1178),(1873,'e8da9606-6e9a-4529-8026-9a912b4bb1ea','998ec87d-772e-4403-a2c4-a711a1843d78','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NetIpMap-e6fr7ywk3ppo','998ec87d-772e-4403-a2c4-a711a1843d78','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1874,'43324748-95a5-422c-b0bd-b7eb7d822130','2c0d5447-031a-46a4-b44d-05487edcb700','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm-NodeExtraConfig-mqzdro5h4k3y','2c0d5447-031a-46a4-b44d-05487edcb700','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1875,'d8ba697d-87ae-4196-9064-2ccaa45c8479','4dad0951-4e9e-4e72-8187-9ec83f44c1d4','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-34-rxzsrz45ruxr','4dad0951-4e9e-4e72-8187-9ec83f44c1d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1876,'eacb5a3b-9a7e-49bf-8311-c7429a922ac1','4dad0951-4e9e-4e72-8187-9ec83f44c1d4','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-34-rxzsrz45ruxr','4dad0951-4e9e-4e72-8187-9ec83f44c1d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1877,'fb0181f5-3b74-4404-a45c-7881dd818074','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','StorageMgmtPort','5e4e0c83-8d8b-4db3-97c2-8e66134158b6','state changed','OS::TripleO::ComputeHCI::Ports::StorageMgmtPort',NULL,1137),(1878,'6ac0d344-3e63-487b-a03c-e3fd98dc8822','998ec87d-772e-4403-a2c4-a711a1843d78','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NetIpMap-e6fr7ywk3ppo-NetIpMapValue-t3idp4zdc4kb','state changed','OS::Heat::Value',NULL,1179),(1879,'1501ee86-5427-41da-8168-1a0f23621139','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','StoragePort','afb8f543-28f8-420c-9cbb-b2387815a289','state changed','OS::TripleO::ComputeHCI::Ports::StoragePort',NULL,1136),(1880,'a2494aaf-1e93-49e1-9f3d-b5a1e2e73d9b','998ec87d-772e-4403-a2c4-a711a1843d78','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NetIpMap-e6fr7ywk3ppo-NetIpMapValue-t3idp4zdc4kb','state changed','OS::Heat::Value',NULL,1179),(1881,'28deb861-6909-4a2c-bee8-3d5fefee1b3b','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','InternalApiPort','e4b54ec6-26b0-4bd9-ba4e-b9d6a6889b02','state changed','OS::TripleO::ComputeHCI::Ports::InternalApiPort',NULL,1138),(1882,'f8478e31-42bd-4d7b-af4d-a39b0380e247','998ec87d-772e-4403-a2c4-a711a1843d78','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w-NetIpMap-e6fr7ywk3ppo','998ec87d-772e-4403-a2c4-a711a1843d78','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1883,'c899f334-1d34-4022-8a7b-b1fbb9c0a6cf','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-ContainersCommon-mcso77ngyagm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1884,'cdaaaeff-4f97-40ec-a73f-ff2c98af3217','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','TenantPort','46d05787-a1ca-4ff4-aad5-ca56d6fad29c','state changed','OS::TripleO::ComputeHCI::Ports::TenantPort',NULL,1142),(1885,'484878f0-e369-45d8-bf2b-37c2a173781d','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','ComputeHCIExtraConfigPre','8ec2e545-af51-4eae-bb77-f936c37151ea','state changed','OS::TripleO::ComputeHCIExtraConfigPre',NULL,1139),(1886,'e45b7444-ff15-4db5-81fc-1689991c2e32','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','GlanceLogging','99e5c2cf-8d87-4bf4-9df9-99b86e546179','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1887,'683a72b5-dc34-4dc8-9bc7-125274fb074d','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NodeExtraConfig-i2nu4qq2idjw','state changed','OS::TripleO::NodeExtraConfig',NULL,1188),(1888,'c54dba29-2f61-49da-90ba-16fe6f462fad','9ce24162-07ea-4133-965e-2226f8613d7c','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-ContainersCommon-mcso77ngyagm','9ce24162-07ea-4133-965e-2226f8613d7c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1889,'4c0c0e58-4256-4f46-9c1a-4c3042fa6563','51130c1e-0cad-430e-a02b-c58eab12421f','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NodeExtraConfig-i2nu4qq2idjw','51130c1e-0cad-430e-a02b-c58eab12421f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1890,'885f245a-3c46-4b16-9abb-4b2584b07c55','51130c1e-0cad-430e-a02b-c58eab12421f','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NodeExtraConfig-i2nu4qq2idjw','51130c1e-0cad-430e-a02b-c58eab12421f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1891,'afb620e1-4610-422e-93b9-a566f7e2050a','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NetIpMap-w7evqcj2qjoj','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1190),(1892,'9b92da63-b1e0-4a98-9225-cfd14c9d5149','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ContainersCommon-3u3iz2rvuog4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1893,'41fd98ad-5cd4-4abb-b25f-fc419ec501ef','9ce24162-07ea-4133-965e-2226f8613d7c','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-ContainersCommon-mcso77ngyagm','9ce24162-07ea-4133-965e-2226f8613d7c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1894,'3983ceb0-da6a-41a3-be84-e1c34962b123','8d0d1215-edd2-4130-b29c-7cf849cfc5f3','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ContainersCommon-3u3iz2rvuog4','8d0d1215-edd2-4130-b29c-7cf849cfc5f3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1895,'3c67772f-06ea-4764-af20-cc5ad72413e7','187e3528-bce8-418f-b903-55b297f5ede9','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NetIpMap-w7evqcj2qjoj','187e3528-bce8-418f-b903-55b297f5ede9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1896,'43fefc0d-3b5e-44b0-a5a5-6c3490393068','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','HeatBase','6040c7b7-b6d6-4cbf-b350-63773ca60dcc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1150),(1897,'592f20fb-c8a4-48e6-a913-06df944195bd','8d0d1215-edd2-4130-b29c-7cf849cfc5f3','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ContainersCommon-3u3iz2rvuog4','8d0d1215-edd2-4130-b29c-7cf849cfc5f3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1898,'a2bb18cd-2be4-4884-881e-263b06011130','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','ContainersCommon','8d0d1215-edd2-4130-b29c-7cf849cfc5f3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1899,'d991cef0-d08d-4b17-a2f6-150fd054116a','187e3528-bce8-418f-b903-55b297f5ede9','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NetIpMap-w7evqcj2qjoj-NetIpMapValue-4vkbtjzlpfy5','state changed','OS::Heat::Value',NULL,1191),(1900,'f18cf4ec-ccf8-4b72-93b4-f33d336223f2','187e3528-bce8-418f-b903-55b297f5ede9','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NetIpMap-w7evqcj2qjoj-NetIpMapValue-4vkbtjzlpfy5','state changed','OS::Heat::Value',NULL,1191),(1901,'67ec2283-6ed8-4239-98ca-a63b40870460','187e3528-bce8-418f-b903-55b297f5ede9','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l-NetIpMap-w7evqcj2qjoj','187e3528-bce8-418f-b903-55b297f5ede9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1902,'8f37c379-dcdf-4be9-b059-552ffe65f790','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-ContainersCommon-brgyhdfigxlz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1903,'8328cd71-50fb-4429-86fd-34fb229981ed','aeb1062b-612d-4677-aac1-30abfb268238','2026-06-13 07:50:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-ContainersCommon-brgyhdfigxlz','aeb1062b-612d-4677-aac1-30abfb268238','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1904,'59607043-7b24-4802-af48-29662f7722f6','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','NodeExtraConfig','cde1b08f-ca39-488b-a04d-1c05d2ab8660','state changed','OS::TripleO::NodeExtraConfig',NULL,1156),(1905,'bee1184d-4bfe-4e1a-860f-e74e244835b8','aeb1062b-612d-4677-aac1-30abfb268238','2026-06-13 07:50:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-ContainersCommon-brgyhdfigxlz','aeb1062b-612d-4677-aac1-30abfb268238','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1906,'fcb5c9ba-e1b6-45d3-a49e-cfaf61489124','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','NetIpMap','b35ca9c7-ce2f-41ef-96f8-c709748b522b','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1175),(1907,'10f7f809-067d-433b-8b6a-2bf46a8d821c','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','NodeExtraConfig','2c0d5447-031a-46a4-b44d-05487edcb700','state changed','OS::TripleO::NodeExtraConfig',NULL,1158),(1908,'22ac7dda-251e-4ba2-b36b-b40bbd68ddd3','80455355-b7ed-4eb3-9e4e-5322701c9e41','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-1-niacq2l3t7mm','80455355-b7ed-4eb3-9e4e-5322701c9e41','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1909,'473a97e6-28e5-45c5-b6d6-99c433db32ea','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','NetIpMap','998ec87d-772e-4403-a2c4-a711a1843d78','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1176),(1910,'5f407ef9-34d7-46ae-b11b-1a3b57d716c2','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-2-gke475dwjn3w','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1911,'17303057-0445-4a2e-b213-e86dce3e7f5c','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','34','4dad0951-4e9e-4e72-8187-9ec83f44c1d4','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1178),(1912,'9dbf7041-f230-47ba-b80e-31b938c3d572','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-CinderNVMeOF-q67vf3f645uo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1913,'d3cc8f39-8ce0-4af4-a247-55e843357f5b','fea90704-5176-487a-a5df-3fc777280260','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-CinderNVMeOF-q67vf3f645uo','fea90704-5176-487a-a5df-3fc777280260','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1914,'b7fcd1c9-d5f4-4b68-bfa2-6a71015b9d01','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','NodeExtraConfig','51130c1e-0cad-430e-a02b-c58eab12421f','state changed','OS::TripleO::NodeExtraConfig',NULL,1188),(1915,'7fe0c43f-6ec7-4d56-8ba5-b1dbc9802f71','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','HeatApiLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-HeatApiLogging-uprrfywem5mn','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1916,'3b9a5e19-5253-4884-9314-9246073294ed','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','ContainersCommon','9ce24162-07ea-4133-965e-2226f8613d7c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1917,'71123078-8fcb-46d8-8de4-61fbb396083a','73a7b329-d495-45ff-81a6-be2eb9c92e4d','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-HeatApiLogging-uprrfywem5mn','73a7b329-d495-45ff-81a6-be2eb9c92e4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1918,'2821fc11-0307-4005-ae56-f100384194f5','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','38','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt','state changed','OS::TripleO::Services::MetricsQdr',NULL,1193),(1919,'a094cd1e-a9a5-4c64-a624-9933494a720f','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','NetIpMap','187e3528-bce8-418f-b903-55b297f5ede9','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1190),(1920,'1e8d7bf4-f6ae-485b-86c7-51e8afdce6c0','fea90704-5176-487a-a5df-3fc777280260','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r-CinderNVMeOF-q67vf3f645uo','fea90704-5176-487a-a5df-3fc777280260','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1921,'ae01b44c-19ed-4b07-a845-ef921ce034bd','73a7b329-d495-45ff-81a6-be2eb9c92e4d','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-HeatApiLogging-uprrfywem5mn','73a7b329-d495-45ff-81a6-be2eb9c92e4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1922,'f0277326-7be7-4f9b-8b6e-b5e7441972a6','55821e71-bee4-4a56-891a-37d4116380a0','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee-0-wfsc4ygajj3l','55821e71-bee4-4a56-891a-37d4116380a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1923,'a4114598-3da4-4ab3-81ca-ab5082dd243f','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','1','80455355-b7ed-4eb3-9e4e-5322701c9e41','state changed','OS::TripleO::ComputeHCI',NULL,1063),(1924,'d612c530-f6f2-4ec7-98ee-9d4e7ba77241','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','2','cd685fa5-fb99-4aa1-bd40-1ab3af6fc562','state changed','OS::TripleO::ComputeHCI',NULL,1057),(1925,'b0078d46-de9d-4948-997e-43a3b61a3e17','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1926,'94e889d0-ea62-4829-8e53-c6c63a6ba4b4','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt-RoleParametersValue-ff6rckufaavg','state changed','OS::Heat::Value',NULL,1194),(1927,'4c5b44f4-68da-4c05-963c-1e07d18ed000','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt-RoleParametersValue-ff6rckufaavg','state changed','OS::Heat::Value',NULL,1194),(1928,'1d5e8dd3-131f-472d-be15-2cb63ca44021','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','GnocchiServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-GnocchiServiceBase-62lwyexa3mt2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml',NULL,1195),(1929,'46cf0db8-f05f-4ef9-b0a7-c435a5264073','fa361f37-df55-4f0d-bf80-910349932260','2026-06-13 07:50:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-GnocchiServiceBase-62lwyexa3mt2','fa361f37-df55-4f0d-bf80-910349932260','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1930,'392d8eb1-5091-42dd-b60e-6285a4491cd3','fa361f37-df55-4f0d-bf80-910349932260','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q-GnocchiServiceBase-62lwyexa3mt2','fa361f37-df55-4f0d-bf80-910349932260','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1931,'1d1f0a87-eb79-43cd-8e05-2ebe682f0357','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:55',NULL,'CREATE','COMPLETE','ContainersCommon','aeb1062b-612d-4677-aac1-30abfb268238','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1932,'8db39e33-ee67-4bae-ae07-6e95378c08c2','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','CinderNVMeOF','fea90704-5176-487a-a5df-3fc777280260','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1933,'e4e0dec9-4c78-4712-9aaf-3d981a40f4f0','5b68e65a-a37e-4f80-a5b0-f4693d93a087','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5-GlanceApi-gm4tlsplnb3r','5b68e65a-a37e-4f80-a5b0-f4693d93a087','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1934,'96865a6c-d113-4b27-9356-4a49bf4aa015','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:56',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ApacheServiceBase-77vy6sbuebgr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1196),(1935,'bd35a89f-9033-4a10-a566-9e733c8d8b39','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','0','55821e71-bee4-4a56-891a-37d4116380a0','state changed','OS::TripleO::ComputeHCI',NULL,1076),(1936,'bb18ddc2-2400-4731-9bce-d964962d9446','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','2026-06-13 07:50:56',NULL,'UPDATE','COMPLETE','overcloud-ComputeHCI-n2ieafyllwee','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(1937,'1892c81a-43bc-4d3b-bef9-8796cde8282f','352928b5-f877-4286-9fa3-defa1fd89f64','2026-06-13 07:50:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ApacheServiceBase-77vy6sbuebgr','352928b5-f877-4286-9fa3-defa1fd89f64','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1938,'966b30a2-58ae-44ad-a28b-8e793ec5ef3e','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','HeatApiLogging','73a7b329-d495-45ff-81a6-be2eb9c92e4d','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1939,'1b68d5d1-599d-43bd-9734-871d8b308094','352928b5-f877-4286-9fa3-defa1fd89f64','2026-06-13 07:50:56',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ApacheServiceBase-77vy6sbuebgr-ApacheNetworks-jt6gc5llz2jr','state changed','OS::Heat::Value',NULL,1197),(1940,'3914f32c-5e56-4055-9ac5-9351c2eb93ff','352928b5-f877-4286-9fa3-defa1fd89f64','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ApacheServiceBase-77vy6sbuebgr-ApacheNetworks-jt6gc5llz2jr','state changed','OS::Heat::Value',NULL,1197),(1941,'c2fe1481-6aa6-49e6-85ed-9d87c4fb5766','352928b5-f877-4286-9fa3-defa1fd89f64','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-ApacheServiceBase-77vy6sbuebgr','352928b5-f877-4286-9fa3-defa1fd89f64','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1942,'70cded8b-c69b-483d-890d-f15344d344b1','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','2026-06-13 07:50:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt-ContainersCommon-rdn7wc4wcnjq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1943,'84942593-1d69-4003-a4bc-9f03fed33717','d3f13831-e04c-48b2-88a7-1642211f94ac','2026-06-13 07:50:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt-ContainersCommon-rdn7wc4wcnjq','d3f13831-e04c-48b2-88a7-1642211f94ac','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1944,'8fd47682-a600-46f9-b324-ceafbdc37d85','d3f13831-e04c-48b2-88a7-1642211f94ac','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt-ContainersCommon-rdn7wc4wcnjq','d3f13831-e04c-48b2-88a7-1642211f94ac','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1945,'046ea9c7-ee61-4f72-84f2-f0fade1c17cb','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','GnocchiServiceBase','fa361f37-df55-4f0d-bf80-910349932260','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml',NULL,1195),(1946,'1e22d57f-36df-40f7-a0c5-9ca50734c3fa','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','2026-06-13 07:50:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-23-vgfjecsdxo6q','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1947,'11a1ebce-d7be-4ab6-bf4f-5ea5846feb18','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','GlanceApi','5b68e65a-a37e-4f80-a5b0-f4693d93a087','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,1071),(1948,'03241ed5-829f-4ea0-8981-3412770ac4dd','e62d45af-4dc6-4341-88d8-699facae4fab','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-20-heqydqwff7p5','e62d45af-4dc6-4341-88d8-699facae4fab','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1949,'1bdf0033-068c-4cbe-8bbd-2f3ebf457147','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','23','535bcb73-1bdf-4efc-88ea-98a3bf3a59ad','state changed','OS::TripleO::Services::GnocchiStatsd',NULL,1098),(1950,'5fc18216-5f4c-4fcd-a27e-e5ff854f7b0e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','ComputeHCI','c2fcf2bd-c5c1-4802-a616-dcc78b12bd0a','state changed','OS::Heat::ResourceGroup',NULL,1047),(1951,'06706fe5-2625-4cb9-ab0e-51b4b9e3f920','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-RoleParametersValue-ktixnsrbwwlr','state changed','OS::Heat::Value',NULL,1198),(1952,'19c53e0a-f72c-44f4-887a-23904a2cf225','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj-RoleParametersValue-ktixnsrbwwlr','state changed','OS::Heat::Value',NULL,1198),(1953,'483582bc-28ab-4736-a9fa-0fd17447bf7a','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','ApacheServiceBase','352928b5-f877-4286-9fa3-defa1fd89f64','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1196),(1954,'bcffbe99-7137-412f-aed7-2aa50c91d501','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-25-jxdg6jsycfzj','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1955,'e172aa1b-c8d2-448d-9e17-c99da2bcdb54','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','20','e62d45af-4dc6-4341-88d8-699facae4fab','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,1056),(1956,'f0a4dd7f-0d56-473f-81f5-e1fd4a3218ef','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','ContainersCommon','d3f13831-e04c-48b2-88a7-1642211f94ac','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1957,'decc9146-2602-48ae-99ef-393565363b3b','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','2026-06-13 07:50:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-38-chk2sjrrnqxt','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1958,'500dc2db-fe6b-4d78-bd88-b85641a94667','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','27','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1214),(1959,'15b49a3e-ee59-4f88-8a68-dae9a2cea118','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh','ba2efeaa-99ed-450f-b64e-216a0da32188','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1960,'b5c9bbf3-5efd-4251-a8bf-40a86d3b2b80','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:58',NULL,'CREATE','COMPLETE','25','ba0f5c7a-13bc-4945-8cd0-8a1c62aaee77','state changed','OS::TripleO::Services::HeatApi',NULL,1133),(1961,'c60d9bd5-4694-44db-a20c-dc55db8b6cde','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-RoleParametersValue-rtkfulq46yj5','state changed','OS::Heat::Value',NULL,1227),(1962,'1bdf2705-1dec-4c74-8f75-ddbc4431fbb3','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:50:58',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-RoleParametersValue-rtkfulq46yj5','state changed','OS::Heat::Value',NULL,1227),(1963,'4197225e-04cc-4c75-8e90-0ba1d5d8a6c0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','ComputeHCINetworkHostnameMap','overcloud-ComputeHCINetworkHostnameMap-e7qli6z3v7ip','state changed','OS::Heat::Value',NULL,1229),(1964,'8af86167-8762-44f0-84b5-0c62bf83740f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:58',NULL,'CREATE','COMPLETE','ComputeHCINetworkHostnameMap','overcloud-ComputeHCINetworkHostnameMap-e7qli6z3v7ip','state changed','OS::Heat::Value',NULL,1229),(1965,'9362c0b2-0234-4f18-a574-43c18d2613dc','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','ComputeHCIIpListMap','overcloud-ComputeHCIIpListMap-7egueflsfvfa','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1242),(1966,'42a40b38-4d06-4a09-aa93-5dd0d4aa11b9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','ComputeHCIServers','overcloud-ComputeHCIServers-csizaja5ma5j','state changed','OS::Heat::Value',NULL,1244),(1967,'addf6a2c-1e5d-4e7f-82d4-4aa05ffa0c2c','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:58',NULL,'CREATE','COMPLETE','38','f6b35bb4-6feb-48fb-983d-fd3cb906fbc4','state changed','OS::TripleO::Services::MetricsQdr',NULL,1193),(1968,'069d82c9-aa51-4194-837f-f44bb26ef5bf','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:50:58',NULL,'CREATE','COMPLETE','ComputeHCIServers','overcloud-ComputeHCIServers-csizaja5ma5j','state changed','OS::Heat::Value',NULL,1244),(1969,'0d568237-c3a7-4fa0-9930-93feee23a221','d795135c-21e1-4236-8ad1-74ae2c1adf60','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeHCIIpListMap-7egueflsfvfa','d795135c-21e1-4236-8ad1-74ae2c1adf60','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1970,'3d449672-a6f0-4093-a531-46266fa38b7e','d795135c-21e1-4236-8ad1-74ae2c1adf60','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeHCIIpListMap-7egueflsfvfa-NetIpMapValue-2vr3vhd27yct','state changed','OS::Heat::Value',NULL,1249),(1971,'76a8d174-f9d6-4552-b12a-ed99466574a3','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:58',NULL,'CREATE','IN_PROGRESS','29','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm','state changed','OS::TripleO::Services::Horizon',NULL,1247),(1972,'aabbe518-6913-4889-a2be-86362380dc1b','d795135c-21e1-4236-8ad1-74ae2c1adf60','2026-06-13 07:50:58',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeHCIIpListMap-7egueflsfvfa-NetIpMapValue-2vr3vhd27yct','state changed','OS::Heat::Value',NULL,1249),(1973,'d8214ebc-1eea-42da-bac0-0bd318632a30','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','24','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk','state changed','OS::TripleO::Services::HAproxy',NULL,1252),(1974,'63361e69-a271-448f-83d5-236f1d422840','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','42','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1253),(1975,'181567fe-8aa9-48a1-a3c7-8d197594ff22','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1976,'0be37663-a42c-485a-9e00-de810170e9a1','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1977,'d3307b4c-46a4-4c6f-8dd8-240cf6daa134','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1978,'7c22c820-ea05-4aa4-9e61-a05ac5d31442','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm-RoleParametersValue-j6bzehcih5iq','state changed','OS::Heat::Value',NULL,1254),(1979,'7f222aff-2448-47dd-bc11-cfc5387a39bd','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','2026-06-13 07:50:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm-RoleParametersValue-j6bzehcih5iq','state changed','OS::Heat::Value',NULL,1254),(1980,'a79f42ff-73b6-47d2-b999-f9ea756023f2','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-RoleParametersValue-5giagpniq2em','state changed','OS::Heat::Value',NULL,1255),(1981,'6b28aed0-84d4-4731-846b-86057d07d557','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','2026-06-13 07:50:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-RoleParametersValue-5giagpniq2em','state changed','OS::Heat::Value',NULL,1255),(1982,'0f09d90a-7923-4858-9b01-2b9f7d39334c','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyInternalTLS-5tiljxi7rgcn','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(1983,'17185aad-691a-4f40-9763-c35c9f4942e1','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:50:59',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','a5fa5bb2-7499-47fe-8482-963232e7cc89','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(1984,'a0c8404c-c5b6-4351-a67e-8d005dcc04a8','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ContainersCommon-7e42fwlyhtju','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1985,'c1101db1-0b89-4491-838b-64ae0657534b','e139faf6-0942-4649-a798-a59f70594c89','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ContainersCommon-7e42fwlyhtju','e139faf6-0942-4649-a798-a59f70594c89','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1986,'a60f9d37-01a3-4939-a35c-d4e47636b2f5','e139faf6-0942-4649-a798-a59f70594c89','2026-06-13 07:50:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ContainersCommon-7e42fwlyhtju','e139faf6-0942-4649-a798-a59f70594c89','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1987,'e91bb6eb-3ebb-41d9-bc10-a302e347be19','d795135c-21e1-4236-8ad1-74ae2c1adf60','2026-06-13 07:50:59',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ComputeHCIIpListMap-7egueflsfvfa-EnabledServicesValue-ysxb7efzadll','state changed','OS::Heat::Value',NULL,1256),(1988,'3aa413b4-275e-45f8-841e-de108cf8dd39','d795135c-21e1-4236-8ad1-74ae2c1adf60','2026-06-13 07:50:59',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ComputeHCIIpListMap-7egueflsfvfa-EnabledServicesValue-ysxb7efzadll','state changed','OS::Heat::Value',NULL,1256),(1989,'993f7e44-e672-4395-8a3a-c8163ff6b5de','d795135c-21e1-4236-8ad1-74ae2c1adf60','2026-06-13 07:50:59',NULL,'CREATE','COMPLETE','overcloud-ComputeHCIIpListMap-7egueflsfvfa','d795135c-21e1-4236-8ad1-74ae2c1adf60','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1990,'263f8efb-e289-47dc-8143-d749eed01139','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm-ContainersCommon-ewiyl5udj2lp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1991,'645e2812-d1c6-41c9-a15c-e0ed1860c855','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1257),(1992,'bf542491-af30-462f-80db-2e1bde95663c','b84a953e-f803-47eb-825c-64e5ec98c598','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm-ContainersCommon-ewiyl5udj2lp','b84a953e-f803-47eb-825c-64e5ec98c598','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1993,'d6ba228a-9882-4dc1-bbd9-a81b1b67f9a8','b84a953e-f803-47eb-825c-64e5ec98c598','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm-ContainersCommon-ewiyl5udj2lp','b84a953e-f803-47eb-825c-64e5ec98c598','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1994,'b3a8efbe-f302-48be-b799-010fb6fbd7ee','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','ContainersCommon','b84a953e-f803-47eb-825c-64e5ec98c598','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1995,'2e0f8551-0ff2-4ba6-a5e7-f01c2fd0c510','e2cf4c05-2ac4-4cda-b4cf-f30629521a33','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd','e2cf4c05-2ac4-4cda-b4cf-f30629521a33','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1996,'e1699061-0be2-41dd-9db9-9313f94d434c','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyPublicTLS-osu3ge3l3psi','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,1258),(1997,'1f14d905-64fc-426a-8a3c-86d508cb4822','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-29-j7mzxnfb37sm','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1998,'63f3ceb2-8d09-497a-96f2-54acde8355b6','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','HeatApiCfnLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-HeatApiCfnLogging-i3ujlgx6nc2u','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1999,'546eebe0-e6e4-425c-b546-98fa0175f8db','e2cf4c05-2ac4-4cda-b4cf-f30629521a33','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','NeutronMl2Base','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd-NeutronMl2Base-dpdr2x33pifn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1259),(2000,'8c881659-c832-4f6c-b16a-794afb24270f','c2d1ceea-e6e3-472d-8b00-f0650d5207e8','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyPublicTLS-osu3ge3l3psi','c2d1ceea-e6e3-472d-8b00-f0650d5207e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2001,'00039f2f-b3e0-40a3-91bf-f61c6736b559','9dac6a9c-761b-45a4-8161-4ea4d21bf07d','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-HeatApiCfnLogging-i3ujlgx6nc2u','9dac6a9c-761b-45a4-8161-4ea4d21bf07d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2002,'42262edc-049a-41af-9506-d151b147265f','c2d1ceea-e6e3-472d-8b00-f0650d5207e8','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyPublicTLS-osu3ge3l3psi','c2d1ceea-e6e3-472d-8b00-f0650d5207e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2003,'fb24317e-2af1-4a48-b4f3-d9cdec11e24c','9dac6a9c-761b-45a4-8161-4ea4d21bf07d','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-HeatApiCfnLogging-i3ujlgx6nc2u','9dac6a9c-761b-45a4-8161-4ea4d21bf07d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2004,'5dab5dce-57c5-41a0-a1c9-de0c1f808491','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','ContainersCommon','e139faf6-0942-4649-a798-a59f70594c89','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2005,'68a3098d-1da8-4f83-b970-27e85cfe7fd9','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','c2d1ceea-e6e3-472d-8b00-f0650d5207e8','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,1258),(2006,'4804ec8d-ac3a-4d11-9c2e-e4d04fd19ae5','a9c591d4-00dd-4aa7-ac08-7c0f3aac839c','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd-NeutronMl2Base-dpdr2x33pifn','a9c591d4-00dd-4aa7-ac08-7c0f3aac839c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2007,'c08a2dfc-1ebd-4cee-b824-8ff4d5f6f715','a9c591d4-00dd-4aa7-ac08-7c0f3aac839c','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd-NeutronMl2Base-dpdr2x33pifn-NeutronBase-z537ecgdaz6c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1260),(2008,'68a12871-a6a6-46a4-9d36-0acf53d6c521','d0a84c03-5b92-41e0-8cbe-ba8d0821dfdd','2026-06-13 07:51:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd-NeutronMl2Base-dpdr2x33pifn-NeutronBase-z537ecgdaz6c','d0a84c03-5b92-41e0-8cbe-ba8d0821dfdd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2009,'a4b154ea-4065-4c78-9c85-d95870f5a004','d0a84c03-5b92-41e0-8cbe-ba8d0821dfdd','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd-NeutronMl2Base-dpdr2x33pifn-NeutronBase-z537ecgdaz6c','d0a84c03-5b92-41e0-8cbe-ba8d0821dfdd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2010,'d3844308-14ee-44c2-8877-0e8f246dcf8c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:51:00',NULL,'CREATE','COMPLETE','ComputeHCIIpListMap','d795135c-21e1-4236-8ad1-74ae2c1adf60','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1242),(2011,'5de6bb69-1489-461a-ab6c-5b8c073025e5','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:01',NULL,'CREATE','COMPLETE','29','fcd4b97f-3eb9-4230-a90b-4df5ba5ad380','state changed','OS::TripleO::Services::Horizon',NULL,1247),(2012,'9d098a50-c6fc-4389-98d4-60ef3a999d48','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','HAProxyBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,1263),(2013,'93a62b0b-38dd-4600-88b2-05a11739d46f','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-HeatBase-53jbgfczhm7t','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1265),(2014,'93d49f0c-75db-48e7-ac9a-233dcd790e5d','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu','9f8d9eb6-4581-46f2-b414-88194ea31cb5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2015,'40b706da-feed-4db7-bf4f-8e617d618e81','2222ee1f-7352-43d8-96a9-e94c941d9804','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-HeatBase-53jbgfczhm7t','2222ee1f-7352-43d8-96a9-e94c941d9804','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2016,'ece82c26-32e3-4a0c-b42d-788502241ccb','2222ee1f-7352-43d8-96a9-e94c941d9804','2026-06-13 07:51:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-HeatBase-53jbgfczhm7t','2222ee1f-7352-43d8-96a9-e94c941d9804','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2017,'d2350a7c-bbc4-4bcf-8575-acfa40e85920','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','33','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26','state changed','OS::TripleO::Services::ManilaApi',NULL,1266),(2018,'6e2a08bb-ab7a-41e7-aa99-18684f636124','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:01',NULL,'CREATE','COMPLETE','HeatApiCfnLogging','9dac6a9c-761b-45a4-8161-4ea4d21bf07d','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(2019,'ff6372ec-9be4-4103-a85b-7c676cfc83cb','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-RoleParametersValue-gntnu4fijgi6','state changed','OS::Heat::Value',NULL,1267),(2020,'5085c6ee-1b7e-45a4-8cf6-56a56a992f3e','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-RoleParametersValue-gntnu4fijgi6','state changed','OS::Heat::Value',NULL,1267),(2021,'1cd474d7-eed8-434b-a376-e52e4998f411','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26','8f92c737-c462-49f3-9b99-0e6237aa07d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2022,'0f397331-f5fe-4417-a1de-05819b0ea8c9','a9c591d4-00dd-4aa7-ac08-7c0f3aac839c','2026-06-13 07:51:01',NULL,'CREATE','COMPLETE','NeutronBase','d0a84c03-5b92-41e0-8cbe-ba8d0821dfdd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1260),(2023,'3a83300e-aa28-459c-a3f6-f676ec2596ff','a9c591d4-00dd-4aa7-ac08-7c0f3aac839c','2026-06-13 07:51:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd-NeutronMl2Base-dpdr2x33pifn','a9c591d4-00dd-4aa7-ac08-7c0f3aac839c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2024,'839e1a61-37b5-4f94-ab7e-dd606e98da78','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-RoleParametersValue-vrwvreql4th4','state changed','OS::Heat::Value',NULL,1268),(2025,'576a4b95-fa40-46ca-9bb9-fb97e37e1bd5','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-RoleParametersValue-vrwvreql4th4','state changed','OS::Heat::Value',NULL,1268),(2026,'9b43fea9-e305-40e9-9cb6-60b18d03ed99','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-RoleParametersValue-xmlbd7cj6vdx','state changed','OS::Heat::Value',NULL,1269),(2027,'bf5775b3-2200-44c4-9268-93a3f97e803a','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-RoleParametersValue-xmlbd7cj6vdx','state changed','OS::Heat::Value',NULL,1269),(2028,'ad8ca66b-b502-4067-872a-1239c7bfe80a','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:02',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ApacheServiceBase-c3fyttcctf2m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1270),(2029,'23683624-c2be-46a4-9a90-df6f10766ad8','28ea94a6-f390-41ce-96b5-9f18a2cf40fd','2026-06-13 07:51:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ApacheServiceBase-c3fyttcctf2m','28ea94a6-f390-41ce-96b5-9f18a2cf40fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2030,'f15b23c0-14ce-4910-81f2-2597945a8190','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:02',NULL,'CREATE','COMPLETE','HeatBase','2222ee1f-7352-43d8-96a9-e94c941d9804','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1265),(2031,'076408f6-618b-4a12-823c-e0cd4914a6bc','28ea94a6-f390-41ce-96b5-9f18a2cf40fd','2026-06-13 07:51:02',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ApacheServiceBase-c3fyttcctf2m-ApacheNetworks-5i5ak6w5rpvl','state changed','OS::Heat::Value',NULL,1271),(2032,'255186c6-b287-4d91-a559-9fba0f7fbd60','e2cf4c05-2ac4-4cda-b4cf-f30629521a33','2026-06-13 07:51:02',NULL,'CREATE','COMPLETE','NeutronMl2Base','a9c591d4-00dd-4aa7-ac08-7c0f3aac839c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1259),(2033,'8d69474c-ccc1-4578-988e-4f508dff8be3','28ea94a6-f390-41ce-96b5-9f18a2cf40fd','2026-06-13 07:51:02',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ApacheServiceBase-c3fyttcctf2m-ApacheNetworks-5i5ak6w5rpvl','state changed','OS::Heat::Value',NULL,1271),(2034,'b0bd9944-c7e4-4100-9d7a-ff92222e9351','e2cf4c05-2ac4-4cda-b4cf-f30629521a33','2026-06-13 07:51:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy-NeutronBase-n76c4w6hclpd','e2cf4c05-2ac4-4cda-b4cf-f30629521a33','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2035,'75d8c802-6841-420c-8841-7b9d65266566','28ea94a6-f390-41ce-96b5-9f18a2cf40fd','2026-06-13 07:51:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh-ApacheServiceBase-c3fyttcctf2m','28ea94a6-f390-41ce-96b5-9f18a2cf40fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2036,'ff1a0790-dc42-4bed-b8fa-7b6890e940a4','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:02',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-HAProxyInternalTLS-5hpacy2moigv','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(2037,'73db0bfd-a491-445d-9317-66390294fdd5','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:02',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','303837fa-9bf8-4ffb-910a-dbb5c67958b1','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(2038,'2ce146ca-093b-46a0-8a7e-c7ac8cfe2248','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:02',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ContainersCommon-rwugfstaeoij','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2039,'6e9ef480-16af-44fd-8f47-d0b8dc1c9f6c','b954ef37-44a4-4b66-9803-d8edf1d570c5','2026-06-13 07:51:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ContainersCommon-rwugfstaeoij','b954ef37-44a4-4b66-9803-d8edf1d570c5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2040,'dfd151dc-dc01-4b10-975b-a51fcdc7c32b','b954ef37-44a4-4b66-9803-d8edf1d570c5','2026-06-13 07:51:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ContainersCommon-rwugfstaeoij','b954ef37-44a4-4b66-9803-d8edf1d570c5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2041,'a3aa87c7-6474-4c65-b19a-0695ddf3c606','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-ContainersCommon-arpqxajxnc6z','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2042,'b47af1a0-6a2e-43a4-bdad-05bde850d53e','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','2026-06-13 07:51:03',NULL,'CREATE','COMPLETE','NeutronBase','e2cf4c05-2ac4-4cda-b4cf-f30629521a33','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1257),(2043,'f597eb0d-5aef-43f2-b2c2-8f3ab078677d','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','2026-06-13 07:51:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-42-6l37eq366tdy','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2044,'43226d34-4076-445d-b096-cf355ab9bc7d','8d62def2-98b3-4c2e-8848-1b515b60b49b','2026-06-13 07:51:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-ContainersCommon-arpqxajxnc6z','8d62def2-98b3-4c2e-8848-1b515b60b49b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2045,'b0742564-70f7-4847-bd5c-02c9eb93627e','8d62def2-98b3-4c2e-8848-1b515b60b49b','2026-06-13 07:51:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-ContainersCommon-arpqxajxnc6z','8d62def2-98b3-4c2e-8848-1b515b60b49b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2046,'1c2680c7-e54f-43a7-bee5-6e536e936103','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:03',NULL,'CREATE','COMPLETE','ApacheServiceBase','28ea94a6-f390-41ce-96b5-9f18a2cf40fd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1270),(2047,'d987f224-cdd3-4de3-8aca-c81fd09fe0fd','ba2efeaa-99ed-450f-b64e-216a0da32188','2026-06-13 07:51:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-27-re2feqgqlxsh','ba2efeaa-99ed-450f-b64e-216a0da32188','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2048,'be16e246-3060-4788-8ff4-a6ae5c7b3c44','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:03',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-HAProxyPublicTLS-arhubofko6ah','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,1272),(2049,'802fc272-ba42-4150-888c-15620d96eead','0d276022-40bd-4973-9210-4731320dc4fb','2026-06-13 07:51:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-HAProxyPublicTLS-arhubofko6ah','0d276022-40bd-4973-9210-4731320dc4fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2050,'1263769e-f2f8-4b88-967e-066f93b8cb7a','0d276022-40bd-4973-9210-4731320dc4fb','2026-06-13 07:51:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-HAProxyPublicTLS-arhubofko6ah','0d276022-40bd-4973-9210-4731320dc4fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2051,'ead681df-640c-4bc7-b249-a4ff0e4e167d','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:03',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ApacheServiceBase-6nk6m7rs5bkr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1273),(2052,'1cb0db0d-fb08-47f8-8403-dc597880c8f5','c7b95eeb-ab32-4b73-a0ca-3d50f772460d','2026-06-13 07:51:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ApacheServiceBase-6nk6m7rs5bkr','c7b95eeb-ab32-4b73-a0ca-3d50f772460d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2053,'4a25f028-1030-4657-9a1f-97c80c77786c','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','ContainersCommon','b954ef37-44a4-4b66-9803-d8edf1d570c5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2054,'a2b40d35-5ce2-45a2-98c8-ccb4457ff6c1','c7b95eeb-ab32-4b73-a0ca-3d50f772460d','2026-06-13 07:51:04',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ApacheServiceBase-6nk6m7rs5bkr-ApacheNetworks-annfbu6vzgtp','state changed','OS::Heat::Value',NULL,1274),(2055,'70357714-fc52-4f56-b0eb-7f70e17fc733','c7b95eeb-ab32-4b73-a0ca-3d50f772460d','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ApacheServiceBase-6nk6m7rs5bkr-ApacheNetworks-annfbu6vzgtp','state changed','OS::Heat::Value',NULL,1274),(2056,'48d18a33-9253-4d9a-b49b-af26a8308726','c7b95eeb-ab32-4b73-a0ca-3d50f772460d','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ApacheServiceBase-6nk6m7rs5bkr','c7b95eeb-ab32-4b73-a0ca-3d50f772460d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2057,'70122cdf-899b-4536-b439-41ae9df2a079','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','42','6ae0dcac-42be-4f45-aeef-f37c25b3a82c','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1253),(2058,'22030a54-34d6-4008-8026-7a91216279b7','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','27','ba2efeaa-99ed-450f-b64e-216a0da32188','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1214),(2059,'f93e6420-9147-4352-9b0d-458075358051','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','ContainersCommon','8d62def2-98b3-4c2e-8848-1b515b60b49b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2060,'19a3d74b-3029-417f-a5b2-bde4a7e015b1','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-ContainersCommon-fkfuiprt245n','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2061,'59bf2743-0c2b-43f6-ad32-47677e872412','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:04',NULL,'CREATE','IN_PROGRESS','46','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4','state changed','OS::TripleO::Services::NovaScheduler',NULL,1285),(2062,'29bfc48b-f91c-4bf9-ac9e-3b3f7887bfe0','26b6e3f7-c33d-414e-a860-31ddb0b71099','2026-06-13 07:51:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-ContainersCommon-fkfuiprt245n','26b6e3f7-c33d-414e-a860-31ddb0b71099','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2063,'0a9ca0cc-01db-4b0f-ace1-1dedb1d33e63','26b6e3f7-c33d-414e-a860-31ddb0b71099','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-ContainersCommon-fkfuiprt245n','26b6e3f7-c33d-414e-a860-31ddb0b71099','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2064,'64f84b4d-9621-47d9-89d7-c69bcd6fd16b','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:04',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','0d276022-40bd-4973-9210-4731320dc4fb','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,1272),(2065,'dd65ffc1-9519-4ceb-9e61-ca969a9b4822','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:04',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ManilaBase-4zxeezv5nqly','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1288),(2066,'36af491d-89b3-47e0-a141-24ca133b02e3','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','31','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-31-vgwumr6ljutj','state changed','OS::TripleO::Services::Kernel',NULL,1289),(2067,'7dd89f9e-0add-456e-beda-d53e340657da','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2068,'f5b9f003-b7cd-47df-af09-263bf2a9ce93','dc70c4fc-9f0e-4e4e-8f7b-bbc766115b90','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ManilaBase-4zxeezv5nqly','dc70c4fc-9f0e-4e4e-8f7b-bbc766115b90','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2069,'90ef0109-d29f-4b49-95d4-f04fdff6863c','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:05',NULL,'CREATE','COMPLETE','ApacheServiceBase','c7b95eeb-ab32-4b73-a0ca-3d50f772460d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1273),(2070,'96d1895a-232a-442c-aae6-55954a7e27b0','dc70c4fc-9f0e-4e4e-8f7b-bbc766115b90','2026-06-13 07:51:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-ManilaBase-4zxeezv5nqly','dc70c4fc-9f0e-4e4e-8f7b-bbc766115b90','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2071,'032bfead-62f3-429e-8ec6-d99bfe9f30e6','78dc9a0a-f15a-4f6f-86b1-d71e5cfcec01','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-31-vgwumr6ljutj','78dc9a0a-f15a-4f6f-86b1-d71e5cfcec01','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2072,'7b855f93-0485-4f7e-bba9-299f5e40b270','78dc9a0a-f15a-4f6f-86b1-d71e5cfcec01','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-31-vgwumr6ljutj-RoleParametersValue-hgbbdqcfbltg','state changed','OS::Heat::Value',NULL,1290),(2073,'e275593d-94b5-49b8-8811-54d04ed54658','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-ContainersCommon-thav7jaychrt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2074,'72c35bed-b44a-4b8b-89b3-9ecf8aaa8d2e','78dc9a0a-f15a-4f6f-86b1-d71e5cfcec01','2026-06-13 07:51:05',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-31-vgwumr6ljutj-RoleParametersValue-hgbbdqcfbltg','state changed','OS::Heat::Value',NULL,1290),(2075,'93b9e3a5-fdf0-4563-8585-8d2c7073d110','78dc9a0a-f15a-4f6f-86b1-d71e5cfcec01','2026-06-13 07:51:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-31-vgwumr6ljutj','78dc9a0a-f15a-4f6f-86b1-d71e5cfcec01','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2076,'27dd5420-4796-4c6a-9321-6796aee60282','1ae752b1-d30d-463c-9131-6a8f3a3dcde1','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-ContainersCommon-thav7jaychrt','1ae752b1-d30d-463c-9131-6a8f3a3dcde1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2077,'aaf09c47-0698-42ae-9a2b-2c15913808c2','1ae752b1-d30d-463c-9131-6a8f3a3dcde1','2026-06-13 07:51:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-ContainersCommon-thav7jaychrt','1ae752b1-d30d-463c-9131-6a8f3a3dcde1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2078,'6f8b4864-ce91-4e93-80e3-26c0d9683abb','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','HAProxyLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-HAProxyLogging-jlt5bwo27myj','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(2079,'7c3afd9b-68be-42cc-b406-cdf6cdbc2828','56d77f13-eff3-4d0d-bbd0-837b9d93362b','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-HAProxyLogging-jlt5bwo27myj','56d77f13-eff3-4d0d-bbd0-837b9d93362b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2080,'01fd389e-c905-409f-8025-f5b34c807673','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:05',NULL,'CREATE','COMPLETE','ContainersCommon','26b6e3f7-c33d-414e-a860-31ddb0b71099','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2081,'72994d56-ba49-484e-8f17-076483d49f86','56d77f13-eff3-4d0d-bbd0-837b9d93362b','2026-06-13 07:51:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu-HAProxyLogging-jlt5bwo27myj','56d77f13-eff3-4d0d-bbd0-837b9d93362b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2082,'25552bcd-5849-47a9-b7b6-062a0b60f940','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-MySQLClient-rq52ro4qk3ma','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2083,'b7717069-547c-4a41-a7a4-cce57801dba4','b1008d68-01cb-4303-9920-bb45f363adaf','2026-06-13 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-MySQLClient-rq52ro4qk3ma','b1008d68-01cb-4303-9920-bb45f363adaf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2084,'afe5b7b1-0ef1-481a-8070-69c4e9b74819','b1008d68-01cb-4303-9920-bb45f363adaf','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26-MySQLClient-rq52ro4qk3ma','b1008d68-01cb-4303-9920-bb45f363adaf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2085,'b413bbc4-ce3c-487a-a38a-d6eb91c596b1','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','ManilaBase','dc70c4fc-9f0e-4e4e-8f7b-bbc766115b90','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1288),(2086,'3cb01560-3538-4517-8609-52e1a9d14baf','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','31','78dc9a0a-f15a-4f6f-86b1-d71e5cfcec01','state changed','OS::TripleO::Services::Kernel',NULL,1289),(2087,'8196f5ec-63b4-48be-9a75-8aa91e663d93','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:06',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-MySQLClient-npxaijzsn6ec','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2088,'98bef0c5-05a5-4f64-8351-b577702c5869','7a4e1fb5-adfa-46ac-adcb-445325ca3c26','2026-06-13 07:51:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-MySQLClient-npxaijzsn6ec','7a4e1fb5-adfa-46ac-adcb-445325ca3c26','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2089,'dad2a08a-ce77-437c-aebd-04df68067ff6','7a4e1fb5-adfa-46ac-adcb-445325ca3c26','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-MySQLClient-npxaijzsn6ec','7a4e1fb5-adfa-46ac-adcb-445325ca3c26','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2090,'113de4d7-ddf5-4a04-81e0-39b6cfb552c4','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','ContainersCommon','1ae752b1-d30d-463c-9131-6a8f3a3dcde1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2091,'b137b1a2-dd94-4d22-b82a-afd556d3e45e','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:06',NULL,'CREATE','IN_PROGRESS','35','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1293),(2092,'4229acde-b35a-4f92-9c1e-9753bc3282b9','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg','649e5c43-72fd-4c42-8115-3a493fa001ad','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2093,'7b1afc58-7128-4791-a14c-d4937419977c','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:06',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-ManilaBase-esfewcxga26n','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1294),(2094,'a4608fad-1bf2-4788-bdf8-237650752cdd','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','HAProxyLogging','56d77f13-eff3-4d0d-bbd0-837b9d93362b','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(2095,'0b54da37-8f6e-40e0-bfc7-f4f68a3b7b12','9f8d9eb6-4581-46f2-b414-88194ea31cb5','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk-HAProxyBase-vs3csjie2gfu','9f8d9eb6-4581-46f2-b414-88194ea31cb5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2096,'ec56ab36-80d8-4fbf-8463-a0793529a26a','6515908e-219c-48e6-b4ee-3a919a8ae792','2026-06-13 07:51:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-ManilaBase-esfewcxga26n','6515908e-219c-48e6-b4ee-3a919a8ae792','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2097,'5106bb41-233c-4814-9a2b-1be6649a630f','6515908e-219c-48e6-b4ee-3a919a8ae792','2026-06-13 07:51:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-ManilaBase-esfewcxga26n','6515908e-219c-48e6-b4ee-3a919a8ae792','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2098,'b347826c-0255-4f75-b26f-ce395104cfaa','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','MySQLClient','b1008d68-01cb-4303-9920-bb45f363adaf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2099,'bccbe663-4711-4006-b02b-27b343e8507a','8f92c737-c462-49f3-9b99-0e6237aa07d4','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-33-ao7xutnrgc26','8f92c737-c462-49f3-9b99-0e6237aa07d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2100,'7ad9c33f-f83d-4cdb-8d40-aa8b0ea1866a','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:07',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaBase-5hmlrjxicbez','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1295),(2101,'9b9f212c-744c-4e09-8351-2a78d4d8466a','bb740c32-1699-43e8-af20-848b49f101e6','2026-06-13 07:51:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaBase-5hmlrjxicbez','bb740c32-1699-43e8-af20-848b49f101e6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2102,'39efb679-88bb-4a08-a9b8-c06fb2a927c0','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','MySQLClient','7a4e1fb5-adfa-46ac-adcb-445325ca3c26','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2103,'297e3903-382d-4b44-b509-6793efa8b9fc','bb740c32-1699-43e8-af20-848b49f101e6','2026-06-13 07:51:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaBase-5hmlrjxicbez-RoleParametersValue-cug4zmiq35ry','state changed','OS::Heat::Value',NULL,1296),(2104,'9f1d4546-c979-46de-9411-a58e1f77fc05','bb740c32-1699-43e8-af20-848b49f101e6','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaBase-5hmlrjxicbez-RoleParametersValue-cug4zmiq35ry','state changed','OS::Heat::Value',NULL,1296),(2105,'82adfd19-26ae-4996-bf27-2c47e3a2c686','bb740c32-1699-43e8-af20-848b49f101e6','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaBase-5hmlrjxicbez','bb740c32-1699-43e8-af20-848b49f101e6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2106,'7b5cf409-6205-49ec-b36f-07491a8d2062','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','HAProxyBase','9f8d9eb6-4581-46f2-b414-88194ea31cb5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,1263),(2107,'de98621c-6fb2-4ce8-a0ed-d5fcad59a319','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-24-dqowwshtc6zk','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2108,'5804a9ae-7717-46d5-ad82-00dae15378c4','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-ContainersCommon-2yku2nbgsidy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2109,'482fd1f2-7c76-41ba-bf29-6663529dae5a','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','33','8f92c737-c462-49f3-9b99-0e6237aa07d4','state changed','OS::TripleO::Services::ManilaApi',NULL,1266),(2110,'9613dab1-a83f-46da-94ac-51dae8fd2765','75c18b7b-1474-490c-ae5f-c3c1913f7370','2026-06-13 07:51:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-ContainersCommon-2yku2nbgsidy','75c18b7b-1474-490c-ae5f-c3c1913f7370','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2111,'485df0da-46ba-4cb6-9701-54c80da95993','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','ManilaBase','6515908e-219c-48e6-b4ee-3a919a8ae792','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1294),(2112,'1c40daca-04c0-44c4-994e-fac2fc3ca620','75c18b7b-1474-490c-ae5f-c3c1913f7370','2026-06-13 07:51:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-ContainersCommon-2yku2nbgsidy','75c18b7b-1474-490c-ae5f-c3c1913f7370','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2113,'83c19f78-25aa-4783-bba3-ad9fa34a34c7','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:08',NULL,'CREATE','COMPLETE','24','ff804078-9dc8-4e86-b8c2-5fed864ca6d0','state changed','OS::TripleO::Services::HAproxy',NULL,1252),(2114,'8ef4b208-7750-46f3-835c-68ab5085e9aa','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','37','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s','state changed','OS::TripleO::Services::Memcached',NULL,1304),(2115,'834ac8a0-34db-49e0-97b3-736de0d12f44','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:08',NULL,'CREATE','COMPLETE','NovaBase','bb740c32-1699-43e8-af20-848b49f101e6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1295),(2116,'582fe42f-55ef-478d-b7c9-301f47d7565d','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaDBClient-wq52xsqjm6ed','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1305),(2117,'3b7160f8-c66e-4636-8dfb-b6b9aeaa7f34','109cfe49-7900-4dd7-90e3-9c2527281fc6','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s','109cfe49-7900-4dd7-90e3-9c2527281fc6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2118,'c9210b9b-80d1-4650-a0c6-a9624c3b4dc6','0c50403f-a053-4df1-8dc4-dc4982d3f73f','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaDBClient-wq52xsqjm6ed','0c50403f-a053-4df1-8dc4-dc4982d3f73f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2119,'40e5ebab-653f-4fec-8b40-5b0b8fbf50d3','0c50403f-a053-4df1-8dc4-dc4982d3f73f','2026-06-13 07:51:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaDBClient-wq52xsqjm6ed','0c50403f-a053-4df1-8dc4-dc4982d3f73f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2120,'b37153a3-f43b-4937-bf7b-f50c74df0ef6','109cfe49-7900-4dd7-90e3-9c2527281fc6','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s-RoleParametersValue-vqbtguqowapc','state changed','OS::Heat::Value',NULL,1312),(2121,'1d5d599d-c7b7-40ac-af4e-c275d1a6332c','109cfe49-7900-4dd7-90e3-9c2527281fc6','2026-06-13 07:51:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s-RoleParametersValue-vqbtguqowapc','state changed','OS::Heat::Value',NULL,1312),(2122,'3d51a00f-af8c-4acf-b922-ec09b3860fb7','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-MySQLClient-7kiy3ogdqnxl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2123,'67047f07-940a-48b5-885e-5d2bbfd3a449','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:08',NULL,'CREATE','COMPLETE','ContainersCommon','75c18b7b-1474-490c-ae5f-c3c1913f7370','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2124,'6b72462a-3c79-42e6-8b10-f56d76dfb6aa','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','28','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx','state changed','OS::TripleO::Services::HeatEngine',NULL,1317),(2125,'94df6b4b-5a2a-40ae-93d2-392638d746d3','33266ae1-1c01-467f-a0fe-115e9356e710','2026-06-13 07:51:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-MySQLClient-7kiy3ogdqnxl','33266ae1-1c01-467f-a0fe-115e9356e710','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2126,'cb097420-f146-4d69-a9cf-138740390df1','33266ae1-1c01-467f-a0fe-115e9356e710','2026-06-13 07:51:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-MySQLClient-7kiy3ogdqnxl','33266ae1-1c01-467f-a0fe-115e9356e710','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2127,'a5973cfb-733b-4e35-b795-6ceed152658b','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx','da938181-6a0a-4d18-88ce-08d55494c29f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2128,'bba68c72-11e6-44c0-a73d-4115b125b463','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-RoleParametersValue-va3z2aqyu2zq','state changed','OS::Heat::Value',NULL,1318),(2129,'8f2ce303-5710-443d-9463-6f18681b3c1d','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-RoleParametersValue-va3z2aqyu2zq','state changed','OS::Heat::Value',NULL,1318),(2130,'4777542f-1db6-4e7b-82d7-fd17328c5484','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-RoleParametersValue-syyc7uce54qb','state changed','OS::Heat::Value',NULL,1319),(2131,'e4159e7e-2a09-4a66-b206-11a3927ded3c','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-RoleParametersValue-syyc7uce54qb','state changed','OS::Heat::Value',NULL,1319),(2132,'112e6fb6-4d12-4071-b78d-c858e8575ae8','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaLogging-suq6bgdwddxn','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1321),(2133,'ccad3592-0cef-41c1-84ec-e2e76e050413','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:09',NULL,'CREATE','COMPLETE','NovaDBClient','0c50403f-a053-4df1-8dc4-dc4982d3f73f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1305),(2134,'baecf964-409e-4d48-bdf6-60a4ec1bda16','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaLogging-suq6bgdwddxn','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2135,'8b4a0c60-f4fe-4b23-a143-6358af7ddf1d','109cfe49-7900-4dd7-90e3-9c2527281fc6','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s-ContainersCommon-ny5lshiek3bi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2136,'60a1c0a5-0aeb-40c5-8a70-5a32aeccf5d4','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaLogging-suq6bgdwddxn-RoleParametersValue-m7tevry3qsgs','state changed','OS::Heat::Value',NULL,1322),(2137,'0b29d9c5-e46b-4b5c-915a-2ef5e9620408','a06ec9bb-8ab4-4813-aae3-bd3c7457557f','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s-ContainersCommon-ny5lshiek3bi','a06ec9bb-8ab4-4813-aae3-bd3c7457557f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2138,'a360397e-6b75-4155-b1fe-cd4b995a6f74','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','2026-06-13 07:51:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaLogging-suq6bgdwddxn-RoleParametersValue-m7tevry3qsgs','state changed','OS::Heat::Value',NULL,1322),(2139,'33c0f7cf-df95-4b10-9ecb-384187072daf','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-RoleParametersValue-ad4rtcrdnlj7','state changed','OS::Heat::Value',NULL,1323),(2140,'1d15ce67-5290-475a-adc3-3cfdaa371bdf','a06ec9bb-8ab4-4813-aae3-bd3c7457557f','2026-06-13 07:51:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s-ContainersCommon-ny5lshiek3bi','a06ec9bb-8ab4-4813-aae3-bd3c7457557f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2141,'929eeaca-c553-4e1f-ad0d-ee9aff0f2752','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg-RoleParametersValue-ad4rtcrdnlj7','state changed','OS::Heat::Value',NULL,1323),(2142,'a60b64f8-e3f8-45fa-9304-9b63db33cb44','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','MySQLClient','33266ae1-1c01-467f-a0fe-115e9356e710','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2143,'78b78d6c-9c25-4d81-9972-87cf8800dc8b','649e5c43-72fd-4c42-8115-3a493fa001ad','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-35-7aixnhcdrjtg','649e5c43-72fd-4c42-8115-3a493fa001ad','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2144,'50e89e3c-ed37-4de2-9b54-e5943ce25943','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:10',NULL,'CREATE','IN_PROGRESS','HeatEngineLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatEngineLogging-atum2e22lhqn','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(2145,'6d8cbd47-7cef-480c-834e-70abec1f877a','11ad1cd0-3595-41a7-9ed4-24d084123efb','2026-06-13 07:51:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatEngineLogging-atum2e22lhqn','11ad1cd0-3595-41a7-9ed4-24d084123efb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2146,'a557f7a8-6dae-43c6-82bb-167b608b23cf','11ad1cd0-3595-41a7-9ed4-24d084123efb','2026-06-13 07:51:10',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatEngineLogging-atum2e22lhqn-RoleParametersValue-jc5vvpc3jvkt','state changed','OS::Heat::Value',NULL,1324),(2147,'afdbd5de-2715-4202-847f-8c8d8591744c','11ad1cd0-3595-41a7-9ed4-24d084123efb','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatEngineLogging-atum2e22lhqn-RoleParametersValue-jc5vvpc3jvkt','state changed','OS::Heat::Value',NULL,1324),(2148,'f02eb14c-6312-457c-b845-d27f0a533702','11ad1cd0-3595-41a7-9ed4-24d084123efb','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatEngineLogging-atum2e22lhqn','11ad1cd0-3595-41a7-9ed4-24d084123efb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2149,'eee4c6b3-877f-477b-8fcf-48448ed69534','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:10',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaApiDBClient-cf3stic5jqdm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1325),(2150,'5dabafaa-5446-415f-968d-f3ba89a56e47','4874d7cd-87d9-4bb5-a2e9-b4618a25984c','2026-06-13 07:51:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaApiDBClient-cf3stic5jqdm','4874d7cd-87d9-4bb5-a2e9-b4618a25984c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2151,'f02fbc45-5a95-4b01-b570-1a961662d756','4874d7cd-87d9-4bb5-a2e9-b4618a25984c','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaApiDBClient-cf3stic5jqdm','4874d7cd-87d9-4bb5-a2e9-b4618a25984c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2152,'21978368-0e71-41ae-821d-9f8f750419ba','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','35','649e5c43-72fd-4c42-8115-3a493fa001ad','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1293),(2153,'f6f038eb-c987-4d95-a929-097974f1c5c2','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','2026-06-13 07:51:10',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaLogging-suq6bgdwddxn-InitLogContainerName-vst5qvfnhgv3','state changed','OS::Heat::Value',NULL,1326),(2154,'ce8cfd12-fdcf-4675-a6b9-0a2c3e7a2a0d','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaLogging-suq6bgdwddxn-InitLogContainerName-vst5qvfnhgv3','state changed','OS::Heat::Value',NULL,1326),(2155,'9538330a-2890-46d0-b593-c40179597757','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4-NovaLogging-suq6bgdwddxn','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2156,'2e0ccc83-a7c3-4e25-b5ea-718439f9bf52','109cfe49-7900-4dd7-90e3-9c2527281fc6','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','ContainersCommon','a06ec9bb-8ab4-4813-aae3-bd3c7457557f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2157,'9ae9a5e2-be8f-4c99-9485-395b1b5e7084','109cfe49-7900-4dd7-90e3-9c2527281fc6','2026-06-13 07:51:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-37-5gx4dlbave6s','109cfe49-7900-4dd7-90e3-9c2527281fc6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2158,'468eb548-cd62-4c1f-b20b-3ac535a259b0','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:11',NULL,'CREATE','IN_PROGRESS','39','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg','state changed','OS::TripleO::Services::MySQL',NULL,1332),(2159,'f7ce27aa-851f-47d0-935f-af88bdc3321a','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg','73bd7b90-2b80-42d4-afc4-344a29d3474a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2160,'ed751792-7e79-4a54-b8d8-4075c89b93aa','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:11',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatBase-w7ewojfgxvwh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1333),(2161,'e6e3d9ca-c175-4b70-a217-e9d0afb7b84b','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:11',NULL,'CREATE','COMPLETE','HeatEngineLogging','11ad1cd0-3595-41a7-9ed4-24d084123efb','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(2162,'4172981c-dbaf-4f6e-80ef-258a91044163','36b133b9-2f80-44b9-a3c8-b08b483fc3f7','2026-06-13 07:51:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatBase-w7ewojfgxvwh','36b133b9-2f80-44b9-a3c8-b08b483fc3f7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2163,'43eb48b2-5d8f-4e94-98e9-b6ade853c032','36b133b9-2f80-44b9-a3c8-b08b483fc3f7','2026-06-13 07:51:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-HeatBase-w7ewojfgxvwh','36b133b9-2f80-44b9-a3c8-b08b483fc3f7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2164,'b925373e-a108-4c41-95e3-ad3429f1a0bb','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-RoleParametersValue-xb42uhhacpxi','state changed','OS::Heat::Value',NULL,1334),(2165,'32347f1b-c195-4e5f-b50a-5a467b10dfc5','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-RoleParametersValue-xb42uhhacpxi','state changed','OS::Heat::Value',NULL,1334),(2166,'feb19627-66b6-44df-a084-006c12a55df2','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:11',NULL,'CREATE','COMPLETE','NovaApiDBClient','4874d7cd-87d9-4bb5-a2e9-b4618a25984c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1325),(2167,'a82feb06-db3f-44fd-a4cc-b44d8acd3e12','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:11',NULL,'CREATE','COMPLETE','37','109cfe49-7900-4dd7-90e3-9c2527281fc6','state changed','OS::TripleO::Services::Memcached',NULL,1304),(2168,'a7177d25-377f-4e50-8657-a4e35041b98b','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:11',NULL,'CREATE','COMPLETE','NovaLogging','c3d4dc3c-c63b-4148-8702-a1b93fd728cf','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1321),(2169,'133a7346-6160-4de0-9eb3-ee041a116874','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','2026-06-13 07:51:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-46-5nqzjbxsiag4','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2170,'e1fcea5b-d225-4376-920a-b0cde48f221d','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:11',NULL,'CREATE','IN_PROGRESS','41','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal','state changed','OS::TripleO::Services::NeutronApi',NULL,1338),(2171,'f5e470c1-43c7-4b6c-af78-6fd980e96134','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:12',NULL,'CREATE','COMPLETE','46','5c87e968-7e07-4ab3-8f6e-045e7ef0da07','state changed','OS::TripleO::Services::NovaScheduler',NULL,1285),(2172,'255eb6f3-cd45-4de2-a7f6-9082e38af1db','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal','89f8cc2e-5b51-4050-92cd-a440f33484af','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2173,'92aec845-5ef3-4f53-93a6-51e47dad6912','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-MySQLClient-2zss4yzwhix2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2174,'2f9a537f-6bcc-4d80-9633-252d6bc681b6','1649c263-4741-4833-83d0-636098730f95','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-MySQLClient-2zss4yzwhix2','1649c263-4741-4833-83d0-636098730f95','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2175,'ff41802d-5edf-4eb9-a1ea-1ed8cfaa0bba','1649c263-4741-4833-83d0-636098730f95','2026-06-13 07:51:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-MySQLClient-2zss4yzwhix2','1649c263-4741-4833-83d0-636098730f95','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2176,'31795c69-91b3-45d7-88c4-bb1c05f68918','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-ContainersCommon-hy6a7fcyhspm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2177,'548e9ea5-8000-4d25-8733-f8ee40025cea','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-MysqlBase-e4nulbn43hhj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1345),(2178,'65f5217d-64dc-4f65-aceb-d51c5743cc32','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:12',NULL,'CREATE','COMPLETE','HeatBase','36b133b9-2f80-44b9-a3c8-b08b483fc3f7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1333),(2179,'1ef3bb04-64bf-45a1-bf42-be9bc3a846a1','b22046fc-c8d8-4ab7-bb63-5f35dc8395bb','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-MysqlBase-e4nulbn43hhj','b22046fc-c8d8-4ab7-bb63-5f35dc8395bb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2180,'00c01450-e5c8-4fbc-bd51-6ebe96bb26d5','c9300786-800d-4cad-bf6f-26a96070a0bc','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-ContainersCommon-hy6a7fcyhspm','c9300786-800d-4cad-bf6f-26a96070a0bc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2181,'7a58bd31-0ddc-4502-ac16-6e5aaf83883e','b22046fc-c8d8-4ab7-bb63-5f35dc8395bb','2026-06-13 07:51:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-MysqlBase-e4nulbn43hhj','b22046fc-c8d8-4ab7-bb63-5f35dc8395bb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2182,'662ec898-6ef8-45ef-bd98-359459cd6e9c','c9300786-800d-4cad-bf6f-26a96070a0bc','2026-06-13 07:51:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-ContainersCommon-hy6a7fcyhspm','c9300786-800d-4cad-bf6f-26a96070a0bc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2183,'93e34135-193b-495e-8efe-cc85a7233ca3','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','50','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk','state changed','OS::TripleO::Services::OVNController',NULL,1350),(2184,'d87772e4-06de-45b5-b1a9-be27bb7bc940','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk','93efd107-b585-4412-b131-3edcb33816a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2185,'b66c63d6-4479-47f7-a3eb-7f13a0aadc49','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk-ContainersCommon-aysyncthkw5u','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2186,'4de31245-6529-491b-8a3c-5f65d223d5f4','51ec4d4d-6180-45a6-ad8f-2827695c0e10','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk-ContainersCommon-aysyncthkw5u','51ec4d4d-6180-45a6-ad8f-2827695c0e10','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2187,'b51cb0a2-5f14-4a80-acdf-5a6dbcaf2129','51ec4d4d-6180-45a6-ad8f-2827695c0e10','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk-ContainersCommon-aysyncthkw5u','51ec4d4d-6180-45a6-ad8f-2827695c0e10','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2188,'fc49c70a-f736-47cf-98ec-5e345898fe7c','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-ContainersCommon-pgswcfx3j22l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2189,'01f62648-b889-471d-86fe-0966278f2816','9225f431-9594-4df4-8398-56052b76f49e','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-ContainersCommon-pgswcfx3j22l','9225f431-9594-4df4-8398-56052b76f49e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2190,'60c8f560-151d-4f4c-af8c-469272479c0b','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','MySQLClient','1649c263-4741-4833-83d0-636098730f95','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2191,'149538cf-114c-4ebd-9e8d-033157429e11','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-MySQLClient-hoalldihpdnt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2192,'74a7cbc4-bbcc-4686-86bf-0d8af452f3f9','9225f431-9594-4df4-8398-56052b76f49e','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx-ContainersCommon-pgswcfx3j22l','9225f431-9594-4df4-8398-56052b76f49e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2193,'2cbb82fb-1081-4b13-9217-e6cdd415d0a1','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-ContainersCommon-lq25xtmdsd2a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2194,'eb002caf-b34b-41b3-8bb6-400a9b3fa5ba','b87f0461-e3e7-436f-bef4-e2dd484e39c0','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-MySQLClient-hoalldihpdnt','b87f0461-e3e7-436f-bef4-e2dd484e39c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2195,'0999a554-23b7-45f9-b361-1737ceffe389','b87f0461-e3e7-436f-bef4-e2dd484e39c0','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-MySQLClient-hoalldihpdnt','b87f0461-e3e7-436f-bef4-e2dd484e39c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2196,'123ce837-52d7-410c-9e52-049e1972cb7c','7c690d5c-fa56-4a0f-bde4-772aafa3baf8','2026-06-13 07:51:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-ContainersCommon-lq25xtmdsd2a','7c690d5c-fa56-4a0f-bde4-772aafa3baf8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2197,'a52fd767-3c30-4651-b984-9abfbc27a4e6','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','MySQLClient','b87f0461-e3e7-436f-bef4-e2dd484e39c0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2198,'ca0c2f7c-adfb-4a24-9fe4-1cd44a663490','7c690d5c-fa56-4a0f-bde4-772aafa3baf8','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg-ContainersCommon-lq25xtmdsd2a','7c690d5c-fa56-4a0f-bde4-772aafa3baf8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2199,'ee71a1dc-edd4-4411-bedb-39378fade3c4','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','MysqlBase','b22046fc-c8d8-4ab7-bb63-5f35dc8395bb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1345),(2200,'b78c2f63-00cc-4e55-b427-02e919dd0b15','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:13',NULL,'CREATE','COMPLETE','ContainersCommon','c9300786-800d-4cad-bf6f-26a96070a0bc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2201,'e4c9712a-dd17-4af2-b32a-4ab3d4dacc58','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:14',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk-OVNBridgeMappingsValue-jns64lkafnyh','state changed','OS::Heat::Value',NULL,1351),(2202,'d13995d8-b05e-434d-b4a0-bfa0aef499cc','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk-OVNBridgeMappingsValue-jns64lkafnyh','state changed','OS::Heat::Value',NULL,1351),(2203,'5f3d9c35-8cf6-4a40-946c-240372ce631e','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','ContainersCommon','51ec4d4d-6180-45a6-ad8f-2827695c0e10','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2204,'b9e900e3-6309-4698-85c3-94ed2d9af089','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:14',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronLogging-jjpfcnlafxji','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1352),(2205,'f60f2924-f260-4a17-8d72-7d2a293d8d2c','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','ContainersCommon','9225f431-9594-4df4-8398-56052b76f49e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2206,'a3de475d-e03e-4bfa-84f4-c2556e789aa1','5c302004-24da-4898-bc97-91940d5fe258','2026-06-13 07:51:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronLogging-jjpfcnlafxji','5c302004-24da-4898-bc97-91940d5fe258','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2207,'6b8474b1-4757-4aee-b84d-b198c9d49f31','da938181-6a0a-4d18-88ce-08d55494c29f','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-28-rmzrftntcckx','da938181-6a0a-4d18-88ce-08d55494c29f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2208,'00146f4e-9a7e-414f-bc7d-3f8529a715c2','5c302004-24da-4898-bc97-91940d5fe258','2026-06-13 07:51:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronLogging-jjpfcnlafxji-RoleParametersValue-th6xceozetrn','state changed','OS::Heat::Value',NULL,1353),(2209,'a6e3406a-a328-4cc9-8fc5-5616d097d07b','5c302004-24da-4898-bc97-91940d5fe258','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronLogging-jjpfcnlafxji-RoleParametersValue-th6xceozetrn','state changed','OS::Heat::Value',NULL,1353),(2210,'819d0a3d-f674-485b-bb87-6d5bc0497a34','5c302004-24da-4898-bc97-91940d5fe258','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronLogging-jjpfcnlafxji','5c302004-24da-4898-bc97-91940d5fe258','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2211,'0f4bc9de-3a1c-4455-915a-78332dab12a6','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','ContainersCommon','7c690d5c-fa56-4a0f-bde4-772aafa3baf8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2212,'5ef8b5dd-9b3d-40ec-b681-80476e866328','73bd7b90-2b80-42d4-afc4-344a29d3474a','2026-06-13 07:51:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-39-v555skhhd5eg','73bd7b90-2b80-42d4-afc4-344a29d3474a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2213,'780bf9f1-643e-4f4d-9c0c-0ddd0034a289','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk-RoleParametersValue-5bu3nhp55xa6','state changed','OS::Heat::Value',NULL,1354),(2214,'7f342675-fff3-4f3f-af34-68158f818848','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk-RoleParametersValue-5bu3nhp55xa6','state changed','OS::Heat::Value',NULL,1354),(2215,'6f8186c0-6acd-4000-bc22-2df294465de6','93efd107-b585-4412-b131-3edcb33816a2','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-50-ik6wo4w7elxk','93efd107-b585-4412-b131-3edcb33816a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2216,'e0cb233f-aae8-4595-812a-ab1f72a14df4','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','28','da938181-6a0a-4d18-88ce-08d55494c29f','state changed','OS::TripleO::Services::HeatEngine',NULL,1317),(2217,'2d95583d-8d5f-4e8a-abf8-53d1c60eef09','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','39','73bd7b90-2b80-42d4-afc4-344a29d3474a','state changed','OS::TripleO::Services::MySQL',NULL,1332),(2218,'9d401966-6e5f-4976-953e-ff5f17177c84','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:15',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronBase-dgxatscxst5z','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1363),(2219,'392a7c94-f3a1-42fb-9f0f-734e00857b7a','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','NeutronLogging','5c302004-24da-4898-bc97-91940d5fe258','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1352),(2220,'7fde88b4-a67a-475b-8d7c-c88f40a51d8e','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:15',NULL,'CREATE','IN_PROGRESS','32','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg','state changed','OS::TripleO::Services::Keystone',NULL,1367),(2221,'eabd3def-8a0e-421c-9ab1-3fedafc77c11','e2842160-4324-412e-be06-78bb07540cf4','2026-06-13 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronBase-dgxatscxst5z','e2842160-4324-412e-be06-78bb07540cf4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2222,'59ca0609-872e-4ee3-955b-b52139c8dc49','e2842160-4324-412e-be06-78bb07540cf4','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-NeutronBase-dgxatscxst5z','e2842160-4324-412e-be06-78bb07540cf4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2223,'e52a26f4-074a-4bfb-9eda-422f87fe4ed0','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:15',NULL,'CREATE','IN_PROGRESS','43','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm','state changed','OS::TripleO::Services::NovaApi',NULL,1368),(2224,'e099eb58-a7e7-4a62-a7f3-4bf51998e3e7','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','NeutronBase','e2842160-4324-412e-be06-78bb07540cf4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1363),(2225,'827305bc-5231-4b97-adcd-cf9467e01637','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg','b275cd60-19db-4453-a9ee-2d1646820598','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2226,'a0202201-885d-477e-b1ef-e8fb4ff60836','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2227,'fc58f5e8-524b-4c67-b2f2-210b3b393938','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:15',NULL,'CREATE','COMPLETE','50','93efd107-b585-4412-b131-3edcb33816a2','state changed','OS::TripleO::Services::OVNController',NULL,1350),(2228,'8bad34ed-1e59-4bf8-af48-b9c165ba3474','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ContainersCommon-sv66rm6rkwd6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2229,'d502f7ae-96ca-4659-8196-37a4fd064e01','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiDBClient-jwa7lui4cwdz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1369),(2230,'4f3d80b2-e763-499e-8f65-dffd6dfeb228','88ba7d2e-059e-445e-bbc9-ec9be4e303dc','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ContainersCommon-sv66rm6rkwd6','88ba7d2e-059e-445e-bbc9-ec9be4e303dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2231,'9daa9bf5-199f-459b-b7db-979e68545906','88ba7d2e-059e-445e-bbc9-ec9be4e303dc','2026-06-13 07:51:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ContainersCommon-sv66rm6rkwd6','88ba7d2e-059e-445e-bbc9-ec9be4e303dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2232,'c4f21186-2b96-4d64-b276-d07ad79cebac','97308369-3369-4495-bd6d-977b82494220','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiDBClient-jwa7lui4cwdz','97308369-3369-4495-bd6d-977b82494220','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2233,'3b4744e5-4626-4b27-a5a2-eb6e6cb46c42','97308369-3369-4495-bd6d-977b82494220','2026-06-13 07:51:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiDBClient-jwa7lui4cwdz','97308369-3369-4495-bd6d-977b82494220','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2234,'92dd4bbb-bc70-4034-99a8-9188841edf6a','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','54','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-54-rjvuhey2a7ip','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1374),(2235,'63c11467-278e-41c4-8e18-26b3ee39d2dc','76898081-2557-4a7d-8a99-d9accc91f6c0','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-54-rjvuhey2a7ip','76898081-2557-4a7d-8a99-d9accc91f6c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2236,'972b926b-824d-41e9-9b1c-ae3480ed1d57','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-RoleParametersValue-qrn7qscd247f','state changed','OS::Heat::Value',NULL,1375),(2237,'a7370887-2764-482c-bc86-9a6e1fd244cb','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-RoleParametersValue-qrn7qscd247f','state changed','OS::Heat::Value',NULL,1375),(2238,'1c79fd70-4ff3-491e-9ffd-080bf14331fc','76898081-2557-4a7d-8a99-d9accc91f6c0','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-54-rjvuhey2a7ip-ContainersCommon-nb25d4d3kgoc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2239,'1676c9b6-6725-40e6-b822-a03b343ddef6','c4eca0c6-bfcb-4ca9-9ac8-5543d13491f9','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-54-rjvuhey2a7ip-ContainersCommon-nb25d4d3kgoc','c4eca0c6-bfcb-4ca9-9ac8-5543d13491f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2240,'da578959-f7fd-4c52-be06-230d979d5347','c4eca0c6-bfcb-4ca9-9ac8-5543d13491f9','2026-06-13 07:51:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-54-rjvuhey2a7ip-ContainersCommon-nb25d4d3kgoc','c4eca0c6-bfcb-4ca9-9ac8-5543d13491f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2241,'de56ddcb-af37-4293-be54-41aef7a70919','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:16',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ApacheServiceBase-mzvd7yh4e7ks','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1376),(2242,'203fb0d4-ba03-4ecd-bfbb-01e7e79a762b','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:17',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ApacheServiceBase-4n6x5yezsqpl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1377),(2243,'9af984ed-d472-49bf-92e7-046f45ddf995','fe28e1cb-7f31-467a-b6f6-aa58b71b7185','2026-06-13 07:51:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ApacheServiceBase-mzvd7yh4e7ks','fe28e1cb-7f31-467a-b6f6-aa58b71b7185','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2244,'e819eed4-ae73-46f8-bd77-6d5521dcac89','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','ContainersCommon','88ba7d2e-059e-445e-bbc9-ec9be4e303dc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2245,'f29f2494-c20e-458a-9e22-17caf2f58050','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','NovaApiDBClient','97308369-3369-4495-bd6d-977b82494220','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1369),(2246,'d11d6431-d011-4fd1-b6b4-a43c92b40fe6','f8a1da63-43a1-4422-8176-b94dfcfba5d4','2026-06-13 07:51:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ApacheServiceBase-4n6x5yezsqpl','f8a1da63-43a1-4422-8176-b94dfcfba5d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2247,'f0d9d43f-ee7b-4cdc-928a-a20d2dd91d3d','fe28e1cb-7f31-467a-b6f6-aa58b71b7185','2026-06-13 07:51:17',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ApacheServiceBase-mzvd7yh4e7ks-ApacheNetworks-lnjjwbse3h6m','state changed','OS::Heat::Value',NULL,1378),(2248,'8712265b-a282-42a5-a5e1-9db449e84314','fe28e1cb-7f31-467a-b6f6-aa58b71b7185','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ApacheServiceBase-mzvd7yh4e7ks-ApacheNetworks-lnjjwbse3h6m','state changed','OS::Heat::Value',NULL,1378),(2249,'085503a5-0fdc-4a86-9979-e007df850773','fe28e1cb-7f31-467a-b6f6-aa58b71b7185','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-ApacheServiceBase-mzvd7yh4e7ks','fe28e1cb-7f31-467a-b6f6-aa58b71b7185','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2250,'ecd62b64-2f79-4663-bb22-81f75d258cc9','f8a1da63-43a1-4422-8176-b94dfcfba5d4','2026-06-13 07:51:17',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ApacheServiceBase-4n6x5yezsqpl-ApacheNetworks-tzgsztceuw3k','state changed','OS::Heat::Value',NULL,1379),(2251,'5bf37b16-d0f6-4bd3-9740-062432444ce2','f8a1da63-43a1-4422-8176-b94dfcfba5d4','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ApacheServiceBase-4n6x5yezsqpl-ApacheNetworks-tzgsztceuw3k','state changed','OS::Heat::Value',NULL,1379),(2252,'81aebe12-7f99-4241-b022-0fe81f8b0038','f8a1da63-43a1-4422-8176-b94dfcfba5d4','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ApacheServiceBase-4n6x5yezsqpl','f8a1da63-43a1-4422-8176-b94dfcfba5d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2253,'38d75202-d989-42a2-a543-ff7eef944288','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:17',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal-TLSProxyBase-bv5smncr373c','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(2254,'f16eac34-07b2-41cf-a07d-34d7c40496c7','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','TLSProxyBase','4ca7235e-b3d9-46cd-856c-5245156ebf1d','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(2255,'a93a5b99-4d4f-4dae-b87e-c0203b2c8806','89f8cc2e-5b51-4050-92cd-a440f33484af','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-41-crvjlp4bzqal','89f8cc2e-5b51-4050-92cd-a440f33484af','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2256,'83a66df1-6d3e-446b-8f2c-2c0e2fab948d','76898081-2557-4a7d-8a99-d9accc91f6c0','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','ContainersCommon','c4eca0c6-bfcb-4ca9-9ac8-5543d13491f9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2257,'02c49c76-cecf-4a2e-8155-9e4d6b02b294','76898081-2557-4a7d-8a99-d9accc91f6c0','2026-06-13 07:51:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-54-rjvuhey2a7ip','76898081-2557-4a7d-8a99-d9accc91f6c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2258,'2649d29d-d581-4bc6-96a1-41f8ac189ed2','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-RoleParametersValue-6gm62hftlebr','state changed','OS::Heat::Value',NULL,1380),(2259,'a3dc3fc9-ca38-45e0-9039-c7c5c3a2bfba','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-RoleParametersValue-6gm62hftlebr','state changed','OS::Heat::Value',NULL,1380),(2260,'07b64e23-da93-46ed-80f0-a99b93d431c1','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:18',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaDBClient-54cs5osjx2hd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1381),(2261,'22971293-ba19-4e0f-a2c8-65c9fec1f659','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:18',NULL,'CREATE','COMPLETE','ApacheServiceBase','fe28e1cb-7f31-467a-b6f6-aa58b71b7185','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1376),(2262,'826ef8b0-64bc-4ea4-b7c6-605515036cae','a81dbec2-217e-4073-99d9-7fe08715a73e','2026-06-13 07:51:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaDBClient-54cs5osjx2hd','a81dbec2-217e-4073-99d9-7fe08715a73e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2263,'80518ff8-ee15-4308-ad14-c804901d1d77','a81dbec2-217e-4073-99d9-7fe08715a73e','2026-06-13 07:51:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaDBClient-54cs5osjx2hd','a81dbec2-217e-4073-99d9-7fe08715a73e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2264,'fe0badf1-94fd-4ff6-9280-65acb607de56','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:18',NULL,'CREATE','COMPLETE','ApacheServiceBase','f8a1da63-43a1-4422-8176-b94dfcfba5d4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1377),(2265,'c11418c5-8bdd-4786-9508-647cc99bc82f','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:18',NULL,'CREATE','COMPLETE','41','89f8cc2e-5b51-4050-92cd-a440f33484af','state changed','OS::TripleO::Services::NeutronApi',NULL,1338),(2266,'8ff4a5a8-dc7a-4f20-be2e-52e11dbb8f66','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:18',NULL,'CREATE','COMPLETE','54','76898081-2557-4a7d-8a99-d9accc91f6c0','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1374),(2267,'946530e2-663d-4ba7-80c7-94c9aad221fe','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:18',NULL,'CREATE','IN_PROGRESS','58','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-58-wq5guit5ozrw','state changed','OS::TripleO::Services::Snmp',NULL,1391),(2268,'173e68a6-ee3b-495a-94aa-2441c041c537','8aefeeb5-2e03-4d2c-9651-089c5564d0cc','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-58-wq5guit5ozrw','8aefeeb5-2e03-4d2c-9651-089c5564d0cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2269,'a4e978ab-135e-444d-b3d5-3131e2401945','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaBase-3ixqowdhehcz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1393),(2270,'9c689721-b2e1-4f3e-8cba-da94c8a92ddb','8aefeeb5-2e03-4d2c-9651-089c5564d0cc','2026-06-13 07:51:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-58-wq5guit5ozrw','8aefeeb5-2e03-4d2c-9651-089c5564d0cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2271,'395c01ef-a737-42f6-8bce-2996f3435abd','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','45','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23','state changed','OS::TripleO::Services::NovaMetadata',NULL,1394),(2272,'913071ba-b3af-4233-8b11-59cdc46397a2','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-MySQLClient-6uqcg7tmlxh7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2273,'8e51a98f-4a26-406b-bcd0-4528e852f44a','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:19',NULL,'CREATE','COMPLETE','NovaDBClient','a81dbec2-217e-4073-99d9-7fe08715a73e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1381),(2274,'55e6701a-e8d8-4de5-82c1-aa3cc9a6c68f','c450ec11-c90c-49ae-94ab-03e5554f2af3','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaBase-3ixqowdhehcz','c450ec11-c90c-49ae-94ab-03e5554f2af3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2275,'960a88bd-8052-4689-a9a9-3acef5639f7b','c450ec11-c90c-49ae-94ab-03e5554f2af3','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaBase-3ixqowdhehcz-RoleParametersValue-2tn7dwy5gt3v','state changed','OS::Heat::Value',NULL,1395),(2276,'f7cc0bc1-cac8-467c-badd-35605ae690bc','c450ec11-c90c-49ae-94ab-03e5554f2af3','2026-06-13 07:51:19',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaBase-3ixqowdhehcz-RoleParametersValue-2tn7dwy5gt3v','state changed','OS::Heat::Value',NULL,1395),(2277,'09088c68-dcdc-4d9a-bfb0-eb398779f8bc','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23','766aa71c-a52d-411e-ad0b-5b499329e408','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2278,'6ea6fbe2-5781-4bf1-9a5a-2867d60ad87b','c450ec11-c90c-49ae-94ab-03e5554f2af3','2026-06-13 07:51:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaBase-3ixqowdhehcz','c450ec11-c90c-49ae-94ab-03e5554f2af3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2279,'49802ad1-bcb8-44b8-8594-a4a38764354e','9a13cec1-20e4-4887-a8c4-4405b5f17fbd','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-MySQLClient-6uqcg7tmlxh7','9a13cec1-20e4-4887-a8c4-4405b5f17fbd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2280,'6426b0bd-4822-45cb-b8bc-094c34a4de8d','9a13cec1-20e4-4887-a8c4-4405b5f17fbd','2026-06-13 07:51:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-MySQLClient-6uqcg7tmlxh7','9a13cec1-20e4-4887-a8c4-4405b5f17fbd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2281,'05b2d3d4-526c-443f-8e55-726fa80f3154','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ContainersCommon-ht36e6z753el','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2282,'62e6664a-3bf2-4837-963b-831bc8d3daac','a1aba355-7dd2-4b6a-9fbf-0ae352537c28','2026-06-13 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ContainersCommon-ht36e6z753el','a1aba355-7dd2-4b6a-9fbf-0ae352537c28','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2283,'99e277fb-2580-4411-ad24-5cee0fc3d1a5','a1aba355-7dd2-4b6a-9fbf-0ae352537c28','2026-06-13 07:51:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ContainersCommon-ht36e6z753el','a1aba355-7dd2-4b6a-9fbf-0ae352537c28','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2284,'42f0b7d7-ece8-44fa-99d0-ac4b8998f4ba','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-RoleParametersValue-bhs3bflxf7qp','state changed','OS::Heat::Value',NULL,1396),(2285,'0e380655-274a-4a3e-84f7-72f1a2f176f4','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-RoleParametersValue-bhs3bflxf7qp','state changed','OS::Heat::Value',NULL,1396),(2286,'c60fa3db-4ded-40b9-b1a0-179454efbfdd','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','58','8aefeeb5-2e03-4d2c-9651-089c5564d0cc','state changed','OS::TripleO::Services::Snmp',NULL,1391),(2287,'7f309b55-8c7f-42c9-b7b4-fa797624f403','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','KeystoneLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-KeystoneLogging-k4bocviufqrj','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(2288,'2881557f-de4d-40c1-b5e9-228ecf265a09','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','NovaBase','c450ec11-c90c-49ae-94ab-03e5554f2af3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1393),(2289,'f16e7736-dd3c-4277-bb12-2c96770c670a','1dbb833e-ece3-4cc3-9ce1-dade2f3c7700','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-KeystoneLogging-k4bocviufqrj','1dbb833e-ece3-4cc3-9ce1-dade2f3c7700','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2290,'92205fac-76c5-4d07-b9ed-78f38c46dabc','1dbb833e-ece3-4cc3-9ce1-dade2f3c7700','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-KeystoneLogging-k4bocviufqrj-RoleParametersValue-44pg26ypefyb','state changed','OS::Heat::Value',NULL,1398),(2291,'e14abde0-09fe-4de4-9086-a16d77fe13e3','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','MySQLClient','9a13cec1-20e4-4887-a8c4-4405b5f17fbd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2292,'4b6e3769-afe8-4a13-a1e7-1447f29f6c08','1dbb833e-ece3-4cc3-9ce1-dade2f3c7700','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-KeystoneLogging-k4bocviufqrj-RoleParametersValue-44pg26ypefyb','state changed','OS::Heat::Value',NULL,1398),(2293,'36cbd245-1c49-478d-9095-7f421d9d7dca','1dbb833e-ece3-4cc3-9ce1-dade2f3c7700','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg-KeystoneLogging-k4bocviufqrj','1dbb833e-ece3-4cc3-9ce1-dade2f3c7700','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2294,'b9aab7aa-e1a6-4888-a273-7f6d733e5d95','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','62','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af','state changed','OS::TripleO::Services::SwiftStorage',NULL,1399),(2295,'bad4be7d-1c8c-4fb3-97a5-3f842fb32c88','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaDBClient-mfl3oqp3knph','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1400),(2296,'2db0be34-e81c-4abd-905d-b1f9e6f54c58','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af','96b52160-efb7-40cc-9979-74dcac699374','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2297,'d57beaf8-ba47-4350-9796-13af5e448d93','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','ContainersCommon','a1aba355-7dd2-4b6a-9fbf-0ae352537c28','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2298,'ca85bd1f-72b3-4342-832c-1f70388badf0','14c12b65-8968-4ca9-b35c-bb4e5a8a0c58','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaDBClient-mfl3oqp3knph','14c12b65-8968-4ca9-b35c-bb4e5a8a0c58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2299,'eb12b155-cfa1-435b-9f7e-344ad7cf4a42','14c12b65-8968-4ca9-b35c-bb4e5a8a0c58','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaDBClient-mfl3oqp3knph','14c12b65-8968-4ca9-b35c-bb4e5a8a0c58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2300,'1efe86d8-cf74-4973-83a9-779c38c27fcf','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-SwiftBase-vmlsxnmxjunv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1401),(2301,'170b822b-7543-45ac-b776-08266f693440','99218598-794b-4d13-b217-252c43df30a3','2026-06-13 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-SwiftBase-vmlsxnmxjunv','99218598-794b-4d13-b217-252c43df30a3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2302,'0389ff0e-e5dc-4063-ae80-b0e8a9e32590','99218598-794b-4d13-b217-252c43df30a3','2026-06-13 07:51:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-SwiftBase-vmlsxnmxjunv','99218598-794b-4d13-b217-252c43df30a3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2303,'65d9860b-c9e5-43a5-89d6-265a01dc79dd','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:21',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-MySQLClient-ljnqqde3ze3i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2304,'a0fae33f-53ec-473f-8574-c6e299104322','700d82c9-85b8-4aa4-ad51-e5a3588fa58a','2026-06-13 07:51:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-MySQLClient-ljnqqde3ze3i','700d82c9-85b8-4aa4-ad51-e5a3588fa58a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2305,'f6bd5bf9-0ba7-41e9-a308-8674c178a0ec','700d82c9-85b8-4aa4-ad51-e5a3588fa58a','2026-06-13 07:51:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-MySQLClient-ljnqqde3ze3i','700d82c9-85b8-4aa4-ad51-e5a3588fa58a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2306,'d99b1918-056f-4674-aa4e-a3902ead4fa1','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:21',NULL,'CREATE','COMPLETE','KeystoneLogging','1dbb833e-ece3-4cc3-9ce1-dade2f3c7700','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(2307,'03a7c3a0-02cc-4f19-aaf7-32574a6c1e15','b275cd60-19db-4453-a9ee-2d1646820598','2026-06-13 07:51:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-32-jjdeujviytvg','b275cd60-19db-4453-a9ee-2d1646820598','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2308,'a79e288a-89f4-4b34-89fc-19a959355cd7','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-RoleParametersValue-u5lp74ndobnc','state changed','OS::Heat::Value',NULL,1402),(2309,'da719a5b-44d1-4e48-aed8-67643338aa17','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-RoleParametersValue-u5lp74ndobnc','state changed','OS::Heat::Value',NULL,1402),(2310,'544e614b-ead9-40f8-b4d6-312db80ae31b','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:21',NULL,'CREATE','COMPLETE','NovaDBClient','14c12b65-8968-4ca9-b35c-bb4e5a8a0c58','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1400),(2311,'956a2345-38a3-41a1-9470-b2a852879870','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:21',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-ContainersCommon-irkeretxd4wx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2312,'67154b78-fa8a-4234-afd2-9c965b17ad8c','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:21',NULL,'CREATE','COMPLETE','32','b275cd60-19db-4453-a9ee-2d1646820598','state changed','OS::TripleO::Services::Keystone',NULL,1367),(2313,'6a69725f-0707-4784-bc20-462d3633a9fa','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:21',NULL,'CREATE','COMPLETE','SwiftBase','99218598-794b-4d13-b217-252c43df30a3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1401),(2314,'d846015e-ebaf-47f0-85da-11ad275cd442','75d25a07-d57b-4013-8261-0a9b5cdbb97b','2026-06-13 07:51:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-ContainersCommon-irkeretxd4wx','75d25a07-d57b-4013-8261-0a9b5cdbb97b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2315,'903be3d3-3a02-448d-b18b-c6092323f73b','75d25a07-d57b-4013-8261-0a9b5cdbb97b','2026-06-13 07:51:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-ContainersCommon-irkeretxd4wx','75d25a07-d57b-4013-8261-0a9b5cdbb97b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2316,'365b2ec9-fae1-4ee7-b14c-ceb8fd0e925b','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','NovaApiLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiLogging-qpkxdhdqxt3n','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2317,'62a8f381-e506-4ae8-8cac-88b44b1165ae','e34504a9-78ce-49cc-a634-df7050c7ca4a','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiLogging-qpkxdhdqxt3n','e34504a9-78ce-49cc-a634-df7050c7ca4a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2318,'6fa55d27-6509-47d5-a894-4adc0d44b890','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:22',NULL,'CREATE','COMPLETE','MySQLClient','700d82c9-85b8-4aa4-ad51-e5a3588fa58a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2319,'d223570a-a69f-483f-b642-0c5fe3e7d14c','e34504a9-78ce-49cc-a634-df7050c7ca4a','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiLogging-qpkxdhdqxt3n-RoleParametersValue-vkt65k3cs7ng','state changed','OS::Heat::Value',NULL,1408),(2320,'cd6b3753-5ca5-4314-8c52-5d06282c1b93','e34504a9-78ce-49cc-a634-df7050c7ca4a','2026-06-13 07:51:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiLogging-qpkxdhdqxt3n-RoleParametersValue-vkt65k3cs7ng','state changed','OS::Heat::Value',NULL,1408),(2321,'1d69fef7-64fc-4c7d-9b67-86a0c6ce1770','e34504a9-78ce-49cc-a634-df7050c7ca4a','2026-06-13 07:51:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-NovaApiLogging-qpkxdhdqxt3n','e34504a9-78ce-49cc-a634-df7050c7ca4a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2322,'5cd06d91-fbe4-4766-b4c0-92e40c09abfa','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','36','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi','state changed','OS::TripleO::Services::ManilaShare',NULL,1412),(2323,'8f254870-27e9-4635-9c42-ced039c7dcf8','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','NovaMetadataLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaMetadataLogging-6zzealiyllpd','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2324,'a646be19-a0ee-4337-b204-c4972c9f789a','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2325,'6c6df0f9-46e9-436b-b06b-b8b4a127a133','871f8ba4-1afc-4e8a-9806-05ea40158a7b','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaMetadataLogging-6zzealiyllpd','871f8ba4-1afc-4e8a-9806-05ea40158a7b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2326,'a3df0fba-2258-4439-8e3c-323305b1ea54','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-RoleParametersValue-q6umm5b22u3i','state changed','OS::Heat::Value',NULL,1413),(2327,'e20db03b-38d3-4035-87f7-b9c1eb28f765','871f8ba4-1afc-4e8a-9806-05ea40158a7b','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaMetadataLogging-6zzealiyllpd-RoleParametersValue-fidxdo5bnorj','state changed','OS::Heat::Value',NULL,1414),(2328,'11be4d7f-a299-4c27-aef9-6240d0a3336b','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af-RoleParametersValue-q6umm5b22u3i','state changed','OS::Heat::Value',NULL,1413),(2329,'58a3043e-d50b-46f3-a163-1d6c31b53804','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','ManilaShareContainerBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1415),(2330,'edb5127b-21df-4607-88de-c0a7e4c12d87','871f8ba4-1afc-4e8a-9806-05ea40158a7b','2026-06-13 07:51:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaMetadataLogging-6zzealiyllpd-RoleParametersValue-fidxdo5bnorj','state changed','OS::Heat::Value',NULL,1414),(2331,'e9591dc7-abb4-494e-9202-f2980c15fb20','871f8ba4-1afc-4e8a-9806-05ea40158a7b','2026-06-13 07:51:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaMetadataLogging-6zzealiyllpd','871f8ba4-1afc-4e8a-9806-05ea40158a7b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2332,'72fe7700-6ada-476d-8328-6cc2e354e02a','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3','07099793-08cb-406f-9e21-d7897a887539','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2333,'554e20d4-8c2c-4ba9-a640-a719e6ca9cd3','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','ContainersCommon','75d25a07-d57b-4013-8261-0a9b5cdbb97b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2334,'72505e69-9e79-404b-8a7f-ea7212ba6f5a','96b52160-efb7-40cc-9979-74dcac699374','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-62-h5ginjook2af','96b52160-efb7-40cc-9979-74dcac699374','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2335,'627e0e94-6581-4fb9-b730-5bcdadcc15dd','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ContainersCommon-duy3eb3z2ffe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2336,'87f3c89e-9db1-43fe-9f0f-92910c5798e7','35b22e6b-0e60-48bc-9238-0cb9309fe609','2026-06-13 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ContainersCommon-duy3eb3z2ffe','35b22e6b-0e60-48bc-9238-0cb9309fe609','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2337,'3583e4fa-7224-49aa-ac13-fbf48a68b36c','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','NovaApiLogging','e34504a9-78ce-49cc-a634-df7050c7ca4a','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2338,'208f9724-b65a-4efe-8005-4917165f9345','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-RoleParametersValue-7rq3rddciurd','state changed','OS::Heat::Value',NULL,1416),(2339,'67b51a32-f149-49a4-ade4-774542068e75','35b22e6b-0e60-48bc-9238-0cb9309fe609','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm-ContainersCommon-duy3eb3z2ffe','35b22e6b-0e60-48bc-9238-0cb9309fe609','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2340,'6c52a5f2-d016-4517-bb69-8daf3a8083be','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-RoleParametersValue-7rq3rddciurd','state changed','OS::Heat::Value',NULL,1416),(2341,'87e4c064-b910-41cb-ba80-91c4ae646ebe','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:23',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaBase-h6okuo6a2bsa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1417),(2342,'ce0b8064-6480-4248-83ba-07fc7b263164','df9d8bc8-7232-4698-ae44-87317b611389','2026-06-13 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaBase-h6okuo6a2bsa','df9d8bc8-7232-4698-ae44-87317b611389','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2343,'8e72e1a9-060d-407a-8894-e71fbc4047cf','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','62','96b52160-efb7-40cc-9979-74dcac699374','state changed','OS::TripleO::Services::SwiftStorage',NULL,1399),(2344,'e2b1d4b9-1de9-46a2-9453-201c3b9f0379','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','NovaMetadataLogging','871f8ba4-1afc-4e8a-9806-05ea40158a7b','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2345,'f4303a45-63d9-4737-92c8-a87e56778163','df9d8bc8-7232-4698-ae44-87317b611389','2026-06-13 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaBase-h6okuo6a2bsa-RoleParametersValue-k765ldxnc3lz','state changed','OS::Heat::Value',NULL,1418),(2346,'f503f9fa-f15f-41f7-a45f-38d472577563','df9d8bc8-7232-4698-ae44-87317b611389','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaBase-h6okuo6a2bsa-RoleParametersValue-k765ldxnc3lz','state changed','OS::Heat::Value',NULL,1418),(2347,'7ee2a8a7-0032-453f-a05d-e23113b89294','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-RoleParametersValue-ry7spehrovm4','state changed','OS::Heat::Value',NULL,1420),(2348,'187b0051-346d-4626-bf9b-9a021886520c','df9d8bc8-7232-4698-ae44-87317b611389','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaBase-h6okuo6a2bsa','df9d8bc8-7232-4698-ae44-87317b611389','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2349,'e9a29ea8-2111-4674-9659-2ee2909555c9','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-RoleParametersValue-ry7spehrovm4','state changed','OS::Heat::Value',NULL,1420),(2350,'13927623-fb1b-43cc-811a-3b619c8b699a','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','66','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls','state changed','OS::TripleO::Services::TripleoPackages',NULL,1424),(2351,'c57185db-88c3-4034-97eb-74c9941c4eb5','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:24',NULL,'CREATE','COMPLETE','ContainersCommon','35b22e6b-0e60-48bc-9238-0cb9309fe609','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2352,'06a332da-1e58-4dcc-8158-22924a1f5518','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-MySQLClient-que3l7wgfhdb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2353,'97757b2c-8e06-48c7-b953-5b9e0adfbfaf','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','2026-06-13 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-43-n5zpp2dhnjbm','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2354,'8668f9ba-ddd6-482b-b28e-585463e122c9','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2355,'d81fea48-4a05-4ff0-80ba-a084f485965f','522eeeb8-adf5-495f-9805-c4e34615f5bf','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-MySQLClient-que3l7wgfhdb','522eeeb8-adf5-495f-9805-c4e34615f5bf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2356,'1b3cde21-0eae-4850-abf2-dfba62a8179e','522eeeb8-adf5-495f-9805-c4e34615f5bf','2026-06-13 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-MySQLClient-que3l7wgfhdb','522eeeb8-adf5-495f-9805-c4e34615f5bf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2357,'c1457414-e27d-4c1f-b0c0-1f53deeac6de','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls-Podman-yiemtsjht2c3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1425),(2358,'4e7015b2-e543-4fcb-9047-c4bd75cad46e','e95713e9-c573-4284-a204-ef7bf7e16063','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls-Podman-yiemtsjht2c3','e95713e9-c573-4284-a204-ef7bf7e16063','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2359,'13bfed07-efa5-4366-86f3-a78da45ff74f','e95713e9-c573-4284-a204-ef7bf7e16063','2026-06-13 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls-Podman-yiemtsjht2c3','e95713e9-c573-4284-a204-ef7bf7e16063','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2360,'c3ac2eef-045a-4b76-8afb-a3e213c6cb1b','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaApiDBClient-f47u5xwmbcst','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1426),(2361,'c226d6ec-94ab-43e1-8bc4-ea1cd5b50aa2','a572f5f0-c7cb-4c3a-83ee-42c31b890c85','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaApiDBClient-f47u5xwmbcst','a572f5f0-c7cb-4c3a-83ee-42c31b890c85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2362,'0390684c-b199-4d3c-857c-3a93ba85fdf6','a572f5f0-c7cb-4c3a-83ee-42c31b890c85','2026-06-13 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-NovaApiDBClient-f47u5xwmbcst','a572f5f0-c7cb-4c3a-83ee-42c31b890c85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2363,'7bdbe8a6-753c-49b1-9a39-ba0ee73c2950','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:24',NULL,'CREATE','COMPLETE','NovaBase','df9d8bc8-7232-4698-ae44-87317b611389','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1417),(2364,'5d87097b-530f-4c0d-a3b6-f001c87b3b6c','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','ManilaCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaCommon-m7s7zup6prlz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(2365,'8c1ef2b7-b44d-44ba-b50f-02eb12b44f43','3a84ed8a-5592-407f-95c7-d21bd1e04e2b','2026-06-13 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaCommon-m7s7zup6prlz','3a84ed8a-5592-407f-95c7-d21bd1e04e2b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2366,'122a945d-a56e-4d9a-b3b0-2de0dab3a8d5','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:24',NULL,'CREATE','COMPLETE','43','2d73fdaf-ed1d-4b64-9478-b9de2a36731c','state changed','OS::TripleO::Services::NovaApi',NULL,1368),(2367,'503e3aaa-655c-4db2-a3c3-64f7898e6afa','3a84ed8a-5592-407f-95c7-d21bd1e04e2b','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaCommon-m7s7zup6prlz-ContainersCommon-xh5wp5uwdcjy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2368,'b6811927-e0c5-4f99-9e99-3d687dd58247','d85a9006-e596-4326-95a3-969165461d80','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaCommon-m7s7zup6prlz-ContainersCommon-xh5wp5uwdcjy','d85a9006-e596-4326-95a3-969165461d80','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2369,'3653ff39-523d-4cbe-9752-8600ac6937b4','d85a9006-e596-4326-95a3-969165461d80','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaCommon-m7s7zup6prlz-ContainersCommon-xh5wp5uwdcjy','d85a9006-e596-4326-95a3-969165461d80','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2370,'82127366-4d62-4190-b42f-8291df560301','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ContainersCommon-3wkcdbqupxxt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2371,'dea16fcb-c676-4699-beef-39cf28556207','5e9d504d-3911-41f3-9d9e-89815a760792','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ContainersCommon-3wkcdbqupxxt','5e9d504d-3911-41f3-9d9e-89815a760792','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2372,'a3747464-fc95-491d-a766-a9b684601474','5e9d504d-3911-41f3-9d9e-89815a760792','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ContainersCommon-3wkcdbqupxxt','5e9d504d-3911-41f3-9d9e-89815a760792','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2373,'1d1e5cba-8249-4a3c-8923-2238e73a3569','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','MySQLClient','522eeeb8-adf5-495f-9805-c4e34615f5bf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2374,'44f3f7f4-5af1-4e9b-b434-e664e8abfe4d','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls-RoleParametersValue-qeieq4vu7hpo','state changed','OS::Heat::Value',NULL,1437),(2375,'5aa9c217-d72e-4759-900a-651a943eb88a','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls-RoleParametersValue-qeieq4vu7hpo','state changed','OS::Heat::Value',NULL,1437),(2376,'be6dc324-7b07-4cd8-930d-ddc53f41b626','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','Podman','e95713e9-c573-4284-a204-ef7bf7e16063','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1425),(2377,'46d9ac55-a4fa-402a-98b4-565bc6fe90aa','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-66-ixysknqd3wls','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2378,'87392a0c-7ac2-456b-a03a-c08a69845d3c','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ApacheServiceBase-6z3gosbkukuy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1440),(2379,'88556ead-b5b5-445b-9c85-ccf7afcb8b85','03fa808d-426c-4c60-bebb-b6b0f1652ed0','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ApacheServiceBase-6z3gosbkukuy','03fa808d-426c-4c60-bebb-b6b0f1652ed0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2380,'1c43cdec-439d-4091-a55a-ee4a8cac7a2b','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','NovaApiDBClient','a572f5f0-c7cb-4c3a-83ee-42c31b890c85','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1426),(2381,'60a36cd6-3e51-40b2-a463-be2307382d59','03fa808d-426c-4c60-bebb-b6b0f1652ed0','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ApacheServiceBase-6z3gosbkukuy-ApacheNetworks-64bjohc7km2p','state changed','OS::Heat::Value',NULL,1441),(2382,'c833b70a-817e-4d56-8280-40325f2b7bd0','03fa808d-426c-4c60-bebb-b6b0f1652ed0','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ApacheServiceBase-6z3gosbkukuy-ApacheNetworks-64bjohc7km2p','state changed','OS::Heat::Value',NULL,1441),(2383,'ece95cb2-8b2a-4806-9f50-ec1c9e59b410','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','47','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1442),(2384,'52543688-7df5-4b45-be90-ce2e4d301bc6','03fa808d-426c-4c60-bebb-b6b0f1652ed0','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-ApacheServiceBase-6z3gosbkukuy','03fa808d-426c-4c60-bebb-b6b0f1652ed0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2385,'abf43d21-5865-4eac-aa0b-d937fae0a583','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ContainersCommon-prk6gcypf722','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2386,'2cb254e5-efc4-4b5f-bcab-83712f087822','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2387,'9a4575c0-ed09-47a8-9046-a91b0053a44f','2a9759af-0920-4f4e-9b8e-e3b4ee81640e','2026-06-13 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ContainersCommon-prk6gcypf722','2a9759af-0920-4f4e-9b8e-e3b4ee81640e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2388,'48313fdd-7bde-4544-ba2b-762713e0a242','2a9759af-0920-4f4e-9b8e-e3b4ee81640e','2026-06-13 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ContainersCommon-prk6gcypf722','2a9759af-0920-4f4e-9b8e-e3b4ee81640e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2389,'71e10d99-579c-421b-bb7c-6891d600bf4a','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-RoleParametersValue-273pirq75cay','state changed','OS::Heat::Value',NULL,1443),(2390,'7c463042-5106-434a-9f1f-01b0f30824aa','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-RoleParametersValue-273pirq75cay','state changed','OS::Heat::Value',NULL,1443),(2391,'a367d0c5-2b07-4b21-a1d1-9191867aa1f8','3a84ed8a-5592-407f-95c7-d21bd1e04e2b','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','ContainersCommon','d85a9006-e596-4326-95a3-969165461d80','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2392,'9b4047b2-1529-414d-b115-8811367da4c4','3a84ed8a-5592-407f-95c7-d21bd1e04e2b','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaCommon-m7s7zup6prlz','3a84ed8a-5592-407f-95c7-d21bd1e04e2b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2393,'56c1ec52-a36e-40ef-8952-046a9c371d7d','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaLogging-ez6zueoz7szd','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1445),(2394,'ee57b1cf-d0d6-4bdc-bc24-3fca681abcdc','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaLogging-ez6zueoz7szd','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2395,'93b06ade-6562-4edb-a204-fe750c3041c0','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','ManilaShareCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaShareCommon-ytwljguyz5v7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(2396,'115e03ca-7181-4cbb-99bc-eec580055e2f','eab428a6-da52-41e6-929a-abcbffec7a03','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaShareCommon-ytwljguyz5v7','eab428a6-da52-41e6-929a-abcbffec7a03','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2397,'b03b5484-e507-4633-858b-5eeda9870f74','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','ContainersCommon','5e9d504d-3911-41f3-9d9e-89815a760792','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2398,'3fb71801-4606-4cfe-a9cb-852dd6315f72','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','66','5b9d0891-e9fc-48e0-a843-7ef4b0aa4a17','state changed','OS::TripleO::Services::TripleoPackages',NULL,1424),(2399,'20d0cce5-59d2-480d-9b45-f3891e879c86','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaLogging-ez6zueoz7szd-RoleParametersValue-exmkafzp7lv6','state changed','OS::Heat::Value',NULL,1446),(2400,'dace2c81-b6d0-4ca8-afb4-cdfa291e3a6d','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaLogging-ez6zueoz7szd-RoleParametersValue-exmkafzp7lv6','state changed','OS::Heat::Value',NULL,1446),(2401,'18d337bb-9e01-41c6-bc76-5d64a049f464','eab428a6-da52-41e6-929a-abcbffec7a03','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaShareCommon-ytwljguyz5v7-ContainersCommon-lrcpuennthop','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2402,'835b6ed4-dbc0-40a8-86e0-4130148516ae','9c769a59-11c1-4b52-8b7d-5b46972856df','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaShareCommon-ytwljguyz5v7-ContainersCommon-lrcpuennthop','9c769a59-11c1-4b52-8b7d-5b46972856df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2403,'3ba55ec3-2a6f-4ebf-9dd7-74bbb66642fd','9c769a59-11c1-4b52-8b7d-5b46972856df','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaShareCommon-ytwljguyz5v7-ContainersCommon-lrcpuennthop','9c769a59-11c1-4b52-8b7d-5b46972856df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2404,'87d21828-e636-4424-906a-af3f7798ccd8','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','ApacheServiceBase','03fa808d-426c-4c60-bebb-b6b0f1652ed0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1440),(2405,'16bf0037-ace0-4fa6-9999-8817bc7df744','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-MySQLClient-arwko6h2jih7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2406,'fc817835-e1ac-44de-bd0e-8f4a9c6f87c5','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-MySQLClient-jnsk4ctla67m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2407,'16d30725-0e1c-458c-a6e5-dfdcfe107d40','b419ae78-7c2e-42cb-9d94-8e5282bcdd97','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-MySQLClient-arwko6h2jih7','b419ae78-7c2e-42cb-9d94-8e5282bcdd97','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2408,'a70105b7-9669-45cd-adfc-bdcaae8d66a6','c987a439-e10f-43dd-b389-a2da01fbe276','2026-06-13 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-MySQLClient-jnsk4ctla67m','c987a439-e10f-43dd-b389-a2da01fbe276','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2409,'2965b4d0-8324-4f79-9dfe-3df628bd857e','b419ae78-7c2e-42cb-9d94-8e5282bcdd97','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23-MySQLClient-arwko6h2jih7','b419ae78-7c2e-42cb-9d94-8e5282bcdd97','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2410,'5e8ead10-5d89-4be8-bccb-d7b9d6b19a02','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','ContainersCommon','2a9759af-0920-4f4e-9b8e-e3b4ee81640e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2411,'ba12704a-6ff9-45a1-933f-2db0f05c12f3','c987a439-e10f-43dd-b389-a2da01fbe276','2026-06-13 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-MySQLClient-jnsk4ctla67m','c987a439-e10f-43dd-b389-a2da01fbe276','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2412,'036c8323-607f-4d91-a9c0-18b245c88a24','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','ManilaCommon','3a84ed8a-5592-407f-95c7-d21bd1e04e2b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(2413,'bbccb479-4b0f-4833-b58e-83ca0ca8893d','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-ContainersCommon-63w5nckqmtas','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2414,'5155e1d7-de36-4a27-82c7-de17b7759451','af3e6e43-9929-4fd4-810b-0b26c9096e0b','2026-06-13 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-ContainersCommon-63w5nckqmtas','af3e6e43-9929-4fd4-810b-0b26c9096e0b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2415,'1653e045-4b91-4ed3-911e-32ff405c4d21','af3e6e43-9929-4fd4-810b-0b26c9096e0b','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-ContainersCommon-63w5nckqmtas','af3e6e43-9929-4fd4-810b-0b26c9096e0b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2416,'52b2fdbc-4dc7-40a2-ad56-5cbf4b1635dd','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:27',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaBase-w4h5i35myuug','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1447),(2417,'fe7e9af7-099e-4294-859a-8777a89825c4','2b132bd2-effd-4791-a633-a8fd679fc366','2026-06-13 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaBase-w4h5i35myuug','2b132bd2-effd-4791-a633-a8fd679fc366','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2418,'0c6682a9-22c8-47f2-9aa9-7284b119e27b','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','2026-06-13 07:51:27',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaLogging-ez6zueoz7szd-InitLogContainerName-m6agepezmwrl','state changed','OS::Heat::Value',NULL,1448),(2419,'2a27141f-8b11-4fad-b17a-862968c6ada6','2b132bd2-effd-4791-a633-a8fd679fc366','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaBase-w4h5i35myuug','2b132bd2-effd-4791-a633-a8fd679fc366','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2420,'feb2380b-7b97-4535-a824-f458404ee0bd','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaLogging-ez6zueoz7szd-InitLogContainerName-m6agepezmwrl','state changed','OS::Heat::Value',NULL,1448),(2421,'441a02ae-3be8-4a94-917b-a7baca7e9b4b','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaLogging-ez6zueoz7szd','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2422,'6733a135-cd75-4188-b919-1f107fca52d0','eab428a6-da52-41e6-929a-abcbffec7a03','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','ContainersCommon','9c769a59-11c1-4b52-8b7d-5b46972856df','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2423,'471550b4-15dc-411c-b81d-217e6bf5410a','eab428a6-da52-41e6-929a-abcbffec7a03','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3-ManilaShareCommon-ytwljguyz5v7','eab428a6-da52-41e6-929a-abcbffec7a03','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2424,'6d08fd22-2880-4ce3-b661-ba0ec3965526','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','MySQLClient','b419ae78-7c2e-42cb-9d94-8e5282bcdd97','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2425,'1540a5ea-223c-4bc2-bc73-137991dc4b16','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','MySQLClient','c987a439-e10f-43dd-b389-a2da01fbe276','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2426,'b1f52e01-4524-4b0c-9b99-9f6236fea21c','766aa71c-a52d-411e-ad0b-5b499329e408','2026-06-13 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-45-7ilqsv7qrs23','766aa71c-a52d-411e-ad0b-5b499329e408','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2427,'c8d0add5-584e-4111-82ac-95df60fa517b','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:28',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaBase-s3lthstdywuy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1449),(2428,'48c90e77-b172-4504-8d16-1a0373ba0be4','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','ContainersCommon','af3e6e43-9929-4fd4-810b-0b26c9096e0b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2429,'5ad41273-da7c-4cec-a315-877c1c1e2a2d','70ab00d1-d84c-4d0f-9446-6afd192d5b26','2026-06-13 07:51:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaBase-s3lthstdywuy','70ab00d1-d84c-4d0f-9446-6afd192d5b26','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2430,'6703fc03-35b7-45ef-9d97-93247185d4ad','70ab00d1-d84c-4d0f-9446-6afd192d5b26','2026-06-13 07:51:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaBase-s3lthstdywuy-RoleParametersValue-av73nshz2m4l','state changed','OS::Heat::Value',NULL,1450),(2431,'31539019-19df-41a9-a34e-a81d697b3771','70ab00d1-d84c-4d0f-9446-6afd192d5b26','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaBase-s3lthstdywuy-RoleParametersValue-av73nshz2m4l','state changed','OS::Heat::Value',NULL,1450),(2432,'5ea11ffc-5335-4f06-8183-a9893fc6648a','70ab00d1-d84c-4d0f-9446-6afd192d5b26','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaBase-s3lthstdywuy','70ab00d1-d84c-4d0f-9446-6afd192d5b26','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2433,'9990bc9d-6681-426a-8c80-9fc03b1d4b8f','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','NovaLogging','572df2f5-4c1b-4991-8b6f-ce6cdfb53712','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1445),(2434,'e24a7566-dc9a-4dcd-a37c-ca51bfab48e7','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','45','766aa71c-a52d-411e-ad0b-5b499329e408','state changed','OS::TripleO::Services::NovaMetadata',NULL,1394),(2435,'f8bbcb95-b0dc-4e47-9949-2379b1a4de43','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','ManilaBase','2b132bd2-effd-4791-a633-a8fd679fc366','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1447),(2436,'c28e29c1-3e52-4847-b7aa-6b5fcb95d48d','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','ManilaShareCommon','eab428a6-da52-41e6-929a-abcbffec7a03','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(2437,'a61f86c3-1c11-4d1b-86df-c8f29b115a68','07099793-08cb-406f-9e21-d7897a887539','2026-06-13 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi-ManilaShareContainerBase-drkoaxipcfu3','07099793-08cb-406f-9e21-d7897a887539','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2438,'e9d4f49c-4708-4a90-bf41-53a6fa03184c','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:29',NULL,'CREATE','COMPLETE','ManilaShareContainerBase','07099793-08cb-406f-9e21-d7897a887539','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1415),(2439,'0a5f1c6c-74d3-47fe-b718-971cfe468fad','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','2026-06-13 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-36-ccishlkdfvhi','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2440,'8ba63e93-94b8-4362-a7fb-669b88fb1f01','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:29',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaDBClient-kb2yawu5p7sn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1463),(2441,'5a882c79-19cd-460a-9d33-53feba120cfd','d1c6843f-e2ae-4848-af3b-f436bc2b2b2b','2026-06-13 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaDBClient-kb2yawu5p7sn','d1c6843f-e2ae-4848-af3b-f436bc2b2b2b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2442,'1f173ef0-5971-426f-8ee9-54a5a457cfa6','d1c6843f-e2ae-4848-af3b-f436bc2b2b2b','2026-06-13 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-NovaDBClient-kb2yawu5p7sn','d1c6843f-e2ae-4848-af3b-f436bc2b2b2b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2443,'f14996ff-ecec-42aa-992e-a1bc918c22a8','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:29',NULL,'CREATE','COMPLETE','NovaBase','70ab00d1-d84c-4d0f-9446-6afd192d5b26','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1449),(2444,'39e0218a-ec1b-4721-8908-b3b26ad40e01','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:29',NULL,'CREATE','IN_PROGRESS','49','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt','state changed','OS::TripleO::Services::OVNDBs',NULL,1464),(2445,'4e65aa35-fc99-43bc-9e37-e327b82850b3','cbf6e48b-2328-4896-a3ee-20b266b55f4b','2026-06-13 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt','cbf6e48b-2328-4896-a3ee-20b266b55f4b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2446,'cf33548f-2ef8-46e2-baaa-e613612c3163','cbf6e48b-2328-4896-a3ee-20b266b55f4b','2026-06-13 07:51:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt-ContainersCommon-77lor7ve4ou3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2447,'473c0080-1591-4c3f-bc95-e2bb4b4b1b3f','cac2f1ac-c4ec-41b6-85c7-21b756b02b3b','2026-06-13 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt-ContainersCommon-77lor7ve4ou3','cac2f1ac-c4ec-41b6-85c7-21b756b02b3b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2448,'64c8206c-267d-4053-a1ca-1cc154b90201','cac2f1ac-c4ec-41b6-85c7-21b756b02b3b','2026-06-13 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt-ContainersCommon-77lor7ve4ou3','cac2f1ac-c4ec-41b6-85c7-21b756b02b3b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2449,'36095cc0-aebb-4828-963e-7a1d5cbd1f24','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:29',NULL,'CREATE','COMPLETE','36','aeff3d0c-1355-4996-9cb1-0de6b09b2f79','state changed','OS::TripleO::Services::ManilaShare',NULL,1412),(2450,'6f72c4c3-353e-49a7-8000-a9f7110f4ea7','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:30',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-MySQLClient-ytg2tn3fvmad','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2451,'29de1736-a458-4826-9703-9e826bb8e490','f74b51ba-d583-4422-a07c-c8e19f1d7aea','2026-06-13 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-MySQLClient-ytg2tn3fvmad','f74b51ba-d583-4422-a07c-c8e19f1d7aea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2452,'76055ea5-bc0d-4c23-a10a-30e52678d681','f74b51ba-d583-4422-a07c-c8e19f1d7aea','2026-06-13 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw-MySQLClient-ytg2tn3fvmad','f74b51ba-d583-4422-a07c-c8e19f1d7aea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2453,'9d6e5cf9-2392-4839-9c1a-564eb096f28d','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:30',NULL,'CREATE','COMPLETE','NovaDBClient','d1c6843f-e2ae-4848-af3b-f436bc2b2b2b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1463),(2454,'b7fa3a03-f37a-4122-ac97-fc4372ae6151','cbf6e48b-2328-4896-a3ee-20b266b55f4b','2026-06-13 07:51:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt-RoleParametersValue-ijscjz5pspcg','state changed','OS::Heat::Value',NULL,1477),(2455,'fa497e4b-a25d-40e1-9b9a-c616ed1ce5ab','cbf6e48b-2328-4896-a3ee-20b266b55f4b','2026-06-13 07:51:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt-RoleParametersValue-ijscjz5pspcg','state changed','OS::Heat::Value',NULL,1477),(2456,'af9c6d2e-71aa-4d4a-82dd-ec78eda863d3','cbf6e48b-2328-4896-a3ee-20b266b55f4b','2026-06-13 07:51:30',NULL,'CREATE','COMPLETE','ContainersCommon','cac2f1ac-c4ec-41b6-85c7-21b756b02b3b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2457,'e1fd922c-3cba-4763-bb81-c0a1595618ce','cbf6e48b-2328-4896-a3ee-20b266b55f4b','2026-06-13 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-49-avcicqlluflt','cbf6e48b-2328-4896-a3ee-20b266b55f4b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2458,'09e02c11-0ca8-48e0-a684-56cedfff005a','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:30',NULL,'CREATE','IN_PROGRESS','40','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-40-x3r7jhmm3pfr','state changed','OS::TripleO::Services::MySQLClient',NULL,1479),(2459,'a4cbb3ab-a7f9-4dc4-83c3-620bb3a9310f','f19fe107-c791-4b3c-b448-3a3e55e7a171','2026-06-13 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-40-x3r7jhmm3pfr','f19fe107-c791-4b3c-b448-3a3e55e7a171','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2460,'bda98ced-dd28-4f0c-8ecf-74bda16d1680','f19fe107-c791-4b3c-b448-3a3e55e7a171','2026-06-13 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-40-x3r7jhmm3pfr','f19fe107-c791-4b3c-b448-3a3e55e7a171','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2461,'792f948b-526d-4a32-9a9f-5df9d8a5e08a','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:31',NULL,'CREATE','COMPLETE','MySQLClient','f74b51ba-d583-4422-a07c-c8e19f1d7aea','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2462,'df91568c-d653-44ea-8b5d-da791bd5ae20','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','2026-06-13 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-47-dwh5u2knzetw','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2463,'0a3cdba6-0f88-4e4d-a098-d2b30d0cc8f5','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:31',NULL,'CREATE','COMPLETE','49','cbf6e48b-2328-4896-a3ee-20b266b55f4b','state changed','OS::TripleO::Services::OVNDBs',NULL,1464),(2464,'8beddfac-ce14-40a4-b4fa-f68be6eedb99','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:31',NULL,'CREATE','COMPLETE','40','f19fe107-c791-4b3c-b448-3a3e55e7a171','state changed','OS::TripleO::Services::MySQLClient',NULL,1479),(2465,'4125508d-b3a9-4c47-afc8-a17478b7dff3','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:31',NULL,'CREATE','IN_PROGRESS','53','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1483),(2466,'89db62ab-2eee-4dd5-8c4b-a68396d78cb8','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2467,'90a7add0-5784-43bf-92d5-73f58d4270de','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:31',NULL,'CREATE','COMPLETE','47','d461f90e-fcc5-4b65-a30f-0f73f59acf0f','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1442),(2468,'62635565-4fb9-4118-aef8-20f6d5e773d3','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-ContainersCommon-puvga6wtrdg7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2469,'370d8b6b-80ce-4222-96e1-ecfbca128b00','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','44','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm','state changed','OS::TripleO::Services::NovaConductor',NULL,1485),(2470,'984e9b4a-613f-4774-b397-eeffd2a3fd7d','ec6af074-9cd1-4b46-bd89-d56fb6830f51','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-ContainersCommon-puvga6wtrdg7','ec6af074-9cd1-4b46-bd89-d56fb6830f51','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2471,'ecaf86e6-da6f-4c38-910d-559c69f67ca5','ec6af074-9cd1-4b46-bd89-d56fb6830f51','2026-06-13 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-ContainersCommon-puvga6wtrdg7','ec6af074-9cd1-4b46-bd89-d56fb6830f51','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2472,'b936a538-65bb-4bb4-acb1-acf944768f66','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm','230d169e-9d98-441d-ba77-40318d4f43aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2473,'2dc34294-5f74-4ff7-b18b-84c6b570145a','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaBase-dkrsfdbx4qe4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1493),(2474,'a9d6a105-7f30-466a-bef8-d53159a2fd5f','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','51','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-51-mw3n6oxobhky','state changed','OS::TripleO::Services::Pacemaker',NULL,1496),(2475,'3211f327-7f28-4568-8b3e-3f5a3bec717e','8fa4f9cc-d158-4595-9f82-0faca9dae1c1','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaBase-dkrsfdbx4qe4','8fa4f9cc-d158-4595-9f82-0faca9dae1c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2476,'ed070152-b958-4160-a4e6-0ec5cd189448','380da617-a5c5-4b7c-8ba9-fa08d79c1d9b','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-51-mw3n6oxobhky','380da617-a5c5-4b7c-8ba9-fa08d79c1d9b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2477,'84702956-72b3-4c34-a6a4-66e7449d2dd2','8fa4f9cc-d158-4595-9f82-0faca9dae1c1','2026-06-13 07:51:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaBase-dkrsfdbx4qe4-RoleParametersValue-vv73g3qnpn65','state changed','OS::Heat::Value',NULL,1497),(2478,'7d0ab48a-823e-46a6-82a8-2d3d9be5f60f','8fa4f9cc-d158-4595-9f82-0faca9dae1c1','2026-06-13 07:51:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaBase-dkrsfdbx4qe4-RoleParametersValue-vv73g3qnpn65','state changed','OS::Heat::Value',NULL,1497),(2479,'e41ee7f8-e377-4516-8355-9a0e7ea6083a','380da617-a5c5-4b7c-8ba9-fa08d79c1d9b','2026-06-13 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-51-mw3n6oxobhky','380da617-a5c5-4b7c-8ba9-fa08d79c1d9b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2480,'8eeb22bd-c0d7-4f80-a890-f7b051de2b72','8fa4f9cc-d158-4595-9f82-0faca9dae1c1','2026-06-13 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaBase-dkrsfdbx4qe4','8fa4f9cc-d158-4595-9f82-0faca9dae1c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2481,'d8d73b53-e375-46af-b34c-54cd50d95b9c','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:33',NULL,'CREATE','IN_PROGRESS','RabbitmqBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1498),(2482,'f45031ec-191b-4ab7-b972-4f471919ff4e','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:33',NULL,'CREATE','COMPLETE','ContainersCommon','ec6af074-9cd1-4b46-bd89-d56fb6830f51','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2483,'65e395b0-9f9e-48a7-88ff-270e977c9699','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx','81353ce9-bf7e-4ce9-856f-f8656da31c67','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2484,'40d4b546-1fab-4260-ab07-7ef873bd5e0f','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-ContainersCommon-oj2cvoxup52w','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2485,'6e168350-6dd8-4d2f-b26a-ef32cfb805e6','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:33',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaDBClient-fslj3tsae6a4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1499),(2486,'e875ba4c-d090-4d5f-965d-736da2a9f25c','ffb1b4cb-3ecc-4ff7-bbc7-d733139c62fc','2026-06-13 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-ContainersCommon-oj2cvoxup52w','ffb1b4cb-3ecc-4ff7-bbc7-d733139c62fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2487,'70e7d071-a3f7-4029-acfb-5e1705452683','ffb1b4cb-3ecc-4ff7-bbc7-d733139c62fc','2026-06-13 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-ContainersCommon-oj2cvoxup52w','ffb1b4cb-3ecc-4ff7-bbc7-d733139c62fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2488,'1c07959b-b8b5-48fd-a2c2-b2bfddc5efa3','6ed42c21-f72b-474f-81ed-6e6ecd6f32b0','2026-06-13 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaDBClient-fslj3tsae6a4','6ed42c21-f72b-474f-81ed-6e6ecd6f32b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2489,'e58780fe-443a-4354-86f9-12fb30003958','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:33',NULL,'CREATE','COMPLETE','ContainersCommon','ffb1b4cb-3ecc-4ff7-bbc7-d733139c62fc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2490,'7a8c5ed1-fc49-4547-bc7d-982123ae95d3','6ed42c21-f72b-474f-81ed-6e6ecd6f32b0','2026-06-13 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaDBClient-fslj3tsae6a4','6ed42c21-f72b-474f-81ed-6e6ecd6f32b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2491,'119ebbda-dcc3-4edc-b029-43d3f4ad9666','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:33',NULL,'CREATE','COMPLETE','NovaBase','8fa4f9cc-d158-4595-9f82-0faca9dae1c1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1493),(2492,'b3a5ed75-669a-46c5-a252-6d60e6f4e010','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:33',NULL,'CREATE','COMPLETE','51','380da617-a5c5-4b7c-8ba9-fa08d79c1d9b','state changed','OS::TripleO::Services::Pacemaker',NULL,1496),(2493,'6f154800-a247-4dca-a947-3d208a3894a0','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','55','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-55-fsr53vfob6p5','state changed','OS::TripleO::Services::Podman',NULL,1501),(2494,'637283d4-31da-499b-8d12-cc309716f07a','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RoleParametersValue-ebejkuzkpdku','state changed','OS::Heat::Value',NULL,1502),(2495,'c4ba7187-fd76-403d-887f-1f45ff89812b','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RoleParametersValue-ebejkuzkpdku','state changed','OS::Heat::Value',NULL,1502),(2496,'1d891666-a5e5-46bd-9702-98eeef35eb31','03351705-8c2b-4884-94de-56d179176487','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-55-fsr53vfob6p5','03351705-8c2b-4884-94de-56d179176487','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2497,'726fb2da-5734-4a1f-91ee-ef7d44470c3f','03351705-8c2b-4884-94de-56d179176487','2026-06-13 07:51:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-55-fsr53vfob6p5','03351705-8c2b-4884-94de-56d179176487','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2498,'397bf308-d718-4ff7-8acb-7ef58df3bcfe','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaApiDBClient-4uyslspmk73t','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1503),(2499,'899a5171-4e4e-4cd7-b150-c9c5bed07cf6','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','RabbitMQServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1504),(2500,'1cebaa92-a27d-4220-bac1-2b9bb682a791','1a3a92c0-e9f2-4186-adf8-de90e192e80b','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaApiDBClient-4uyslspmk73t','1a3a92c0-e9f2-4186-adf8-de90e192e80b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2501,'d014fd60-98f1-4aff-8a5f-3d2d246062ec','323a68aa-70ea-49b8-85d6-c4c795daddda','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn','323a68aa-70ea-49b8-85d6-c4c795daddda','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2502,'c7666f45-9912-4d82-8721-c62994de6ea7','1a3a92c0-e9f2-4186-adf8-de90e192e80b','2026-06-13 07:51:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaApiDBClient-4uyslspmk73t','1a3a92c0-e9f2-4186-adf8-de90e192e80b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2503,'f7270deb-4668-4d6a-9343-069aeef6f0d6','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:34',NULL,'CREATE','COMPLETE','NovaDBClient','6ed42c21-f72b-474f-81ed-6e6ecd6f32b0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1499),(2504,'4db8db99-b0c2-4879-b42c-aea8a75ffd8e','323a68aa-70ea-49b8-85d6-c4c795daddda','2026-06-13 07:51:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn-RoleParametersValue-lyot74nwuhaf','state changed','OS::Heat::Value',NULL,1505),(2505,'9147927d-17d7-42e0-bd2d-4c115728cba5','323a68aa-70ea-49b8-85d6-c4c795daddda','2026-06-13 07:51:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn-RoleParametersValue-lyot74nwuhaf','state changed','OS::Heat::Value',NULL,1505),(2506,'abf8a1cf-be4a-493d-9fa5-d4592b85040b','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:35',NULL,'CREATE','COMPLETE','55','03351705-8c2b-4884-94de-56d179176487','state changed','OS::TripleO::Services::Podman',NULL,1501),(2507,'b946f6c2-e68e-4b6c-aec8-f34a149fd600','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-ContainersCommon-76gbtlbra7ot','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2508,'54699836-a632-4a74-b2ac-05216a3829d3','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:35',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RoleParametersValue-6puazkq4yttv','state changed','OS::Heat::Value',NULL,1507),(2509,'867ae443-b871-43d8-b1b3-941f49316240','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:35',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RoleParametersValue-6puazkq4yttv','state changed','OS::Heat::Value',NULL,1507),(2510,'26fc0570-32d0-4a0e-b2f4-553a04438f7c','a753af02-7307-4f82-a757-223e2e2f0f04','2026-06-13 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-ContainersCommon-76gbtlbra7ot','a753af02-7307-4f82-a757-223e2e2f0f04','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2511,'9211d068-1187-4edf-8ad1-baafb344f56c','a753af02-7307-4f82-a757-223e2e2f0f04','2026-06-13 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-ContainersCommon-76gbtlbra7ot','a753af02-7307-4f82-a757-223e2e2f0f04','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2512,'28f1f1f4-8361-4f64-8a43-d7f76d790464','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:35',NULL,'CREATE','COMPLETE','NovaApiDBClient','1a3a92c0-e9f2-4186-adf8-de90e192e80b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1503),(2513,'2185549c-8171-4043-8bfd-94e31aa3c749','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:35',NULL,'CREATE','IN_PROGRESS','59','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-59-l6dtujdg4p2g','state changed','OS::TripleO::Services::Sshd',NULL,1508),(2514,'29d07a6e-bcae-42e5-9ccb-19735772b0ac','f3ce3f0a-7ba8-4e9e-8c25-ce0ffa0478e4','2026-06-13 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-59-l6dtujdg4p2g','f3ce3f0a-7ba8-4e9e-8c25-ce0ffa0478e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2515,'cc24ce4f-8a76-4375-823c-9a076972e06f','323a68aa-70ea-49b8-85d6-c4c795daddda','2026-06-13 07:51:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn-ContainersCommon-z6ld2paqea4p','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2516,'4e14b064-b247-4bbb-bbdb-e2a86ebf2d8d','f3ce3f0a-7ba8-4e9e-8c25-ce0ffa0478e4','2026-06-13 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-59-l6dtujdg4p2g','f3ce3f0a-7ba8-4e9e-8c25-ce0ffa0478e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2517,'bf2697f3-00d3-4a5e-bc16-fb930562239a','ad9d9915-dae3-49c4-b297-f116afa73d56','2026-06-13 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn-ContainersCommon-z6ld2paqea4p','ad9d9915-dae3-49c4-b297-f116afa73d56','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2518,'1c585600-b7b3-4c88-8267-0f450579ab0c','ad9d9915-dae3-49c4-b297-f116afa73d56','2026-06-13 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn-ContainersCommon-z6ld2paqea4p','ad9d9915-dae3-49c4-b297-f116afa73d56','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2519,'74339d7c-0cce-44a8-a9e5-0d1f46df1369','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:36',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-MySQLClient-4vv4rtjciaq2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2520,'ba50a8db-f0e8-41b2-b3cf-9ae48a894e9d','e2cc594d-87f0-4d1e-bcdd-e2e9038086cb','2026-06-13 07:51:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-MySQLClient-4vv4rtjciaq2','e2cc594d-87f0-4d1e-bcdd-e2e9038086cb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2521,'c9b6f933-be34-43ee-b89c-2df329b479be','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:36',NULL,'CREATE','COMPLETE','ContainersCommon','a753af02-7307-4f82-a757-223e2e2f0f04','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2522,'2e204d6b-4330-46e6-9b31-f50cbc5c7283','e2cc594d-87f0-4d1e-bcdd-e2e9038086cb','2026-06-13 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-MySQLClient-4vv4rtjciaq2','e2cc594d-87f0-4d1e-bcdd-e2e9038086cb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2523,'239012e6-2796-4a4a-af53-1e48c2f88035','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:36',NULL,'CREATE','COMPLETE','59','f3ce3f0a-7ba8-4e9e-8c25-ce0ffa0478e4','state changed','OS::TripleO::Services::Sshd',NULL,1508),(2524,'bfd41074-902b-49a5-b0f1-fee8df7da5ee','323a68aa-70ea-49b8-85d6-c4c795daddda','2026-06-13 07:51:36',NULL,'CREATE','COMPLETE','ContainersCommon','ad9d9915-dae3-49c4-b297-f116afa73d56','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2525,'d3f92700-e404-48c4-a02f-502433783ce0','323a68aa-70ea-49b8-85d6-c4c795daddda','2026-06-13 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx-RabbitMQServiceBase-jnxbr4zokdyn','323a68aa-70ea-49b8-85d6-c4c795daddda','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2526,'d906a42a-7fa8-4340-947a-ed4a721f5ea0','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:36',NULL,'CREATE','IN_PROGRESS','63','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-63-2eol34azvy3s','state changed','OS::TripleO::Services::Timesync',NULL,1510),(2527,'32d3a23b-0ef5-4fb8-a42a-aeb230db98f3','c0bb1a9f-ca83-404a-ade8-a2d11bcaa089','2026-06-13 07:51:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-63-2eol34azvy3s','c0bb1a9f-ca83-404a-ade8-a2d11bcaa089','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2528,'473d5393-f046-4524-abda-7903bf45b3cf','c0bb1a9f-ca83-404a-ade8-a2d11bcaa089','2026-06-13 07:51:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-63-2eol34azvy3s','c0bb1a9f-ca83-404a-ade8-a2d11bcaa089','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2529,'c33d0746-6329-4dbc-aee2-51aa13a13c56','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-RoleParametersValue-65nn4kshoe4l','state changed','OS::Heat::Value',NULL,1511),(2530,'05d2cb21-855c-4ecc-89f1-28fcc019984e','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-RoleParametersValue-65nn4kshoe4l','state changed','OS::Heat::Value',NULL,1511),(2531,'7a788d82-ebfa-465a-8dd4-7f5cd154e30d','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:37',NULL,'CREATE','COMPLETE','MySQLClient','e2cc594d-87f0-4d1e-bcdd-e2e9038086cb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2532,'2fdccdcd-2a45-4e39-aaed-0732ec096222','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:37',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaLogging-7hxq3r5oub5v','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1513),(2533,'5a8b3aaa-759c-405c-865d-90c197a974ed','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:37',NULL,'CREATE','COMPLETE','RabbitMQServiceBase','323a68aa-70ea-49b8-85d6-c4c795daddda','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1504),(2534,'746bc029-3978-4289-a2a9-ad5a863a45c0','81353ce9-bf7e-4ce9-856f-f8656da31c67','2026-06-13 07:51:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d-RabbitmqBase-i2xqzik65lbx','81353ce9-bf7e-4ce9-856f-f8656da31c67','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2535,'9708d16a-0dce-4bad-8d4b-bbc887b7b53d','9639cdf9-9c51-48db-877a-0df0098a99ef','2026-06-13 07:51:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaLogging-7hxq3r5oub5v','9639cdf9-9c51-48db-877a-0df0098a99ef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2536,'90c6eb6a-cbf3-4861-bcad-0e4a33c8f87c','9639cdf9-9c51-48db-877a-0df0098a99ef','2026-06-13 07:51:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaLogging-7hxq3r5oub5v-RoleParametersValue-esrlu7dxf7gt','state changed','OS::Heat::Value',NULL,1514),(2537,'716a81f0-b99a-4090-94ce-072b8588b8e0','9639cdf9-9c51-48db-877a-0df0098a99ef','2026-06-13 07:51:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaLogging-7hxq3r5oub5v-RoleParametersValue-esrlu7dxf7gt','state changed','OS::Heat::Value',NULL,1514),(2538,'358d2206-9b77-4aa5-bbc2-e421da8dadf2','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','63','c0bb1a9f-ca83-404a-ade8-a2d11bcaa089','state changed','OS::TripleO::Services::Timesync',NULL,1510),(2539,'cdd1200f-725d-430f-bc44-646104bc541f','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','RabbitmqBase','81353ce9-bf7e-4ce9-856f-f8656da31c67','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1498),(2540,'adb9a802-fbed-47a0-98db-06e7aba0933d','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-53-ugywrwcbz74d','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2541,'b19e3629-81ad-4ce5-a320-945a042c13df','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:38',NULL,'CREATE','IN_PROGRESS','67','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-67-eukwevpbdobp','state changed','OS::TripleO::Services::Tuned',NULL,1516),(2542,'9f78bb1c-655c-4982-aa32-a36f0629788f','9d80266a-2c42-4bbe-8570-09004a93870a','2026-06-13 07:51:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-67-eukwevpbdobp','9d80266a-2c42-4bbe-8570-09004a93870a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2543,'9c76d292-d8b7-409b-89db-9caef88269e1','9d80266a-2c42-4bbe-8570-09004a93870a','2026-06-13 07:51:38',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-67-eukwevpbdobp-RoleParametersValue-rv3acglmj22j','state changed','OS::Heat::Value',NULL,1517),(2544,'ec5e5e9e-9523-4261-916a-a5a319519bac','9d80266a-2c42-4bbe-8570-09004a93870a','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-67-eukwevpbdobp-RoleParametersValue-rv3acglmj22j','state changed','OS::Heat::Value',NULL,1517),(2545,'5a76568b-852b-47a3-95c0-fbedc095963f','9d80266a-2c42-4bbe-8570-09004a93870a','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-67-eukwevpbdobp','9d80266a-2c42-4bbe-8570-09004a93870a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2546,'d0196253-6ddd-469b-a028-2ccf4ccbfe5a','9639cdf9-9c51-48db-877a-0df0098a99ef','2026-06-13 07:51:38',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaLogging-7hxq3r5oub5v-InitLogContainerName-agualrajac7q','state changed','OS::Heat::Value',NULL,1518),(2547,'15b3c90f-2ae2-447c-9ab9-63ffa0f3dc0c','9639cdf9-9c51-48db-877a-0df0098a99ef','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaLogging-7hxq3r5oub5v-InitLogContainerName-agualrajac7q','state changed','OS::Heat::Value',NULL,1518),(2548,'ea8f9c6f-6377-4aec-9217-78558894181b','9639cdf9-9c51-48db-877a-0df0098a99ef','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm-NovaLogging-7hxq3r5oub5v','9639cdf9-9c51-48db-877a-0df0098a99ef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2549,'f4e3121c-b6de-47da-98c0-3c5cece04312','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:38',NULL,'CREATE','COMPLETE','53','53e2b683-5cfb-44d5-9278-1dc9b9a7f05e','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1483),(2550,'27b04fdf-1613-4f5b-a861-5ea271ea3665','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:39',NULL,'CREATE','COMPLETE','67','9d80266a-2c42-4bbe-8570-09004a93870a','state changed','OS::TripleO::Services::Tuned',NULL,1516),(2551,'ad845afb-5353-4afa-b9ec-708a803626ef','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:39',NULL,'CREATE','IN_PROGRESS','57','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e','state changed','OS::TripleO::Services::Rsyslog',NULL,1528),(2552,'ef4ab87a-39ee-4be8-976a-5fbe63c6b891','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:39',NULL,'CREATE','COMPLETE','NovaLogging','9639cdf9-9c51-48db-877a-0df0098a99ef','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1513),(2553,'e118f3d9-67e0-46ff-942c-f1a4c525eefc','230d169e-9d98-441d-ba77-40318d4f43aa','2026-06-13 07:51:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-44-rugxwmv6x4dm','230d169e-9d98-441d-ba77-40318d4f43aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2554,'5b807168-a4e8-4d49-bf50-04f43a3e5d37','966aed3b-0a10-4065-83c1-3082aff33e94','2026-06-13 07:51:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e','966aed3b-0a10-4065-83c1-3082aff33e94','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2555,'68956955-7544-4f7d-9d8e-ac496fd68208','966aed3b-0a10-4065-83c1-3082aff33e94','2026-06-13 07:51:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e-RoleParametersValue-tgkulriug4hd','state changed','OS::Heat::Value',NULL,1529),(2556,'21708f7f-be2f-4f49-9a89-95aa32dd5b31','966aed3b-0a10-4065-83c1-3082aff33e94','2026-06-13 07:51:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e-RoleParametersValue-tgkulriug4hd','state changed','OS::Heat::Value',NULL,1529),(2557,'d3a99b95-6c77-4fa1-8cff-dbaf77742d6f','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:40',NULL,'CREATE','COMPLETE','44','230d169e-9d98-441d-ba77-40318d4f43aa','state changed','OS::TripleO::Services::NovaConductor',NULL,1485),(2558,'2dbd4d9c-da93-4d49-9bab-6ec41d6d3b31','966aed3b-0a10-4065-83c1-3082aff33e94','2026-06-13 07:51:40',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e-ContainersCommon-45q5dfxw3krn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2559,'3cce11c7-9d6a-4080-92ea-2ca3075fb221','449d8a29-ec26-4856-b84f-cd130d1af400','2026-06-13 07:51:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e-ContainersCommon-45q5dfxw3krn','449d8a29-ec26-4856-b84f-cd130d1af400','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2560,'6f18018c-44bb-4030-984d-454c16dbe996','449d8a29-ec26-4856-b84f-cd130d1af400','2026-06-13 07:51:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e-ContainersCommon-45q5dfxw3krn','449d8a29-ec26-4856-b84f-cd130d1af400','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2561,'a99c844e-91b0-4b42-9200-fd741c5d82f9','966aed3b-0a10-4065-83c1-3082aff33e94','2026-06-13 07:51:40',NULL,'CREATE','COMPLETE','ContainersCommon','449d8a29-ec26-4856-b84f-cd130d1af400','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2562,'3e09606d-e5d3-40bc-88dc-e01605fdfb69','966aed3b-0a10-4065-83c1-3082aff33e94','2026-06-13 07:51:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-57-rcsix2uwro4e','966aed3b-0a10-4065-83c1-3082aff33e94','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2563,'f6ebded8-7bbf-4ff5-947d-f2b71726e625','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:41',NULL,'CREATE','IN_PROGRESS','48','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1540),(2564,'04a75d2b-9b0f-4e69-b1ac-67d1d5e432a9','bcad40c3-5593-46fc-a72c-bf0d483b7820','2026-06-13 07:51:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap','bcad40c3-5593-46fc-a72c-bf0d483b7820','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2565,'1810fe0d-5133-460b-aa54-959fcf2219da','bcad40c3-5593-46fc-a72c-bf0d483b7820','2026-06-13 07:51:41',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap-RoleParametersValue-d4ng75hezlom','state changed','OS::Heat::Value',NULL,1541),(2566,'eca2cea9-6aa8-4f23-aa49-e2fc1a4950bc','bcad40c3-5593-46fc-a72c-bf0d483b7820','2026-06-13 07:51:41',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap-RoleParametersValue-d4ng75hezlom','state changed','OS::Heat::Value',NULL,1541),(2567,'4811a028-0a7e-4adf-ab7b-8daea9f6828f','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:41',NULL,'CREATE','COMPLETE','57','966aed3b-0a10-4065-83c1-3082aff33e94','state changed','OS::TripleO::Services::Rsyslog',NULL,1528),(2568,'2aac04f5-d66f-4001-8a52-d20240f04dfe','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:42',NULL,'CREATE','IN_PROGRESS','61','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-61-v7m4wqvmq7lx','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1545),(2569,'3c33e003-f017-45d3-ae84-c71c12207304','9aeabda5-846c-448d-a913-18c32623dd38','2026-06-13 07:51:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-61-v7m4wqvmq7lx','9aeabda5-846c-448d-a913-18c32623dd38','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2570,'811c6052-23bf-4575-9131-03a40560da1b','9aeabda5-846c-448d-a913-18c32623dd38','2026-06-13 07:51:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-61-v7m4wqvmq7lx-RoleParametersValue-al53lamtixpr','state changed','OS::Heat::Value',NULL,1546),(2571,'26c92fc0-86ce-4a62-b797-6a3eb836e0be','9aeabda5-846c-448d-a913-18c32623dd38','2026-06-13 07:51:42',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-61-v7m4wqvmq7lx-RoleParametersValue-al53lamtixpr','state changed','OS::Heat::Value',NULL,1546),(2572,'b0f224b2-fb3e-4e91-8dfe-37ad2ac4a9ae','bcad40c3-5593-46fc-a72c-bf0d483b7820','2026-06-13 07:51:42',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap-ContainersCommon-s5n6gw5xnsb4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2573,'9e37f2e0-1e52-4deb-afb3-e6dd720284bd','9aeabda5-846c-448d-a913-18c32623dd38','2026-06-13 07:51:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-61-v7m4wqvmq7lx','9aeabda5-846c-448d-a913-18c32623dd38','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2574,'e26a3181-a930-4840-a18e-8bbec108ff84','bc09f9fb-62df-4b81-ba8d-4328f038c4d3','2026-06-13 07:51:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap-ContainersCommon-s5n6gw5xnsb4','bc09f9fb-62df-4b81-ba8d-4328f038c4d3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2575,'8f9bc1a8-e7c5-419b-9cb1-be1a8e0ccabd','bc09f9fb-62df-4b81-ba8d-4328f038c4d3','2026-06-13 07:51:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap-ContainersCommon-s5n6gw5xnsb4','bc09f9fb-62df-4b81-ba8d-4328f038c4d3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2576,'a4f6f9ca-1193-4dcc-8967-0995b848e484','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:43',NULL,'CREATE','COMPLETE','61','9aeabda5-846c-448d-a913-18c32623dd38','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1545),(2577,'d62e588f-0112-46ae-a5aa-aa484c59b3d4','bcad40c3-5593-46fc-a72c-bf0d483b7820','2026-06-13 07:51:43',NULL,'CREATE','COMPLETE','ContainersCommon','bc09f9fb-62df-4b81-ba8d-4328f038c4d3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2578,'08c80364-d3f4-4cc6-b81e-f29a99f66829','bcad40c3-5593-46fc-a72c-bf0d483b7820','2026-06-13 07:51:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-48-2zeh5jlowlap','bcad40c3-5593-46fc-a72c-bf0d483b7820','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2579,'7c40a49b-8a0d-459a-b003-4c5a40909df9','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:43',NULL,'CREATE','IN_PROGRESS','65','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-65-uehnyburlwod','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1549),(2580,'c90c544a-db97-48c0-880a-782c35813afd','c33ae925-9564-480b-8ac7-f177daf37f6f','2026-06-13 07:51:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-65-uehnyburlwod','c33ae925-9564-480b-8ac7-f177daf37f6f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2581,'d67286b8-533d-437d-a394-3921f64822b8','c33ae925-9564-480b-8ac7-f177daf37f6f','2026-06-13 07:51:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-65-uehnyburlwod-RoleParametersValue-q33otv5l4sq2','state changed','OS::Heat::Value',NULL,1550),(2582,'40384972-9b5b-475b-b8ea-edabbae9b430','c33ae925-9564-480b-8ac7-f177daf37f6f','2026-06-13 07:51:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-65-uehnyburlwod-RoleParametersValue-q33otv5l4sq2','state changed','OS::Heat::Value',NULL,1550),(2583,'350209f6-22c5-4352-b814-fd820f3a67cc','c33ae925-9564-480b-8ac7-f177daf37f6f','2026-06-13 07:51:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-65-uehnyburlwod','c33ae925-9564-480b-8ac7-f177daf37f6f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2584,'bd111b84-1c3b-4b7f-b218-0d151a304b0b','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:44',NULL,'CREATE','COMPLETE','48','bcad40c3-5593-46fc-a72c-bf0d483b7820','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1540),(2585,'d38a5155-262b-486b-9705-a05b9013bfcb','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:44',NULL,'CREATE','COMPLETE','65','c33ae925-9564-480b-8ac7-f177daf37f6f','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1549),(2586,'50599c21-ae4c-476a-96c9-d7704265f95b','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:44',NULL,'CREATE','IN_PROGRESS','52','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33','state changed','OS::TripleO::Services::PlacementApi',NULL,1554),(2587,'537204bb-cbb8-43d2-9665-5897913e4afb','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33','c07492d1-e032-487e-9734-d514005b89e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2588,'1f9c7f54-826a-42f1-8ef4-c497614a1d4a','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:45',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-MySQLClient-6u6q2j2evsca','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2589,'74787fbd-f5e1-42cc-8db8-93e2c8d4d24d','61784182-abdc-4b5c-8a3c-576c10af2742','2026-06-13 07:51:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-MySQLClient-6u6q2j2evsca','61784182-abdc-4b5c-8a3c-576c10af2742','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2590,'03ffa75e-8d50-422a-ac13-3eb745f9af13','61784182-abdc-4b5c-8a3c-576c10af2742','2026-06-13 07:51:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-MySQLClient-6u6q2j2evsca','61784182-abdc-4b5c-8a3c-576c10af2742','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2591,'777e6fe6-2a02-4dfa-a396-cf4a0d0ffaba','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:46',NULL,'CREATE','IN_PROGRESS','PlacementLogging','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-PlacementLogging-lkrp6j6ojljv','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2592,'eb42ec1d-2f9c-4382-bb92-ed68b2c915eb','200d967a-47ba-4824-b20f-0452da8010e5','2026-06-13 07:51:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-PlacementLogging-lkrp6j6ojljv','200d967a-47ba-4824-b20f-0452da8010e5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2593,'e039d9ca-06fc-49f8-b1c0-e7386bf47708','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:46',NULL,'CREATE','COMPLETE','MySQLClient','61784182-abdc-4b5c-8a3c-576c10af2742','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2594,'239df9df-1da2-45dc-ae5f-3879b8375137','200d967a-47ba-4824-b20f-0452da8010e5','2026-06-13 07:51:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-PlacementLogging-lkrp6j6ojljv-RoleParametersValue-st7f4dbrzarc','state changed','OS::Heat::Value',NULL,1555),(2595,'2f49aa48-80f5-4292-acc2-30d3b70e5cfc','200d967a-47ba-4824-b20f-0452da8010e5','2026-06-13 07:51:46',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-PlacementLogging-lkrp6j6ojljv-RoleParametersValue-st7f4dbrzarc','state changed','OS::Heat::Value',NULL,1555),(2596,'002ac1d2-fb5e-4531-bc7c-38de5a4f843e','200d967a-47ba-4824-b20f-0452da8010e5','2026-06-13 07:51:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-PlacementLogging-lkrp6j6ojljv','200d967a-47ba-4824-b20f-0452da8010e5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2597,'5c4ef8c8-5de9-4a2a-8c34-4b7b76ac2e3a','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:47',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ContainersCommon-4zdj372xl5ms','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2598,'2c0048ed-ae26-479b-b44d-cae7c56de598','e2622079-02d9-4a53-8306-196b0034d634','2026-06-13 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ContainersCommon-4zdj372xl5ms','e2622079-02d9-4a53-8306-196b0034d634','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2599,'ffcc6f09-5544-486d-a569-37884d096d3f','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:47',NULL,'CREATE','COMPLETE','PlacementLogging','200d967a-47ba-4824-b20f-0452da8010e5','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2600,'dd4a4f0a-a917-45ba-b985-e2b43dd90f75','e2622079-02d9-4a53-8306-196b0034d634','2026-06-13 07:51:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ContainersCommon-4zdj372xl5ms','e2622079-02d9-4a53-8306-196b0034d634','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2601,'b6c3e984-60c3-4359-94e0-270b0253ccf3','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:48',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ApacheServiceBase-wnjlrohrenq6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1556),(2602,'b425f728-e4d8-4db7-b229-b708181fa329','3c766d82-0bd9-4be5-918e-ec9ba607be98','2026-06-13 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ApacheServiceBase-wnjlrohrenq6','3c766d82-0bd9-4be5-918e-ec9ba607be98','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2603,'e0c9f80c-466d-4a99-a26a-6250c3de2e3b','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:48',NULL,'CREATE','COMPLETE','ContainersCommon','e2622079-02d9-4a53-8306-196b0034d634','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2604,'43e4cf7c-4c27-4b20-99cc-5c101c37282e','3c766d82-0bd9-4be5-918e-ec9ba607be98','2026-06-13 07:51:48',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ApacheServiceBase-wnjlrohrenq6-ApacheNetworks-7v2yz4uob3h6','state changed','OS::Heat::Value',NULL,1557),(2605,'b51b8a6a-4ece-4c9d-ba15-baf0a98c4f81','3c766d82-0bd9-4be5-918e-ec9ba607be98','2026-06-13 07:51:48',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ApacheServiceBase-wnjlrohrenq6-ApacheNetworks-7v2yz4uob3h6','state changed','OS::Heat::Value',NULL,1557),(2606,'629574e4-70c2-45bc-b119-bee0261a6f98','3c766d82-0bd9-4be5-918e-ec9ba607be98','2026-06-13 07:51:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-ApacheServiceBase-wnjlrohrenq6','3c766d82-0bd9-4be5-918e-ec9ba607be98','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2607,'859c9cdf-c2c3-4d2b-b76e-7184d7d2de12','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-RoleParametersValue-5mxgozmipqxq','state changed','OS::Heat::Value',NULL,1558),(2608,'c48a3a0d-f88b-4a84-bdb5-15bff7c13426','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33-RoleParametersValue-5mxgozmipqxq','state changed','OS::Heat::Value',NULL,1558),(2609,'ec38d529-d233-47dd-92c8-92bf61c131cf','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:49',NULL,'CREATE','COMPLETE','ApacheServiceBase','3c766d82-0bd9-4be5-918e-ec9ba607be98','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1556),(2610,'516a799f-d768-40af-a326-d217edff14a9','c07492d1-e032-487e-9734-d514005b89e9','2026-06-13 07:51:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-52-3bn3rb6pnv33','c07492d1-e032-487e-9734-d514005b89e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2611,'59b5bec6-8d0c-4d04-9a79-21fa4a0078f0','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:49',NULL,'CREATE','COMPLETE','52','c07492d1-e032-487e-9734-d514005b89e9','state changed','OS::TripleO::Services::PlacementApi',NULL,1554),(2612,'a5dfff7d-d3f6-4c17-869d-87ab29988cdb','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:50',NULL,'CREATE','IN_PROGRESS','56','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo','state changed','OS::TripleO::Services::Redis',NULL,1567),(2613,'d6aac7fb-084c-47bf-8eeb-3231ee9e6c17','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo','46cdc9a4-4874-4a37-92ab-e1d4303db5db','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2614,'72f4b9e7-d8f1-4c4f-a259-864bd518bfd3','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RoleParametersValue-x3enog7ubq5m','state changed','OS::Heat::Value',NULL,1568),(2615,'e6dc8f11-916d-419f-9c1a-4340e196f807','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:50',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RoleParametersValue-x3enog7ubq5m','state changed','OS::Heat::Value',NULL,1568),(2616,'a35dcd2d-713a-4b61-8491-8e3e74b490fb','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:51',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1569),(2617,'72368985-be7f-44ad-a7d9-6a76a3820f06','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh','5cd61918-6e6b-4a59-a173-c3bf8618ea62','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2618,'209f3172-bcf7-40e8-b93c-2b0624fb2adf','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-RoleParametersValue-um35b4unsz5t','state changed','OS::Heat::Value',NULL,1570),(2619,'7b1814d8-aef6-44f9-a1b2-0e7f68193ce2','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-RoleParametersValue-um35b4unsz5t','state changed','OS::Heat::Value',NULL,1570),(2620,'3469de2c-dd0d-47f4-8943-6f0c872984e8','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:52',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-ContainersCommon-iz3mwipk2vjq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2621,'15aabfa8-e9bc-4ff2-977d-b69a764dc57b','06e5dcb9-2bf1-4935-8ea0-7aa658bf8529','2026-06-13 07:51:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-ContainersCommon-iz3mwipk2vjq','06e5dcb9-2bf1-4935-8ea0-7aa658bf8529','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2622,'0b26898c-60af-4296-ba41-f200e9f7f6de','06e5dcb9-2bf1-4935-8ea0-7aa658bf8529','2026-06-13 07:51:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-ContainersCommon-iz3mwipk2vjq','06e5dcb9-2bf1-4935-8ea0-7aa658bf8529','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2623,'370399d9-62cb-409b-8fe5-ecfe2dd2b2a4','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:53',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-RedisBase-ahenp5rdgvun','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1571),(2624,'c80f8dc5-9f74-4d67-aeeb-2d074d28c131','d8b63d5d-a620-449d-b108-a87421d6c2f6','2026-06-13 07:51:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-RedisBase-ahenp5rdgvun','d8b63d5d-a620-449d-b108-a87421d6c2f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2625,'e9702dfb-c0b2-4d1b-9988-ba9f3b626513','d8b63d5d-a620-449d-b108-a87421d6c2f6','2026-06-13 07:51:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-RedisBase-ahenp5rdgvun','d8b63d5d-a620-449d-b108-a87421d6c2f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2626,'90d32f36-e3e6-46c8-9945-a429d6709cd6','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:53',NULL,'CREATE','COMPLETE','ContainersCommon','06e5dcb9-2bf1-4935-8ea0-7aa658bf8529','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2627,'9c04020b-ed4c-4fd3-8b1e-99907b697f32','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:54',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-ContainersCommon-t3o6qw7z7rp7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2628,'32c9f91f-009d-4d6c-b9f2-1c341a24c248','38c9359b-4dec-4e10-a02c-294e34ef645a','2026-06-13 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-ContainersCommon-t3o6qw7z7rp7','38c9359b-4dec-4e10-a02c-294e34ef645a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2629,'cf80aeeb-e845-4782-98eb-d502d98b474d','38c9359b-4dec-4e10-a02c-294e34ef645a','2026-06-13 07:51:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh-ContainersCommon-t3o6qw7z7rp7','38c9359b-4dec-4e10-a02c-294e34ef645a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2630,'27ff4ce4-b0ce-4d0e-b3cf-7a7a4344bd8a','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:54',NULL,'CREATE','COMPLETE','RedisBase','d8b63d5d-a620-449d-b108-a87421d6c2f6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1571),(2631,'a0060206-1683-44f3-b955-2e41c16d572e','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:55',NULL,'CREATE','COMPLETE','ContainersCommon','38c9359b-4dec-4e10-a02c-294e34ef645a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2632,'89500467-522d-422c-af65-dfd54af7a9a2','5cd61918-6e6b-4a59-a173-c3bf8618ea62','2026-06-13 07:51:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo-RedisBase-aspj7dpa3rlh','5cd61918-6e6b-4a59-a173-c3bf8618ea62','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2633,'d4a3087e-6787-493e-8a2f-4151e3235a4a','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:55',NULL,'CREATE','COMPLETE','RedisBase','5cd61918-6e6b-4a59-a173-c3bf8618ea62','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1569),(2634,'13b7af0a-82e9-45a8-81c4-69fb8eeb7444','46cdc9a4-4874-4a37-92ab-e1d4303db5db','2026-06-13 07:51:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-56-tpbdqpx7iooo','46cdc9a4-4874-4a37-92ab-e1d4303db5db','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2635,'9374372e-22bb-46f3-a709-fd75c30925aa','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:56',NULL,'CREATE','COMPLETE','56','46cdc9a4-4874-4a37-92ab-e1d4303db5db','state changed','OS::TripleO::Services::Redis',NULL,1567),(2636,'e25549a7-729e-4abe-9032-9a2cfc42dc80','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:51:57',NULL,'CREATE','IN_PROGRESS','60','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g','state changed','OS::TripleO::Services::SwiftProxy',NULL,1579),(2637,'be29455c-7606-4327-ae28-6f9ec3f9ad95','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:51:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2638,'fbaf9e1e-0f52-473b-8e25-66f8583b1415','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:51:57',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-TLSProxyBase-yexycy5l5vtb','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(2639,'705fb0c8-a5ad-4168-a242-71d653402cd5','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:51:57',NULL,'CREATE','COMPLETE','TLSProxyBase','0e11f65c-69b8-4b8b-9f85-6acdc7475219','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(2640,'632a3c76-6ab8-471f-998d-9e810d452a45','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:51:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-RoleParametersValue-o6mjgik7wxjr','state changed','OS::Heat::Value',NULL,1580),(2641,'c1fcb1fa-2cb2-4594-af18-ba218dc478f9','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:51:58',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-RoleParametersValue-o6mjgik7wxjr','state changed','OS::Heat::Value',NULL,1580),(2642,'86339c53-4948-4b60-a37d-8a29902214d7','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:51:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-ContainersCommon-tccjtawr6v7t','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2643,'71ae8e4b-f812-4fe3-a523-5cc5e2b7e9c1','aad68e75-901d-4e49-a81a-4dc305258353','2026-06-13 07:51:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-ContainersCommon-tccjtawr6v7t','aad68e75-901d-4e49-a81a-4dc305258353','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2644,'f692645e-7412-4a08-a8fa-aee670beb664','aad68e75-901d-4e49-a81a-4dc305258353','2026-06-13 07:51:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-ContainersCommon-tccjtawr6v7t','aad68e75-901d-4e49-a81a-4dc305258353','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2645,'d5e81c7b-42ca-457d-8433-38958fac65dd','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:52:00',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-SwiftBase-xdhlljzyxyse','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1581),(2646,'1c80b898-f688-4f09-b538-0d277b006607','88726053-0adf-4371-a875-3d09c64fc04d','2026-06-13 07:52:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-SwiftBase-xdhlljzyxyse','88726053-0adf-4371-a875-3d09c64fc04d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2647,'95fe3b76-4b29-4411-b3c0-4e3a188e3862','88726053-0adf-4371-a875-3d09c64fc04d','2026-06-13 07:52:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g-SwiftBase-xdhlljzyxyse','88726053-0adf-4371-a875-3d09c64fc04d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2648,'bfce942e-2da3-45d8-bb40-c9c99609cbac','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:52:00',NULL,'CREATE','COMPLETE','ContainersCommon','aad68e75-901d-4e49-a81a-4dc305258353','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2649,'e3f41567-7eb0-4568-83e7-6926bb053e37','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:52:01',NULL,'CREATE','COMPLETE','SwiftBase','88726053-0adf-4371-a875-3d09c64fc04d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1581),(2650,'7f0e489d-d3c2-4098-9308-fa7be40956b0','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','2026-06-13 07:52:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-60-hqwovvm3jb7g','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2651,'b6b9ecb1-6206-4a55-9e16-3a53a68c9975','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:52:02',NULL,'CREATE','COMPLETE','60','cd42a303-e7c5-4d47-a4f5-d1c7b62f154f','state changed','OS::TripleO::Services::SwiftProxy',NULL,1579),(2652,'5dd9bb2e-3995-42e6-9fcc-fd87c09cfe53','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:52:02',NULL,'CREATE','IN_PROGRESS','64','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-64-me2s6l5kdynm','state changed','OS::TripleO::Services::Timezone',NULL,1587),(2653,'1ab6b09c-d1d5-48a2-bddb-e9f610b94e9e','d91d884a-d0ae-45ad-a42d-590e155359e8','2026-06-13 07:52:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-64-me2s6l5kdynm','d91d884a-d0ae-45ad-a42d-590e155359e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2654,'18e11ad6-d3dd-45b0-a16f-e1c92007b441','d91d884a-d0ae-45ad-a42d-590e155359e8','2026-06-13 07:52:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6-64-me2s6l5kdynm','d91d884a-d0ae-45ad-a42d-590e155359e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2655,'04bce33e-57fe-4b8e-9582-b1dca6543f6b','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:52:03',NULL,'CREATE','COMPLETE','64','d91d884a-d0ae-45ad-a42d-590e155359e8','state changed','OS::TripleO::Services::Timezone',NULL,1587),(2656,'54f7951a-5b02-4bbf-8e1a-bc89af73f365','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','2026-06-13 07:52:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceChain-kemokwte3qi6','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2657,'b650fdbd-27c6-4271-8d4b-10c2d288c4bb','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:03',NULL,'CREATE','COMPLETE','ServiceChain','9ea49ccd-3ca4-467f-8d69-82b61e875bf5','state changed','OS::Heat::ResourceChain',NULL,94),(2658,'ac008018-812f-45c0-8b50-5eaac600f5bf','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:05',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-DockerConfig-k2pkyl4s2cat','state changed','OS::Heat::Value',NULL,1596),(2659,'6cae5b68-39e7-4999-9d31-651fd037e9ca','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:05',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-PuppetConfig-v7lmjbvmok4s','state changed','OS::Heat::Value',NULL,1597),(2660,'d031b4c7-0c17-4db3-9bd0-6eab10c0b1d0','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:05',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-PuppetConfig-v7lmjbvmok4s','state changed','OS::Heat::Value',NULL,1597),(2661,'f4e67217-a190-42cb-a77b-22e3f727907a','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-DockerConfig-k2pkyl4s2cat','state changed','OS::Heat::Value',NULL,1596),(2662,'06ed9f5e-8e03-47c1-a685-2bc21d0ddac7','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceServerMetadataHook-x7nf7gnahdto','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,NULL),(2663,'e7b592b7-c81e-4257-ac5f-4b184c2881fd','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','5409ba80-7f95-4378-a3e5-611dbe3c574c','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,NULL),(2664,'fee90742-29b7-46c0-b30a-6a5c0dac73df','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PreDeployStepTasks-czltq6pjc76m','state changed','OS::Heat::Value',NULL,1598),(2665,'634294a2-1687-46ea-8895-18b0e8a2a643','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PreDeployStepTasks-czltq6pjc76m','state changed','OS::Heat::Value',NULL,1598),(2666,'7fab5928-f99a-4fd3-8d14-0a3584fca5ee','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-DockerPuppetTasks-22mkcmrpw7uo','state changed','OS::Heat::Value',NULL,1599),(2667,'58c9d5a9-3096-44c6-a354-adc8d0712c1f','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ScaleTasks-qgrbpbes52uo','state changed','OS::Heat::Value',NULL,1600),(2668,'371af3ec-559d-4cc5-9d73-f85eb3ce6fe9','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ScaleTasks-qgrbpbes52uo','state changed','OS::Heat::Value',NULL,1600),(2669,'f59d5f1f-dd1c-45b7-a26d-061e7b621d2a','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:06',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-DockerPuppetTasks-22mkcmrpw7uo','state changed','OS::Heat::Value',NULL,1599),(2670,'35a24a8d-5fd9-4c2a-be85-bebd5292fc5d','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-DeployStepsTasks-w76fec32qtpv','state changed','OS::Heat::Value',NULL,1601),(2671,'4dde9bd2-c6fd-44a0-89e0-911fe543698d','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-DeployStepsTasks-w76fec32qtpv','state changed','OS::Heat::Value',NULL,1601),(2672,'b40c7491-e079-4517-9f11-e2103c67c123','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-HostPrepTasks-ejj7c7m3vvgd','state changed','OS::Heat::Value',NULL,1602),(2673,'7e127f2b-1ace-487f-b300-3c73e4d79499','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-HostPrepTasks-ejj7c7m3vvgd','state changed','OS::Heat::Value',NULL,1602),(2674,'97a997b1-85b1-49f9-8e49-7cfead965032','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-UpdateTasks-4rtzufc7h5bu','state changed','OS::Heat::Value',NULL,1603),(2675,'113e4899-82e0-4db1-b1e0-341551c37af9','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-IpaRegistrationTasks-oukc4so6rocr','state changed','OS::Heat::Value',NULL,1604),(2676,'7de17540-1c77-40df-b35f-5b6a84073ab7','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-IpaRegistrationTasks-oukc4so6rocr','state changed','OS::Heat::Value',NULL,1604),(2677,'7fd22430-06a4-4e03-822b-93217a097f64','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-UpdateTasks-4rtzufc7h5bu','state changed','OS::Heat::Value',NULL,1603),(2678,'39e205eb-b5a0-4247-b981-84323e6f5392','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:07',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalDeployTasks-hk5cfsvwr5ns','state changed','OS::Heat::Value',NULL,1605),(2679,'c45ac5ef-0f02-4b7d-aff6-056389d8fd5e','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalDeployTasks-hk5cfsvwr5ns','state changed','OS::Heat::Value',NULL,1605),(2680,'6b19dfa8-0d11-415b-a939-2fc6fd776861','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-PuppetStepConfig-qfamzkuvye4x','state changed','OS::Heat::Value',NULL,1606),(2681,'a485d1bb-2cc7-4a80-acb2-ba909cce3b8e','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-PuppetStepConfig-qfamzkuvye4x','state changed','OS::Heat::Value',NULL,1606),(2682,'f4926c46-d32a-4d3b-8d0a-fd7d9fa5b47d','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PostUpgradeTasks-yeq4chsfrg6o','state changed','OS::Heat::Value',NULL,1607),(2683,'e4e30695-c0a5-4ae8-81ae-ee27bed5641f','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ControllerServiceChain-vhdt72nhe4ji-DockerConfigScripts-mckjxtbe7qc5','state changed','OS::Heat::Value',NULL,1608),(2684,'f9762084-7911-41ae-a3aa-99620da0e9cf','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ControllerServiceChain-vhdt72nhe4ji-DockerConfigScripts-mckjxtbe7qc5','state changed','OS::Heat::Value',NULL,1608),(2685,'44a2dd9c-de70-4588-8941-8ad079f8cd17','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PostUpgradeTasks-yeq4chsfrg6o','state changed','OS::Heat::Value',NULL,1607),(2686,'de5a7e19-4550-4ae3-9df5-4798d6679005','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalUpdateTasks-ty77chbqhhzn','state changed','OS::Heat::Value',NULL,1609),(2687,'fc9e6861-ac74-475a-9824-d7de76f2bb72','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalUpdateTasks-ty77chbqhhzn','state changed','OS::Heat::Value',NULL,1609),(2688,'4797d31d-4300-4900-aee9-74d46e87b40e','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:08',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-KollaConfig-i6sxhicighhk','state changed','OS::Heat::Value',NULL,1610),(2689,'7e84d35f-0dfc-4c32-93d7-8f85fb128868','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-KollaConfig-i6sxhicighhk','state changed','OS::Heat::Value',NULL,1610),(2690,'e47a695b-5d66-45a6-b1b1-44d28c9e8d1d','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ControllerServiceChain-vhdt72nhe4ji-GlobalConfigSettings-2ii653j6ggcd','state changed','OS::Heat::Value',NULL,1611),(2691,'8a312c80-59bd-463f-8fec-1c98083286da','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ControllerServiceChain-vhdt72nhe4ji-FirewallRules-3muopmlymr3a','state changed','OS::Heat::Value',NULL,1612),(2692,'26c3ffb3-a5ba-40f8-8d32-fd2b29b6f4f2','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ControllerServiceChain-vhdt72nhe4ji-FirewallRules-3muopmlymr3a','state changed','OS::Heat::Value',NULL,1612),(2693,'c46dc31d-e2e6-46ca-a464-df357a879785','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ControllerServiceChain-vhdt72nhe4ji-GlobalConfigSettings-2ii653j6ggcd','state changed','OS::Heat::Value',NULL,1611),(2694,'ed59c4b6-ef32-4d81-aeb9-2b1f8daadcbb','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-HostFirewallTasks-skcswis6jqwg','state changed','OS::Heat::Value',NULL,1613),(2695,'82385519-b9bb-497a-92de-a4634c7cd4bd','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-HostFirewallTasks-skcswis6jqwg','state changed','OS::Heat::Value',NULL,1613),(2696,'fcc05280-1e62-4c7c-89c5-1676c29806d1','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:09',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PreUpgradeRollingTasks-3pxh2mtshoe6','state changed','OS::Heat::Value',NULL,1614),(2697,'1774598b-0a8b-4e05-b6f2-0d1c0c6afc96','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PreUpgradeRollingTasks-3pxh2mtshoe6','state changed','OS::Heat::Value',NULL,1614),(2698,'fac55aa7-755a-4b5f-a115-62ed8d2a7ea8','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PostUpdateTasks-jnyacaamtguk','state changed','OS::Heat::Value',NULL,1615),(2699,'3d9edf5e-b998-459d-b717-a943ff54f807','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-UpgradeTasks-mjof753qcocv','state changed','OS::Heat::Value',NULL,1616),(2700,'314313dd-6846-4480-a677-1d6296dee9f8','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-PostUpdateTasks-jnyacaamtguk','state changed','OS::Heat::Value',NULL,1615),(2701,'a100898e-4c5b-45af-b54c-ef759f4d783c','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceConfigSettings-dapnbehyowkd','state changed','OS::Heat::Value',NULL,1617),(2702,'92939596-c40a-4d59-b1a6-6801b973bd18','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceConfigSettings-dapnbehyowkd','state changed','OS::Heat::Value',NULL,1617),(2703,'2ed64a7e-ab3f-4101-9101-59118242b8ee','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-UpgradeTasks-mjof753qcocv','state changed','OS::Heat::Value',NULL,1616),(2704,'594d8657-af81-455d-8925-32e04751e103','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-UpgradeBatchTasks-zunuap5j4pd5','state changed','OS::Heat::Value',NULL,1618),(2705,'b2936597-8e30-442e-a7e1-f7fd74c24d16','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:10',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-UpgradeBatchTasks-zunuap5j4pd5','state changed','OS::Heat::Value',NULL,1618),(2706,'26f3f0ec-74c8-4dbf-9a8b-bdcfb01134c8','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ContainerPuppetTasks-twiszl4ergtv','state changed','OS::Heat::Value',NULL,1619),(2707,'8a1832a7-8056-4dfb-afa5-3223caa666ae','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-AnsibleGroupVars-jbbg6vbp45nc','state changed','OS::Heat::Value',NULL,1620),(2708,'6cd24b63-767d-487a-b6ba-5acc5575b2e7','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ControllerServiceChain-vhdt72nhe4ji-AnsibleGroupVars-jbbg6vbp45nc','state changed','OS::Heat::Value',NULL,1620),(2709,'3abe984c-079c-4b32-9b8f-7d73ec7d7e13','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ContainerPuppetTasks-twiszl4ergtv','state changed','OS::Heat::Value',NULL,1619),(2710,'1777598c-41cd-4aa5-9ee8-943234fe6673','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-vhdt72nhe4ji-KeystoneResourcesConfigs-ujfquakttc3x','state changed','OS::Heat::Value',NULL,1621),(2711,'4b4519f4-686f-4e28-a511-1ead201e4db8','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-vhdt72nhe4ji-KeystoneResourcesConfigs-ujfquakttc3x','state changed','OS::Heat::Value',NULL,1621),(2712,'5ae456aa-57e8-4564-a59b-767fb6b1227d','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceNames-6avjpgk3lgfv','state changed','OS::Heat::Value',NULL,1622),(2713,'534308e2-bec6-4d04-8aeb-da42dbae6cb0','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:11',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ControllerServiceChain-vhdt72nhe4ji-ServiceNames-6avjpgk3lgfv','state changed','OS::Heat::Value',NULL,1622),(2714,'bb5eaaf1-ed90-4173-b7ae-aec721785e72','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalPostDeployTasks-bitvn2o2bvxr','state changed','OS::Heat::Value',NULL,1623),(2715,'c5b070d8-366a-4b49-a06b-fcc3987115d9','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalPostDeployTasks-bitvn2o2bvxr','state changed','OS::Heat::Value',NULL,1623),(2716,'69729378-9a8f-4f0f-b787-12a17d6f7126','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ControllerServiceChain-vhdt72nhe4ji-FirewallFrontendRules-iaeepsn4alwl','state changed','OS::Heat::Value',NULL,1624),(2717,'d5d9da9c-eb2f-45cb-9669-7f9ca55cc744','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-MonitoringSubscriptionsConfig-rceg73oywlm4','state changed','OS::Heat::Value',NULL,1625),(2718,'db08c919-717a-4537-93cf-124de977ae4e','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-vhdt72nhe4ji-MonitoringSubscriptionsConfig-rceg73oywlm4','state changed','OS::Heat::Value',NULL,1625),(2719,'43648e4c-54e7-4b65-ba23-16ee4f8e398e','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ControllerServiceChain-vhdt72nhe4ji-FirewallFrontendRules-iaeepsn4alwl','state changed','OS::Heat::Value',NULL,1624),(2720,'852db212-d41d-46b9-bc1a-ed8ce4763c6d','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalUpgradeTasks-45mqkjhg6rvc','state changed','OS::Heat::Value',NULL,1627),(2721,'589ce441-210c-4c1b-908b-281a5cd92039','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ControllerServiceChain-vhdt72nhe4ji-ExternalUpgradeTasks-45mqkjhg6rvc','state changed','OS::Heat::Value',NULL,1627),(2722,'1b553ff5-c46b-4b25-8c3a-151fffaac34a','6672b166-a959-4a82-90bf-0df8a99740f1','2026-06-13 07:52:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-vhdt72nhe4ji','6672b166-a959-4a82-90bf-0df8a99740f1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2723,'9e625eb9-cb41-442f-86f1-7e9ac354b26b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:13',NULL,'CREATE','COMPLETE','ControllerServiceChain','6672b166-a959-4a82-90bf-0df8a99740f1','state changed','OS::TripleO::ControllerServices',NULL,89),(2724,'e892104f-4807-49d2-a0fb-913d8cb15c90','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','IN_PROGRESS','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-5khsj3x7lrap','state changed','OS::Heat::Value',NULL,1661),(2725,'1b6f30d4-8f51-448e-b00e-bdfe1006558c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','COMPLETE','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-5khsj3x7lrap','state changed','OS::Heat::Value',NULL,1661),(2726,'7b8270a2-4b53-4c7e-90b3-5ba13e3ac84f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-ite6n7dobul2','state changed','OS::Heat::Value',NULL,1662),(2727,'32d96a3d-9209-41fe-b539-f9207c9d9a1f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','COMPLETE','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-ite6n7dobul2','state changed','OS::Heat::Value',NULL,1662),(2728,'bd267c0b-8cb6-428f-97e8-7349c73d7a2b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','IN_PROGRESS','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-wgaeosw2zgqr','state changed','OS::Heat::Value',NULL,1664),(2729,'de744d61-a332-4b67-918f-6170fe5707e0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','COMPLETE','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-wgaeosw2zgqr','state changed','OS::Heat::Value',NULL,1664),(2730,'c9c2c655-17c3-41c5-8298-e62c39ca29ff','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','IN_PROGRESS','GlobalConfig','overcloud-GlobalConfig-ruhkg67tvzmy','state changed','OS::Heat::Value',NULL,1665),(2731,'69e58789-21f2-40f9-af2c-bba795431669','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:14',NULL,'CREATE','COMPLETE','GlobalConfig','overcloud-GlobalConfig-ruhkg67tvzmy','state changed','OS::Heat::Value',NULL,1665),(2732,'f06d1643-7f18-4334-8ed2-d8f1923bbe53','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-FirewallFrontendRules-uq2ddcbvkseq','state changed','OS::Heat::Value',NULL,1666),(2733,'45b3d4fd-fb2c-4ff3-a53c-0acfa1ab5ef8','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-FirewallFrontendRules-uq2ddcbvkseq','state changed','OS::Heat::Value',NULL,1666),(2734,'5e14dc37-39d3-4ea6-af8b-2b8d05e94b24','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-hjpxlh2zg6vy','state changed','OS::Heat::Value',NULL,1667),(2735,'0108fc9f-4565-40da-85cf-f2e1c3172210','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-hjpxlh2zg6vy','state changed','OS::Heat::Value',NULL,1667),(2736,'853e2f20-caa1-4fd0-abfe-7f018d8b922f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-qaoxjhly3ehb','state changed','OS::Heat::Value',NULL,1668),(2737,'5410f23d-722f-44d5-b705-b005a1b16738','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-qaoxjhly3ehb','state changed','OS::Heat::Value',NULL,1668),(2738,'7848fb4a-fe05-468b-8b5a-2afba6ee2e60','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','ComputeConfigData','overcloud-ComputeConfigData-ejpp6dppyesl','state changed','OS::Heat::Value',NULL,1672),(2739,'57832d58-1bf3-4fd3-85d7-b07394a63d7d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','ComputeConfigData','overcloud-ComputeConfigData-ejpp6dppyesl','state changed','OS::Heat::Value',NULL,1672),(2740,'045ceb12-dcad-4460-a2d4-f418de32e7a1','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-bcsaskykl5ii','state changed','OS::Heat::Value',NULL,1671),(2741,'df933c50-2401-411f-aee0-0cd1af5b0a90','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','ComputeGroupVars','overcloud-ComputeGroupVars-6cafgqjcgayx','state changed','OS::Heat::Value',NULL,1673),(2742,'a323e255-05a9-4530-8c34-f86250cba81c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','NetworkerGroupVars','overcloud-NetworkerGroupVars-2bmvmyhihrvh','state changed','OS::Heat::Value',NULL,1670),(2743,'adcca5e4-6e76-457d-9269-bebc6d5c982d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-bcsaskykl5ii','state changed','OS::Heat::Value',NULL,1671),(2744,'ec8a4d9b-378c-43f3-9393-c16d38277e6a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','ComputeGroupVars','overcloud-ComputeGroupVars-6cafgqjcgayx','state changed','OS::Heat::Value',NULL,1673),(2745,'992ac7c9-292f-4247-9eee-a6c5c95432c6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','BlockStorageConfigData','overcloud-BlockStorageConfigData-nr7niafppqdc','state changed','OS::Heat::Value',NULL,1675),(2746,'3622d68b-ab02-4292-9d4a-29d9db538dc9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','BlockStorageConfigData','overcloud-BlockStorageConfigData-nr7niafppqdc','state changed','OS::Heat::Value',NULL,1675),(2747,'556c688a-c87d-45c2-932b-1cf2ad720fc7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-5vvikm642yc5','state changed','OS::Heat::Value',NULL,1678),(2748,'80846e4f-2bd9-469e-8f37-5bdb857f23d8','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','NetworkerGroupVars','overcloud-NetworkerGroupVars-2bmvmyhihrvh','state changed','OS::Heat::Value',NULL,1670),(2749,'c6e65fe3-e41b-4cf7-90ff-1a6af0e1ad9a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','CellControllerGroupVars','overcloud-CellControllerGroupVars-67rjavyhnyfd','state changed','OS::Heat::Value',NULL,1677),(2750,'7d361448-985b-4391-87f7-7268a588a310','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-5vvikm642yc5','state changed','OS::Heat::Value',NULL,1678),(2751,'d8470617-084e-4cdb-90cf-a3294d8b187b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-bcgq7bgo54x4','state changed','OS::Heat::Value',NULL,1676),(2752,'43b75ba0-6192-4097-a0bb-30909c27c0e6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','IN_PROGRESS','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-xuo45kcl6aho','state changed','OS::Heat::Value',NULL,1679),(2753,'1f0cf523-f482-4ee9-81e2-410edb8d2a66','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-bcgq7bgo54x4','state changed','OS::Heat::Value',NULL,1676),(2754,'fb92d1b7-a49b-4c01-b9c3-cd2626fe0a49','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:15',NULL,'CREATE','COMPLETE','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-xuo45kcl6aho','state changed','OS::Heat::Value',NULL,1679),(2755,'ed1bb2fa-6509-4323-950c-4d87061b0734','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','CephStorageConfigData','overcloud-CephStorageConfigData-ay3oxqqi35zc','state changed','OS::Heat::Value',NULL,1683),(2756,'7c33e88e-f300-44ba-9a13-dbf4ce015593','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','CephStorageGroupVars','overcloud-CephStorageGroupVars-lfkacqn6g62u','state changed','OS::Heat::Value',NULL,1682),(2757,'d194ce72-095b-4e6b-8ca5-8b517ea8c498','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','CephStorageConfigData','overcloud-CephStorageConfigData-ay3oxqqi35zc','state changed','OS::Heat::Value',NULL,1683),(2758,'3561a469-c72e-43e2-8a2d-e1d8cafcf507','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','CellControllerGroupVars','overcloud-CellControllerGroupVars-67rjavyhnyfd','state changed','OS::Heat::Value',NULL,1677),(2759,'ba4306e7-00bf-44d8-8964-b24823a5e6f1','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','NetworkerConfigData','overcloud-NetworkerConfigData-ygo7htulytk3','state changed','OS::Heat::Value',NULL,1684),(2760,'0d1d308d-a059-432d-bc63-da96bbeda145','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','NetworkerConfigData','overcloud-NetworkerConfigData-ygo7htulytk3','state changed','OS::Heat::Value',NULL,1684),(2761,'80e7d83b-7586-4dbe-b97d-86f61449adb7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','ComputeHCIGroupVars','overcloud-ComputeHCIGroupVars-55gr5kb4q5h4','state changed','OS::Heat::Value',NULL,1685),(2762,'2b256a7f-06f4-41fd-b402-5a3a75eabbf4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','ComputeHCIGroupVars','overcloud-ComputeHCIGroupVars-55gr5kb4q5h4','state changed','OS::Heat::Value',NULL,1685),(2763,'8b87a912-8d8b-49d0-8ff2-9751424e5258','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','CephStorageGroupVars','overcloud-CephStorageGroupVars-lfkacqn6g62u','state changed','OS::Heat::Value',NULL,1682),(2764,'5c41c907-6628-4b30-8feb-e3eb18574e4f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-la57cs2k7i3v','state changed','OS::Heat::Value',NULL,1688),(2765,'5a27c3f3-fa4c-4fa6-8507-33d352e3f2b5','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-b5cejrvb5kwe','state changed','OS::Heat::Value',NULL,1687),(2766,'309b0d14-18f5-444e-93f2-709f88505f7a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-la57cs2k7i3v','state changed','OS::Heat::Value',NULL,1688),(2767,'d28bcd6a-c506-4edb-b9c2-32924f81db8a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-b5cejrvb5kwe','state changed','OS::Heat::Value',NULL,1687),(2768,'2d3dc474-446d-4e07-bb60-999f3fc886c9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-tdy4hpvs6uvo','state changed','OS::Heat::Value',NULL,1690),(2769,'9f3f1751-9236-4888-b57a-09f4442fa33d','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-tdy4hpvs6uvo','state changed','OS::Heat::Value',NULL,1690),(2770,'13991be6-fa17-4114-977d-ea0eae36cca0','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','IN_PROGRESS','ComputeHCIServiceConfigSettings','overcloud-ComputeHCIServiceConfigSettings-muals5epm42q','state changed','OS::Heat::Value',NULL,1691),(2771,'3eb59df6-bf4c-44e3-b3e2-4a47293bf81c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:16',NULL,'CREATE','COMPLETE','ComputeHCIServiceConfigSettings','overcloud-ComputeHCIServiceConfigSettings-muals5epm42q','state changed','OS::Heat::Value',NULL,1691),(2772,'7282a8b1-b9f9-4a8b-9c03-98f6c9adf7cb','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','IN_PROGRESS','ComputeHCIConfigData','overcloud-ComputeHCIConfigData-lfnww4667jfv','state changed','OS::Heat::Value',NULL,1694),(2773,'139aaf35-0619-4105-85ee-92ddc36ba509','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','COMPLETE','ComputeHCIConfigData','overcloud-ComputeHCIConfigData-lfnww4667jfv','state changed','OS::Heat::Value',NULL,1694),(2774,'5e5c12c2-b94d-4003-87a1-d2cfc5d1fe91','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','IN_PROGRESS','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-td6qnefk25kp','state changed','OS::Heat::Value',NULL,1693),(2775,'827a923d-a142-42b6-b4fc-65b34617a97b','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','IN_PROGRESS','ControllerGroupVars','overcloud-ControllerGroupVars-3tizbm4w67an','state changed','OS::Heat::Value',NULL,1695),(2776,'27902af5-e4b4-4f6c-bb86-28bde0e23b5a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','COMPLETE','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-td6qnefk25kp','state changed','OS::Heat::Value',NULL,1693),(2777,'2d602e8f-7a7c-4bd2-9a9f-f50b6a915a1c','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','COMPLETE','ControllerGroupVars','overcloud-ControllerGroupVars-3tizbm4w67an','state changed','OS::Heat::Value',NULL,1695),(2778,'f2f3220d-ebd6-40ce-a8e9-19c52bc140cc','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','IN_PROGRESS','ControllerServiceNames','overcloud-ControllerServiceNames-ujz2y37ptpsi','state changed','OS::Heat::Value',NULL,1698),(2779,'ffd8a008-e77b-48fe-b7a1-3996ee28c8a6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','COMPLETE','ControllerServiceNames','overcloud-ControllerServiceNames-ujz2y37ptpsi','state changed','OS::Heat::Value',NULL,1698),(2780,'1700f4fb-02b1-4639-aa66-23312e98f857','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','IN_PROGRESS','CellControllerConfigData','overcloud-CellControllerConfigData-ktfk2hu4aqbd','state changed','OS::Heat::Value',NULL,1699),(2781,'bb3c2583-a7c3-43ea-af48-f4f0f7b9d0ff','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','COMPLETE','CellControllerConfigData','overcloud-CellControllerConfigData-ktfk2hu4aqbd','state changed','OS::Heat::Value',NULL,1699),(2782,'8079bd00-4d76-4a1b-ad2e-2fe74d616277','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:17',NULL,'CREATE','IN_PROGRESS','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-xiwoqlkfcbya','state changed','OS::Heat::Value',NULL,1700),(2783,'7215cfb0-523a-4c68-8b66-9b784d840c47','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:18',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-mmj6lie32q3f','state changed','OS::Heat::ResourceGroup',NULL,1702),(2784,'7bd0944e-ad9e-4d09-97cd-eef3710942b7','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:18',NULL,'CREATE','COMPLETE','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-xiwoqlkfcbya','state changed','OS::Heat::Value',NULL,1700),(2785,'e8000453-24a3-4810-8d3f-c95a038875c3','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:18',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f','80d7c08a-7c8d-457d-bf84-9313b8a18e70','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2786,'77dc167e-0715-42d2-b671-dbd6cea26d91','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:18',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f','80d7c08a-7c8d-457d-bf84-9313b8a18e70','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2787,'df37dc27-3ead-427e-a6c1-d3ea4ab54129','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:18',NULL,'CREATE','IN_PROGRESS','ControllerConfigData','overcloud-ControllerConfigData-pywa4xqrmyst','state changed','OS::Heat::Value',NULL,1704),(2788,'a4d36d6b-04e7-4131-91b3-63b9aaab76e5','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:18',NULL,'CREATE','COMPLETE','ControllerConfigData','overcloud-ControllerConfigData-pywa4xqrmyst','state changed','OS::Heat::Value',NULL,1704),(2789,'9af02864-13b4-4217-a888-be2e366e05b2','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:19',NULL,'UPDATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f','80d7c08a-7c8d-457d-bf84-9313b8a18e70','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(2790,'fb405da5-8f91-4e9c-b5eb-38083c7b7514','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:19',NULL,'CREATE','IN_PROGRESS','1','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp','state changed','OS::TripleO::Controller',NULL,1705),(2791,'4ee662dc-fd73-46fb-851e-6a4fb6c56599','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:19',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2792,'891d6fb4-a541-4388-9104-4f1e7a44abd6','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:19',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-Controller-z56ic74gwk6i','state changed','OS::TripleO::ControllerServer',NULL,1706),(2793,'35a76a70-4e18-46fd-bf7e-f4f0a419053e','b06f53d0-6b39-45fc-8b05-048a506bfd45','2026-06-13 07:52:19',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-Controller-z56ic74gwk6i','b06f53d0-6b39-45fc-8b05-048a506bfd45','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2794,'638943ee-51a8-4ff5-8693-d6e2a6afadae','b06f53d0-6b39-45fc-8b05-048a506bfd45','2026-06-13 07:52:20',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-z56ic74gwk6i-deployed-server-wzqnevlmxs56','state changed','OS::Heat::DeployedServer',NULL,1707),(2795,'d744f03c-8456-4d61-b0b5-a9ddffbf4be6','b06f53d0-6b39-45fc-8b05-048a506bfd45','2026-06-13 07:52:20',NULL,'CREATE','COMPLETE','deployed-server','56cbcbbe-0d25-4b66-9528-8717f0783e35','state changed','OS::Heat::DeployedServer',NULL,1707),(2796,'2e33b72f-781c-4b11-b6fc-9270a0ee7bae','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:20',NULL,'CREATE','IN_PROGRESS','0','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi','state changed','OS::TripleO::Controller',NULL,1708),(2797,'c7b57f08-5867-4581-92b1-d0e6db57138f','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:20',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2798,'a0a643c4-3657-43be-87e4-248ad762e7ff','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:20',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-DeploymentActions-y5ufb2u5niq5','state changed','OS::Heat::Value',NULL,1709),(2799,'9e1aaeeb-4db3-4ae4-856e-cf7e0f198dd8','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:20',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-Controller-37ulrll6mga7','state changed','OS::TripleO::ControllerServer',NULL,1710),(2800,'a665f911-0d5f-4060-b0a1-aedc2ecd974e','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:20',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-DeploymentActions-y5ufb2u5niq5','state changed','OS::Heat::Value',NULL,1709),(2801,'96af0de7-4807-4581-9b69-fea7d39cb903','1eb333cd-ad19-4f10-a583-d0f42943a103','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-Controller-37ulrll6mga7','1eb333cd-ad19-4f10-a583-d0f42943a103','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2802,'31cf2977-aaab-4a81-a7a2-12543ddf4987','b06f53d0-6b39-45fc-8b05-048a506bfd45','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-Controller-z56ic74gwk6i-ControlPlanePort-2mkb22slwbct','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1712),(2803,'7bacd94c-d961-4926-90b8-94c7a82430ed','1eb333cd-ad19-4f10-a583-d0f42943a103','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-Controller-37ulrll6mga7-ControlPlanePort-lobo4m2ttigz','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1713),(2804,'c3402015-8f67-4ccd-9957-b5d6142c7b93','e09defd3-0ec0-4079-a4b3-c0366693d9aa','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-Controller-z56ic74gwk6i-ControlPlanePort-2mkb22slwbct','e09defd3-0ec0-4079-a4b3-c0366693d9aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2805,'8c5d6fbf-8ce6-4f9a-87c1-0a281219d37d','e09defd3-0ec0-4079-a4b3-c0366693d9aa','2026-06-13 07:52:21',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-Controller-z56ic74gwk6i-ControlPlanePort-2mkb22slwbct','e09defd3-0ec0-4079-a4b3-c0366693d9aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2806,'ab37955f-cc21-4031-9ac4-39fdf8a16949','9c612968-8db3-4f97-91e9-a1cddacaec4d','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-Controller-37ulrll6mga7-ControlPlanePort-lobo4m2ttigz','9c612968-8db3-4f97-91e9-a1cddacaec4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2807,'b58aec6e-37da-4c64-9d4f-49fb29e2fa6e','9c612968-8db3-4f97-91e9-a1cddacaec4d','2026-06-13 07:52:21',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-Controller-37ulrll6mga7-ControlPlanePort-lobo4m2ttigz','9c612968-8db3-4f97-91e9-a1cddacaec4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2808,'a3a6321a-4198-45cf-ba79-8626bfaaab8c','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','2','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq','state changed','OS::TripleO::Controller',NULL,1714),(2809,'02d986cb-66bb-45f8-b8dd-7809f8bfcb10','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq','6f265096-1894-4e30-ae54-f9f605a427df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2810,'4e30f775-f1e0-415f-a272-6af106550d8f','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-Controller-ljmkac3qpr45','state changed','OS::TripleO::ControllerServer',NULL,1715),(2811,'aee634a1-837c-46db-8abc-6ca6e7661ff8','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-DeploymentActions-7jip7vorwix7','state changed','OS::Heat::Value',NULL,1716),(2812,'37245718-0149-4490-bed8-59c88ebd71af','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:21',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-DeploymentActions-7jip7vorwix7','state changed','OS::Heat::Value',NULL,1716),(2813,'c6cd5092-3739-4dd4-aedd-76c823901649','f2b440eb-f7d9-459d-8588-e4392264424a','2026-06-13 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-Controller-ljmkac3qpr45','f2b440eb-f7d9-459d-8588-e4392264424a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2814,'e3f1dc04-e229-487a-90b6-af27234e0613','f2b440eb-f7d9-459d-8588-e4392264424a','2026-06-13 07:52:22',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-ljmkac3qpr45-deployed-server-ymy4rwvowrzr','state changed','OS::Heat::DeployedServer',NULL,1718),(2815,'7974e90d-5ccf-472c-808d-44f439bb339b','f2b440eb-f7d9-459d-8588-e4392264424a','2026-06-13 07:52:22',NULL,'CREATE','COMPLETE','deployed-server','aaeb4731-1c8d-4c33-a715-31c4e2efc59d','state changed','OS::Heat::DeployedServer',NULL,1718),(2816,'59b58efe-5fcd-4694-9985-204ceea8f64d','1eb333cd-ad19-4f10-a583-d0f42943a103','2026-06-13 07:52:22',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-37ulrll6mga7-deployed-server-vv7cij76a2e5','state changed','OS::Heat::DeployedServer',NULL,1719),(2817,'8e77309a-22aa-44bc-89e0-3cad5ebc06e9','b06f53d0-6b39-45fc-8b05-048a506bfd45','2026-06-13 07:52:22',NULL,'CREATE','COMPLETE','ControlPlanePort','e09defd3-0ec0-4079-a4b3-c0366693d9aa','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1712),(2818,'4fec86e5-28be-467b-9183-45beb45089d4','1eb333cd-ad19-4f10-a583-d0f42943a103','2026-06-13 07:52:22',NULL,'CREATE','COMPLETE','deployed-server','7fe0689d-e242-4ad7-931f-d1763be51438','state changed','OS::Heat::DeployedServer',NULL,1719),(2819,'73293b87-5e29-472e-a059-afc7b7a2670e','b06f53d0-6b39-45fc-8b05-048a506bfd45','2026-06-13 07:52:22',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-Controller-z56ic74gwk6i','b06f53d0-6b39-45fc-8b05-048a506bfd45','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2820,'bd34ccf0-610e-4134-a991-db30d1c3598d','1eb333cd-ad19-4f10-a583-d0f42943a103','2026-06-13 07:52:22',NULL,'CREATE','COMPLETE','ControlPlanePort','9c612968-8db3-4f97-91e9-a1cddacaec4d','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1713),(2821,'daecda04-d28d-4385-9109-8053992316d5','1eb333cd-ad19-4f10-a583-d0f42943a103','2026-06-13 07:52:22',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-Controller-37ulrll6mga7','1eb333cd-ad19-4f10-a583-d0f42943a103','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2822,'3f53a46b-61dd-4bd6-be62-c87982a9a041','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:22',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-DeploymentActions-zqw3at3ahpwp','state changed','OS::Heat::Value',NULL,1720),(2823,'c14bda67-2489-4ad7-ba7f-9932436707fb','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:22',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-DeploymentActions-zqw3at3ahpwp','state changed','OS::Heat::Value',NULL,1720),(2824,'0b315284-e8e1-4116-820c-ec798e7c3c08','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','Controller','b06f53d0-6b39-45fc-8b05-048a506bfd45','state changed','OS::TripleO::ControllerServer',NULL,1706),(2825,'4ae8ab8f-5b56-42f0-8363-f2e43ec62a04','f2b440eb-f7d9-459d-8588-e4392264424a','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-Controller-ljmkac3qpr45-ControlPlanePort-7jaxrym22o4z','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1722),(2826,'d2b0a977-632b-4b04-9268-8b2f0dbced9e','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','Controller','1eb333cd-ad19-4f10-a583-d0f42943a103','state changed','OS::TripleO::ControllerServer',NULL,1710),(2827,'36b311b0-7b6a-4464-bc46-a1f6b67b0a4a','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NodeTLSCAData-raddnvv22f55','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2828,'6415931e-6a86-4a5a-a93b-486a1184f9ef','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','NodeTLSCAData','c58c9bcb-2e95-4773-bb23-f90d9a9efed6','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2829,'fdd1d20c-c1bb-4c41-93de-3f00d22c1e52','86cf58d2-3df6-49aa-9f9c-a35780b8a30f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-Controller-ljmkac3qpr45-ControlPlanePort-7jaxrym22o4z','86cf58d2-3df6-49aa-9f9c-a35780b8a30f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2830,'be3a0d82-0f33-48f7-941b-52f256b39fe3','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StorageMgmtPort-uyy6y5mw5ymu','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1724),(2831,'7991b0ac-be24-4243-95c5-b9ef42f86cbf','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-PreNetworkConfig-tisjuxjtitvd','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2832,'4238919a-95e3-461b-b8df-b8af7156b65c','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','PreNetworkConfig','e6dd24f6-2110-4325-b7b0-d79617b5d7f9','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2833,'a8392709-4bd7-4653-99d3-d4bc7e1869fe','86cf58d2-3df6-49aa-9f9c-a35780b8a30f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-Controller-ljmkac3qpr45-ControlPlanePort-7jaxrym22o4z','86cf58d2-3df6-49aa-9f9c-a35780b8a30f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2834,'6f5e0a3c-b735-4d48-bf04-e71d397b4718','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-TenantPort-bdi2foqf5ygy','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1728),(2835,'e1e3a135-30d3-4e05-9d67-240d2c102254','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NetHostMap-2ogydo6tb6pj','state changed','OS::Heat::Value',NULL,1726),(2836,'a3a964f2-32ca-4a7e-aaa1-5a9d7e0d2d58','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-InternalApiPort-quxv55veinqw','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1727),(2837,'ffcc48de-cdcb-4bf4-b1e0-80696454d1e3','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NetHostMap-2ogydo6tb6pj','state changed','OS::Heat::Value',NULL,1726),(2838,'d83106c1-6508-4492-afcd-884fc63f0f8f','b7e22370-3efe-425f-92fe-b6d2edfee5e3','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StorageMgmtPort-uyy6y5mw5ymu','b7e22370-3efe-425f-92fe-b6d2edfee5e3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2839,'785816ba-a36d-4455-bdd9-b5025ca632f6','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StoragePort-cfjvveotjapk','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1730),(2840,'7a683218-eda6-4800-aae9-18fdd2e57c97','f2b440eb-f7d9-459d-8588-e4392264424a','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','ControlPlanePort','86cf58d2-3df6-49aa-9f9c-a35780b8a30f','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1722),(2841,'6c05fc9a-f982-43ef-9fd3-b34fce517d5b','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-ControllerAnsibleHostVars-2fjkhvd5icae','state changed','OS::Heat::Value',NULL,1732),(2842,'f85b830a-2cee-4a47-b9d2-3c79772c1c75','5a3cb39d-8c8f-416f-99ae-320e2dad174f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-InternalApiPort-quxv55veinqw','5a3cb39d-8c8f-416f-99ae-320e2dad174f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2843,'576d9236-5f8b-4fec-ba11-710407877164','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-ControllerAnsibleHostVars-2fjkhvd5icae','state changed','OS::Heat::Value',NULL,1732),(2844,'29a830c4-a766-470f-b4f0-836f5086b8ec','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-ControllerExtraConfigPre-vzr3r5feproc','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1733),(2845,'56780aee-f2db-40ae-8187-63be7d21e0ca','b7e22370-3efe-425f-92fe-b6d2edfee5e3','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StorageMgmtPort-uyy6y5mw5ymu-StorageMgmtDeployedPort-jjjs7hixfr35','state changed','OS::Heat::Value',NULL,1735),(2846,'c777d241-22cf-482c-8972-5a8df7b522f9','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NetHostMap-fin3b6c6q4j2','state changed','OS::Heat::Value',NULL,1734),(2847,'bf926f31-3462-4e69-ac8f-ba408b41a58f','f2b440eb-f7d9-459d-8588-e4392264424a','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-Controller-ljmkac3qpr45','f2b440eb-f7d9-459d-8588-e4392264424a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2848,'71f7f4e4-1102-405d-9a12-6f0d968059c6','ac1cea34-9746-4d97-a50a-de3ea7c1b0ca','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-TenantPort-bdi2foqf5ygy','ac1cea34-9746-4d97-a50a-de3ea7c1b0ca','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2849,'6de22af1-d6f0-413c-9576-088b802381a5','b7e22370-3efe-425f-92fe-b6d2edfee5e3','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StorageMgmtPort-uyy6y5mw5ymu-StorageMgmtDeployedPort-jjjs7hixfr35','state changed','OS::Heat::Value',NULL,1735),(2850,'53cf6338-e485-4653-a769-ffde33024712','f7f91c21-7636-4fda-a6d4-61efcef72472','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StoragePort-cfjvveotjapk','f7f91c21-7636-4fda-a6d4-61efcef72472','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2851,'e0546c33-570c-43a8-a655-3845992a7ab0','b7e22370-3efe-425f-92fe-b6d2edfee5e3','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StorageMgmtPort-uyy6y5mw5ymu','b7e22370-3efe-425f-92fe-b6d2edfee5e3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2852,'e99c5370-767c-49cb-8ab2-68d9abce27bf','5a3cb39d-8c8f-416f-99ae-320e2dad174f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-InternalApiPort-quxv55veinqw-InternalApiDeployedPort-iumevz7bkweu','state changed','OS::Heat::Value',NULL,1737),(2853,'c3dc1651-4c03-4088-bfa5-2b5cd7e9f542','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-TenantPort-yonfz7rjix7y','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1736),(2854,'35f8b0dc-09f8-44c3-9a69-2ad594148ac1','5a3cb39d-8c8f-416f-99ae-320e2dad174f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-InternalApiPort-quxv55veinqw-InternalApiDeployedPort-iumevz7bkweu','state changed','OS::Heat::Value',NULL,1737),(2855,'edc65e04-f3ad-46f5-8379-cc6e220193af','5a3cb39d-8c8f-416f-99ae-320e2dad174f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-InternalApiPort-quxv55veinqw','5a3cb39d-8c8f-416f-99ae-320e2dad174f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2856,'89afdaac-d4cd-4f10-98d9-96182b46c4b7','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NetHostMap-fin3b6c6q4j2','state changed','OS::Heat::Value',NULL,1734),(2857,'0ed0074f-0480-49a6-a411-a2d5816d6834','f7f91c21-7636-4fda-a6d4-61efcef72472','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StoragePort-cfjvveotjapk-StorageDeployedPort-newhbrgy3qhl','state changed','OS::Heat::Value',NULL,1738),(2858,'e19d6f14-8a27-4ee0-aaea-f2c5e1e57ac0','f7f91c21-7636-4fda-a6d4-61efcef72472','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StoragePort-cfjvveotjapk-StorageDeployedPort-newhbrgy3qhl','state changed','OS::Heat::Value',NULL,1738),(2859,'2d63c0ce-2200-4490-8948-24a9f9be1525','f7f91c21-7636-4fda-a6d4-61efcef72472','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-StoragePort-cfjvveotjapk','f7f91c21-7636-4fda-a6d4-61efcef72472','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2860,'5d18a2c1-9d05-4cc2-9486-a3625e1bb2a6','d6008882-6636-4af7-826d-c2e73d48f98f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-ControllerExtraConfigPre-vzr3r5feproc','d6008882-6636-4af7-826d-c2e73d48f98f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2861,'2baf556b-eb13-4282-9e4f-ea7d73ed4dc3','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-PreNetworkConfig-suyn32n2p443','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2862,'8846483b-a831-44cb-8f8f-1a652a2ffb0a','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-InternalApiPort-b3kfzd3lpvdu','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1739),(2863,'3a2adbf3-bf2b-4119-905d-282a76f272d2','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-ControllerExtraConfigPre-wzhgbg5lcfjd','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1741),(2864,'a6ab8952-eeb6-4f4e-880c-bedcc3752480','869d42fd-28eb-42f2-99ad-f3321f1e2928','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-TenantPort-yonfz7rjix7y','869d42fd-28eb-42f2-99ad-f3321f1e2928','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2865,'43d8ad60-fa69-4135-adb0-cb41264742d1','8d583262-279a-4f51-9aa8-8fb08f0e3db5','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-InternalApiPort-b3kfzd3lpvdu','8d583262-279a-4f51-9aa8-8fb08f0e3db5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2866,'1a987fab-036c-47f7-bce6-de3fa5e4ba00','ac1cea34-9746-4d97-a50a-de3ea7c1b0ca','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-TenantPort-bdi2foqf5ygy-TenantDeployedPort-z6eby3vxhu6g','state changed','OS::Heat::Value',NULL,1743),(2867,'331465e8-bb2f-42f8-b074-69955ebf2abb','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-ControllerAnsibleHostVars-gvlxo2nbwswr','state changed','OS::Heat::Value',NULL,1742),(2868,'10729840-feec-4f4e-8703-acec0677f775','869d42fd-28eb-42f2-99ad-f3321f1e2928','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-TenantPort-yonfz7rjix7y-TenantDeployedPort-fipfdawg6zsm','state changed','OS::Heat::Value',NULL,1744),(2869,'8504f3cb-6b28-48d7-8bea-b84107a19bdf','e0ffc5b8-f495-4289-b96c-ca040550efcd','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-ControllerExtraConfigPre-wzhgbg5lcfjd','e0ffc5b8-f495-4289-b96c-ca040550efcd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2870,'0266b6c2-8310-49d7-8be3-2995c48b356d','ac1cea34-9746-4d97-a50a-de3ea7c1b0ca','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-TenantPort-bdi2foqf5ygy-TenantDeployedPort-z6eby3vxhu6g','state changed','OS::Heat::Value',NULL,1743),(2871,'ac4ad3b7-9474-4b09-89d4-adf9379ec3a9','869d42fd-28eb-42f2-99ad-f3321f1e2928','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-TenantPort-yonfz7rjix7y-TenantDeployedPort-fipfdawg6zsm','state changed','OS::Heat::Value',NULL,1744),(2872,'6c93e8c8-8cae-4773-9d13-0929c037c365','869d42fd-28eb-42f2-99ad-f3321f1e2928','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-TenantPort-yonfz7rjix7y','869d42fd-28eb-42f2-99ad-f3321f1e2928','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2873,'7e772184-6e93-4262-8ea4-3ba4377ddbc6','e0ffc5b8-f495-4289-b96c-ca040550efcd','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-ControllerExtraConfigPre-wzhgbg5lcfjd','e0ffc5b8-f495-4289-b96c-ca040550efcd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2874,'6c585c55-5319-4356-96be-6576ea64d1ec','ac1cea34-9746-4d97-a50a-de3ea7c1b0ca','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-TenantPort-bdi2foqf5ygy','ac1cea34-9746-4d97-a50a-de3ea7c1b0ca','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2875,'6c0ae1bc-fa3e-4ee0-9b1c-f16567a924cf','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StorageMgmtPort-lnvdv5zzxjwu','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1745),(2876,'4d94bfa5-3a9f-4b10-a6ed-f8366cd606be','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NodeTLSCAData-lzfovkuljd2l','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2877,'a78d3dc7-e8dc-497b-b0bb-b7c8045caed0','d6008882-6636-4af7-826d-c2e73d48f98f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-ControllerExtraConfigPre-vzr3r5feproc','d6008882-6636-4af7-826d-c2e73d48f98f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2878,'ca923040-2541-4cf7-8779-34cbe007e3ce','8d583262-279a-4f51-9aa8-8fb08f0e3db5','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-InternalApiPort-b3kfzd3lpvdu-InternalApiDeployedPort-iaimuiplfqon','state changed','OS::Heat::Value',NULL,1747),(2879,'e63b5087-6798-4067-b03d-23f744835621','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','PreNetworkConfig','0fe2f4a0-5366-4a55-873d-57ef034cc71b','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2880,'9cf50fc3-74cd-4b8c-9431-4698c0fdece9','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StoragePort-ysosvty4rl7b','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1748),(2881,'e1ac12ea-c8a2-4bde-ab46-ff46ce24ff0e','8d583262-279a-4f51-9aa8-8fb08f0e3db5','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-InternalApiPort-b3kfzd3lpvdu-InternalApiDeployedPort-iaimuiplfqon','state changed','OS::Heat::Value',NULL,1747),(2882,'7de71f3f-f381-42b0-aea1-b0b67c57af4e','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-ControllerAnsibleHostVars-gvlxo2nbwswr','state changed','OS::Heat::Value',NULL,1742),(2883,'2d6a7e8c-b663-420a-99f7-a7d78c212277','8d583262-279a-4f51-9aa8-8fb08f0e3db5','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-InternalApiPort-b3kfzd3lpvdu','8d583262-279a-4f51-9aa8-8fb08f0e3db5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2884,'211d9fe9-30f1-4169-b58f-b412f2e9f9ee','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','NodeTLSCAData','4dedc63e-019a-4bd5-a890-14e36ee6723d','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2885,'b54ef175-36b9-4437-9594-fded55184fe6','35ad68a3-e303-426b-a43a-25596d810584','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StorageMgmtPort-lnvdv5zzxjwu','35ad68a3-e303-426b-a43a-25596d810584','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2886,'6d58011c-3d45-4bfc-80c9-2c3141a05ad1','8d1643a9-87c3-4236-a98a-0658c9dac5bb','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StoragePort-ysosvty4rl7b','8d1643a9-87c3-4236-a98a-0658c9dac5bb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2887,'2c4bad1a-2fb4-44fb-bd11-5b4c68b2421c','35ad68a3-e303-426b-a43a-25596d810584','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StorageMgmtPort-lnvdv5zzxjwu-StorageMgmtDeployedPort-gwicride5yc4','state changed','OS::Heat::Value',NULL,1749),(2888,'71cdd8f1-1485-42c5-8ad8-34c2a05e1953','35ad68a3-e303-426b-a43a-25596d810584','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StorageMgmtPort-lnvdv5zzxjwu-StorageMgmtDeployedPort-gwicride5yc4','state changed','OS::Heat::Value',NULL,1749),(2889,'758937ce-76b1-4de3-8845-85e9d84d2b14','35ad68a3-e303-426b-a43a-25596d810584','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StorageMgmtPort-lnvdv5zzxjwu','35ad68a3-e303-426b-a43a-25596d810584','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2890,'901b6be5-6375-4486-8601-4c75066908af','8d1643a9-87c3-4236-a98a-0658c9dac5bb','2026-06-13 07:52:23',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StoragePort-ysosvty4rl7b-StorageDeployedPort-wqpdjzf5ussp','state changed','OS::Heat::Value',NULL,1750),(2891,'387869a6-ef88-498e-bd74-55fc986cf152','8d1643a9-87c3-4236-a98a-0658c9dac5bb','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StoragePort-ysosvty4rl7b-StorageDeployedPort-wqpdjzf5ussp','state changed','OS::Heat::Value',NULL,1750),(2892,'12000f81-dd45-4794-87ce-b668739646dc','8d1643a9-87c3-4236-a98a-0658c9dac5bb','2026-06-13 07:52:23',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-StoragePort-ysosvty4rl7b','8d1643a9-87c3-4236-a98a-0658c9dac5bb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2893,'f747ebbb-6f3f-4986-8346-1d9e75ed5cd7','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','Controller','f2b440eb-f7d9-459d-8588-e4392264424a','state changed','OS::TripleO::ControllerServer',NULL,1715),(2894,'e416b209-42f9-4745-947a-e000c805a305','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NetHostMap-dcuf2glfra4p','state changed','OS::Heat::Value',NULL,1752),(2895,'b0a6bc4e-4af9-4cff-a284-db21b8a003e3','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NetHostMap-dcuf2glfra4p','state changed','OS::Heat::Value',NULL,1752),(2896,'f88e59a3-25b6-4a7f-a126-578166747f5d','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-InternalApiPort-3ckeigqerefc','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1753),(2897,'15095c7c-7fb5-447e-a01b-faa5a7edbb8b','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-ControllerExtraConfigPre-ac3id2zq5aev','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1754),(2898,'3e9ca391-79e3-4587-a1c8-b8bb3fae4cf4','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StoragePort-6zbkml7pqzjq','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1756),(2899,'a83af880-bbcb-4dbb-a107-88d4574ffc0a','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-ControllerAnsibleHostVars-f5huxttuwblw','state changed','OS::Heat::Value',NULL,1757),(2900,'ff8033cc-3515-4bbd-87f2-709e0761f416','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-ControllerAnsibleHostVars-f5huxttuwblw','state changed','OS::Heat::Value',NULL,1757),(2901,'69e67ea9-effd-449d-86d5-8b1d399e2017','20c4f88e-1553-4362-b833-a902b55f9855','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-ControllerExtraConfigPre-ac3id2zq5aev','20c4f88e-1553-4362-b833-a902b55f9855','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2902,'3549752b-9c46-44a4-8ef5-8d82bc4d320e','20c4f88e-1553-4362-b833-a902b55f9855','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-ControllerExtraConfigPre-ac3id2zq5aev','20c4f88e-1553-4362-b833-a902b55f9855','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2903,'5e4ebae6-136f-480e-ab94-49d4e65df30e','748a60f3-8d25-4e04-b9ad-950a5291faf7','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-InternalApiPort-3ckeigqerefc','748a60f3-8d25-4e04-b9ad-950a5291faf7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2904,'2f483869-1f11-4483-aee3-96c4bcd95fb9','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-TenantPort-3r4tg63kfwpr','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1758),(2905,'ba0f5154-ac8b-4ecf-a97d-4a54b35f3cc7','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NodeTLSCAData-bo2uzghcjpi6','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2906,'a743e1d1-2785-4a66-8fa1-a56bd967a7e1','ab2a9da8-f0db-43cf-87ca-e49ddf6cf7dd','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StoragePort-6zbkml7pqzjq','ab2a9da8-f0db-43cf-87ca-e49ddf6cf7dd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2907,'7cafdb52-0a8e-4536-8932-4534e02fcd6b','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StorageMgmtPort-6anlywqnbimc','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1759),(2908,'002a4417-7c82-41e1-92ed-59f63b115bae','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','20c4f88e-1553-4362-b833-a902b55f9855','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1754),(2909,'240330e5-27c5-46ff-8113-3c0152c66804','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','StorageMgmtPort','b7e22370-3efe-425f-92fe-b6d2edfee5e3','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1724),(2910,'2fa45096-97d0-4b14-9229-ea3dbae1f64f','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','NodeTLSCAData','cf5036b9-22dd-4cbc-a040-078a261bf242','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2911,'27a0dd51-bf89-4b85-b977-c2768f6f9eff','3cda7f14-a5d6-4674-8231-09530cc05d9d','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-TenantPort-3r4tg63kfwpr','3cda7f14-a5d6-4674-8231-09530cc05d9d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2912,'1c4481a6-1e25-44cf-a6e3-841f83771a9a','748a60f3-8d25-4e04-b9ad-950a5291faf7','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-InternalApiPort-3ckeigqerefc-InternalApiDeployedPort-7zyvsycgxu54','state changed','OS::Heat::Value',NULL,1761),(2913,'3b112a95-2d90-4781-a284-63e729f48bf3','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-PreNetworkConfig-fvgusoce25hn','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2914,'3b5381b8-c20c-46b2-947e-8bfa01fba48c','6fdf0332-cf18-4369-a2b8-8eb2e455d05e','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StorageMgmtPort-6anlywqnbimc','6fdf0332-cf18-4369-a2b8-8eb2e455d05e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2915,'cf13dbf0-f7fd-4290-85b5-c6c5c514a681','748a60f3-8d25-4e04-b9ad-950a5291faf7','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-InternalApiPort-3ckeigqerefc-InternalApiDeployedPort-7zyvsycgxu54','state changed','OS::Heat::Value',NULL,1761),(2916,'57e0a9a3-f4fb-4741-9dab-9aaadae4bcd2','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','PreNetworkConfig','d99316bc-2ee1-411e-8880-5a92500aa6e1','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2917,'1b5a2927-e77e-48d3-9830-4233e7def665','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','InternalApiPort','5a3cb39d-8c8f-416f-99ae-320e2dad174f','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1727),(2918,'599622bf-7a53-4fbe-b6fd-92707d21504c','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','TenantPort','ac1cea34-9746-4d97-a50a-de3ea7c1b0ca','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1728),(2919,'7699b48f-a08c-4197-aa89-2892faf1867a','748a60f3-8d25-4e04-b9ad-950a5291faf7','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-InternalApiPort-3ckeigqerefc','748a60f3-8d25-4e04-b9ad-950a5291faf7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2920,'c8892b14-889a-4585-b4f4-bd4df12f4648','3cda7f14-a5d6-4674-8231-09530cc05d9d','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-TenantPort-3r4tg63kfwpr-TenantDeployedPort-vjfd326biw72','state changed','OS::Heat::Value',NULL,1765),(2921,'fb58db53-5833-4d8a-9389-914d78f32dbb','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NodeExtraConfig-c7d7nwughpce','state changed','OS::TripleO::NodeExtraConfig',NULL,1764),(2922,'ff0dba2a-2e38-4554-91bc-c6d0c3393411','3cda7f14-a5d6-4674-8231-09530cc05d9d','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-TenantPort-3r4tg63kfwpr-TenantDeployedPort-vjfd326biw72','state changed','OS::Heat::Value',NULL,1765),(2923,'d283e2c1-40c4-46bf-a4e8-391ee58a68c8','ab2a9da8-f0db-43cf-87ca-e49ddf6cf7dd','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StoragePort-6zbkml7pqzjq-StorageDeployedPort-qnz63mbnkove','state changed','OS::Heat::Value',NULL,1769),(2924,'aa05354a-c572-40da-ab8b-aaf402f41cf1','3cda7f14-a5d6-4674-8231-09530cc05d9d','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-TenantPort-3r4tg63kfwpr','3cda7f14-a5d6-4674-8231-09530cc05d9d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2925,'147c4a47-ffcd-48db-a64d-747ce16324ba','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','StoragePort','f7f91c21-7636-4fda-a6d4-61efcef72472','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1730),(2926,'1e1c9304-3c7e-4bf6-bffa-c33d64fa1ad1','ab2a9da8-f0db-43cf-87ca-e49ddf6cf7dd','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StoragePort-6zbkml7pqzjq-StorageDeployedPort-qnz63mbnkove','state changed','OS::Heat::Value',NULL,1769),(2927,'cc334cef-7720-4204-b67a-3dce7c3946bd','ab2a9da8-f0db-43cf-87ca-e49ddf6cf7dd','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StoragePort-6zbkml7pqzjq','ab2a9da8-f0db-43cf-87ca-e49ddf6cf7dd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2928,'db616b4f-cce2-41d6-b2fc-8609630f7297','8360f14c-66de-4ea1-ba09-284142f382ec','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NodeExtraConfig-c7d7nwughpce','8360f14c-66de-4ea1-ba09-284142f382ec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2929,'b0dcad49-a331-4a55-8782-8356d6ee1508','6fdf0332-cf18-4369-a2b8-8eb2e455d05e','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StorageMgmtPort-6anlywqnbimc-StorageMgmtDeployedPort-6igblzrqp3oa','state changed','OS::Heat::Value',NULL,1772),(2930,'99552145-6457-40ca-92c4-30e55535c0c6','6fdf0332-cf18-4369-a2b8-8eb2e455d05e','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StorageMgmtPort-6anlywqnbimc-StorageMgmtDeployedPort-6igblzrqp3oa','state changed','OS::Heat::Value',NULL,1772),(2931,'6aa2bbae-8cbc-4012-a43b-b7b6db8e7374','8360f14c-66de-4ea1-ba09-284142f382ec','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NodeExtraConfig-c7d7nwughpce','8360f14c-66de-4ea1-ba09-284142f382ec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2932,'6b7a842e-86de-4b4a-97fc-19fa389291a4','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','d6008882-6636-4af7-826d-c2e73d48f98f','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1733),(2933,'2328c36e-2e17-4833-9bc2-850b3f43a185','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','TenantPort','869d42fd-28eb-42f2-99ad-f3321f1e2928','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1736),(2934,'6673f47e-05a8-4df3-b36f-98d5cbb075ee','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NetIpMap-2mxpetp4vjaa','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1775),(2935,'6bdc5b57-13b7-4a74-891e-adeefe0449b8','6fdf0332-cf18-4369-a2b8-8eb2e455d05e','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-StorageMgmtPort-6anlywqnbimc','6fdf0332-cf18-4369-a2b8-8eb2e455d05e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2936,'4e15e141-1bea-4f01-a592-a8f46146f90a','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','InternalApiPort','8d583262-279a-4f51-9aa8-8fb08f0e3db5','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1739),(2937,'042b2f53-0e90-4334-8447-fbab6c6a460a','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','e0ffc5b8-f495-4289-b96c-ca040550efcd','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1741),(2938,'c837c8b4-690f-4938-be54-946b75207f5a','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NodeExtraConfig-qcdsbzdkzqz2','state changed','OS::TripleO::NodeExtraConfig',NULL,1778),(2939,'48fb6ec2-1560-4f62-9e85-3030c460dcb2','07255a32-d3aa-4566-a487-565e0c9394c8','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NetIpMap-2mxpetp4vjaa','07255a32-d3aa-4566-a487-565e0c9394c8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2940,'eba1cc1f-b2c4-49e8-8866-7818937f1776','c335bd7e-d15f-4d85-828b-65a10de7005b','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NodeExtraConfig-qcdsbzdkzqz2','c335bd7e-d15f-4d85-828b-65a10de7005b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2941,'f8ef97a8-7363-4898-a3dc-00f7aec68c07','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NodeExtraConfig-gi7rfw2qw3rp','state changed','OS::TripleO::NodeExtraConfig',NULL,1783),(2942,'c8575e22-7dd1-489e-b07f-4e3b9daeb603','c335bd7e-d15f-4d85-828b-65a10de7005b','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NodeExtraConfig-qcdsbzdkzqz2','c335bd7e-d15f-4d85-828b-65a10de7005b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2943,'f64be2ad-3679-43e0-824e-d44acd753b90','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','StoragePort','8d1643a9-87c3-4236-a98a-0658c9dac5bb','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1748),(2944,'dc5b9608-13d3-4861-8dad-54f14d25677c','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','StorageMgmtPort','35ad68a3-e303-426b-a43a-25596d810584','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1745),(2945,'c0786ea7-f32d-47ae-b4ec-fb0f9da3868e','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','NodeExtraConfig','c335bd7e-d15f-4d85-828b-65a10de7005b','state changed','OS::TripleO::NodeExtraConfig',NULL,1778),(2946,'904f523b-b7fb-4de9-a7fc-c0f43de0a528','185afee1-b398-4f30-b20a-bf952faa3545','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NodeExtraConfig-gi7rfw2qw3rp','185afee1-b398-4f30-b20a-bf952faa3545','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2947,'c5415c4b-16f3-48c8-92e5-9a6d50f00042','185afee1-b398-4f30-b20a-bf952faa3545','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NodeExtraConfig-gi7rfw2qw3rp','185afee1-b398-4f30-b20a-bf952faa3545','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2948,'740f4fb5-3cc5-437b-a2ea-aa1dc1083a5b','07255a32-d3aa-4566-a487-565e0c9394c8','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NetIpMap-2mxpetp4vjaa-NetIpMapValue-fjiq25ed5slu','state changed','OS::Heat::Value',NULL,1787),(2949,'456a899b-6ca4-4453-9e35-bf515fb66936','07255a32-d3aa-4566-a487-565e0c9394c8','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NetIpMap-2mxpetp4vjaa-NetIpMapValue-fjiq25ed5slu','state changed','OS::Heat::Value',NULL,1787),(2950,'35cf6d23-940d-4597-b924-f6a1b8ca5e33','07255a32-d3aa-4566-a487-565e0c9394c8','2026-06-13 07:52:24',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp-NetIpMap-2mxpetp4vjaa','07255a32-d3aa-4566-a487-565e0c9394c8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2951,'5d0c31e9-b6dc-4f38-a556-d50fe9f2a20a','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NetIpMap-qhg2j46zaxfy','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1789),(2952,'351fe33b-5dee-424b-ad37-47fbf0ac03c6','6321533c-18e3-4ea3-835b-d4f9cb7970b3','2026-06-13 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NetIpMap-qhg2j46zaxfy','6321533c-18e3-4ea3-835b-d4f9cb7970b3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2953,'06dc70cb-4b0a-44f4-a131-4dac759337f7','6321533c-18e3-4ea3-835b-d4f9cb7970b3','2026-06-13 07:52:25',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NetIpMap-qhg2j46zaxfy-NetIpMapValue-tlxlfqvng45l','state changed','OS::Heat::Value',NULL,1790),(2954,'218c7fe8-33d9-40a8-9c78-7e6e048cd3c8','6321533c-18e3-4ea3-835b-d4f9cb7970b3','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NetIpMap-qhg2j46zaxfy-NetIpMapValue-tlxlfqvng45l','state changed','OS::Heat::Value',NULL,1790),(2955,'a33865a1-6d9b-4752-a711-db1ec23ce0d2','6321533c-18e3-4ea3-835b-d4f9cb7970b3','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi-NetIpMap-qhg2j46zaxfy','6321533c-18e3-4ea3-835b-d4f9cb7970b3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2956,'f59abdcb-bb07-4303-9852-7b043a4dc333','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','InternalApiPort','748a60f3-8d25-4e04-b9ad-950a5291faf7','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1753),(2957,'d3b1d2b6-c8fd-4fe5-9d22-cde3bdb071fc','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','StoragePort','ab2a9da8-f0db-43cf-87ca-e49ddf6cf7dd','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1756),(2958,'d7456a89-68dd-4baa-ad85-47beca1c06e2','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','TenantPort','3cda7f14-a5d6-4674-8231-09530cc05d9d','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1758),(2959,'e6513445-adcd-4c76-b21b-7308a7c62121','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','StorageMgmtPort','6fdf0332-cf18-4369-a2b8-8eb2e455d05e','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1759),(2960,'14277c01-983a-4dc4-b4a2-4c2e5534fba0','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','NodeExtraConfig','8360f14c-66de-4ea1-ba09-284142f382ec','state changed','OS::TripleO::NodeExtraConfig',NULL,1764),(2961,'35b7013d-f7b8-4102-80b8-1c278404268c','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:25',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NetIpMap-kp35bspybfne','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1799),(2962,'e47a6c8b-64b9-44f6-a6a7-2c2d1690cf2f','cbd71d04-c239-4729-87f1-f91f0f96564b','2026-06-13 07:52:25',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NetIpMap-kp35bspybfne','cbd71d04-c239-4729-87f1-f91f0f96564b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2963,'092d2852-5e43-4189-aa9b-faeb71c16058','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','NetIpMap','07255a32-d3aa-4566-a487-565e0c9394c8','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1775),(2964,'279e4126-125e-44dd-af12-5b1b94ddd04d','cbd71d04-c239-4729-87f1-f91f0f96564b','2026-06-13 07:52:25',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NetIpMap-kp35bspybfne-NetIpMapValue-cydkxh3q57oo','state changed','OS::Heat::Value',NULL,1800),(2965,'1431ab1c-92c7-4a15-ad21-abe0b960bee7','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-1-qjpcjoiyfoyp','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2966,'3754739b-72f3-4b7f-99c9-721362a29279','cbd71d04-c239-4729-87f1-f91f0f96564b','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NetIpMap-kp35bspybfne-NetIpMapValue-cydkxh3q57oo','state changed','OS::Heat::Value',NULL,1800),(2967,'5b74ec6e-ebc0-48e9-9f49-c2d43a6407fa','cbd71d04-c239-4729-87f1-f91f0f96564b','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq-NetIpMap-kp35bspybfne','cbd71d04-c239-4729-87f1-f91f0f96564b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2968,'3a170426-34b6-4953-b3c7-f3463d5c77f0','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','NodeExtraConfig','185afee1-b398-4f30-b20a-bf952faa3545','state changed','OS::TripleO::NodeExtraConfig',NULL,1783),(2969,'0a019e31-5013-45db-ac39-49c2347ecb13','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:25',NULL,'CREATE','COMPLETE','NetIpMap','6321533c-18e3-4ea3-835b-d4f9cb7970b3','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1789),(2970,'209d8dc8-8478-41cb-a695-96d823d38bc2','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','2026-06-13 07:52:26',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-0-f65xrlpmcxoi','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2971,'4ca8c961-90b8-4248-a40f-6fa16b480be8','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:26',NULL,'CREATE','COMPLETE','0','43d6c8d5-d91b-4d1e-9bfe-d5b59a19265f','state changed','OS::TripleO::Controller',NULL,1708),(2972,'06a51c66-42b6-470e-bce3-a3c73b0fdd76','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:26',NULL,'CREATE','COMPLETE','NetIpMap','cbd71d04-c239-4729-87f1-f91f0f96564b','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1799),(2973,'0f2c55de-7ed3-487d-bb67-d31208a94d1d','6f265096-1894-4e30-ae54-f9f605a427df','2026-06-13 07:52:26',NULL,'CREATE','COMPLETE','overcloud-Controller-mmj6lie32q3f-2-ztpickx6zojq','6f265096-1894-4e30-ae54-f9f605a427df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2974,'288c149a-332d-42bd-81c7-358c00182cc8','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:26',NULL,'CREATE','COMPLETE','1','5dd4a3c9-be0d-4622-a277-2d4ddb2e398f','state changed','OS::TripleO::Controller',NULL,1705),(2975,'4f283f62-f588-4b5e-875b-71454181c558','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:26',NULL,'CREATE','COMPLETE','2','6f265096-1894-4e30-ae54-f9f605a427df','state changed','OS::TripleO::Controller',NULL,1714),(2976,'0e9b17a6-f91d-4552-b9f9-b4a9479036d8','80d7c08a-7c8d-457d-bf84-9313b8a18e70','2026-06-13 07:52:26',NULL,'UPDATE','COMPLETE','overcloud-Controller-mmj6lie32q3f','80d7c08a-7c8d-457d-bf84-9313b8a18e70','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(2977,'22993259-ed39-4c45-84c1-f953af4aaaa4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:27',NULL,'CREATE','COMPLETE','Controller','80d7c08a-7c8d-457d-bf84-9313b8a18e70','state changed','OS::Heat::ResourceGroup',NULL,1702),(2978,'2fe858d0-792e-4474-b872-9d985393729a','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','ServerIdMap','overcloud-ServerIdMap-lj3nyihsd2ec','state changed','OS::Heat::Value',NULL,1816),(2979,'a9858e74-9c62-4ae8-a76f-5334e604a758','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-wbjy7zrokd55','state changed','OS::Heat::Value',NULL,1817),(2980,'42f91a6b-9c4f-4ec1-b9d7-69366c2b1221','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','ServerIdMap','overcloud-ServerIdMap-lj3nyihsd2ec','state changed','OS::Heat::Value',NULL,1816),(2981,'5ccee4e8-b9fc-40db-a201-a0b02d14b9b6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-i6ylyvgu4itl','state changed','OS::Heat::Value',NULL,1818),(2982,'3cf784f8-7afb-4e31-9af3-e2ce782d4c2f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-wbjy7zrokd55','state changed','OS::Heat::Value',NULL,1817),(2983,'2d7ada39-e0d1-48c1-ae1b-6f2a1cb6dcd8','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-i6ylyvgu4itl','state changed','OS::Heat::Value',NULL,1818),(2984,'a17a24f6-0b82-47af-900c-4650ee0a811e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','ControllerServers','overcloud-ControllerServers-stm7atpoweuq','state changed','OS::Heat::Value',NULL,1819),(2985,'7350b64a-93f5-45da-95c6-d0e95b503008','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','ControllerServers','overcloud-ControllerServers-stm7atpoweuq','state changed','OS::Heat::Value',NULL,1819),(2986,'eb08c660-8eba-4d0f-a82c-074b42f9434e','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','ControllerIpListMap','overcloud-ControllerIpListMap-l5i4m4btizav','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1821),(2987,'b9a3f459-023e-4fd5-9266-65f748658ddb','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','AllNodesExtraConfig','overcloud-AllNodesExtraConfig-4dg7oizt5qcb','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2988,'4ae964bc-8840-4a4a-851c-b518638998a6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','AllNodesExtraConfig','b29796a2-8673-4f20-9e39-f07eeb9b9799','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2989,'6b6eac4d-071a-40e8-ac05-5aa373994717','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','BlacklistedHostnames','overcloud-BlacklistedHostnames-w7ptrkcotekd','state changed','OS::Heat::Value',NULL,1822),(2990,'bd4ade12-d382-4c35-ad5e-54873b76d73f','50b6938c-f467-4652-916c-1e6f50c69004','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerIpListMap-l5i4m4btizav','50b6938c-f467-4652-916c-1e6f50c69004','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2991,'3c015aeb-3a09-44b7-9d39-89247cb1f6a4','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','BlacklistedHostnames','overcloud-BlacklistedHostnames-w7ptrkcotekd','state changed','OS::Heat::Value',NULL,1822),(2992,'b0eeeca6-f0cd-4350-a191-04b275c2fed9','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','AnsibleHostVars','overcloud-AnsibleHostVars-dgdbwbqyadqy','state changed','OS::Heat::Value',NULL,1823),(2993,'48e8cce9-1046-4b65-bcb8-18f532ade65f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','AnsibleHostVars','overcloud-AnsibleHostVars-dgdbwbqyadqy','state changed','OS::Heat::Value',NULL,1823),(2994,'e3889585-f2ff-4e67-a234-836d8c0a5001','50b6938c-f467-4652-916c-1e6f50c69004','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ControllerIpListMap-l5i4m4btizav-EnabledServicesValue-s572jn5ddzpu','state changed','OS::Heat::Value',NULL,1826),(2995,'ebbad0c3-692a-4758-8c1e-e85cf81e9b5c','50b6938c-f467-4652-916c-1e6f50c69004','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ControllerIpListMap-l5i4m4btizav-EnabledServicesValue-s572jn5ddzpu','state changed','OS::Heat::Value',NULL,1826),(2996,'0d7aa399-df64-4f25-989e-938baf00b72f','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','IN_PROGRESS','HostsEntryValue','overcloud-HostsEntryValue-5yy7q3ijnw5x','state changed','OS::Heat::Value',NULL,1827),(2997,'0059cce5-2239-471b-bce3-f599ce6bd0f6','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:28',NULL,'CREATE','COMPLETE','HostsEntryValue','overcloud-HostsEntryValue-5yy7q3ijnw5x','state changed','OS::Heat::Value',NULL,1827),(2998,'fc177710-8de4-432a-a514-4f1f94b3a8ed','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:29',NULL,'CREATE','IN_PROGRESS','AllNodesDeploySteps','overcloud-AllNodesDeploySteps-prjevktw7cl5','state changed','OS::TripleO::PostDeploySteps',NULL,1829),(2999,'a7c0d655-bda8-4858-a489-139716a9f7c5','50b6938c-f467-4652-916c-1e6f50c69004','2026-06-13 07:52:29',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ControllerIpListMap-l5i4m4btizav-NetIpMapValue-tnaps42n4qu5','state changed','OS::Heat::Value',NULL,1830),(3000,'e97b94ac-a904-4828-9d78-606bd6720f5e','50b6938c-f467-4652-916c-1e6f50c69004','2026-06-13 07:52:30',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ControllerIpListMap-l5i4m4btizav-NetIpMapValue-tnaps42n4qu5','state changed','OS::Heat::Value',NULL,1830),(3001,'141d0a02-44ba-418f-81b8-01ad6f620529','50b6938c-f467-4652-916c-1e6f50c69004','2026-06-13 07:52:30',NULL,'CREATE','COMPLETE','overcloud-ControllerIpListMap-l5i4m4btizav','50b6938c-f467-4652-916c-1e6f50c69004','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(3002,'c9d43376-b670-4412-a6bf-1aac7bf653c2','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:30',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-prjevktw7cl5','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(3003,'df0eba8b-a6b1-4b74-8b68-7d7551346e55','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:30',NULL,'CREATE','IN_PROGRESS','BootstrapServerId','overcloud-AllNodesDeploySteps-prjevktw7cl5-BootstrapServerId-zlo7pitgfanj','state changed','OS::Heat::Value',NULL,1831),(3004,'1a140f66-7b27-4080-a36c-dd5b33a06287','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:30',NULL,'CREATE','COMPLETE','BootstrapServerId','overcloud-AllNodesDeploySteps-prjevktw7cl5-BootstrapServerId-zlo7pitgfanj','state changed','OS::Heat::Value',NULL,1831),(3005,'e9687a76-52af-41bb-b63a-87a6cd659599','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:30',NULL,'CREATE','COMPLETE','ControllerIpListMap','50b6938c-f467-4652-916c-1e6f50c69004','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1821),(3006,'bc2979a5-3275-4030-8db5-9e197c53de67','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:31',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ScaleTasks-lvmqzqrqr4rb','state changed','OS::Heat::Value',NULL,1832),(3007,'834bc62b-ba1c-480f-a383-ba38a16f326c','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:31',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ScaleTasks-lvmqzqrqr4rb','state changed','OS::Heat::Value',NULL,1832),(3008,'5f80968e-8e27-42b2-852d-ef2f3ddebf24','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:32',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalUpgradeTasks-lq5mddzztyrs','state changed','OS::Heat::Value',NULL,1833),(3009,'69ec9f1e-9d5e-4e8a-b150-45f71481478f','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:32',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalUpgradeTasks-lq5mddzztyrs','state changed','OS::Heat::Value',NULL,1833),(3010,'f3936ede-d2f2-4549-ad5d-58416f35ffdd','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:33',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalDeployTasks-6rpcglht2iam','state changed','OS::Heat::Value',NULL,1834),(3011,'c5bb3897-8dd3-4834-8d49-3b734c84f237','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:33',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalDeployTasks-6rpcglht2iam','state changed','OS::Heat::Value',NULL,1834),(3012,'ce64e1c3-e3a6-4877-9068-57e29f778201','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:34',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalUpdateTasks-yssoo6r43oko','state changed','OS::Heat::Value',NULL,1835),(3013,'b4a496fe-52dc-487d-a7ad-0bdb9811ec43','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:34',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalUpdateTasks-yssoo6r43oko','state changed','OS::Heat::Value',NULL,1835),(3014,'9a71988c-d5c6-46e5-96e7-63e8a5bac6fd','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:35',NULL,'CREATE','IN_PROGRESS','ComputeHCIExtraConfigPost','overcloud-AllNodesDeploySteps-prjevktw7cl5-ComputeHCIExtraConfigPost-iuag6im2m5t2','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1836),(3015,'001b6d62-2275-4cc7-8e0b-4f6288017466','bc62c3a7-65d6-44f7-be5e-9f635b85d698','2026-06-13 07:52:35',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-prjevktw7cl5-ComputeHCIExtraConfigPost-iuag6im2m5t2','bc62c3a7-65d6-44f7-be5e-9f635b85d698','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(3016,'64c5a7c1-7164-473b-87e5-6bda42cccc80','bc62c3a7-65d6-44f7-be5e-9f635b85d698','2026-06-13 07:52:35',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-prjevktw7cl5-ComputeHCIExtraConfigPost-iuag6im2m5t2','bc62c3a7-65d6-44f7-be5e-9f635b85d698','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(3017,'aaa6ad2a-30e4-494d-ab2d-3954b0c11cfb','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:36',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPost','overcloud-AllNodesDeploySteps-prjevktw7cl5-ControllerExtraConfigPost-usl4nismt65a','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1837),(3018,'0b899017-8cb6-43b3-a6b9-c2ad94aa0638','92747d14-05bb-4be5-969b-0468ba8b48a6','2026-06-13 07:52:36',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-prjevktw7cl5-ControllerExtraConfigPost-usl4nismt65a','92747d14-05bb-4be5-969b-0468ba8b48a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(3019,'90a8b01a-a728-40ca-b7b2-e86a05e61107','92747d14-05bb-4be5-969b-0468ba8b48a6','2026-06-13 07:52:36',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-prjevktw7cl5-ControllerExtraConfigPost-usl4nismt65a','92747d14-05bb-4be5-969b-0468ba8b48a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(3020,'7e730966-7b14-4aec-a663-c11629b5a9ea','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:36',NULL,'CREATE','COMPLETE','ComputeHCIExtraConfigPost','bc62c3a7-65d6-44f7-be5e-9f635b85d698','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1836),(3021,'08afa99f-da57-41a6-a9b0-019dc2d1c784','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:37',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalPostDeployTasks-fs3rcmxq4ljn','state changed','OS::Heat::Value',NULL,1839),(3022,'cfd8e431-0f8e-4766-a83f-5d65ae633450','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:37',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-ExternalPostDeployTasks-fs3rcmxq4ljn','state changed','OS::Heat::Value',NULL,1839),(3023,'dfcf873e-1a3e-43c7-94e0-405525608fc2','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:37',NULL,'CREATE','COMPLETE','ControllerExtraConfigPost','92747d14-05bb-4be5-969b-0468ba8b48a6','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1837),(3024,'22243cb8-f72f-4172-9453-c0a751cb1d6f','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:37',NULL,'CREATE','IN_PROGRESS','ControllerPostConfig','overcloud-AllNodesDeploySteps-prjevktw7cl5-ControllerPostConfig-ini2xrqx62tg','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(3025,'a645f5d5-52ea-4d1a-9a1e-7180a10924d6','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:37',NULL,'CREATE','IN_PROGRESS','ComputeHCIPostConfig','overcloud-AllNodesDeploySteps-prjevktw7cl5-ComputeHCIPostConfig-2c3odspwxcml','state changed','OS::TripleO::Tasks::ComputeHCIPostConfig',NULL,NULL),(3026,'9c4314a4-0af7-4454-a13e-dd0792da95c2','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:37',NULL,'CREATE','COMPLETE','ControllerPostConfig','53f45cec-1d20-47b7-bc97-fd841f115e2a','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(3027,'c6237213-0d31-47a7-a446-de7abeb954e6','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:37',NULL,'CREATE','COMPLETE','ComputeHCIPostConfig','b2119055-6642-4f8f-a960-b4d05197e7a2','state changed','OS::TripleO::Tasks::ComputeHCIPostConfig',NULL,NULL),(3028,'440dc3ca-a51b-4668-9bbf-a3d8cce64123','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:38',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-PreDeployStepTasks-7frba2ehu6t7','state changed','OS::Heat::Value',NULL,1841),(3029,'6277a97f-2995-479e-aaef-98de2dc23d4a','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:38',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-AllNodesDeploySteps-prjevktw7cl5-PreDeployStepTasks-7frba2ehu6t7','state changed','OS::Heat::Value',NULL,1841),(3030,'a8dd6d4c-471b-4ba7-a0d4-9e3409ab4bb3','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','2026-06-13 07:52:38',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-prjevktw7cl5','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(3031,'2fb8717d-a705-4ae0-bb32-1831f333fb52','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:39',NULL,'CREATE','COMPLETE','AllNodesDeploySteps','e988c2b3-1bf8-42cb-af8b-d49e1b0d0cf2','state changed','OS::TripleO::PostDeploySteps',NULL,1829),(3032,'0944d5ec-5f6e-47af-87bb-a169c3687a54','a373631c-90fc-4131-92e5-bf52321b3306','2026-06-13 07:52:39',NULL,'CREATE','COMPLETE','overcloud','a373631c-90fc-4131-92e5-bf52321b3306','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL);
/*!40000 ALTER TABLE `event` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrate_version`
--

DROP TABLE IF EXISTS `migrate_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migrate_version` (
  `repository_id` varchar(250) NOT NULL,
  `repository_path` text DEFAULT NULL,
  `version` int(11) DEFAULT NULL,
  PRIMARY KEY (`repository_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrate_version`
--

LOCK TABLES `migrate_version` WRITE;
/*!40000 ALTER TABLE `migrate_version` DISABLE KEYS */;
INSERT INTO `migrate_version` VALUES ('heat','/usr/lib/python3.9/site-packages/heat/db/sqlalchemy/migrate_repo',86);
/*!40000 ALTER TABLE `migrate_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template`
--

DROP TABLE IF EXISTS `raw_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `template` longtext DEFAULT NULL,
  `files` longtext DEFAULT NULL,
  `environment` longtext DEFAULT NULL,
  `files_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `raw_tmpl_files_fkey_ref` (`files_id`),
  CONSTRAINT `raw_tmpl_files_fkey_ref` FOREIGN KEY (`files_id`) REFERENCES `raw_template_files` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=438 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template`
--

LOCK TABLES `raw_template` WRITE;
/*!40000 ALTER TABLE `raw_template` DISABLE KEYS */;
INSERT INTO `raw_template` VALUES (1,'2026-06-13 07:49:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deploy an OpenStack environment, consisting of several node types (roles), Controller, Compute, BlockStorage, SwiftStorage and CephStorage. The Storage roles enable independent scaling of the storage components, but the minimal deployment is one Controller and one Compute node.\\n\", \"parameters\": {\"CloudNameStorage\": {\"default\": \"overcloud.storage.localdomain\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.localdomain\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageMgmtVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageMgmtVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.localdomain\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"InternalApiVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the InternalApiVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"PublicVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the PublicVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ExternalVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ExternalVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.localdomain\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}, \"ExtraHostFileEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"UndercloudHostsEntries\": {\"default\": [], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"EndpointMapOverride\": {\"default\": {}, \"description\": \"Can be used to override the calcluated EndpointMap\", \"type\": \"json\"}, \"ExtraConfig\": {\"default\": {}, \"description\": \"Additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"DeployedServerPortMap\": {\"default\": {}, \"type\": \"json\"}, \"NeutronControlPlaneID\": {\"default\": \"ctlplane\", \"type\": \"string\", \"description\": \"Neutron ID or name for ctlplane network.\"}, \"NeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create for accessing external networks.\", \"type\": \"string\"}, \"NeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"Which interface to add to the NeutronPhysicalBridge.\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"DnsSearchDomains\": {\"default\": [], \"description\": \"A list of DNS search domains to be added (in order) to resolv.conf.\", \"type\": \"comma_delimited_list\"}, \"ControlFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ControlVirtualIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"RabbitCookieSalt\": {\"type\": \"string\", \"default\": \"unset\", \"description\": \"Salt for the rabbit cookie, change this to force the randomly generated rabbit cookie to change.\"}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API.\\n\", \"type\": \"json\"}, \"HypervisorNeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create on each hypervisor. This defaults to br-ex the same as the control plane nodes, as we have a uniform configuration of the openvswitch agent. Typically should not need to be changed.\\n\", \"type\": \"string\"}, \"HypervisorNeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"What interface to add to the HypervisorNeutronPhysicalBridge.\", \"type\": \"string\"}, \"NodeCreateBatchSize\": {\"default\": 30, \"description\": \"Maxiumum batch size for creating nodes\", \"type\": \"number\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"BondInterfaceOvsOptions\": {\"default\": \"\", \"description\": \"The ovs_options or bonding_options string for the bond interface. Set things like lacp=active and/or bond_mode=balance-slb for OVS bonds or like mode=4 for Linux bonds using this option.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^((?!balance.tcp).)*$\", \"description\": \"The balance-tcp bond mode is known to cause packet loss and should not be used in BondInterfaceOvsOptions.\"}]}, \"NetworkConfigWithAnsible\": {\"description\": \"NetworkConfig with ansible flag\", \"type\": \"boolean\", \"default\": true}, \"ControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ControllerNetworkConfigTemplate\": {\"description\": \"Controller NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"controllerExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ControllerExtraConfig instead\\n\", \"type\": \"json\"}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\"}, \"ControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Controller node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"ControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Controller ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Controller ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nControllerServiceChain resource and the Controller resource group.\\nFor example:\\nControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerNetworkConfigTemplate\": {\"description\": \"CellController NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellController node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"CellControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellController ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellController ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerServiceChain resource and the CellController resource group.\\nFor example:\\nCellControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerComputeNetworkConfigTemplate\": {\"description\": \"CellControllerCompute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellControllerCompute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-compute-%index%\"}, \"CellControllerComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellControllerCompute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellControllerCompute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerComputeServiceChain resource and the CellControllerCompute resource group.\\nFor example:\\nCellControllerComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeNetworkConfigTemplate\": {\"description\": \"Compute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NovaComputeExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\"}, \"ComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Compute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-novacompute-%index%\"}, \"ComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Compute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Compute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NovaComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"DEPRECATED - use ComputeSchedulerHints instead\", \"default\": {}}, \"ComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeServiceChain resource and the Compute resource group.\\nFor example:\\nComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"BlockStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"BlockStorageNetworkConfigTemplate\": {\"description\": \"BlockStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"BlockStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\"}, \"BlockStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"BlockStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"BlockStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for BlockStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-blockstorage-%index%\"}, \"BlockStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from BlockStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"BlockStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for BlockStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"BlockStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"BlockStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"BlockStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"BlockStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"BlockStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nBlockStorageServiceChain resource and the BlockStorage resource group.\\nFor example:\\nBlockStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"BlockStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ObjectStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ObjectStorageNetworkConfigTemplate\": {\"description\": \"ObjectStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ObjectStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\"}, \"ObjectStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ObjectStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ObjectStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ObjectStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-objectstorage-%index%\"}, \"ObjectStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ObjectStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ObjectStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ObjectStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ObjectStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ObjectStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ObjectStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ObjectStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ObjectStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nObjectStorageServiceChain resource and the ObjectStorage resource group.\\nFor example:\\nObjectStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ObjectStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CephStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CephStorageNetworkConfigTemplate\": {\"description\": \"CephStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CephStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\"}, \"CephStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CephStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CephStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CephStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-cephstorage-%index%\"}, \"CephStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CephStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CephStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CephStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CephStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CephStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CephStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CephStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CephStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCephStorageServiceChain resource and the CephStorage resource group.\\nFor example:\\nCephStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CephStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"NetworkerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"NetworkerNetworkConfigTemplate\": {\"description\": \"Networker NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"NetworkerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\"}, \"NetworkerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"NetworkerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"NetworkerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Networker node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-networker-%index%\"}, \"NetworkerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Networker ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"NetworkerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Networker ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"NetworkerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NetworkerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"NetworkerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"NetworkerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"NetworkerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nNetworkerServiceChain resource and the Networker resource group.\\nFor example:\\nNetworkerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"NetworkerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeHCILocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeHCINetworkConfigTemplate\": {\"description\": \"ComputeHCI NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeHCIExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ComputeHCIServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ComputeHCI role.\", \"type\": \"comma_delimited_list\"}, \"ComputeHCINetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeHCIUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeHCIIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeHCIUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeHCIAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeHCIMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeHCICount\": {\"description\": \"Number of ComputeHCI nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeHCIHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ComputeHCI node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-computehci-%index%\"}, \"ComputeHCIRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ComputeHCI ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeHCIRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ComputeHCI ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeHCISchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ComputeHCIParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeHCIExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeHCIControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeHCIServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeHCIServiceChain resource and the ComputeHCI resource group.\\nFor example:\\nComputeHCIServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeHCINetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"DeployIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AddVipsToEtcHosts\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set to true to append per network Vips to /etc/hosts on each node.\\n\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"GlobalConfigExtraMapData\": {\"type\": \"json\", \"default\": {}, \"description\": \"Map of extra global_config_settings data to set on each node.\"}, \"NetConfigDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"Configure os-net-config mappings for specific nodes Your environment file needs to look like:\\n  parameter_defaults:\\n    NetConfigDataLookup:\\n      node1:\\n        nic1: \\\"00:c8:7c:e6:f0:2e\\\"\\n      node2:\\n        nic1: \\\"00:18:7d:99:0c:b6\\\"\\n      node3:\\n        dmiString: \'system-uuid\'\\n        id: \'A8C85861-1B16-4803-8689-AFC62984F8F6\'\\n        nic1: em3\\n      # Dell PowerEdge\\n      nodegroup1:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"PowerEdge R630\\\"\\n        nic1: em3\\n        nic2: em1\\n        nic3: em2\\n      # Cisco UCS B200-M4\\\"\\n      nodegroup2:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"UCSB-B200-M4\\\"\\n        nic1: enp7s0\\n        nic2: enp6s0\\n\\nThis will result in the first node* entry where either a mac matches a local device or a DMI String matches the specified id being written as a mapping file for os-net-config. (/etc/os-net-config/mapping.yaml)\\n\"}, \"DnsServers\": {\"default\": [], \"description\": \"DNS servers to use for the Overcloud (2 max for some implementations). If not set the nameservers configured in the ctlplane subnet\'s dns_nameservers attribute will be used.\\n\", \"type\": \"comma_delimited_list\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"DnsServers\", \"controllerExtraConfig\"]}], \"conditions\": {\"add_vips_to_etc_hosts\": {\"equals\": [{\"get_param\": \"AddVipsToEtcHosts\"}, true]}, \"control_fixed_ip_not_set\": {\"equals\": [{\"get_param\": \"ControlFixedIPs\"}, []]}, \"storage_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageVirtualFixedIPs\"}, []]}}, \"storage_mgmt_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, []]}}, \"internal_api_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalApiVirtualFixedIPs\"}, []]}}, \"tenant_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"TenantVirtualFixedIPs\"}, []]}}, \"public_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"PublicVirtualFixedIPs\"}, []]}}, \"set_default_mysql_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"MysqlCellInternal\"]}, \"\"]}]}]}, \"set_default_nova_vnc_proxy_cell_public\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaVNCProxyCellPublic\"]}, \"\"]}]}]}, \"set_default_nova_metadata_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaMetadataCellInternal\"]}, \"\"]}]}]}, \"dnsservers_set\": {\"not\": {\"equals\": [{\"get_param\": \"DnsServers\"}, []]}}}, \"resources\": {\"VipHosts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": [{\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"ctlplane\"]}, \"HOST\": {\"get_param\": \"CloudNameCtlplane\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage\"]}, \"HOST\": {\"get_param\": \"CloudNameStorage\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage_mgmt\"]}, \"HOST\": {\"get_param\": \"CloudNameStorageManagement\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"internal_api\"]}, \"HOST\": {\"get_param\": \"CloudNameInternal\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"external\"]}, \"HOST\": {\"get_param\": \"CloudName\"}}}}]}}, \"NetCidrMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_cidr_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"NetIpVersionMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_ip_version_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"subnets\", 0, \"ip_version\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"ServiceNetMap\": {\"type\": \"OS::TripleO::ServiceNetMap\"}, \"EndpointMap\": {\"type\": \"OS::TripleO::EndpointMap\", \"properties\": {\"CloudEndpoints\": {\"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}, \"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}}, \"NetIpMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}}}, \"EndpointMapData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"EndpointMap\", \"endpoint_map\"]}, {\"get_param\": \"EndpointMapOverride\"}, {\"if\": [\"set_default_mysql_cell_internal\", {\"MysqlCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"MysqlInternal\"]}}, {}]}, {\"if\": [\"set_default_nova_vnc_proxy_cell_public\", {\"NovaVNCProxyCellPublic\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaVNCProxyPublic\"]}}, {}]}, {\"if\": [\"set_default_nova_metadata_cell_internal\", {\"NovaMetadataCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaMetadataInternal\"]}}, {}]}]}}}, \"NodeAdminUserData\": {\"type\": \"OS::TripleO::NodeAdminUserData\"}, \"NodeTimesyncUserData\": {\"type\": \"OS::TripleO::NodeTimesyncUserData\"}, \"NodeUserData\": {\"type\": \"OS::TripleO::NodeUserData\"}, \"ControllerServiceChain\": {\"type\": \"OS::TripleO::ControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"ControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}}}, \"ControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ControllerServiceChain\", \"role_data\"]}}}, \"ControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"ControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}}}}]}}}, \"ControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ControllerServiceNetMap\"}}}}]}}}, \"ControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Controller\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Controller\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}}}, \"ControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Controller\", \"hostname_map\"]}]}}}}, \"ControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ControllerRoleUserData\": {\"type\": \"OS::TripleO::Controller::NodeUserData\"}, \"Controller\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ControllerCount\"}, \"removal_policies\": {\"get_param\": \"ControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"ControllerUserData\"}}}}}, \"CellControllerServiceChain\": {\"type\": \"OS::TripleO::CellControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}}}, \"CellControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerServiceChain\", \"role_data\"]}}}, \"CellControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}}}}]}}}, \"CellControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerServiceNetMap\"}}}}]}}}, \"CellControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellController\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellController\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}}}, \"CellControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellController\", \"hostname_map\"]}]}}}}, \"CellControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerRoleUserData\": {\"type\": \"OS::TripleO::CellController::NodeUserData\"}, \"CellController\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerUserData\"}}}}}, \"CellControllerComputeServiceChain\": {\"type\": \"OS::TripleO::CellControllerComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}}}, \"CellControllerComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerComputeServiceChain\", \"role_data\"]}}}, \"CellControllerComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}}}}]}}}, \"CellControllerComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerComputeServiceNetMap\"}}}}]}}}, \"CellControllerComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellControllerCompute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}}}, \"CellControllerComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellControllerCompute\", \"hostname_map\"]}]}}}}, \"CellControllerComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerComputeRoleUserData\": {\"type\": \"OS::TripleO::CellControllerCompute::NodeUserData\"}, \"CellControllerCompute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerComputeCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellControllerCompute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerComputeUserData\"}}}}}, \"ComputeServiceChain\": {\"type\": \"OS::TripleO::ComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}}}, \"ComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeServiceChain\", \"role_data\"]}}}, \"ComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NovaComputeExtraConfig\"}, {\"get_param\": \"ComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}}}}]}}}, \"ComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeServiceNetMap\"}}}}]}}}, \"ComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Compute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Compute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}}}, \"ComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Compute\", \"hostname_map\"]}]}}}}, \"ComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeRoleUserData\": {\"type\": \"OS::TripleO::Compute::NodeUserData\"}, \"Compute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeCount\"}, \"removal_policies\": {\"get_param\": \"ComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NovaComputeSchedulerHints\"}, {\"get_param\": \"ComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeUserData\"}}}}}, \"BlockStorageServiceChain\": {\"type\": \"OS::TripleO::BlockStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"BlockStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}}}, \"BlockStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"BlockStorageServiceChain\", \"role_data\"]}}}, \"BlockStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"BlockStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"BlockStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"BlockStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}}}}]}}}, \"BlockStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"BlockStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"BlockStorageServiceNetMap\"}}}}]}}}, \"BlockStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"BlockStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}}}, \"BlockStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"BlockStorage\", \"hostname_map\"]}]}}}}, \"BlockStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"BlockStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"BlockStorageRoleUserData\": {\"type\": \"OS::TripleO::BlockStorage::NodeUserData\"}, \"BlockStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"BlockStorageCount\"}, \"removal_policies\": {\"get_param\": \"BlockStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"BlockStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::BlockStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"BlockStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"BlockStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"BlockStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"BlockStorageUserData\"}}}}}, \"ObjectStorageServiceChain\": {\"type\": \"OS::TripleO::ObjectStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"ObjectStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}}}, \"ObjectStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ObjectStorageServiceChain\", \"role_data\"]}}}, \"ObjectStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ObjectStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ObjectStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ObjectStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}}}}]}}}, \"ObjectStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ObjectStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ObjectStorageServiceNetMap\"}}}}]}}}, \"ObjectStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ObjectStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}}}, \"ObjectStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ObjectStorage\", \"hostname_map\"]}]}}}}, \"ObjectStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ObjectStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ObjectStorageRoleUserData\": {\"type\": \"OS::TripleO::ObjectStorage::NodeUserData\"}, \"ObjectStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ObjectStorageCount\"}, \"removal_policies\": {\"get_param\": \"ObjectStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ObjectStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ObjectStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ObjectStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ObjectStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ObjectStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"ObjectStorageUserData\"}}}}}, \"CephStorageServiceChain\": {\"type\": \"OS::TripleO::CephStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"CephStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}}}, \"CephStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CephStorageServiceChain\", \"role_data\"]}}}, \"CephStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CephStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"CephStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CephStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}}}}]}}}, \"CephStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CephStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CephStorageServiceNetMap\"}}}}]}}}, \"CephStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"EnabledServices\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CephStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}}}, \"CephStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CephStorage\", \"hostname_map\"]}]}}}}, \"CephStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CephStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CephStorageRoleUserData\": {\"type\": \"OS::TripleO::CephStorage::NodeUserData\"}, \"CephStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CephStorageCount\"}, \"removal_policies\": {\"get_param\": \"CephStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CephStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CephStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CephStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CephStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CephStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"CephStorageUserData\"}}}}}, \"NetworkerServiceChain\": {\"type\": \"OS::TripleO::NetworkerServices\", \"properties\": {\"Services\": {\"get_param\": \"NetworkerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}}}, \"NetworkerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"NetworkerServiceChain\", \"role_data\"]}}}, \"NetworkerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"NetworkerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NetworkerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"NetworkerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}}]}}}, \"NetworkerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"NetworkerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetworkerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"NetworkerServiceNetMap\"}}}}]}}}, \"NetworkerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Networker\", \"ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Networker\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"NetworkerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Networker\", \"hostname_map\"]}]}}}}, \"NetworkerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NetworkerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"NetworkerRoleUserData\": {\"type\": \"OS::TripleO::Networker::NodeUserData\"}, \"Networker\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"NetworkerCount\"}, \"removal_policies\": {\"get_param\": \"NetworkerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"NetworkerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Networker\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"NetworkerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"NetworkerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NetworkerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}, \"UserData\": {\"get_resource\": \"NetworkerUserData\"}}}}}, \"ComputeHCIServiceChain\": {\"type\": \"OS::TripleO::ComputeHCIServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeHCIServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeHCIServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, {\"get_param\": \"ComputeHCIParameters\"}]}}}, \"ComputeHCIServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeHCIServiceChain\", \"role_data\"]}}}, \"ComputeHCIConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeHCIServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeHCIServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ComputeHCIExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeHCIServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeHCIServiceNames\", \"value\"]}}}}]}}}, \"ComputeHCIServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeHCIServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeHCIServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeHCIServiceNetMap\"}}}}]}}}, \"ComputeHCIIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ComputeHCI\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ComputeHCI\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ComputeHCI\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ComputeHCI\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"ComputeHCI\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeHCIServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeHCIServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ComputeHCI\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeHCINetworkHostnameMap\", \"value\"]}}}, \"ComputeHCINetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ComputeHCI\", \"hostname_map\"]}]}}}}, \"ComputeHCIUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeHCIRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeHCIRoleUserData\": {\"type\": \"OS::TripleO::ComputeHCI::NodeUserData\"}, \"ComputeHCI\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeHCICount\"}, \"removal_policies\": {\"get_param\": \"ComputeHCIRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeHCIRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ComputeHCI\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeHCIServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHCIHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeHCISchedulerHints\": {\"map_merge\": [{\"get_param\": \"ComputeHCISchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeHCIServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, {\"get_param\": \"ComputeHCIParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeHCIUserData\"}}}}}, \"ControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Controller\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Controller\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellController\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellController\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerCompute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellControllerCompute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Compute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Compute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"BlockStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"BlockStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ObjectStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ObjectStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CephStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CephStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"NetworkerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Networker\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Networker\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeHCIServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeHCI\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ComputeHCI\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ServerIdMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"server_ids\": {\"Controller\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}, \"CellController\": {\"get_attr\": [\"CellController\", \"nova_server_resource\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}, \"Compute\": {\"get_attr\": [\"Compute\", \"nova_server_resource\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorage\", \"nova_server_resource\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorage\", \"nova_server_resource\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorage\", \"nova_server_resource\"]}, \"Networker\": {\"get_attr\": [\"Networker\", \"nova_server_resource\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCI\", \"nova_server_resource\"]}}, \"bootstrap_server_id\": {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}}}}}}, \"DeploymentServerBlacklistDict\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"hostname\": 1}, \"for_each\": {\"hostname\": {\"get_param\": \"DeploymentServerBlacklist\"}}}}}}}, \"HostsEntryValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": {\"list_concat\": [[{\"get_param\": \"UndercloudHostsEntries\"}], [{\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}], {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"CellController\", \"hosts_entry\"]}, {\"get_attr\": [\"CellControllerCompute\", \"hosts_entry\"]}, {\"get_attr\": [\"Compute\", \"hosts_entry\"]}, {\"get_attr\": [\"BlockStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"ObjectStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"CephStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"Networker\", \"hosts_entry\"]}, {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"ComputeHCI\", \"hosts_entry\"]}, [{\"get_param\": \"ExtraHostFileEntries\"}]]}}}}, \"CloudNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"cloud_name_storage\": {\"get_param\": \"CloudNameStorage\"}, \"cloud_name_storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"cloud_name_internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"cloud_name_external\": {\"get_param\": \"CloudName\"}, \"cloud_name_ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}, \"GlobalConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"global_config_settings\"]}]}}}, \"Networks\": {\"type\": \"OS::TripleO::Network\", \"depends_on\": \"ServiceNetMap\", \"properties\": {\"CtlplaneNetworkCidrs\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}]}, \"ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}]}, \"edge_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}]}, \"edge_ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}]}}}}, \"ControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}}}}, \"ControllerNetworkConfig\": {\"type\": \"OS::TripleO::Controller::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"CellControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\"], \"service_net_map\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}}}}, \"CellControllerNetworkConfig\": {\"type\": \"OS::TripleO::CellController::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}}}}, \"CellControllerComputeNetworkConfig\": {\"type\": \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"ComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}}}}, \"ComputeNetworkConfig\": {\"type\": \"OS::TripleO::Compute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"BlockStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"BlockStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"BlockStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}}}}, \"BlockStorageNetworkConfig\": {\"type\": \"OS::TripleO::BlockStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"ObjectStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ObjectStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ObjectStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}}}}, \"ObjectStorageNetworkConfig\": {\"type\": \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"CephStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CephStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CephStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"ceph\", \"storage\"], \"service_net_map\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}}}}, \"CephStorageNetworkConfig\": {\"type\": \"OS::TripleO::CephStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}}}, \"NetworkerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"NetworkerLocalMtu\"}, \"role_networks\": [\"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"NetworkerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}}}}, \"NetworkerNetworkConfig\": {\"type\": \"OS::TripleO::Networker::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ComputeHCIGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeHCILocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeHCINetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\"], \"service_net_map\": {\"get_attr\": [\"ComputeHCIServiceNetMapLower\", \"value\"]}}}}, \"ComputeHCINetworkConfig\": {\"type\": \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ControlVirtualIP\": {\"depends_on\": \"ServiceNetMap\", \"type\": \"OS::TripleO::Network::Ports::ControlPlaneVipPort\", \"properties\": {\"name\": \"control_virtual_ip\", \"dns_name\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameCtlplane\"}, 0]}, \"network\": {\"get_param\": \"NeutronControlPlaneID\"}, \"fixed_ips\": {\"if\": [\"control_fixed_ip_not_set\", [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}}], {\"get_param\": \"ControlFixedIPs\"}]}, \"replacement_policy\": \"AUTO\", \"tags\": [\"tripleo_vip_net=ctlplane\", {\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"OS::stack_name\"}}}}]}}, \"StorageVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorage\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_virtual_fixed_ip_set\", {\"get_param\": \"StorageVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"Storage\"]}}]]}, \"IsVirtualIP\": true}}, \"StorageMgmtVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageMgmtVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorageManagement\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_mgmt_virtual_fixed_ip_set\", {\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"StorageMgmt\"]}}]]}, \"IsVirtualIP\": true}}, \"InternalApiVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::InternalApiVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"internal_api_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameInternal\"}, 0]}, \"FixedIPs\": {\"if\": [\"internal_api_virtual_fixed_ip_set\", {\"get_param\": \"InternalApiVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"InternalApi\"]}}]]}, \"IsVirtualIP\": true}}, \"PublicVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::ExternalVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"external_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudName\"}, 0]}, \"FixedIPs\": {\"if\": [\"public_virtual_fixed_ip_set\", {\"get_param\": \"PublicVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"External\"]}}]]}, \"IsVirtualIP\": true}}, \"VipMap\": {\"type\": \"OS::TripleO::Network::Ports::NetVipMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"StorageIp\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address\"]}, \"StorageIpUri\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address_uri\"]}, \"ExternalIp\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address\"]}, \"ExternalIpUri\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address_uri\"]}}, \"depends_on\": \"ServiceNetMap\"}, \"AllNodesExtraConfig\": {\"type\": \"OS::TripleO::AllNodesExtraConfig\", \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCIServers\", \"value\"]}}}}, \"BlacklistedIpAddresses\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellController\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Compute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Networker\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ComputeHCI\", \"blacklist_ip_address\"]}]}}}, \"AnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"Controller\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"ansible_host_vars_map\"]}]}}, \"CellController\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellController\", \"ansible_host_vars_map\"]}]}}, \"CellControllerCompute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellControllerCompute\", \"ansible_host_vars_map\"]}]}}, \"Compute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Compute\", \"ansible_host_vars_map\"]}]}}, \"BlockStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"BlockStorage\", \"ansible_host_vars_map\"]}]}}, \"ObjectStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ObjectStorage\", \"ansible_host_vars_map\"]}]}}, \"CephStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CephStorage\", \"ansible_host_vars_map\"]}]}}, \"Networker\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Networker\", \"ansible_host_vars_map\"]}]}}, \"ComputeHCI\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ComputeHCI\", \"ansible_host_vars_map\"]}]}}}}}, \"BlacklistedHostnames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellController\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Compute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Networker\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ComputeHCI\", \"blacklist_hostname\"]}]}}}, \"AllNodesDeploySteps\": {\"type\": \"OS::TripleO::PostDeploySteps\", \"depends_on\": [\"AllNodesExtraConfig\"], \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCIServers\", \"value\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"role_data\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\"]}}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ComputeHCICount\": {\"get_param\": \"ComputeHCICount\"}, \"ServiceNetMapLower\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, \"PingTestGatewayIPsMap\": {\"Controller\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"CellController\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"Compute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"CephStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}]}}, \"Networker\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"ComputeHCI\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}}, \"PingTestIpsMap\": {\"Controller\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}}}]]}, \"CellController\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}}}]]}, \"CellControllerCompute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}}}]]}, \"Compute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}}}]]}, \"BlockStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}}}]]}, \"ObjectStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}}}]]}, \"CephStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}}}]]}, \"Networker\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}}}]]}, \"ComputeHCI\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ComputeHCI\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ComputeHCI\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ComputeHCI\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ComputeHCI\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ComputeHCI\", \"tenant_ip_address\"]}}}]]}}, \"HostsEntry\": {\"get_attr\": [\"HostsEntryValue\", \"value\"]}, \"EnabledServices\": {\"list_concat\": [{\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeHCIServiceNames\", \"value\"]}]}, \"ControlVirtualIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"EnabledNetworks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"NetVipMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"CloudNames\": {\"get_attr\": [\"CloudNames\", \"value\"]}, \"UndercloudHostsEntries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"ExtraHostsEntries\": {\"get_param\": \"ExtraHostFileEntries\"}, \"VipHostsEntries\": {\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}, \"KeystoneResourcesConfigs\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\", \"keystone_resources\"]}]}, \"NetCidrMap\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}}}}, \"outputs\": {\"ManagedEndpoints\": {\"description\": \"Asserts that the keystone endpoints have been provisioned.\", \"value\": true}, \"KeystoneURL\": {\"description\": \"URL for the Overcloud Keystone service\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\", \"KeystonePublic\", \"uri_no_suffix\"]}}, \"KeystoneAdminVip\": {\"description\": \"Keystone Admin VIP endpoint\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\", \"KeystoneAdminApiNetwork\"]}]}}, \"EndpointMap\": {\"description\": \"Mapping of the resources with the needed info for their endpoints.\\nThis includes the protocol used, the IP, port and also a full\\nrepresentation of the URI.\\n\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}}, \"HostsEntry\": {\"description\": \"The content that should be appended to your /etc/hosts if you want to get\\nhostname-based access to the deployed nodes (useful for testing without\\nsetting up a DNS).\\n\", \"value\": {\"list_concat_unique\": [{\"get_attr\": [\"HostsEntryValue\", \"value\"]}, {\"get_attr\": [\"VipHosts\", \"value\"]}]}}, \"EnabledServices\": {\"description\": \"The services enabled on each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCIServiceNames\", \"value\"]}}}, \"RoleData\": {\"description\": \"The configuration data associated with each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCIServiceChainRoleData\", \"value\"]}}}, \"RoleConfig\": {\"description\": \"The configuration workflows associated with each role\", \"value\": {\"get_attr\": [\"AllNodesDeploySteps\", \"RoleConfig\"]}}, \"RoleNetIpMap\": {\"description\": \"Mapping of each network to a list of IPs for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerIpListMap\", \"net_ip_map\"]}, \"CellController\": {\"get_attr\": [\"CellControllerIpListMap\", \"net_ip_map\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeIpListMap\", \"net_ip_map\"]}, \"Compute\": {\"get_attr\": [\"ComputeIpListMap\", \"net_ip_map\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageIpListMap\", \"net_ip_map\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageIpListMap\", \"net_ip_map\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageIpListMap\", \"net_ip_map\"]}, \"Networker\": {\"get_attr\": [\"NetworkerIpListMap\", \"net_ip_map\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCIIpListMap\", \"net_ip_map\"]}}}, \"RoleGroupVars\": {\"description\": \"Mapping of roles to ansible group_vars to be applied config in those roles\", \"value\": {\"Controller\": {\"map_merge\": [{\"get_attr\": [\"ControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"ControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ControllerExtraGroupVars\"}]}, \"CellController\": {\"map_merge\": [{\"get_attr\": [\"CellControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerExtraGroupVars\"}]}, \"CellControllerCompute\": {\"map_merge\": [{\"get_attr\": [\"CellControllerComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerComputeExtraGroupVars\"}]}, \"Compute\": {\"map_merge\": [{\"get_attr\": [\"ComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeExtraGroupVars\"}]}, \"BlockStorage\": {\"map_merge\": [{\"get_attr\": [\"BlockStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"BlockStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"BlockStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"BlockStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"BlockStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"BlockStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"BlockStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"BlockStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"BlockStorageExtraGroupVars\"}]}, \"ObjectStorage\": {\"map_merge\": [{\"get_attr\": [\"ObjectStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"ObjectStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ObjectStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ObjectStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ObjectStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ObjectStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ObjectStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ObjectStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ObjectStorageExtraGroupVars\"}]}, \"CephStorage\": {\"map_merge\": [{\"get_attr\": [\"CephStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"CephStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CephStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CephStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CephStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CephStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CephStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CephStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CephStorageExtraGroupVars\"}]}, \"Networker\": {\"map_merge\": [{\"get_attr\": [\"NetworkerGroupVars\", \"value\"]}, {\"get_attr\": [\"NetworkerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"NetworkerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"NetworkerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"NetworkerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"NetworkerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"NetworkerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"NetworkerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"NetworkerExtraGroupVars\"}]}, \"ComputeHCI\": {\"map_merge\": [{\"get_attr\": [\"ComputeHCIGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeHCIConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeHCIAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeHCIMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeHCINetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeHCIUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeHCIIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeHCINetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeHCIExtraGroupVars\"}]}}}, \"RoleNetHostnameMap\": {\"description\": \"Mapping of each network to a list of hostnames for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCINetworkHostnameMap\", \"value\"]}}}, \"RoleTags\": {\"description\": \"Tags for each role, as defined in roles_data.yaml\", \"value\": {\"Controller\": [\"primary\", \"controller\", \"external_bridge\"], \"CellController\": [\"primary\", \"controller\"], \"CellControllerCompute\": [\"primary\", \"controller\", \"external_bridge\"], \"Compute\": [\"compute\", \"external_bridge\"], \"BlockStorage\": [\"storage\"], \"ObjectStorage\": [\"storage\"], \"CephStorage\": [\"ceph\", \"storage\"], \"Networker\": [\"external_bridge\"], \"ComputeHCI\": [\"compute\"]}}, \"VipMap\": {\"description\": \"Mapping of each network to VIP addresses. Also includes the Redis and OVN DBs VIPs.\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}}, \"ServerIdData\": {\"description\": \"Mapping of each role to a list of nova server IDs and the bootstrap ID\", \"value\": {\"get_attr\": [\"ServerIdMap\", \"value\"]}}, \"BlacklistedHostnames\": {\"description\": \"List of blacklisted hostnames\", \"value\": {\"get_attr\": [\"BlacklistedHostnames\", \"value\"]}}, \"BlacklistedIpAddresses\": {\"description\": \"List of blacklisted ctlplane IP addresses\", \"value\": {\"get_attr\": [\"BlacklistedIpAddresses\", \"value\"]}}, \"GlobalConfig\": {\"description\": \"The global_config (hieradata).\", \"value\": {\"get_attr\": [\"GlobalConfig\", \"value\"]}}, \"RoleNetworkConfigMap\": {\"description\": \"Mapping of roles to network config\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkConfig\", \"config\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkConfig\", \"config\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkConfig\", \"config\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkConfig\", \"config\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkConfig\", \"config\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkConfig\", \"config\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkConfig\", \"config\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkConfig\", \"config\"]}, \"ComputeHCI\": {\"get_attr\": [\"ComputeHCINetworkConfig\", \"config\"]}}}, \"AnsibleHostVarsMap\": {\"description\": \"Map of Ansible Host variables per role\", \"value\": {\"get_attr\": [\"AnsibleHostVars\", \"value\"]}}, \"TripleoHeatTemplatesJinja2RenderingDataSources\": {\"description\": \"The role_data and the network_data used when rendering the THT Jinja2 templates\", \"value\": {\"roles_data\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"ComputeHCI\", \"description\": \"Compute Node role hosting Ceph OSD too\\\\n\", \"tags\": [\"compute\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}], \"networks_data\": [{\"name\": \"Storage\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage\", \"dns_domain\": \"storage.localdomain.\", \"service_net_map_replace\": \"storage\", \"subnets\": {\"storage_subnet\": {\"vlan\": 21, \"ip_subnet\": \"172.18.0.0/24\", \"allocation_pools\": [{\"start\": \"172.18.0.120\", \"end\": \"172.18.0.250\"}]}}, \"idx\": 0}, {\"name\": \"StorageMgmt\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage_mgmt\", \"dns_domain\": \"storagemgmt.localdomain.\", \"service_net_map_replace\": \"storage_mgmt\", \"subnets\": {\"storage_mgmt_subnet\": {\"vlan\": 23, \"ip_subnet\": \"172.20.0.0/24\", \"allocation_pools\": [{\"start\": \"172.20.0.120\", \"end\": \"172.20.0.250\"}]}}, \"idx\": 1}, {\"name\": \"InternalApi\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"internal_api\", \"dns_domain\": \"internal-api.localdomain.\", \"service_net_map_replace\": \"internal_api\", \"subnets\": {\"internal_api_subnet\": {\"vlan\": 20, \"ip_subnet\": \"172.17.0.0/24\", \"allocation_pools\": [{\"start\": \"172.17.0.120\", \"end\": \"172.17.0.250\"}]}}, \"idx\": 2}, {\"name\": \"Tenant\", \"mtu\": 1500, \"vip\": false, \"name_lower\": \"tenant\", \"dns_domain\": \"tenant.localdomain.\", \"service_net_map_replace\": \"tenant\", \"subnets\": {\"tenant_subnet\": {\"vlan\": 22, \"ip_subnet\": \"172.19.0.0/24\", \"allocation_pools\": [{\"start\": \"172.19.0.120\", \"end\": \"172.19.0.250\"}]}}, \"idx\": 3}, {\"name\": \"External\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"external\", \"dns_domain\": \"external.localdomain.\", \"service_net_map_replace\": \"external\", \"subnets\": {\"external_subnet\": {\"vlan\": 44, \"ip_subnet\": \"172.21.0.0/24\", \"allocation_pools\": [{\"start\": \"172.21.0.120\", \"end\": \"172.21.0.250\"}]}}, \"idx\": 4}]}}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"value\": {\"get_param\": \"AdminPassword\"}}, \"KeystoneRegion\": {\"description\": \"Keystone region for endpoint\", \"value\": {\"get_param\": \"KeystoneRegion\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(2,'2026-06-13 07:49:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(3,'2026-06-13 07:49:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(4,'2026-06-13 07:49:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(5,'2026-06-13 07:49:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(6,'2026-06-13 07:49:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(7,'2026-06-13 07:49:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(8,'2026-06-13 07:49:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (9,'2026-06-13 07:49:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(10,'2026-06-13 07:49:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(11,'2026-06-13 07:49:55',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"NtpService\": {\"default\": \"chrony\", \"description\": \"NTP Service to use for the timesync bootstrap.\", \"type\": \"string\"}}, \"description\": \"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\n\", \"conditions\": {\"use_chrony\": {\"equals\": [{\"get_param\": \"NtpService\"}, \"chrony\"]}}, \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"timesync_chrony\"}}, {\"config\": {\"get_resource\": \"timesync_sync\"}}]}}, \"timesync_chrony\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nif [ \\\"$service\\\" != \\\"chrony\\\" ]; then\\n  exit 0\\nfi\\nset -x\\nSERVERS=\\\"$ntp_servers\\\"\\nPOOLS=\\\"$ntp_pools\\\"\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\nfor server in $SERVERS; do\\n  chronyc add server \\\"${server}\\\" iburst\\ndone\\nfor pool in $POOLS; do\\n  chronyc add server \\\"${pool}\\\" iburst\\ndone\\nchronyc sources\\n\", \"params\": {\"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}, \"$ntp_pools\": {\"list_join\": [\" \", {\"get_param\": \"NtpPool\"}]}, \"$service\": {\"get_param\": \"NtpService\"}}}}}}, \"timesync_sync\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nset -x\\nif [ \\\"$service\\\" = \\\"chrony\\\" ]; then\\n    if command -v chronyc >/dev/null; then\\n        chronyc makestep\\n        chronyc waitsync 30\\n    else\\n        echo \\\"No chronyc available, skipping sync\\\"\\n    fi\\nelif [ \\\"$service\\\" = \\\"ntp\\\" ]; then\\n    if command -v ntpdate >/dev/null; then\\n        ntpdate -u $ntp_servers\\n    else\\n        echo \\\"No ntpdate available, skipping sync\\\"\\n    fi\\nfi\\nhwclock --systohc --utc\\n\", \"params\": {\"$service\": {\"get_param\": \"NtpService\"}, \"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}}}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(12,'2026-06-13 07:49:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(13,'2026-06-13 07:49:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mapping of service_name_network -> network name\\n\", \"parameters\": {\"ServiceNetMap\": {\"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\", \"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"VipSubnetMap\": {\"description\": \"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\", \"default\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMapDeprecatedMapping\": {\"default\": {\"RabbitMqNetwork\": \"RabbitmqNetwork\", \"CephPublicNetwork\": \"CephMonNetwork\", \"SwiftMgmtNetwork\": \"SwiftStorageNetwork\"}, \"description\": \"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\", \"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ServiceNetMapDeprecatedMapping\"]}], \"resources\": {\"ServiceNetMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"map_replace\": [{\"get_param\": \"ServiceNetMap\"}, {\"values\": {\"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}, \"keys\": {\"get_param\": \"ServiceNetMapDeprecatedMapping\"}}]}, {\"NovaVncProxyNetwork\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}]}}}}, \"outputs\": {\"service_net_map\": {\"value\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}, \"service_net_map_lower\": {\"value\": {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}}}}, \"vip_subnet_map\": {\"value\": {\"map_replace\": [{\"get_param\": \"VipSubnetMap\"}, {\"values\": {\"ctlplane-subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(14,'2026-06-13 07:49:58',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"node_admin_username\": {\"type\": \"string\", \"default\": \"heat-admin\"}, \"node_admin_extra_ssh_keys\": {\"type\": \"comma_delimited_list\", \"default\": []}}, \"description\": \"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"user_config\"}}]}}, \"user_config\": {\"type\": \"OS::Heat::CloudConfig\", \"properties\": {\"cloud_config\": {\"user\": {\"get_param\": \"node_admin_username\"}, \"ssh_authorized_keys\": {\"get_param\": \"node_admin_extra_ssh_keys\"}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(15,'2026-06-13 07:49:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Control Plane network.\\n\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlPlaneVipData\": {\"description\": \"Control Plane Virtual IP data\\n\", \"default\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"type\": \"json\"}}, \"outputs\": {\"name\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"name\"]}}, \"fixed_ips\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"fixed_ips\"]}}, \"network\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"network\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"subnets\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"control_virtual_ip\", \"dns_name\": \"overcloud\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_vip_net=ctlplane,tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(16,'2026-06-13 07:50:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Create networks to split out Overcloud traffic\", \"parameters\": {\"DeployedNetworkEnvironment\": {\"type\": \"json\", \"description\": \"Deployed network environment\", \"default\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}}, \"CtlplaneNetworkCidrs\": {\"type\": \"json\", \"description\": \"Cidrs for the ctlplane network.\"}, \"CtlplaneNetworkAttributes\": {\"type\": \"json\", \"default\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"description\": \"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\n\"}}, \"resources\": {\"NetworkExtraConfig\": {\"type\": \"OS::TripleO::Network::ExtraConfig\"}, \"NetworkAttributesMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkAttributes\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_attributes_map\"]}]}}}, \"NetworkCidrMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkCidrs\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_cidr_map\"]}]}}}, \"NetworkIpVersionMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"yaql\": {\"expression\": \"$.data.items().first().last().ip_version\", \"data\": {\"get_param\": [\"CtlplaneNetworkAttributes\", \"subnets\"]}}}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_ip_version_map\"]}]}}}}, \"outputs\": {\"net_cidr_map\": {\"value\": {\"get_attr\": [\"NetworkCidrMap\", \"value\"]}}, \"net_ip_version_map\": {\"value\": {\"get_attr\": [\"NetworkIpVersionMap\", \"value\"]}}, \"net_attributes_map\": {\"value\": {\"get_attr\": [\"NetworkAttributesMap\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"CtlplaneNetworkCidrs\": \"[\\\"192.168.122.0/24\\\"]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(17,'2026-06-13 07:50:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(18,'2026-06-13 07:50:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the External network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"External network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"external_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"external_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(19,'2026-06-13 07:50:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (20,'2026-06-13 07:50:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"internal_api_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(21,'2026-06-13 07:50:07',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.157\", \"StorageIpUri\": \"172.18.0.157\", \"StorageMgmtIp\": \"172.20.0.196\", \"StorageMgmtIpUri\": \"172.20.0.196\", \"InternalApiIp\": \"172.17.0.249\", \"InternalApiIpUri\": \"172.17.0.249\", \"ExternalIp\": \"172.21.0.204\", \"ExternalIpUri\": \"172.21.0.204\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(22,'2026-06-13 07:50:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\", \"parameters\": {\"NetIpMap\": {\"type\": \"json\", \"default\": {}, \"description\": \"The Net IP map\"}, \"ServiceNetMap\": {\"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"The Service Net map\"}, \"EndpointMap\": {\"type\": \"json\", \"default\": {\"AodhAdmin\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"AodhInternal\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"AodhPublic\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"BarbicanAdmin\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"BarbicanInternal\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"BarbicanPublic\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"CephDashboardInternal\": {\"protocol\": \"http\", \"port\": \"8444\", \"host\": \"IP_ADDRESS\"}, \"CephGrafanaInternal\": {\"protocol\": \"http\", \"port\": \"3100\", \"host\": \"IP_ADDRESS\"}, \"CephRgwAdmin\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CephRgwInternal\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CephRgwPublic\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CinderAdmin\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"CinderInternal\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"CinderPublic\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"DesignateAdmin\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DesignateInternal\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DesignatePublic\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DockerRegistryInternal\": {\"protocol\": \"http\", \"port\": \"8787\", \"host\": \"IP_ADDRESS\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"http\", \"port\": \"9293\", \"host\": \"IP_ADDRESS\"}, \"GlanceInternal\": {\"protocol\": \"http\", \"port\": \"9293\", \"host\": \"IP_ADDRESS\"}, \"GlancePublic\": {\"protocol\": \"http\", \"port\": \"9292\", \"host\": \"IP_ADDRESS\"}, \"GnocchiAdmin\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"GnocchiInternal\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"GnocchiPublic\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"HeatAdmin\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatInternal\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatPublic\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnAdmin\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnInternal\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnPublic\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HorizonPublic\": {\"protocol\": \"http\", \"port\": \"80\", \"host\": \"IP_ADDRESS\"}, \"IronicAdmin\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicInternal\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicPublic\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorPublic\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"KeystoneAdmin\": {\"protocol\": \"http\", \"port\": \"35357\", \"host\": \"IP_ADDRESS\"}, \"KeystoneInternal\": {\"protocol\": \"http\", \"port\": \"5000\", \"host\": \"IP_ADDRESS\"}, \"KeystonePublic\": {\"protocol\": \"http\", \"port\": \"5000\", \"host\": \"IP_ADDRESS\"}, \"ManilaAdmin\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"ManilaInternal\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"ManilaPublic\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"IP_ADDRESS\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"IP_ADDRESS\"}, \"NeutronAdmin\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NeutronInternal\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NeutronPublic\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NovaAdmin\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaInternal\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaPublic\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaMetadataInternal\": {\"protocol\": \"http\", \"port\": \"8775\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovajoinAdmin\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"NovajoinInternal\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"NovajoinPublic\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"OctaviaAdmin\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"OctaviaInternal\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"OctaviaPublic\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"PlacementAdmin\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"PlacementInternal\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"PlacementPublic\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"SwiftAdmin\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"SwiftInternal\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"SwiftPublic\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}, \"CloudEndpoints\": {\"type\": \"json\", \"default\": {}, \"description\": \"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\"}}, \"outputs\": {\"endpoint_map\": {\"value\": {\"AodhAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}}, \"AodhInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}}, \"AodhPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}}, \"BarbicanAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}}, \"BarbicanInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}}, \"BarbicanPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}}, \"CephDashboardInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}}, \"CephGrafanaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}}, \"CephRgwAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}}}}, \"CephRgwInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}}}}, \"CephRgwPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}}}}, \"CinderAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV2Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV2Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV2Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"DesignateAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}}}}, \"DesignateInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}}}}, \"DesignatePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}}}}, \"DockerRegistryInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}}, \"GaneshaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}}, \"GlanceAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}}, \"GlanceInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, \"GlancePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}}, \"GnocchiAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}}, \"GnocchiInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}}, \"GnocchiPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}}, \"HeatAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}}}}, \"HeatInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}}}}, \"HeatPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}}}}, \"HeatCfnAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}}}}, \"HeatCfnInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}}}}, \"HeatCfnPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}}, \"HorizonPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"path\": \"/dashboard\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}}}}, \"IronicAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}}}}, \"IronicInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}}}}, \"IronicPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}}}}, \"IronicInspectorAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}}, \"IronicInspectorInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}}, \"IronicInspectorPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}}, \"KeystoneAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystonePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"KeystoneV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystoneV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"ManilaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"ManilaV1Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaV1Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaV1Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"MetricsQdrPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}}, \"MysqlInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}}, \"NeutronAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}}, \"NeutronInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}}, \"NeutronPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}}, \"NovaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}}}}, \"NovaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}}}}, \"NovaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}}}}, \"NovaMetadataInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}}, \"NovaVNCProxyAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}}, \"NovaVNCProxyInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}}, \"NovaVNCProxyPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}}, \"NovajoinAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}}}}, \"NovajoinInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}}}}, \"NovajoinPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}}}}, \"OctaviaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}}, \"OctaviaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}}, \"OctaviaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}}, \"PlacementAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}}}}, \"PlacementInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}}}}, \"PlacementPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}}}}, \"SwiftAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}, \"SwiftS3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftS3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftS3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NetIpMap\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"CloudEndpoints\": {\"ctlplane\": \"overcloud.ctlplane.localdomain\", \"storage\": \"overcloud.storage.localdomain\", \"storage_mgmt\": \"overcloud.storagemgmt.localdomain\", \"internal_api\": \"overcloud.internalapi.localdomain\", \"external\": \"overcloud.localdomain\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(23,'2026-06-13 07:50:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::BlockStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(24,'2026-06-13 07:50:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ObjectStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(25,'2026-06-13 07:50:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CephStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(26,'2026-06-13 07:50:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeHCIServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::CephClient,OS::TripleO::Services::CephOSD,OS::TripleO::Services::Collectd,OS::TripleO::Services::ComputeCeilometerAgent,OS::TripleO::Services::CeilometerAgentIpmi,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NovaCompute,OS::TripleO::Services::NovaLibvirt,OS::TripleO::Services::NovaLibvirtGuests,OS::TripleO::Services::NovaMigrationTarget,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::Podman,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned,OS::TripleO::Services::OVNController,OS::TripleO::Services::OVNMetadataAgent\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (27,'2026-06-13 07:50:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(28,'2026-06-13 07:50:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::NetworkerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(29,'2026-06-13 07:50:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::AodhApi,OS::TripleO::Services::AodhEvaluator,OS::TripleO::Services::AodhListener,OS::TripleO::Services::AodhNotifier,OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::CeilometerAgentCentral,OS::TripleO::Services::CeilometerAgentNotification,OS::TripleO::Services::CephClient,OS::TripleO::Services::CephMds,OS::TripleO::Services::CephMgr,OS::TripleO::Services::CephMon,OS::TripleO::Services::CinderApi,OS::TripleO::Services::CinderBackup,OS::TripleO::Services::CinderScheduler,OS::TripleO::Services::CinderVolume,OS::TripleO::Services::Clustercheck,OS::TripleO::Services::Collectd,OS::TripleO::Services::ContainerImagePrepare,OS::TripleO::Services::GlanceApi,OS::TripleO::Services::GlanceApiInternal,OS::TripleO::Services::GnocchiApi,OS::TripleO::Services::GnocchiMetricd,OS::TripleO::Services::GnocchiStatsd,OS::TripleO::Services::HAproxy,OS::TripleO::Services::HeatApi,OS::TripleO::Services::HeatApiCloudwatch,OS::TripleO::Services::HeatApiCfn,OS::TripleO::Services::HeatEngine,OS::TripleO::Services::Horizon,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::Keystone,OS::TripleO::Services::ManilaApi,OS::TripleO::Services::ManilaBackendCephFs,OS::TripleO::Services::ManilaScheduler,OS::TripleO::Services::ManilaShare,OS::TripleO::Services::Memcached,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQL,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NeutronApi,OS::TripleO::Services::NeutronCorePlugin,OS::TripleO::Services::NovaApi,OS::TripleO::Services::NovaConductor,OS::TripleO::Services::NovaMetadata,OS::TripleO::Services::NovaScheduler,OS::TripleO::Services::NovaVncProxy,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::OVNDBs,OS::TripleO::Services::OVNController,OS::TripleO::Services::Pacemaker,OS::TripleO::Services::PlacementApi,OS::TripleO::Services::OsloMessagingRpc,OS::TripleO::Services::OsloMessagingNotify,OS::TripleO::Services::Podman,OS::TripleO::Services::Redis,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::SwiftProxy,OS::TripleO::Services::SwiftRingBuilder,OS::TripleO::Services::SwiftStorage,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(30,'2026-06-13 07:50:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(31,'2026-06-13 07:50:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(32,'2026-06-13 07:50:11',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(33,'2026-06-13 07:50:11',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(34,'2026-06-13 07:50:11',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (35,'2026-06-13 07:50:11',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::AodhApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::AodhEvaluator\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::AodhListener\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::AodhNotifier\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::CeilometerAgentCentral\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::CeilometerAgentNotification\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::CephClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::CephMds\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::CephMgr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::CephMon\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::CinderApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::CinderBackup\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::CinderScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::CinderVolume\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Clustercheck\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::ContainerImagePrepare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::GlanceApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::GlanceApiInternal\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::GnocchiApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::GnocchiMetricd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::GnocchiStatsd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::HAproxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::HeatApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"21\"]}, \"26\": {\"type\": \"OS::TripleO::Services::HeatApiCloudwatch\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"22\"]}, \"27\": {\"type\": \"OS::TripleO::Services::HeatApiCfn\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"23\"]}, \"28\": {\"type\": \"OS::TripleO::Services::HeatEngine\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"24\"]}, \"29\": {\"type\": \"OS::TripleO::Services::Horizon\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"25\"]}, \"30\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"26\"]}, \"31\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"27\"]}, \"32\": {\"type\": \"OS::TripleO::Services::Keystone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"28\"]}, \"33\": {\"type\": \"OS::TripleO::Services::ManilaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"29\"]}, \"34\": {\"type\": \"OS::TripleO::Services::ManilaBackendCephFs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"30\"]}, \"35\": {\"type\": \"OS::TripleO::Services::ManilaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"31\"]}, \"36\": {\"type\": \"OS::TripleO::Services::ManilaShare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"32\"]}, \"37\": {\"type\": \"OS::TripleO::Services::Memcached\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"33\"]}, \"38\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"34\"]}, \"39\": {\"type\": \"OS::TripleO::Services::MySQL\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"35\"]}, \"40\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"36\"]}, \"41\": {\"type\": \"OS::TripleO::Services::NeutronApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"37\"]}, \"42\": {\"type\": \"OS::TripleO::Services::NeutronCorePlugin\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"38\"]}, \"43\": {\"type\": \"OS::TripleO::Services::NovaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"39\"]}, \"44\": {\"type\": \"OS::TripleO::Services::NovaConductor\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"40\"]}, \"45\": {\"type\": \"OS::TripleO::Services::NovaMetadata\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"41\"]}, \"46\": {\"type\": \"OS::TripleO::Services::NovaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"42\"]}, \"47\": {\"type\": \"OS::TripleO::Services::NovaVncProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"43\"]}, \"48\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"44\"]}, \"49\": {\"type\": \"OS::TripleO::Services::OVNDBs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"45\"]}, \"50\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"46\"]}, \"51\": {\"type\": \"OS::TripleO::Services::Pacemaker\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"47\"]}, \"52\": {\"type\": \"OS::TripleO::Services::PlacementApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"48\"]}, \"53\": {\"type\": \"OS::TripleO::Services::OsloMessagingRpc\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"49\"]}, \"54\": {\"type\": \"OS::TripleO::Services::OsloMessagingNotify\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"50\"]}, \"55\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"51\"]}, \"56\": {\"type\": \"OS::TripleO::Services::Redis\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"52\"]}, \"57\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"53\"]}, \"58\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"54\"]}, \"59\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"55\"]}, \"60\": {\"type\": \"OS::TripleO::Services::SwiftProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"56\"]}, \"61\": {\"type\": \"OS::TripleO::Services::SwiftRingBuilder\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"57\"]}, \"62\": {\"type\": \"OS::TripleO::Services::SwiftStorage\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"58\"]}, \"63\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"59\"]}, \"64\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"60\"]}, \"65\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"61\"]}, \"66\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"62\"]}, \"67\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"63\"]}}, \"outputs\": {\"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"58\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"59\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"60\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"61\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"62\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"63\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"64\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"65\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"66\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"67\", \"role_data\", \"step_config\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"26\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"27\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"28\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"29\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"30\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"31\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"32\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"33\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"34\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"35\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"36\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"37\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"38\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"39\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"40\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"41\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"42\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"43\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"44\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"45\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"46\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"47\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"48\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"49\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"50\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"51\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"52\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"53\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"54\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"55\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"56\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"57\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"58\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"59\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"60\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"61\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"62\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"63\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"64\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"65\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"66\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"67\", \"role_data\", \"config_settings\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"58\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"59\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"60\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"61\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"62\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"63\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"64\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"65\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"66\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"67\", \"role_data\", \"service_name\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"58\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"59\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"60\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"61\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"62\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"63\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"64\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"65\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"66\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"67\", \"role_data\", \"docker_config\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"26\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"27\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"28\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"29\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"30\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"31\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"32\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"33\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"34\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"35\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"36\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"37\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"38\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"39\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"40\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"41\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"42\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"43\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"44\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"45\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"46\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"47\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"48\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"49\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"50\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"51\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"52\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"53\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"54\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"55\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"56\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"57\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"58\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"59\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"60\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"61\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"62\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"63\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"64\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"65\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"66\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"67\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}, {\"get_attr\": [\"26\", \"role_data\"]}, {\"get_attr\": [\"27\", \"role_data\"]}, {\"get_attr\": [\"28\", \"role_data\"]}, {\"get_attr\": [\"29\", \"role_data\"]}, {\"get_attr\": [\"30\", \"role_data\"]}, {\"get_attr\": [\"31\", \"role_data\"]}, {\"get_attr\": [\"32\", \"role_data\"]}, {\"get_attr\": [\"33\", \"role_data\"]}, {\"get_attr\": [\"34\", \"role_data\"]}, {\"get_attr\": [\"35\", \"role_data\"]}, {\"get_attr\": [\"36\", \"role_data\"]}, {\"get_attr\": [\"37\", \"role_data\"]}, {\"get_attr\": [\"38\", \"role_data\"]}, {\"get_attr\": [\"39\", \"role_data\"]}, {\"get_attr\": [\"40\", \"role_data\"]}, {\"get_attr\": [\"41\", \"role_data\"]}, {\"get_attr\": [\"42\", \"role_data\"]}, {\"get_attr\": [\"43\", \"role_data\"]}, {\"get_attr\": [\"44\", \"role_data\"]}, {\"get_attr\": [\"45\", \"role_data\"]}, {\"get_attr\": [\"46\", \"role_data\"]}, {\"get_attr\": [\"47\", \"role_data\"]}, {\"get_attr\": [\"48\", \"role_data\"]}, {\"get_attr\": [\"49\", \"role_data\"]}, {\"get_attr\": [\"50\", \"role_data\"]}, {\"get_attr\": [\"51\", \"role_data\"]}, {\"get_attr\": [\"52\", \"role_data\"]}, {\"get_attr\": [\"53\", \"role_data\"]}, {\"get_attr\": [\"54\", \"role_data\"]}, {\"get_attr\": [\"55\", \"role_data\"]}, {\"get_attr\": [\"56\", \"role_data\"]}, {\"get_attr\": [\"57\", \"role_data\"]}, {\"get_attr\": [\"58\", \"role_data\"]}, {\"get_attr\": [\"59\", \"role_data\"]}, {\"get_attr\": [\"60\", \"role_data\"]}, {\"get_attr\": [\"61\", \"role_data\"]}, {\"get_attr\": [\"62\", \"role_data\"]}, {\"get_attr\": [\"63\", \"role_data\"]}, {\"get_attr\": [\"64\", \"role_data\"]}, {\"get_attr\": [\"65\", \"role_data\"]}, {\"get_attr\": [\"66\", \"role_data\"]}, {\"get_attr\": [\"67\", \"role_data\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"58\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"59\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"60\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"61\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"62\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"63\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"64\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"65\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"66\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"67\", \"role_data\", \"service_names\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (36,'2026-06-13 07:50:12',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(37,'2026-06-13 07:50:12',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}}, \"2\": {\"type\": \"OS::TripleO::Services::CephClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}}, \"3\": {\"type\": \"OS::TripleO::Services::CephOSD\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}}, \"4\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::ComputeCeilometerAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::CeilometerAgentIpmi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::NovaCompute\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::NovaLibvirt\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::NovaLibvirtGuests\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::NovaMigrationTarget\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"21\"]}, \"26\": {\"type\": \"OS::TripleO::Services::OVNMetadataAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"depends_on\": [\"22\"]}}, \"outputs\": {\"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"step_config\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"26\", \"role_data\", \"config_settings\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_name\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"docker_config\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"26\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}, {\"get_attr\": [\"26\", \"role_data\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_names\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(38,'2026-06-13 07:50:14',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(39,'2026-06-13 07:50:15',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (40,'2026-06-13 07:50:15',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(41,'2026-06-13 07:50:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(42,'2026-06-13 07:50:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(43,'2026-06-13 07:50:16',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"internal_api_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(44,'2026-06-13 07:50:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph Client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientConfigVars\": {\"default\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"type\": \"string\", \"description\": \"The undercloud path where cephadm exports the Ceph Client configuration.\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephExternalMonHost\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of externally managed Ceph Mon Host IPs. Only used for external Ceph deployments.\"}}, \"resources\": {\"CephBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"DefaultPasswords\": {\"get_param\": \"DefaultPasswords\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph Client service.\", \"value\": {\"service_name\": \"ceph_client\", \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"external_deploy_tasks\": {\"list_concat\": [{\"get_attr\": [\"CephBase\", \"role_data\", \"external_deploy_tasks\"]}, [{\"name\": \"ceph_base_external_deploy_init\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set some tripleo-ansible facts\", \"set_fact\": {\"ceph_external_multi_config\": {\"get_param\": \"CephExternalMultiConfig\"}}}]}, {\"name\": \"Configure Ceph Clients\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Check if the input variable file exists\", \"stat\": {\"path\": \"{{ tripleo_ceph_client_vars }}\"}, \"register\": \"ceph_input_vars\", \"vars\": {\"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}}}, {\"name\": \"Populate CephClientConfigVars from THT\", \"copy\": {\"dest\": \"{{ tripleo_ceph_client_vars }}\", \"content\": \"tripleo_ceph_client_fsid: \\\"{{ tripleo_ceph_client_fsid }}\\\"\\nexternal_cluster_mon_ips: \\\"{{ external_cluster_mon_ips }}\\\"\\n\"}, \"when\": [\"ceph_input_vars.stat.exists == False\", \"external_cluster_mon_ips | length > 0\"], \"vars\": {\"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}, \"tripleo_ceph_client_fsid\": {\"get_param\": \"CephClusterFSID\"}, \"external_cluster_mon_ips\": {\"get_param\": \"CephExternalMonHost\"}}}, {\"name\": \"configure ceph clients\", \"include_role\": {\"name\": \"tripleo_ceph_client\"}, \"vars\": {\"tripleo_ceph_client_config_home\": {\"get_param\": \"CephConfigPath\"}, \"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}}}, {\"include_role\": {\"name\": \"tripleo_ceph_client\"}, \"name\": \"tripleo client role\", \"vars\": {\"tripleo_ceph_client_config_home\": {\"get_param\": \"CephConfigPath\"}, \"multiple\": \"{{ item }}\"}, \"loop\": \"{{ ceph_external_multi_config }}\", \"when\": [\"ceph_external_multi_config is defined\"]}, {\"name\": \"Load variables for standalone ganesha\", \"include_vars\": \"{{ playbook_dir }}/cephadm/cephadm-extra-vars-heat.yml\", \"when\": [\"groups[\'ceph_mon\'] | default([]) | length == 0\", \"groups[\'ceph_nfs\'] | default([]) | length > 0\"]}, {\"name\": \"Config Standalone Ganesha\", \"include_role\": {\"name\": \"tripleo_cephadm\", \"tasks_from\": \"nfs\"}, \"when\": [\"groups[\'ceph_mon\'] | default([]) | length == 0\", \"groups[\'ceph_nfs\'] | default([]) | length > 0\"], \"vars\": {\"tripleo_cephadm_config_home\": {\"get_param\": \"CephConfigPath\"}}}]}]]}, \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"config_settings\": {}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(45,'2026-06-13 07:50:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph base service. Shared by all Ceph services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NodeDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"json containing per-node configuration map\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}, \"CephConfigOverrides\": {\"type\": \"json\", \"description\": \"Extra config settings to dump into ceph.conf\", \"default\": {}}, \"ApplyCephConfigOverridesOnUpdate\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If true, CephConfigOverrides are applied to the Ceph cluster not only during the initial deployment but also during each update.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephMsgrSecureMode\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable Ceph msgr2 secure mode to enable on-wire encryption between Ceph daemons and also between Ceph clients and daemons.\\n\"}, \"CephPools\": {\"description\": \"Used to override settings (mainly target_size_ratio or pg_num) in pools. Pacific has pg_autoscale_mode enabled by default so set target_size_ratio as a percentage of the expected data consumption. The example below sets cinder volumes 40%, glance images 10%, nova vms 30% (20% of space free). Not set by default but overrides are encouraged to avoid data rebalancing. For example, CephPools:\\n  - name: volumes\\n    target_size_ratio: 0.4\\n    application: rbd\\n  - name: images\\n    target_size_ratio: 0.1\\n    application: rbd\\n  - name: vms\\n    target_size_ratio: 0.3\\n    application: rbd\\n\", \"default\": [], \"type\": \"json\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceBackend\": {\"default\": \"rbd\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GnocchiRbdPoolName\": {\"default\": \"metrics\", \"type\": \"string\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephRgwClientName\": {\"default\": \"radosgw\", \"type\": \"string\"}, \"CephRgwKey\": {\"description\": \"The cephx key for the radosgw client. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\"}, \"ManilaCephFSDataPoolName\": {\"default\": \"manila_data\", \"type\": \"string\"}, \"ManilaCephFSMetadataPoolName\": {\"default\": \"manila_metadata\", \"type\": \"string\"}, \"ManilaCephFSShareBackendName\": {\"default\": \"cephfs\", \"type\": \"string\"}, \"ManilaCephFSCephFSAuthId\": {\"default\": \"manila\", \"type\": \"string\"}, \"CephManilaClientKey\": {\"default\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}]}, \"CephIPv6\": {\"default\": false, \"type\": \"boolean\"}, \"SwiftPassword\": {\"description\": \"The password for the swift service account\", \"type\": \"string\", \"hidden\": true, \"default\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\"}, \"ContainerCephDaemonImage\": {\"description\": \"image\", \"type\": \"string\", \"default\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\"}, \"CephAnsiblePlaybookVerbosity\": {\"default\": 1, \"description\": \"The number of \'-v\', \'-vv\', etc. passed to ansible-playbook command\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 5}}]}, \"CephAnsibleEnvironmentVariables\": {\"default\": {}, \"description\": \"Mapping of Ansible environment variables to override defaults.\", \"type\": \"json\"}, \"SwiftFetchDirGetTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to download the fetch_directory from.\", \"type\": \"string\"}, \"SwiftFetchDirPutTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to upload the fetch_directory to.\", \"type\": \"string\"}, \"LocalCephAnsibleFetchDirectoryBackup\": {\"default\": \"\", \"description\": \"Filesystem path on undercloud to persist a copy of the data from the ceph-ansible fetch directory. Used as an alternative to backing up the fetch_directory in Swift. Path must be writable and readable by the user running ansible from config-download, e.g. the mistral user in the mistral-executor container is able to read/write to /var/lib/mistral/ceph_fetch\", \"type\": \"string\"}, \"CephOsdPercentageMin\": {\"default\": 0, \"description\": \"The minimum percentage of Ceph OSDs which must be running and in the Ceph cluster, according to ceph osd stat, for the deployment not to fail. Used to catch deployment errors early. Set this value to 0 to disable this check. Deprecated in Wallaby because of the move from ceph-ansible to cephadm; the later only brings up OSDs out of band and deployment does not block while waiting for them to come up, thus we cannot do this anymore.\", \"type\": \"number\"}, \"CephAnsiblePlaybook\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths to the ceph-ansible playbooks to execute. If not specified, the playbook will be determined automatically depending on type of operation being performed (deploy/update/upgrade).\\n\", \"default\": [\"default\"]}, \"CephAnsibleExtraConfig\": {\"type\": \"json\", \"description\": \"Extra vars for the ceph-ansible playbook\", \"default\": {}}, \"CephAnsibleSkipTags\": {\"type\": \"string\", \"description\": \"List of ceph-ansible tags to skip\", \"default\": \"package-install,with_pkg\"}, \"CephAnsibleRepo\": {\"type\": \"string\", \"description\": \"The repository that should be used to install the right ceph-ansible\\npackage. This value can be used by tripleo-validations to double check\\nthe right ceph-ansible version is installed.\\n\", \"default\": \"centos-ceph-nautilus\"}, \"CephAnsibleWarning\": {\"type\": \"boolean\", \"description\": \"In particular scenarios we want this validation to show the warning but\\ndon\'t fail because the package is installed on the system but repos are\\ndisabled.\\n\", \"default\": true}, \"CephPoolDefaultPgNum\": {\"description\": \"default pg_num to use for the RBD pools\", \"type\": \"number\", \"default\": 16}, \"CephPoolDefaultSize\": {\"description\": \"default minimum replication for RBD copies\", \"type\": \"number\", \"default\": 3}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\", \"default\": {}}, \"CephExtraKeys\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra keys which will be created on the deployed\\nCeph cluster. Uses ceph-ansible/library/ceph_key.py ansible module. Each\\nitem in the list must be in the following example format\\n  - name: \\\"client.glance\\\"\\n    caps:\\n      mgr: \\\"allow *\\\"\\n      mon: \\\"profile rbd\\\"\\n      osd: \\\"profile rbd pool=images\\\"\\n    key: \\\"AQBRgQ9eAAAAABAAv84zEilJYZPNuJ0Iwn9Ndg==\\\"\\n    mode: \\\"0600\\\"\\n\", \"default\": []}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderBackupBackend\": {\"default\": \"ceph\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"GnocchiBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Gnocchi backend to use. Should be one of swift, rbd, file or s3.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"s3\"]}]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CephClientConfigVars\": {\"default\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"type\": \"string\", \"description\": \"The undercloud path where cephadm exports the Ceph Client configuration.\"}, \"CephAnsibleSkipClient\": {\"description\": \"This boolean (when true) prevents the ceph-ansible client role execution\\nby adding the ceph-ansible tag \'ceph_client\' to the --skip-tags list.\\n\", \"type\": \"boolean\", \"default\": true}, \"CephDynamicSpec\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If true the tripleo_run_cephadm role will build an orchestrator-cli-service-spec\\nfile based on the data found in the inventory (which is based on composable roles)\\nby using the ceph_spec_bootstrap Ansible module in tripleo-ansible.\\n\"}, \"CephSpecPath\": {\"default\": \"{{ playbook_dir }}/cephadm/ceph_spec.yaml\", \"type\": \"string\", \"description\": \"The path on the undercloud to a valid Ceph orchestrator CLI service spec file.\\nIf you do not want the spec to be generated automatically and instead prefer\\nto supply your own spec, then place your spec at this path on the undercloud\\nand set CephDynamicSpec to false. If CephDynamicSpec is true and CephSpecPath\\nis set to a valid path, then the spec will be created at that path before it\\nis used to deploy Ceph. By default the spec will be created by config-download\\nin config-download/<stack>/cephadm/ceph_spec.yaml.\\n\"}, \"CephOsdSpec\": {\"description\": \"If CephDynamicSpec is true, then any valid OSD service specification set in\\nCephOsdSpec will appear in the genereated Ceph spec for the \'osd\' service_type.\\nReplaces CephAnsibleDisksConfig. This parameter has no effect if CephDynamicSpec\\nis false. Use this paramter to override the default of using all available block\\ndevices as data_devices. See the Ceph documentation for cephadm drivegroups.\\nExclude service_type, service_id, and placement from this parameter. In the\\nexample below all rotating devices will be data devices and all non-rotating\\ndevices will be used as shared devices (wal, db).\\n  CephOsdSpec:\\n    data_devices:\\n      rotational: 1\\n    db_devices:\\n      rotational: 0\\n\", \"type\": \"json\", \"default\": {\"data_devices\": {\"all\": true}}}, \"CephSpecFqdn\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If both CephDynamicSpec and CephSpecFqdn are true, then the hostname and\\nhosts of the generated Ceph spec will have their fully qualified domain\\nname instead of their short hostname. This parameter has no effect if\\nCephDynamicSpec is false.\\n\"}, \"CephCrushRules\": {\"type\": \"json\", \"description\": \"List of rules describing the device classes that will be found on the deployed\\nCeph cluster. They can be specified in the following form\\n- name: HDD\\n  root: default\\n  type: host\\n  class: hdd\\n  default: true\\n\", \"default\": []}, \"CephAdmDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, then cephadm sets the debug related mgr\\nconfig-key and produces a more verbose output.\\n\"}, \"CephAdmVerbose\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, the cephadm playbook is able to print\\nsome ceph related information during its execution.\\n\"}, \"DeployedCeph\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"DisableCephadm\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Disable cephadm after Ceph is deployed\"}, \"CephRbdTrashPurgeInterval\": {\"default\": 15, \"type\": \"string\", \"description\": \"The interval applied to the rbd trash purge scheduler, that can be\\nexpressed in minutes.\\n\"}, \"CephRbdTrashSchedulerEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable Ceph rbd trash scheduler\"}, \"CephadmDefaultContainer\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Use the default continer defined in cephadm instead of\\nthe one defined in container_image_prepare_defaults.yaml.\\n\"}, \"ExternalCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has been deployed outside of TripleO.\\nDeployedCeph and ExternalCeph are mutually exclusive.\\n\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"LocalCephAnsibleFetchDirectoryBackup\", \"SwiftFetchDirGetTempurl\", \"SwiftFetchDirPutTempurl\", \"CephIPv6\", \"CephAnsibleEnvironmentVariables\", \"CephAnsibleExtraConfig\", \"CephAnsiblePlaybook\", \"CephAnsiblePlaybookVerbosity\", \"CephAnsibleRepo\", \"CephAnsibleSkipTags\", \"CephAnsibleSkipClient\", \"CephAnsibleWarning\", \"CephOsdPercentageMin\", \"CephPoolDefaultPgNum\", \"CephPoolDefaultSize\"]}], \"conditions\": {\"custom_registry_host\": {\"yaql\": {\"data\": {\"get_param\": \"ContainerCephDaemonImage\"}, \"expression\": \"$.data.split(\'/\')[0].matches(\'(\\\\.|:)\')\"}}, \"ceph_authenticated_registry\": {\"and\": [{\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\").isEmpty()\"}}}, {\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\").isEmpty()\"}}}]}}, \"resources\": {\"ContainerImageUrlParts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"host\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, \"docker.io\"]}, \"image\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[2]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[0]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}]}, \"image_tag\": {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}}}, \"DefaultCephConfigOverrides\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {}}}}, \"CephAdmVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {\"tripleo_cephadm_fsid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo_cephadm_cluster\": {\"get_param\": \"CephClusterName\"}, \"tripleo_cephadm_container_cli\": {\"get_param\": \"ContainerCli\"}, \"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}, \"tripleo_cephadm_dashboard_enabled\": {\"get_param\": \"CephEnableDashboard\"}, \"cephfs\": {\"get_param\": \"ManilaCephFSShareBackendName\"}, \"tripleo_cephadm_container_ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}, \"tripleo_cephadm_container_image\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image\"]}, \"tripleo_cephadm_container_tag\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image_tag\"]}, \"tripleo_cephadm_crush_rules\": {\"get_param\": \"CephCrushRules\"}, \"tripleo_cephadm_debug\": {\"get_param\": \"CephAdmDebug\"}, \"tripleo_cephadm_verbose\": {\"get_param\": \"CephAdmVerbose\"}, \"tripleo_cephadm_rbd_trash\": {\"get_param\": \"CephRbdTrashPurgeInterval\"}, \"tripleo_cephadm_enable_trash_scheduler\": {\"get_param\": \"CephRbdTrashSchedulerEnable\"}, \"tripleo_cephadm_apply_ceph_conf_overrides_on_update\": {\"get_param\": \"ApplyCephConfigOverridesOnUpdate\"}, \"tripleo_cephadm_default_container\": {\"get_param\": \"CephadmDefaultContainer\"}, \"ceph_container_registry_auth\": {\"if\": [\"ceph_authenticated_registry\", true, false]}, \"ceph_container_registry_username\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\")\"}}, \"ceph_container_registry_password\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\")\"}}, \"public_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephMonNetwork\"]}]}]}, \"cluster_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephClusterNetwork\"]}]}]}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph base service.\", \"value\": {\"service_name\": \"ceph_base\", \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"config_settings\": {}, \"external_deploy_tasks\": [{\"name\": \"ceph_base_external_deploy_task\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"create cephadm working directory and related files\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"prepare.yml\"}, \"vars\": {\"ceph_pools\": {\"gnocchi_pool\": {\"name\": {\"get_param\": \"GnocchiRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"GnocchiBackend\"}, \"rbd\"]}, true, false]}}, \"nova_pool\": {\"name\": {\"get_param\": \"NovaRbdPoolName\"}, \"enabled\": {\"get_param\": \"NovaEnableRbdBackend\"}}, \"glance_pool\": {\"name\": {\"get_param\": \"GlanceRbdPoolName\"}, \"enabled\": {\"or\": [{\"yaql\": {\"data\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"expression\": \"$.data.values().where($ != null).GlanceBackend.contains(\\\"rbd\\\")\"}}, {\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}]}}, \"cinder_pool\": {\"name\": {\"get_param\": \"CinderRbdPoolName\"}, \"enabled\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"cinder_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}}, \"cinder_backup_pool\": {\"name\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, true, false]}}, \"extra_pools\": {\"get_param\": \"CephPools\"}}, \"manila_pools\": {\"data\": {\"get_param\": \"ManilaCephFSDataPoolName\"}, \"metadata\": {\"get_param\": \"ManilaCephFSMetadataPoolName\"}}, \"ceph_keys\": {\"openstack_client\": {\"name\": {\"get_param\": \"CephClientUserName\"}, \"key\": {\"get_param\": \"CephClientKey\"}}, \"manila\": {\"name\": {\"get_param\": \"ManilaCephFSCephFSAuthId\"}, \"key\": {\"get_param\": \"CephManilaClientKey\"}}, \"radosgw\": {\"name\": {\"get_param\": \"CephRgwClientName\"}, \"key\": {\"get_param\": \"CephRgwKey\"}}, \"extra_keys\": {\"get_param\": \"CephExtraKeys\"}}, \"ceph_config_overrides\": {\"get_param\": \"CephConfigOverrides\"}, \"tripleo_run_cephadm_spec_path\": {\"get_param\": \"CephSpecPath\"}, \"tripleo_cephadm_dynamic_spec\": {\"get_param\": \"CephDynamicSpec\"}, \"ceph_spec_fqdn\": {\"get_param\": \"CephSpecFqdn\"}, \"ceph_osd_spec\": {\"get_param\": \"CephOsdSpec\"}, \"ceph_default_overrides\": {\"global\": {\"if\": [{\"get_param\": \"CephMsgrSecureMode\"}, {\"map_merge\": [{\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}, {\"ms_cluster_mode\": \"secure\", \"ms_service_mode\": \"secure\", \"ms_client_mode\": \"secure\"}]}, {\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}]}}, \"cephadm_extra_vars\": {\"get_attr\": [\"CephAdmVars\", \"value\", \"vars\"]}, \"tripleo_cephadm_deployed_ceph\": {\"get_param\": \"DeployedCeph\"}}}, {\"name\": \"Prepare cephadm user and keys\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"enable_ceph_admin_user.yml\"}, \"when\": [\"not external_ceph\", \"(not deployed_ceph and (groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0)) or (deployed_ceph and ((groups[\'ceph_rgw\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rgw\'] | default([]) | length > 0) or (groups[\'ceph_mds\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_mds\'] | default([]) | length > 0) or (groups[\'ceph_nfs\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_nfs\'] | default([]) | length > 0) or (groups[\'ceph_rbdmirror\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rbdmirror\'] | default([]) | length > 0)))\"], \"vars\": {\"deployed_ceph\": {\"get_param\": \"DeployedCeph\"}, \"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}, {\"name\": \"Deploy or configure the cephadm Ceph cluster\", \"include_role\": {\"name\": \"tripleo_run_cephadm\"}, \"when\": [\"not external_ceph\", \"groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0\"], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}]}, {\"name\": \"ceph_base_external_deploy_task\", \"when\": [\"(step | int) == 3\", {\"get_param\": \"DisableCephadm\"}, \"not external_ceph\"], \"block\": [{\"name\": \"Pause cephadm\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"disable_cephadm.yml\"}}], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}], \"post_upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"DefaultPasswords\": {}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(46,'2026-06-13 07:50:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(47,'2026-06-13 07:50:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(48,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"internal_api_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hostname\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (49,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"nova_server_resource\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(50,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"internal_api_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(51,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"compute_hcihostname_resolve_network\": \"internal_api\", \"compute_hcimetrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(52,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph OSD service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephAnsibleDisksConfig\": {\"type\": \"json\", \"description\": \"Disks config settings.\", \"default\": {\"devices\": [], \"osd_scenario\": \"lvm\", \"osd_objectstore\": \"bluestore\"}}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}, \"CephHciOsdCount\": {\"type\": \"number\", \"default\": 0, \"tags\": [\"role_specific\"], \"description\": \"The number of expected Ceph OSDs per HCI node. Used by Ansible\\nmodule tripleo_derive_hci_parameters when cephadm/HCI is used. Since\\nCephOsdSpec might only specify a description of devices to be used\\nas OSDs (e.g. all devices), and not a list of devices as found in\\nCephAnsibleDisksConfig, this number is necessary in order to know\\nhow much CPU/RAM to reserve.\\n\"}, \"CephHciOsdType\": {\"type\": \"string\", \"default\": \"hdd\", \"tags\": [\"role_specific\"], \"constraints\": [{\"allowed_values\": [\"hdd\", \"ssd\", \"nvme\"]}], \"description\": \"CephHciOsdType is the type of data_device (not db_device) used for each\\nHCI node\'s OSD and must be one of hdd, ssd, or nvme. Used by Ansible\\nmodule tripleo_derive_hci_parameters when cephadm/HCI is used. Since\\nCephOsdSpec might only specify a description of devices to be used\\nas OSDs (e.g. all devices), and not a list of devices as found in\\nCephAnsibleDisksConfig, the device path is not hard coded so we cannot\\nlook up that device in Ironic to determine its type. If CephOsdSpec\\nhas data_devices/rotational=1 and db_devices/rotational=0, then set\\nCephHciOsdType to \'hdd\', since only the DB/WAL are on SSD. If an OSD\\ndata device is an SSD or NVMe SSD, then set the type accordingly so\\nthat the derive paramters module can allocate the optimal number of\\nCPUs per device.\\n\"}}, \"resources\": {\"CephBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"DefaultPasswords\": {\"get_param\": \"DefaultPasswords\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph OSD service.\", \"value\": {\"service_name\": \"ceph_osd\", \"firewall_rules\": {\"111 ceph_osd\": {\"dport\": {\"list_concat\": [[\"6800-7300\"], {\"if\": [{\"get_param\": \"CephEnableDashboard\"}, [\"9100\"]]}]}}}, \"service_config_settings\": {\"collectd\": {\"tripleo.collectd.plugins.ceph_osd\": [\"ceph\"], \"collectd::plugin::ceph::daemons\": []}}, \"upgrade_tasks\": {\"list_concat\": [{\"get_attr\": [\"CephBase\", \"role_data\", \"upgrade_tasks\"]}, [{\"name\": \"Set noout flag\", \"shell\": \"cephadm shell -c /etc/ceph/{{ tripleo_cephadm_cluster }}.conf -k /etc/ceph/{{ tripleo_cephadm_cluster }}.client.admin.keyring -- ceph osd set {{ item }}\", \"become\": true, \"with_items\": [\"noout\", \"norecover\", \"nobackfill\", \"norebalance\", \"nodeep-scrub\"], \"delegate_to\": \"{{ groups[\'ceph_mon\'][0] }}\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"vars\": {\"tripleo_cephadm_cluster\": {\"get_param\": \"CephClusterName\"}}, \"when\": [\"step|int == 1\", \"upgrade_leapp_enabled\"]}], [{\"name\": \"Unset noout flag\", \"shell\": \"cephadm shell -c /etc/ceph/{{ tripleo_cephadm_cluster }}.conf -k /etc/ceph/{{ tripleo_cephadm_cluster }}.client.admin.keyring -- ceph osd unset {{ item }}\", \"with_items\": [\"noout\", \"norecover\", \"nobackfill\", \"norebalance\", \"nodeep-scrub\"], \"delegate_to\": \"{{ groups[\'ceph_mon\'][0] }}\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"vars\": {\"tripleo_cephadm_cluster\": {\"get_param\": \"CephClusterName\"}}, \"when\": [\"step|int == 5\"]}]]}, \"puppet_config\": {}, \"docker_config\": {}, \"external_deploy_tasks\": {\"list_concat\": [{\"get_attr\": [\"CephBase\", \"role_data\", \"external_deploy_tasks\"]}, [{\"name\": \"ceph_osd_external_deploy_init\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Build disk list for cephadm\", \"set_fact\": {\"cephadm_disk_list\": {\"get_param\": \"CephAnsibleDisksConfig\"}}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(53,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph base service. Shared by all Ceph services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NodeDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"json containing per-node configuration map\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}, \"CephConfigOverrides\": {\"type\": \"json\", \"description\": \"Extra config settings to dump into ceph.conf\", \"default\": {}}, \"ApplyCephConfigOverridesOnUpdate\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If true, CephConfigOverrides are applied to the Ceph cluster not only during the initial deployment but also during each update.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephMsgrSecureMode\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable Ceph msgr2 secure mode to enable on-wire encryption between Ceph daemons and also between Ceph clients and daemons.\\n\"}, \"CephPools\": {\"description\": \"Used to override settings (mainly target_size_ratio or pg_num) in pools. Pacific has pg_autoscale_mode enabled by default so set target_size_ratio as a percentage of the expected data consumption. The example below sets cinder volumes 40%, glance images 10%, nova vms 30% (20% of space free). Not set by default but overrides are encouraged to avoid data rebalancing. For example, CephPools:\\n  - name: volumes\\n    target_size_ratio: 0.4\\n    application: rbd\\n  - name: images\\n    target_size_ratio: 0.1\\n    application: rbd\\n  - name: vms\\n    target_size_ratio: 0.3\\n    application: rbd\\n\", \"default\": [], \"type\": \"json\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceBackend\": {\"default\": \"rbd\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GnocchiRbdPoolName\": {\"default\": \"metrics\", \"type\": \"string\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephRgwClientName\": {\"default\": \"radosgw\", \"type\": \"string\"}, \"CephRgwKey\": {\"description\": \"The cephx key for the radosgw client. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\"}, \"ManilaCephFSDataPoolName\": {\"default\": \"manila_data\", \"type\": \"string\"}, \"ManilaCephFSMetadataPoolName\": {\"default\": \"manila_metadata\", \"type\": \"string\"}, \"ManilaCephFSShareBackendName\": {\"default\": \"cephfs\", \"type\": \"string\"}, \"ManilaCephFSCephFSAuthId\": {\"default\": \"manila\", \"type\": \"string\"}, \"CephManilaClientKey\": {\"default\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}]}, \"CephIPv6\": {\"default\": false, \"type\": \"boolean\"}, \"SwiftPassword\": {\"description\": \"The password for the swift service account\", \"type\": \"string\", \"hidden\": true, \"default\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\"}, \"ContainerCephDaemonImage\": {\"description\": \"image\", \"type\": \"string\", \"default\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\"}, \"CephAnsiblePlaybookVerbosity\": {\"default\": 1, \"description\": \"The number of \'-v\', \'-vv\', etc. passed to ansible-playbook command\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 5}}]}, \"CephAnsibleEnvironmentVariables\": {\"default\": {}, \"description\": \"Mapping of Ansible environment variables to override defaults.\", \"type\": \"json\"}, \"SwiftFetchDirGetTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to download the fetch_directory from.\", \"type\": \"string\"}, \"SwiftFetchDirPutTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to upload the fetch_directory to.\", \"type\": \"string\"}, \"LocalCephAnsibleFetchDirectoryBackup\": {\"default\": \"\", \"description\": \"Filesystem path on undercloud to persist a copy of the data from the ceph-ansible fetch directory. Used as an alternative to backing up the fetch_directory in Swift. Path must be writable and readable by the user running ansible from config-download, e.g. the mistral user in the mistral-executor container is able to read/write to /var/lib/mistral/ceph_fetch\", \"type\": \"string\"}, \"CephOsdPercentageMin\": {\"default\": 0, \"description\": \"The minimum percentage of Ceph OSDs which must be running and in the Ceph cluster, according to ceph osd stat, for the deployment not to fail. Used to catch deployment errors early. Set this value to 0 to disable this check. Deprecated in Wallaby because of the move from ceph-ansible to cephadm; the later only brings up OSDs out of band and deployment does not block while waiting for them to come up, thus we cannot do this anymore.\", \"type\": \"number\"}, \"CephAnsiblePlaybook\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths to the ceph-ansible playbooks to execute. If not specified, the playbook will be determined automatically depending on type of operation being performed (deploy/update/upgrade).\\n\", \"default\": [\"default\"]}, \"CephAnsibleExtraConfig\": {\"type\": \"json\", \"description\": \"Extra vars for the ceph-ansible playbook\", \"default\": {}}, \"CephAnsibleSkipTags\": {\"type\": \"string\", \"description\": \"List of ceph-ansible tags to skip\", \"default\": \"package-install,with_pkg\"}, \"CephAnsibleRepo\": {\"type\": \"string\", \"description\": \"The repository that should be used to install the right ceph-ansible\\npackage. This value can be used by tripleo-validations to double check\\nthe right ceph-ansible version is installed.\\n\", \"default\": \"centos-ceph-nautilus\"}, \"CephAnsibleWarning\": {\"type\": \"boolean\", \"description\": \"In particular scenarios we want this validation to show the warning but\\ndon\'t fail because the package is installed on the system but repos are\\ndisabled.\\n\", \"default\": true}, \"CephPoolDefaultPgNum\": {\"description\": \"default pg_num to use for the RBD pools\", \"type\": \"number\", \"default\": 16}, \"CephPoolDefaultSize\": {\"description\": \"default minimum replication for RBD copies\", \"type\": \"number\", \"default\": 3}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\", \"default\": {}}, \"CephExtraKeys\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra keys which will be created on the deployed\\nCeph cluster. Uses ceph-ansible/library/ceph_key.py ansible module. Each\\nitem in the list must be in the following example format\\n  - name: \\\"client.glance\\\"\\n    caps:\\n      mgr: \\\"allow *\\\"\\n      mon: \\\"profile rbd\\\"\\n      osd: \\\"profile rbd pool=images\\\"\\n    key: \\\"AQBRgQ9eAAAAABAAv84zEilJYZPNuJ0Iwn9Ndg==\\\"\\n    mode: \\\"0600\\\"\\n\", \"default\": []}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderBackupBackend\": {\"default\": \"ceph\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"GnocchiBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Gnocchi backend to use. Should be one of swift, rbd, file or s3.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"s3\"]}]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CephClientConfigVars\": {\"default\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"type\": \"string\", \"description\": \"The undercloud path where cephadm exports the Ceph Client configuration.\"}, \"CephAnsibleSkipClient\": {\"description\": \"This boolean (when true) prevents the ceph-ansible client role execution\\nby adding the ceph-ansible tag \'ceph_client\' to the --skip-tags list.\\n\", \"type\": \"boolean\", \"default\": true}, \"CephDynamicSpec\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If true the tripleo_run_cephadm role will build an orchestrator-cli-service-spec\\nfile based on the data found in the inventory (which is based on composable roles)\\nby using the ceph_spec_bootstrap Ansible module in tripleo-ansible.\\n\"}, \"CephSpecPath\": {\"default\": \"{{ playbook_dir }}/cephadm/ceph_spec.yaml\", \"type\": \"string\", \"description\": \"The path on the undercloud to a valid Ceph orchestrator CLI service spec file.\\nIf you do not want the spec to be generated automatically and instead prefer\\nto supply your own spec, then place your spec at this path on the undercloud\\nand set CephDynamicSpec to false. If CephDynamicSpec is true and CephSpecPath\\nis set to a valid path, then the spec will be created at that path before it\\nis used to deploy Ceph. By default the spec will be created by config-download\\nin config-download/<stack>/cephadm/ceph_spec.yaml.\\n\"}, \"CephOsdSpec\": {\"description\": \"If CephDynamicSpec is true, then any valid OSD service specification set in\\nCephOsdSpec will appear in the genereated Ceph spec for the \'osd\' service_type.\\nReplaces CephAnsibleDisksConfig. This parameter has no effect if CephDynamicSpec\\nis false. Use this paramter to override the default of using all available block\\ndevices as data_devices. See the Ceph documentation for cephadm drivegroups.\\nExclude service_type, service_id, and placement from this parameter. In the\\nexample below all rotating devices will be data devices and all non-rotating\\ndevices will be used as shared devices (wal, db).\\n  CephOsdSpec:\\n    data_devices:\\n      rotational: 1\\n    db_devices:\\n      rotational: 0\\n\", \"type\": \"json\", \"default\": {\"data_devices\": {\"all\": true}}}, \"CephSpecFqdn\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If both CephDynamicSpec and CephSpecFqdn are true, then the hostname and\\nhosts of the generated Ceph spec will have their fully qualified domain\\nname instead of their short hostname. This parameter has no effect if\\nCephDynamicSpec is false.\\n\"}, \"CephCrushRules\": {\"type\": \"json\", \"description\": \"List of rules describing the device classes that will be found on the deployed\\nCeph cluster. They can be specified in the following form\\n- name: HDD\\n  root: default\\n  type: host\\n  class: hdd\\n  default: true\\n\", \"default\": []}, \"CephAdmDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, then cephadm sets the debug related mgr\\nconfig-key and produces a more verbose output.\\n\"}, \"CephAdmVerbose\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, the cephadm playbook is able to print\\nsome ceph related information during its execution.\\n\"}, \"DeployedCeph\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"DisableCephadm\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Disable cephadm after Ceph is deployed\"}, \"CephRbdTrashPurgeInterval\": {\"default\": 15, \"type\": \"string\", \"description\": \"The interval applied to the rbd trash purge scheduler, that can be\\nexpressed in minutes.\\n\"}, \"CephRbdTrashSchedulerEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable Ceph rbd trash scheduler\"}, \"CephadmDefaultContainer\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Use the default continer defined in cephadm instead of\\nthe one defined in container_image_prepare_defaults.yaml.\\n\"}, \"ExternalCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has been deployed outside of TripleO.\\nDeployedCeph and ExternalCeph are mutually exclusive.\\n\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"LocalCephAnsibleFetchDirectoryBackup\", \"SwiftFetchDirGetTempurl\", \"SwiftFetchDirPutTempurl\", \"CephIPv6\", \"CephAnsibleEnvironmentVariables\", \"CephAnsibleExtraConfig\", \"CephAnsiblePlaybook\", \"CephAnsiblePlaybookVerbosity\", \"CephAnsibleRepo\", \"CephAnsibleSkipTags\", \"CephAnsibleSkipClient\", \"CephAnsibleWarning\", \"CephOsdPercentageMin\", \"CephPoolDefaultPgNum\", \"CephPoolDefaultSize\"]}], \"conditions\": {\"custom_registry_host\": {\"yaql\": {\"data\": {\"get_param\": \"ContainerCephDaemonImage\"}, \"expression\": \"$.data.split(\'/\')[0].matches(\'(\\\\.|:)\')\"}}, \"ceph_authenticated_registry\": {\"and\": [{\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\").isEmpty()\"}}}, {\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\").isEmpty()\"}}}]}}, \"resources\": {\"ContainerImageUrlParts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"host\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, \"docker.io\"]}, \"image\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[2]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[0]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}]}, \"image_tag\": {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}}}, \"DefaultCephConfigOverrides\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {}}}}, \"CephAdmVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {\"tripleo_cephadm_fsid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo_cephadm_cluster\": {\"get_param\": \"CephClusterName\"}, \"tripleo_cephadm_container_cli\": {\"get_param\": \"ContainerCli\"}, \"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}, \"tripleo_cephadm_dashboard_enabled\": {\"get_param\": \"CephEnableDashboard\"}, \"cephfs\": {\"get_param\": \"ManilaCephFSShareBackendName\"}, \"tripleo_cephadm_container_ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}, \"tripleo_cephadm_container_image\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image\"]}, \"tripleo_cephadm_container_tag\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image_tag\"]}, \"tripleo_cephadm_crush_rules\": {\"get_param\": \"CephCrushRules\"}, \"tripleo_cephadm_debug\": {\"get_param\": \"CephAdmDebug\"}, \"tripleo_cephadm_verbose\": {\"get_param\": \"CephAdmVerbose\"}, \"tripleo_cephadm_rbd_trash\": {\"get_param\": \"CephRbdTrashPurgeInterval\"}, \"tripleo_cephadm_enable_trash_scheduler\": {\"get_param\": \"CephRbdTrashSchedulerEnable\"}, \"tripleo_cephadm_apply_ceph_conf_overrides_on_update\": {\"get_param\": \"ApplyCephConfigOverridesOnUpdate\"}, \"tripleo_cephadm_default_container\": {\"get_param\": \"CephadmDefaultContainer\"}, \"ceph_container_registry_auth\": {\"if\": [\"ceph_authenticated_registry\", true, false]}, \"ceph_container_registry_username\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\")\"}}, \"ceph_container_registry_password\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\")\"}}, \"public_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephMonNetwork\"]}]}]}, \"cluster_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephClusterNetwork\"]}]}]}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph base service.\", \"value\": {\"service_name\": \"ceph_base\", \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"config_settings\": {}, \"external_deploy_tasks\": [{\"name\": \"ceph_base_external_deploy_task\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"create cephadm working directory and related files\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"prepare.yml\"}, \"vars\": {\"ceph_pools\": {\"gnocchi_pool\": {\"name\": {\"get_param\": \"GnocchiRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"GnocchiBackend\"}, \"rbd\"]}, true, false]}}, \"nova_pool\": {\"name\": {\"get_param\": \"NovaRbdPoolName\"}, \"enabled\": {\"get_param\": \"NovaEnableRbdBackend\"}}, \"glance_pool\": {\"name\": {\"get_param\": \"GlanceRbdPoolName\"}, \"enabled\": {\"or\": [{\"yaql\": {\"data\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"expression\": \"$.data.values().where($ != null).GlanceBackend.contains(\\\"rbd\\\")\"}}, {\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}]}}, \"cinder_pool\": {\"name\": {\"get_param\": \"CinderRbdPoolName\"}, \"enabled\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"cinder_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}}, \"cinder_backup_pool\": {\"name\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, true, false]}}, \"extra_pools\": {\"get_param\": \"CephPools\"}}, \"manila_pools\": {\"data\": {\"get_param\": \"ManilaCephFSDataPoolName\"}, \"metadata\": {\"get_param\": \"ManilaCephFSMetadataPoolName\"}}, \"ceph_keys\": {\"openstack_client\": {\"name\": {\"get_param\": \"CephClientUserName\"}, \"key\": {\"get_param\": \"CephClientKey\"}}, \"manila\": {\"name\": {\"get_param\": \"ManilaCephFSCephFSAuthId\"}, \"key\": {\"get_param\": \"CephManilaClientKey\"}}, \"radosgw\": {\"name\": {\"get_param\": \"CephRgwClientName\"}, \"key\": {\"get_param\": \"CephRgwKey\"}}, \"extra_keys\": {\"get_param\": \"CephExtraKeys\"}}, \"ceph_config_overrides\": {\"get_param\": \"CephConfigOverrides\"}, \"tripleo_run_cephadm_spec_path\": {\"get_param\": \"CephSpecPath\"}, \"tripleo_cephadm_dynamic_spec\": {\"get_param\": \"CephDynamicSpec\"}, \"ceph_spec_fqdn\": {\"get_param\": \"CephSpecFqdn\"}, \"ceph_osd_spec\": {\"get_param\": \"CephOsdSpec\"}, \"ceph_default_overrides\": {\"global\": {\"if\": [{\"get_param\": \"CephMsgrSecureMode\"}, {\"map_merge\": [{\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}, {\"ms_cluster_mode\": \"secure\", \"ms_service_mode\": \"secure\", \"ms_client_mode\": \"secure\"}]}, {\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}]}}, \"cephadm_extra_vars\": {\"get_attr\": [\"CephAdmVars\", \"value\", \"vars\"]}, \"tripleo_cephadm_deployed_ceph\": {\"get_param\": \"DeployedCeph\"}}}, {\"name\": \"Prepare cephadm user and keys\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"enable_ceph_admin_user.yml\"}, \"when\": [\"not external_ceph\", \"(not deployed_ceph and (groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0)) or (deployed_ceph and ((groups[\'ceph_rgw\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rgw\'] | default([]) | length > 0) or (groups[\'ceph_mds\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_mds\'] | default([]) | length > 0) or (groups[\'ceph_nfs\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_nfs\'] | default([]) | length > 0) or (groups[\'ceph_rbdmirror\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rbdmirror\'] | default([]) | length > 0)))\"], \"vars\": {\"deployed_ceph\": {\"get_param\": \"DeployedCeph\"}, \"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}, {\"name\": \"Deploy or configure the cephadm Ceph cluster\", \"include_role\": {\"name\": \"tripleo_run_cephadm\"}, \"when\": [\"not external_ceph\", \"groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0\"], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}]}, {\"name\": \"ceph_base_external_deploy_task\", \"when\": [\"(step | int) == 3\", {\"get_param\": \"DisableCephadm\"}, \"not external_ceph\"], \"block\": [{\"name\": \"Pause cephadm\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"disable_cephadm.yml\"}}], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}], \"post_upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"DefaultPasswords\": {}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(54,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"compute_hcihostname_resolve_network\": \"internal_api\", \"compute_hcimetrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(55,'2026-06-13 07:50:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Compute service\\n\", \"parameters\": {\"ContainerCeilometerComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerCompute\": {\"default\": \"overcloud-ceilometer-agent-compute\", \"type\": \"string\"}, \"InstanceDiscoveryMethod\": {\"default\": \"libvirt_metadata\", \"description\": \"Method used to discover instances running on compute node\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"naive\", \"libvirt_metadata\", \"workload_partitioning\"]}]}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerComputeImage\": \"ContainerCeilometerComputeImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerComputeImage\": {\"get_param\": \"ContainerCeilometerComputeImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Compute role.\", \"value\": {\"service_name\": \"ceilometer_agent_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::polling::instance_discovery_method\": {\"get_param\": \"InstanceDiscoveryMethod\"}}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"compute_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"ceilometer_agent_compute\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerComputeImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(56,'2026-06-13 07:50:19',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"compute_hcihostname_resolve_network\": \"internal_api\", \"compute_hcimetrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(57,'2026-06-13 07:50:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CdhGooXCxTME1ITxFl9q0xUTr\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"xYUZeqAicsuHn0JOHQOq1idQJ\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IOcEXVmeV2fpzQjbFPUW1TNW\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"high\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (58,'2026-06-13 07:50:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Aodh Notifier service\\n\", \"parameters\": {\"ContainerAodhNotifierImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\"}, \"ContainerAodhConfigImage\": {\"description\": \"The container image to use for the aodh config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionAodhNotifier\": {\"default\": \"overcloud-ceilometer-aodh-notifier\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"AodhBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerAodhNotifierImage\": \"ContainerAodhNotifierImage\", \"ContainerAodhConfigImage\": \"ContainerAodhConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerAodhNotifierImage\": {\"get_param\": \"ContainerAodhNotifierImage\"}, \"ContainerAodhConfigImage\": {\"get_param\": \"ContainerAodhConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Aodh API role.\", \"value\": {\"service_name\": \"aodh_notifier\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionAodhNotifier\"}, \"config_settings\": {\"get_attr\": [\"AodhBase\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"get_attr\": [\"AodhBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"aodh\", \"puppet_tags\": \"aodh_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::aodh::notifier\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/aodh_notifier.json\": {\"command\": \"/usr/bin/aodh-notifier\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/aodh\", \"owner\": \"aodh:aodh\", \"recurse\": true}]}}, \"docker_config\": {\"step_4\": {\"aodh_notifier\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhNotifierImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/aodh_notifier.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/aodh:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/aodh:/var/log/aodh:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/aodh\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/aodh\", \"setype\": \"container_file_t\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop aodh notifier container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"aodh_notifier\"], \"tripleo_delegate_to\": \"{{ groups[\'aodh_notifier\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(59,'2026-06-13 07:50:19',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"internal_api_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(60,'2026-06-13 07:50:19',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"compute_hcihostname_resolve_network\": \"internal_api\", \"compute_hcimetrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(61,'2026-06-13 07:50:19',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"internal_api_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"external_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(62,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(63,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Ipmi service\\n\", \"parameters\": {\"ContainerCeilometerIpmiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentIpmiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.ipmi\", \"file\": \"/var/log/containers/ceilometer/ipmi.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"MonitoringSubscriptionCeilometerIpmi\": {\"default\": \"overcloud-ceilometer-agent-ipmi\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CeilometerAgentCentralBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerIpmiImage\": \"ContainerCeilometerIpmiImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerIpmiImage\": {\"get_param\": \"ContainerCeilometerIpmiImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Ipmi role.\", \"value\": {\"service_name\": \"ceilometer_agent_ipmi\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerIpmi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"ipmi_namespace\": true}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_ipmi\": [{\"get_param\": \"CeilometerAgentIpmiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_ipmi\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(64,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(65,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Aodh service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"AodhPassword\": {\"description\": \"The password for the aodh services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"9AJygE1s9mctpR1exZtvx6E4S\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"AodhDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Aodh services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Aodh role.\", \"value\": {\"service_name\": \"aodh_base\", \"config_settings\": {\"aodh_redis_password\": {\"get_param\": \"RedisPassword\"}, \"aodh::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"aodh\", \"password\": {\"get_param\": \"AodhPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/aodh\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"aodh\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"aodh::logging::debug\": {\"if\": [{\"get_param\": \"AodhDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"aodh::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"aodh::rabbit_heartbeat_in_pthread\": false, \"aodh::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"aodh::service_credentials::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"aodh::service_credentials::project_name\": \"service\", \"aodh::service_credentials::user_domain_name\": \"Default\", \"aodh::service_credentials::project_domain_name\": \"Default\"}, \"service_config_settings\": {\"mysql\": {\"aodh::db::mysql::user\": \"aodh\", \"aodh::db::mysql::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::db::mysql::host\": \"%\", \"aodh::db::mysql::dbname\": \"aodh\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(66,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CdhGooXCxTME1ITxFl9q0xUTr\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"xYUZeqAicsuHn0JOHQOq1idQJ\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IOcEXVmeV2fpzQjbFPUW1TNW\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"high\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (67,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized aodh service\\n\", \"parameters\": {\"ContainerAodhApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\"}, \"ContainerAodhConfigImage\": {\"description\": \"The container image to use for the aodh config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"GnocchiExternalProject\": {\"default\": \"service\", \"description\": \"Project name of resources creator in Gnocchi.\", \"type\": \"string\"}, \"MonitoringSubscriptionAodhApi\": {\"default\": \"overcloud-ceilometer-aodh-api\", \"type\": \"string\"}, \"AodhApiPolicies\": {\"description\": \"A hash of policies to configure for Aodh API.\\ne.g. { aodh-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"AodhPassword\": {\"description\": \"The password for the aodh services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"9AJygE1s9mctpR1exZtvx6E4S\"}, \"AodhAlarmHistoryTTL\": {\"description\": \"Number of seconds that alarm histories are kept in the database\", \"default\": \"86400\", \"type\": \"string\"}, \"EnableAodhExpirer\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Enable aodh expirer to periodically delete alarms from db\"}, \"AodhExpirerMinute\": {\"type\": \"string\", \"description\": \"Cron to delete alarms data from db - Minute\\n\", \"default\": \"1\"}, \"AodhExpirerHour\": {\"type\": \"string\", \"description\": \"Cron to delete alarms data from db - Hour\\n\", \"default\": \"0\"}, \"AodhExpirerMonthday\": {\"type\": \"string\", \"description\": \"Cron to delete alarms data from db - Month Day\\n\", \"default\": \"*\"}, \"AodhExpirerMonth\": {\"type\": \"string\", \"description\": \"Cron to delete alarms data from db - Month\\n\", \"default\": \"*\"}, \"AodhExpirerWeekday\": {\"type\": \"string\", \"description\": \"Cron to delete alarms from db - Week Day\\n\", \"default\": \"*\"}, \"AodhExpirerMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to delete alarms from db - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"AodhBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerAodhApiImage\": \"ContainerAodhApiImage\", \"ContainerAodhConfigImage\": \"ContainerAodhConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerAodhApiImage\": {\"get_param\": \"ContainerAodhApiImage\"}, \"ContainerAodhConfigImage\": {\"get_param\": \"ContainerAodhConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the aodh API role.\", \"value\": {\"service_name\": \"aodh_api\", \"firewall_rules\": {\"128 aodh-api\": {\"dport\": [8042]}}, \"firewall_frontend_rules\": {\"100 aodh_haproxy_frontend\": {\"dport\": [8042]}}, \"firewall_ssl_frontend_rules\": {\"100 aodh_haproxy_frontend_ssl\": {\"dport\": [13042]}}, \"keystone_resources\": {\"aodh\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"uri\"]}}, \"users\": {\"aodh\": {\"password\": {\"get_param\": \"AodhPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"alarming\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionAodhApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"AodhBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"aodh::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"aodh::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}}}, \"aodh::wsgi::apache::wsgi_process_display_name\": \"aodh_wsgi\", \"aodh::api::service_name\": \"httpd\", \"aodh::api::enable_proxy_headers_parsing\": true, \"aodh::api::gnocchi_external_project_owner\": {\"get_param\": \"GnocchiExternalProject\"}, \"aodh::keystone::authtoken::project_name\": \"service\", \"aodh::keystone::authtoken::user_domain_name\": \"Default\", \"aodh::keystone::authtoken::project_domain_name\": \"Default\", \"aodh::keystone::authtoken::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"aodh::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"aodh::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"aodh::keystone::authtoken::interface\": \"internal\", \"aodh::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"aodh::policy::policies\": {\"get_param\": \"AodhApiPolicies\"}, \"aodh::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}}}, \"aodh::alarm_history_time_to_live\": {\"get_param\": \"AodhAlarmHistoryTTL\"}, \"enable_aodh_expirer\": {\"get_param\": \"EnableAodhExpirer\"}, \"aodh::expirer::minute\": {\"get_param\": \"AodhExpirerMinute\"}, \"aodh::expirer::hour\": {\"get_param\": \"AodhExpirerHour\"}, \"aodh::expirer::monthday\": {\"get_param\": \"AodhExpirerMonthday\"}, \"aodh::expirer::month\": {\"get_param\": \"AodhExpirerMonth\"}, \"aodh::expirer::weekday\": {\"get_param\": \"AodhExpirerWeekday\"}, \"aodh::expirer::maxdelay\": {\"get_param\": \"AodhExpirerMaxDelay\"}}]}, \"service_config_settings\": {\"get_attr\": [\"AodhBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"aodh\", \"puppet_tags\": \"aodh_api_paste_ini,aodh_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::aodh::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/aodh_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/aodh\", \"owner\": \"aodh:aodh\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/aodh_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec aodh_api su aodh -s /bin/bash -c /usr/bin/aodh-dbsync\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/aodh\", \"owner\": \"aodh:aodh\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/aodh_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/aodh\", \"owner\": \"aodh:aodh\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"aodh_init_log\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhApiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/aodh:/var/log/aodh:z\", \"/var/log/containers/httpd/aodh-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R aodh:aodh /var/log/aodh\"]}}, \"step_3\": {\"aodh_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/aodh_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/aodh:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/aodh:/var/log/aodh\", \"/var/log/containers/httpd/aodh-api:/var/log/httpd\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"aodh_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/aodh_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/aodh:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/aodh:/var/log/aodh\", \"/var/log/containers/httpd/aodh-api:/var/log/httpd\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"aodh_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron aodh\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/aodh_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/aodh:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/aodh:/var/log/aodh\", \"/var/log/containers/httpd/aodh-api:/var/log/httpd\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/aodh\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/aodh-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop aodh api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"aodh_api\", \"aodh_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'aodh_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(68,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"internal_api_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"external_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(69,'2026-06-13 07:50:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Aodh service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"AodhPassword\": {\"description\": \"The password for the aodh services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"9AJygE1s9mctpR1exZtvx6E4S\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"AodhDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Aodh services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Aodh role.\", \"value\": {\"service_name\": \"aodh_base\", \"config_settings\": {\"aodh_redis_password\": {\"get_param\": \"RedisPassword\"}, \"aodh::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"aodh\", \"password\": {\"get_param\": \"AodhPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/aodh\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"aodh\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"aodh::logging::debug\": {\"if\": [{\"get_param\": \"AodhDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"aodh::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"aodh::rabbit_heartbeat_in_pthread\": false, \"aodh::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"aodh::service_credentials::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"aodh::service_credentials::project_name\": \"service\", \"aodh::service_credentials::user_domain_name\": \"Default\", \"aodh::service_credentials::project_domain_name\": \"Default\"}, \"service_config_settings\": {\"mysql\": {\"aodh::db::mysql::user\": \"aodh\", \"aodh::db::mysql::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::db::mysql::host\": \"%\", \"aodh::db::mysql::dbname\": \"aodh\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(70,'2026-06-13 07:50:21',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"compute_hcihostname_resolve_network\": \"internal_api\", \"compute_hcimetrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(71,'2026-06-13 07:50:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": true, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"xYUZeqAicsuHn0JOHQOq1idQJ\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(72,'2026-06-13 07:50:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Aodh Listener service\\n\", \"parameters\": {\"ContainerAodhListenerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\"}, \"ContainerAodhConfigImage\": {\"description\": \"The container image to use for the aodh config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionAodhListener\": {\"default\": \"overcloud-ceilometer-aodh-listener\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"AodhBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerAodhListenerImage\": \"ContainerAodhListenerImage\", \"ContainerAodhConfigImage\": \"ContainerAodhConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerAodhListenerImage\": {\"get_param\": \"ContainerAodhListenerImage\"}, \"ContainerAodhConfigImage\": {\"get_param\": \"ContainerAodhConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Aodh API role.\", \"value\": {\"service_name\": \"aodh_listener\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionAodhListener\"}, \"config_settings\": {\"get_attr\": [\"AodhBase\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"get_attr\": [\"AodhBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"aodh\", \"puppet_tags\": \"aodh_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::aodh::listener\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/aodh_listener.json\": {\"command\": \"/usr/bin/aodh-listener\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/aodh\", \"owner\": \"aodh:aodh\", \"recurse\": true}]}}, \"docker_config\": {\"step_4\": {\"aodh_listener\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhListenerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/aodh_listener.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/aodh:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/aodh:/var/log/aodh:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/aodh\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop aodh listener container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"aodh_listener\"], \"tripleo_delegate_to\": \"{{ groups[\'aodh_listener\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(73,'2026-06-13 07:50:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CdhGooXCxTME1ITxFl9q0xUTr\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"xYUZeqAicsuHn0JOHQOq1idQJ\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IOcEXVmeV2fpzQjbFPUW1TNW\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"high\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(74,'2026-06-13 07:50:21',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"compute_hcihostname_resolve_network\": \"internal_api\", \"compute_hcimetrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (75,'2026-06-13 07:50:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Modular Libvirt Service\\n\", \"parameters\": {\"ContainerNovaLibvirtImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtUlimit\": {\"default\": [\"nofile=131072\", \"nproc=126960\"], \"description\": \"ulimit for Nova Libvirt Container\", \"type\": \"comma_delimited_list\"}, \"ContainerNovaLibvirtPidsLimit\": {\"default\": 65536, \"description\": \"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"UseCustomGnuTlsQemuCryptoPolicy\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If set to true, will use CustomGnuTlsQemuCryptoPolicy in crypto policy.\"}, \"CustomGnuTlsQemuCryptoPolicy\": {\"default\": \"QEMU=NONE:+ECDHE-RSA:+ECDHE-ECDSA:+RSA:+DHE-RSA:+GROUP-X25519:+GROUP-X448:+GROUP-SECP256R1:+GROUP-SECP384R1:+GROUP-SECP521R1:+GROUP-FFDHE2048:+GROUP-FFDHE3072:+GROUP-FFDHE4096:+GROUP-FFDHE6144:+GROUP-FFDHE8192:+CHACHA20-POLY1305:+AEAD:+SHA1:+SHA512:+SIGN-ECDSA-SHA256:+SIGN-ECDSA-SECP256R1-SHA256:+SIGN-ECDSA-SHA384:+SIGN-ECDSA-SECP384R1-SHA384:+SIGN-ECDSA-SHA512:+SIGN-ECDSA-SECP521R1-SHA512:+SIGN-EdDSA-Ed25519:+SIGN-EdDSA-Ed448:+SIGN-RSA-PSS-SHA256:+SIGN-RSA-PSS-SHA384:+SIGN-RSA-PSS-SHA512:+SIGN-RSA-PSS-RSAE-SHA256:+SIGN-RSA-PSS-RSAE-SHA384:+SIGN-RSA-PSS-RSAE-SHA512:+SIGN-RSA-SHA256:+SIGN-RSA-SHA384:+SIGN-RSA-SHA512:+VERS-TLS1.3:+VERS-TLS1.2:+VERS-DTLS1.2\", \"description\": \"Custom GnuTls Crypto Policy for QEMU\", \"type\": \"string\"}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"UseTLSTransportForNbd\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"LibvirtCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuServerCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"QemuCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"VhostuserSocketGroup\": {\"default\": \"qemu\", \"description\": \"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtType\": {\"type\": \"string\", \"default\": \"qemu\"}, \"LibvirtEnabledPerfEvents\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\"}, \"MonitoringSubscriptionNovaLibvirt\": {\"default\": \"overcloud-nova-libvirt\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"LibvirtTLSPassword\": {\"description\": \"The password for the libvirt service when TLS is enabled\", \"type\": \"string\", \"hidden\": true, \"default\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\"}, \"QemuDefaultTLSVerify\": {\"description\": \"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\n\", \"default\": true, \"type\": \"boolean\"}, \"LibvirtLogFilters\": {\"description\": \"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\"}, \"LibvirtVirtlogdLogFilters\": {\"description\": \"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:logging 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtsecretdLogFilters\": {\"description\": \"Defines a filter in virtsecretd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtnodedevdLogFilters\": {\"description\": \"Defines a filter in virtnodedevd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtstoragedLogFilters\": {\"description\": \"Defines a filter in virtstoraged to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtqemudLogFilters\": {\"description\": \"Defines a filter in virtqemud to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtproxydLogFilters\": {\"description\": \"Defines a filter in virtproxyd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtTLSPriority\": {\"description\": \"Override the compile time default TLS priority string.\\n\", \"type\": \"string\", \"default\": \"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\"}, \"NovaLibvirtOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaEnableVirtlogdContainerWrapper\": {\"description\": \"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\", \"type\": \"boolean\", \"default\": true}, \"VirtlogdWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}}, \"conditions\": {\"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"libvirt_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCACert\"}, \"\"]}}, \"need_libvirt_secret\": {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaEnableRbdBackend\"}, true]}]}, {\"get_param\": \"CinderEnableRbdBackend\"}]}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"use_tls_for_nbd\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForNbd\"}]}, \"qemu_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuCACert\"}, \"\"]}}, \"key_size_libvirt_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_client_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuClientCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_server_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuServerCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"vhostuser_socket_group\": \"VhostuserSocketGroup\", \"nova_libvirt_opt_volumes\": \"NovaLibvirtOptVolumes\", \"ContainerNovaLibvirtImage\": \"ContainerNovaLibvirtImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"VhostuserSocketGroup\": {\"get_param\": \"VhostuserSocketGroup\"}, \"NovaLibvirtOptVolumes\": {\"get_param\": \"NovaLibvirtOptVolumes\"}, \"ContainerNovaLibvirtImage\": {\"get_param\": \"ContainerNovaLibvirtImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NovaLibvirtLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaLibvirt\"}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLibvirtCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Libvirt service.\", \"value\": {\"service_name\": \"nova_libvirt\", \"firewall_rules\": {\"200 nova_libvirt\": {\"dport\": [16514, \"61152-61215\", \"5900-6923\"]}}, \"ansible_group_vars\": {\"tripleo_nova_libvirt_virsh_container\": \"nova_virtproxyd\"}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaLibvirt\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"config_settings\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\": {\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\": \"/var/lib/container-config-scripts/virtlogd_wrapper\", \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"tripleo::profile::base::nova::virtlogd_wrapper::debug\": {\"if\": [{\"get_param\": \"VirtlogdWrapperDebug\"}, true, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}]}, \"nova::compute::libvirt::migration_support\": false, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::nova::migration::client::libvirt_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::libvirt::services::libvirt_virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::enabled_perf_events\": {\"get_param\": \"LibvirtEnabledPerfEvents\"}, \"nova::compute::libvirt::qemu::configure_qemu\": true, \"nova::compute::libvirt::qemu::max_files\": 32768, \"nova::compute::libvirt::qemu::max_processes\": 131072, \"nova::migration::qemu::configure_qemu\": true, \"nova::migration::qemu::migration_port_min\": 61152, \"nova::migration::qemu::migration_port_max\": 61215, \"nova::compute::libvirt::vncserver_listen\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::libvirt::log_filters\": {\"get_param\": \"LibvirtLogFilters\"}, \"nova::compute::libvirt::virtlogd::log_filters\": {\"get_param\": \"LibvirtVirtlogdLogFilters\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::compute::libvirt::virtsecretd::log_filters\": {\"get_param\": \"LibvirtVirtsecretdLogFilters\"}, \"nova::compute::libvirt::virtnodedevd::log_filters\": {\"get_param\": \"LibvirtVirtnodedevdLogFilters\"}, \"nova::compute::libvirt::virtstoraged::log_filters\": {\"get_param\": \"LibvirtVirtstoragedLogFilters\"}, \"nova::compute::libvirt::virtqemud::log_filters\": {\"get_param\": \"LibvirtVirtqemudLogFilters\"}, \"nova::compute::libvirt::virtproxyd::log_filters\": {\"get_param\": \"LibvirtVirtproxydLogFilters\"}, \"tripleo::profile::base::nova::libvirt::modular_libvirt\": true, \"nova::compute::libvirt::services::modular_libvirt\": true, \"nova::compute::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::modular_libvirt\": true}, {\"if\": [\"use_tls_for_live_migration\", {\"tripleo::profile::base::nova::migration::client::libvirt_tls\": true, \"tripleo::profile::base::nova::libvirt::tls_password\": {\"get_param\": [\"LibvirtTLSPassword\"]}, \"nova::compute::libvirt::qemu::default_tls_verify\": {\"get_param\": \"QemuDefaultTLSVerify\"}, \"nova::compute::libvirt::tls_priority\": {\"get_param\": \"LibvirtTLSPriority\"}, \"nova::migration::libvirt::listen_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}]}, {\"if\": [\"use_tls_for_vnc\", {\"nova::compute::libvirt::qemu::vnc_tls\": true, \"nova::compute::libvirt::qemu::vnc_tls_verify\": true}]}, {\"if\": [\"use_tls_for_nbd\", {\"nova::compute::libvirt::qemu::nbd_tls\": true, \"nova::migration::libvirt::live_migration_with_native_tls\": true}]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_virtlogd.json\": {\"command\": {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"/usr/local/bin/virtlogd_wrapper\", \"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\"]}, \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtsecretd.json\": {\"command\": \"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtnodedevd.json\": {\"command\": \"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtstoraged.json\": {\"command\": \"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtqemud.json\": {\"command\": \"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtproxyd.json\": {\"command\": \"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}}, \"container_config_scripts\": {\"nova_libvirt_init_secret.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\"}}}, \"docker_config\": {\"step_2\": {\"nova_virtqemud_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"net\": \"none\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"user\": \"root\", \"volumes\": [\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R tss:tss /var/log/swtpm\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"create_virtlogd_wrapper\": {\"start_order\": 1, \"detach\": false, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::nova::virtlogd_wrapper\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_3\": {\"map_merge\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, {\"nova_virtlogd_wrapper\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"nova_virtlogd\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}, {\"nova_virtsecretd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtnodedevd\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtstoraged\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtqemud\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\", {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, \"/etc/crypto-policies:/etc/crypto-policies:ro\"]}]]}}}, {\"nova_virtproxyd\": {\"start_order\": 5, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}]}, \"step_4\": {\"if\": [\"need_libvirt_secret\", {\"nova_libvirt_init_secret\": {\"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"security_opt\": [\"label=disable\"], \"privileged\": false, \"user\": \"root\", \"cgroupns\": \"host\", \"net\": \"host\", \"environment\": {\"LIBVIRT_DEFAULT_URI\": \"qemu:///system\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\", \"/etc/libvirt:/etc/libvirt\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\", {\"str_replace\": {\"template\": \"HOST_CEPH:/etc/ceph:ro\", \"params\": {\"HOST_CEPH\": {\"get_param\": \"CephConfigPath\"}}}}]]}, \"command\": {\"list_join\": [\" \", [{\"str_replace\": {\"template\": \"/nova_libvirt_init_secret.sh CLUSTER:USER\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}], {\"repeat\": {\"template\": \"<%ceph_info%>\", \"for_each\": {\"<%ceph_info%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\":\\\" + $.get(\\\"CephClientUserName\\\", $u))\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Ensure recovery of containerized virtqemud\", \"when\": \"step|int == 4\", \"become\": true, \"block\": [{\"name\": \"Create virtqemud recovery script\", \"copy\": {\"dest\": \"/usr/libexec/recover_tripleo_nova_virtqemud.sh\", \"mode\": \"0755\", \"content\": \"#!/bin/bash\\npgrep -f /sbin/virtqemud\\n[ $? -eq 0 ] && exit 0\\nkill -9 $(cat /run/nova_virtqemud.pid)\\n\"}}, {\"name\": \"Create virtqemud recovery trigger service\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud\\nAfter=tripleo_nova_virtqemud.service\\nRequisite=tripleo_nova_virtqemud.service\\n[Service]\\nType=oneshot\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Create virtqemud recovery trigger timer\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\nPartOf=tripleo_nova_virtqemud.service\\n[Timer]\\nOnCalendar=*:5/10\\nOnActiveSec=120\\nOnUnitActiveSec=60\\nRandomizedDelaySec=1m\\n[Install]\\nWantedBy=timers.target\\n\"}}, {\"name\": \"Enable virtqemud recovery trigger service\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.service\", \"enabled\": true, \"daemon_reload\": true}}, {\"name\": \"Enable virtqemud recovery trigger timer\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.timer\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"register\": \"virtqemud_recover_timer_result\"}, {\"name\": \"Really enable virtqemud recovery trigger timer\", \"shell\": {\"cmd\": \"systemctl enable --now tripleo_nova_virtqemud_recover.timer\"}, \"when\": \"virtqemud_recover_timer_result.status.UnitFileState != \\\"enabled\\\"\"}]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/libvirt\", \"/etc/pki/libvirt/private\", \"/etc/pki/qemu\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"libvirt-server-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to libvirt dirs\\ncp CACERT /etc/pki/CA/cacert.pem\\nchown root:root /etc/pki/CA/cacert.pem\\nchmod 644 /etc/pki/CA/cacert.pem\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_specific_ca_set\", {\"get_param\": \"LibvirtCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"libvirt-client-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to libvirt dirs\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-server-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to qemu dir\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\nchown root:root /etc/pki/qemu/ca-cert.pem\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\nchgrp qemu /etc/pki/qemu/server-*\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\nchmod 0640 /etc/pki/qemu/server-key.pem\\n\", \"params\": {\"CACERT\": {\"if\": [\"qemu_specific_ca_set\", {\"get_param\": \"QemuCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_qemu_server_override_set\", {\"get_param\": \"QemuServerCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-client-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to qemu dir\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\nchgrp qemu /etc/pki/qemu/client-*\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\nchmod 0640 /etc/pki/qemu/client-key.pem\\n\", \"key_size\": {\"if\": [\"key_size_qemu_client_override_set\", {\"get_param\": \"QemuClientCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, [{\"name\": \"Set up systemd target for libvirt services\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Create systemd file\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt.target\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"[Unit]\\nWants=tripleo_nova_virtsecretd.service\\nWants=tripleo_nova_virtnodedevd.service\\nWants=tripleo_nova_virtstoraged.service\\nWants=tripleo_nova_virtproxyd.service\\nWants=tripleo_nova_virtqemud.service\\nAfter=tripleo_nova_virtsecretd.service\\nAfter=tripleo_nova_virtnodedevd.service\\nAfter=tripleo_nova_virtstoraged.service\\nAfter=tripleo_nova_virtproxyd.service\\nAfter=tripleo_nova_virtqemud.service\\n\"}, \"become\": true, \"register\": \"libvirt_target_result\"}, {\"name\": \"Reload systemd\", \"systemd\": {\"name\": \"tripleo_nova_libvirt.target\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"become\": true, \"when\": \"libvirt_target_result.changed\"}]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\", \"mode\": \"{{ item.mode | default(omit) }}\"}, \"with_items\": [{\"path\": \"/etc/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/secrets\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/qemu\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/libvirt\"}, {\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/run/libvirt\"}, {\"path\": \"/var/log/containers/libvirt/swtpm\", \"setype\": \"container_file_t\", \"mode\": \"0770\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create directory for vhost-user sockets with qemu ownership\", \"file\": {\"path\": \"/var/lib/vhost_sockets\", \"state\": \"directory\", \"owner\": \"qemu\", \"group\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"vhostuser_socket_group\"]}, \"setype\": \"virt_cache_t\", \"seuser\": \"system_u\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"with_items\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": \"libvirt_installed.rc == 0\"}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}, {\"name\": \"Enable os_enable_vtpm SELinux boolean for vTPM\", \"seboolean\": {\"name\": \"os_enable_vtpm\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, [{\"name\": \"set gnutls_qemu_config_crypto_policy fact\", \"set_fact\": {\"gnutls_qemu_config_crypto_policy\": {\"get_param\": \"CustomGnuTlsQemuCryptoPolicy\"}}}, {\"name\": \"create gnutls-qemu.config\", \"copy\": {\"dest\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"{{ gnutls_qemu_config_crypto_policy }}\\n\"}, \"register\": \"update_gnutls_config\"}], [{\"name\": \"remove gnutls-qemu.config\", \"file\": {\"path\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"state\": \"absent\"}, \"register\": \"update_gnutls_config\"}]]}, {\"name\": \"update crypto policies\", \"command\": \"update-crypto-policies\", \"when\": \"update_gnutls_config.changed\"}]]}, \"metadata_settings\": {\"list_concat\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"libvirt\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"qemu\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}]}, \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Fail if we are on RHEL8 as this is monolithic libvirt deployment\", \"when\": [\"step|int == 0\", \"\'system_upgrade\' not in ansible_run_tags\", \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"], \"fail\": {\"msg\": \"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\"}}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Get container virtlogd image\", \"when\": \"step|int == 1\", \"tags\": \"always\", \"set_fact\": {\"virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}}}, {\"name\": \"Force pull image novalibvirt\", \"when\": [\"step|int == 1\"], \"containers.podman.podman_image\": {\"name\": \"{{ virtlogd_image }}\", \"force\": true}}, {\"name\": \"Diff OS release in container image and baremetal\", \"when\": \"step|int == 1\", \"shell\": \"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"failed_when\": false, \"register\": \"libvirt_ubi_diff\"}, {\"name\": \"Fail if UBI of the container does not match RHEL of running host\", \"when\": [\"\'system_upgrade\' not in ansible_run_tags\", \"step|int == 1\", \"libvirt_ubi_diff.rc == 1\"], \"fail\": {\"msg\": \"The host operating system versus container UBI does not match.\\n{{ libvirt_ubi_diff.stdout }}\\nMost likely container passed to NovaLibvirt was EL8 one.\\nYou have to pass the correct container for container-image-prepare.\\nIf you would continue all running workloads would get destroyed.\\n\"}}], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [{\"name\": \"Switch virtlogd image before system upgrade\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade\"], \"block\": [{\"name\": \"Get running image version\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"old_virtlogd_image\"}, {\"name\": \"Switch running image to new image in wrapper script\", \"shell\": \"set -o pipefail\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\n\", \"when\": [\"old_virtlogd_image.stdout != virtlogd_image\", \"old_virtlogd_image.stdout != \'\'\"]}]}]]}]}, \"update_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtCommon\", \"update_tasks\"]}, [{\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(76,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(77,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(78,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"compute_hcihostname_resolve_network\": \"internal_api\", \"compute_hcimetrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(79,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(80,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Aodh service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"AodhPassword\": {\"description\": \"The password for the aodh services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"9AJygE1s9mctpR1exZtvx6E4S\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"AodhDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Aodh services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Aodh role.\", \"value\": {\"service_name\": \"aodh_base\", \"config_settings\": {\"aodh_redis_password\": {\"get_param\": \"RedisPassword\"}, \"aodh::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"aodh\", \"password\": {\"get_param\": \"AodhPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/aodh\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"aodh\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"aodh::logging::debug\": {\"if\": [{\"get_param\": \"AodhDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"aodh::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"aodh::rabbit_heartbeat_in_pthread\": false, \"aodh::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"aodh::service_credentials::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"aodh::service_credentials::project_name\": \"service\", \"aodh::service_credentials::user_domain_name\": \"Default\", \"aodh::service_credentials::project_domain_name\": \"Default\"}, \"service_config_settings\": {\"mysql\": {\"aodh::db::mysql::user\": \"aodh\", \"aodh::db::mysql::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::db::mysql::host\": \"%\", \"aodh::db::mysql::dbname\": \"aodh\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(81,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Aodh Evaluator service\\n\", \"parameters\": {\"ContainerAodhEvaluatorImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\"}, \"ContainerAodhConfigImage\": {\"description\": \"The container image to use for the aodh config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionAodhEvaluator\": {\"default\": \"overcloud-ceilometer-aodh-evaluator\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"AodhBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerAodhEvaluatorImage\": \"ContainerAodhEvaluatorImage\", \"ContainerAodhConfigImage\": \"ContainerAodhConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerAodhEvaluatorImage\": {\"get_param\": \"ContainerAodhEvaluatorImage\"}, \"ContainerAodhConfigImage\": {\"get_param\": \"ContainerAodhConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Aodh API role.\", \"value\": {\"service_name\": \"aodh_evaluator\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionAodhEvaluator\"}, \"config_settings\": {\"get_attr\": [\"AodhBase\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"get_attr\": [\"AodhBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"aodh\", \"puppet_tags\": \"aodh_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::aodh::evaluator\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/aodh_evaluator.json\": {\"command\": \"/usr/bin/aodh-evaluator\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/aodh\", \"owner\": \"aodh:aodh\", \"recurse\": true}]}}, \"docker_config\": {\"step_4\": {\"aodh_evaluator\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerAodhEvaluatorImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/aodh_evaluator.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/aodh:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/aodh:/var/log/aodh:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/aodh\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop aodh evaluator container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"aodh_evaluator\"], \"tripleo_delegate_to\": \"{{ groups[\'aodh_evaluator\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(82,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"], \"ComputeHCI\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (83,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(84,'2026-06-13 07:50:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Aodh service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"AodhPassword\": {\"description\": \"The password for the aodh services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"9AJygE1s9mctpR1exZtvx6E4S\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"AodhDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Aodh services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Aodh role.\", \"value\": {\"service_name\": \"aodh_base\", \"config_settings\": {\"aodh_redis_password\": {\"get_param\": \"RedisPassword\"}, \"aodh::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"aodh\", \"password\": {\"get_param\": \"AodhPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/aodh\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"aodh\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"aodh::logging::debug\": {\"if\": [{\"get_param\": \"AodhDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"aodh::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"aodh::rabbit_heartbeat_in_pthread\": false, \"aodh::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"aodh::service_credentials::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"aodh::service_credentials::project_name\": \"service\", \"aodh::service_credentials::user_domain_name\": \"Default\", \"aodh::service_credentials::project_domain_name\": \"Default\"}, \"service_config_settings\": {\"mysql\": {\"aodh::db::mysql::user\": \"aodh\", \"aodh::db::mysql::password\": {\"get_param\": \"AodhPassword\"}, \"aodh::db::mysql::host\": \"%\", \"aodh::db::mysql::dbname\": \"aodh\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(85,'2026-06-13 07:50:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(86,'2026-06-13 07:50:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}}, \"conditions\": {\"memory_backing_dir_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"QemuMemoryBackingDir\"}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"QemuMemoryBackingDir\"]}, \"\"]}]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::libvirt::qemu::memory_backing_dir\": \"QemuMemoryBackingDir\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"QemuMemoryBackingDir\": {\"get_param\": \"QemuMemoryBackingDir\"}}}]}}}}, \"outputs\": {\"kolla_config_files\": {\"description\": \"Common kolla config_files.\", \"value\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}]]}}, \"kolla_permissions\": {\"description\": \"Common kolla permissions.\", \"value\": {\"list_concat\": [[{\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"config_settings\": {\"description\": \"Extra hieradata for all modular virt daemons.\", \"value\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}}, \"volumes\": {\"description\": \"Common volumes for all modular virt daemons.\", \"value\": {\"list_concat\": [[\"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\", \"/etc/pki/libvirt:/etc/pki/libvirt:ro\", \"/etc/pki/qemu:/etc/pki/qemu:ro\"]]}, {\"if\": [\"memory_backing_dir_set\", [{\"str_replace\": {\"template\": \"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\", \"params\": {\"MEMORY_BACKING_DIR\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::compute::libvirt::qemu::memory_backing_dir\"]}}}}]]}]}}, \"update_tasks\": {\"description\": \"Common update tasks for modular virt daemons\", \"value\": [{\"name\": \"check systemd-container package present or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\"}, {\"name\": \"download systemd-container package if not present\", \"yum\": {\"name\": \"systemd-container\", \"state\": \"present\", \"download_only\": true, \"download_dir\": \"/var/tmp/\"}, \"when\": \"is_systemd_container_package.changed\"}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(87,'2026-06-13 07:50:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(88,'2026-06-13 07:50:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(89,'2026-06-13 07:50:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(90,'2026-06-13 07:50:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(91,'2026-06-13 07:50:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova libvirt service\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"LibvirtDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Set to True to enable debugging libvirt services.\"}, \"LibvirtLogLevel\": {\"default\": 3, \"description\": \"Defines log level in libvirt to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtlogdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtlogd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtsecretdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtsecretd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtnodedevdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtnodedevd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtqemudLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtqemud to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtproxydLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtproxyd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtstoragedLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtstoraged to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": {\"nova::compute::libvirt::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/libvirtd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtLogLevel\"}]}}}}, \"nova::compute::libvirt::virtlogd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtlogd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtlogdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtsecretd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtsecretd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtsecretdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtnodedevd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtnodedevd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtnodedevdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtqemud::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtqemud.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtqemudLogLevel\"}]}}}}, \"nova::compute::libvirt::virtproxyd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtproxyd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtproxydLogLevel\"}]}}}}, \"nova::compute::libvirt::virtstoraged::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtstoraged.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtstoragedLogLevel\"}]}}}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to file in the host.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/libvirt\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(92,'2026-06-13 07:50:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (93,'2026-06-13 07:50:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(94,'2026-06-13 07:50:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(95,'2026-06-13 07:50:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"iGVLW3iUSnJVJpZdHixGVnqNe\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"B5b9hxoqds8je7HIcmKZM8Gjs\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(96,'2026-06-13 07:50:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Notification service\\n\", \"parameters\": {\"ContainerCeilometerNotificationImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentNotificationLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.notification\", \"file\": \"/var/log/containers/ceilometer/agent-notification.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerNotification\": {\"default\": \"overcloud-ceilometer-agent-notification\", \"type\": \"string\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"CeilometerQdrPublishEvents\": {\"default\": false, \"description\": \"Whether to send events to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrPublishMetrics\": {\"default\": false, \"description\": \"Whether to send telemetry data to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrEventsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"event\"}, \"description\": \"Configuration for notifier publisher for events.\", \"type\": \"json\"}, \"CeilometerQdrMetricsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"metering\"}, \"description\": \"Configuration for notifier publisher for metrics.\", \"type\": \"json\"}, \"ManageEventPipeline\": {\"default\": true, \"description\": \"Whether to manage event_pipeline.yaml.\", \"type\": \"boolean\"}, \"EventPipelinePublishers\": {\"default\": [\"gnocchi://\"], \"description\": \"A list of publishers to put in event_pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManageEventPipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}, \"ManagePipeline\": {\"default\": true, \"description\": \"Whether to manage pipeline.yaml.\", \"type\": \"boolean\"}, \"PipelinePublishers\": {\"default\": [\"gnocchi://\"], \"description\": \"A list of publishers to put in pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManagePipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerNotificationImage\": \"ContainerCeilometerNotificationImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerNotificationImage\": {\"get_param\": \"ContainerCeilometerNotificationImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"conditions\": {\"ceilometer_qdr_publish\": {\"or\": [{\"get_param\": \"CeilometerQdrPublishEvents\"}, {\"get_param\": \"CeilometerQdrPublishMetrics\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Notification role.\", \"value\": {\"service_name\": \"ceilometer_agent_notification\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerNotification\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::notification::manage_event_pipeline\": {\"get_param\": \"ManageEventPipeline\"}, \"ceilometer::agent::notification::manage_pipeline\": {\"get_param\": \"ManagePipeline\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_enabled\": {\"get_param\": \"CeilometerQdrPublishMetrics\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_events_enabled\": {\"get_param\": \"CeilometerQdrPublishEvents\"}, \"tripleo::profile::base::ceilometer::agent::notification::pipeline_publishers\": {\"get_param\": \"PipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::event_pipeline_publishers\": {\"get_param\": \"EventPipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_params\": {\"get_param\": \"CeilometerQdrMetricsConfig\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_event_params\": {\"get_param\": \"CeilometerQdrEventsConfig\"}}, {\"if\": [\"ceilometer_qdr_publish\", {\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_host_port\": {\"get_param\": \"MetricsQdrPort\"}}]}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_notification\": [{\"get_param\": \"CeilometerAgentNotificationLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::notification\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_notification.json\": {\"command\": \"/usr/bin/ceilometer-agent-notification --logfile /var/log/ceilometer/agent-notification.log\", \"config_files\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]]}}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_notification\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_notification.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent notification container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_notification\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_notification\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(97,'2026-06-13 07:50:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(98,'2026-06-13 07:50:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CdhGooXCxTME1ITxFl9q0xUTr\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"xYUZeqAicsuHn0JOHQOq1idQJ\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IOcEXVmeV2fpzQjbFPUW1TNW\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"high\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(99,'2026-06-13 07:50:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Compute service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"DockerNovaComputeUlimit\": {\"default\": [\"nofile=131072\", \"memlock=67108864\"], \"description\": \"ulimit for Nova Compute Container\", \"type\": \"comma_delimited_list\"}, \"NovaComputeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.compute\", \"file\": \"/var/log/containers/nova/nova-compute.log\"}}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"NovaComputeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaComputeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"NovaComputeStartupDelay\": {\"default\": 0, \"description\": \"Delays the startup of nova-compute service after compute node is booted. This is to give a chance to ceph to get back healthy before booting instances after and overcloud reboot.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 0, \"max\": 600}}], \"tags\": [\"role_specific\"]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"NovaMkisofsCmd\": {\"default\": \"mkisofs\", \"description\": \"Name or path of the tool used for ISO image creation.\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsEnabled\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Nova\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsOptions\": {\"default\": \"context=system_u:object_r:nfs_t:s0\", \"description\": \"NFS mount options for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsVersion\": {\"default\": \"4.2\", \"description\": \"NFS version used for nova storage (when NovaNfsEnabled is true). Since NFSv3 does not support full locking a NFSv4 version need to be used.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^4.?[0-9]?\"}], \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeForceRawImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to convert non-raw cached base images to raw format.\\nSet to \\\"False\\\" if you have a system with slow I/O or low available space,\\ntrading the higher CPU requirements of compression for that of minimized input\\nbandwidth.\\nNotes::\\n- The Compute service removes any compression from the base image during\\n  compression, to avoid CPU bottlenecks. Converted images cannot have backing\\n  files, which might be a security issue.\\n- The raw image format uses more space than other image formats, for example,\\n  qcow2.\\n  Raw base images are always used with libvirt_images_type=lvm.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeUseCowImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to use CoW (Copy on Write) images in cqow2 format for libvirt\\ninstance disks. With CoW, depending on the backing store and host caching,\\nthere might be better concurrency achieved by having each instance operate\\non its own copy.\\nSet to \\\"False\\\" to use the raw format. Raw format uses more space for common\\nparts of the disk image.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtPreAllocateImages\": {\"default\": \"none\", \"description\": \"Specifies the preallocation mode for libvirt instance disks.\\nSet to one of the following valid values::\\n- none - No storage is provisioned at instance start.\\n- space - Storage is fully allocated at instance start using fallocate,\\n          which can help with both space guarantees and I/O performance.\\n\\nEven when not using CoW instance disks, the copy each instance gets is sparse\\nand so the instance might fail unexpectedly at run time with ENOSPC. By\\nrunning fallocate(1) on the instance disk images, the Compute service\\nimmediately and efficiently allocates the space for them in the file system,\\nif supported. Run time performance should also be improved because the file\\nsystem does not have to dynamically allocate blocks at run time, which reduces\\nCPU overhead and file fragmentation.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"space\"]}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheManagerInterval\": {\"default\": 2400, \"description\": \"Specifies the number of seconds to wait between runs of the image cache\\nmanager, which impacts base image caching on Compute nodes. This period\\nis used in the auto removal of unused cached images configured with\\nremove_unused_base_images and remove_unused_original_minimum_age_seconds.\\n\\nSet to \\\"0\\\" to run at the default interval of 60 seconds (not recommended)\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": -1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to automatically remove unused base images from the cache\\nat intervals configured by using image_cache_manager_interval. Images\\nare defined as unused if they have not been accessed during the time\\nspecified by using remove_unused_original_minimum_age_seconds.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"default\": 3600, \"description\": \"Specifies the minimum age that an unused resized base image must be to\\nbe removed from the cache, in seconds. Unused unresized base images\\nyounger than this will not be removed.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCachePrecacheConcurrency\": {\"default\": 1, \"description\": \"Maximum number of Compute nodes to trigger image precaching in parallel.\\nWhen an image precache request is made, Compute nodes are contacted {by\\nwho/which service} to initiate the download.\\n\\nHigher numbers will cause more computes to work in parallel and may result\\nin reduced time to complete the operation, but may also DDoS the image\\nservice. Lower numbers will result in more sequential operation, lower\\nimage service load, but likely longer runtime to completion.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaPCIPassthrough\": {\"description\": \"List of PCI Passthrough whitelist parameters. Example - NovaPCIPassthrough:\\n  - vendor_id: \\\"8086\\\"\\n    product_id: \\\"154c\\\"\\n    address: \\\"0000:05:00.0\\\"\\n    physical_network: \\\"datacentre\\\"\\nFor different formats, refer to the nova.conf documentation for pci_passthrough_whitelist configuration\\n\", \"type\": \"json\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeCpuSharedSet\": {\"description\": \"The behavior of this option depends on the deprecated `NovaVcpuPinSet` option:\\n\\n* `NovaVcpuPinSet` is not set: `NovaComputeCpuSharedSet` is set to a\\n  comma-separated list or range of physical host CPU numbers used to:\\n\\n  - provide vCPU inventory\\n  - determine the host CPUs that unpinned instances can be scheduled to\\n  - determine the host CPUS that instance emulator threads should be\\n    offloaded to for instances configured with the share emulator thread\\n    policy, `hw:emulator_threads_policy=share`\\n\\n* `NovaVcpuPinSet` is set: `NovaComputeCpuSharedSet` is set to a list or\\n  range of host CPU cores used to determine the host CPUs that instance\\n  emulator threads should be offloaded to for instances configured with\\n  the share emulator thread policy (`hw:emulator_threads_policy=share`).\\n  In this case, `NovaVcpuPinSet` is used to provide vCPU inventory and to\\n  determine the host CPUs that both pinned and unpinned instances can be\\n  scheduled to.\\n\\nEx. NovaComputeCpuSharedSet: [4-12,^8,15] will reserve cores from 4-12\\nand 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaComputeCpuDedicatedSet\": {\"description\": \"A list or range of host CPU cores to which processes for pinned instance CPUs (PCPUs) can be scheduled. Ex. NovaComputeCpuDedicatedSet: [4-12,^8,15] will reserve cores from 4-12 and 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaReservedHostMemory\": {\"description\": \"Reserved RAM for host processes.\\n\", \"type\": \"number\", \"default\": 512, \"constraints\": [{\"range\": {\"min\": 512}}], \"tags\": [\"role_specific\"]}, \"NovaReservedHugePages\": {\"description\": \"A list of valid key=value which reflect NUMA node ID, page size (Default unit is KiB) and number of pages to be reserved. Example - NovaReservedHugePages: [\\\"node:0,size:2048,count:64\\\",\\\"node:1,size:1GB,count:1\\\"] will reserve on NUMA node 0 64 pages of 2MiB and on NUMA node 1 1 page of 1GiB\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"OvsDpdkSocketMemory\": {\"default\": \"\", \"description\": \"Sets the amount of hugepage memory to assign per NUMA node. It is recommended to use the socket closest to the PCIe slot used for the desired DPDK NIC.  The format should be in \\\"<socket 0 mem>, <socket 1 mem>, <socket n mem>\\\", where the value is specified in MB.  For example: \\\"1024,0\\\".\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"MonitoringSubscriptionNovaCompute\": {\"default\": \"overcloud-nova-compute\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"VerifyGlanceSignatures\": {\"default\": false, \"description\": \"Whether to verify image signatures.\", \"type\": \"boolean\"}, \"NovaAutoDisabling\": {\"default\": \"10\", \"description\": \"Max number of consecutive build failures before the nova-compute will disable itself.\", \"type\": \"string\"}, \"NeutronPhysnetNUMANodesMapping\": {\"description\": \"Map of physnet name as key and NUMA nodes as value.\\nEx. NeutronPhysnetNUMANodesMapping: {\'foo\': [0, 1], \'bar\': [1]} where `foo` and `bar` are\\nphysnet names and corresponding values are list of associated numa_nodes.\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NeutronTunnelNUMANodes\": {\"description\": \"Used to configure NUMA affinity for all tunneled networks.\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtRxQueueSize\": {\"description\": \"virtio-net RX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtTxQueueSize\": {\"description\": \"virtio-net TX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtFileBackedMemory\": {\"description\": \"Available capacity in MiB for file-backed memory. When configured, the ``NovaRAMAllocationRatio`` and ``NovaReservedHostMemory`` parameters must be set to 0.\\n\", \"default\": 0, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtVolumeUseMultipath\": {\"default\": false, \"description\": \"Whether to enable or not the multipath connection of the volumes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaHWMachineType\": {\"description\": \"To specify a default machine type per host architecture.\\n\", \"default\": \"x86_64=pc-q35-rhel9.0.0\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaComputeEnableKsm\": {\"default\": false, \"description\": \"Whether to enable KSM on compute nodes or not. Especially in NFV use case one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"32HDlh1wtNuoeOyht2a9njXCx\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NovaLibvirtNumPciePorts\": {\"description\": \"Set `num_pcie_ports` to specify the number of PCIe ports an instance will get. Libvirt allows a custom number of PCIe ports (pcie-root-port controllers) a target instance will get. Some will be used by default, rest will be available for hotplug use.\\n\", \"default\": 16, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"description\": \"A number of seconds to memory usage statistics period, zero or negative value mean to disable memory usage statistics.\\n\", \"default\": 10, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationWaitForVIFPlug\": {\"description\": \"Whether to wait for `network-vif-plugged` events before starting guest transfer.\", \"default\": true, \"type\": \"boolean\"}, \"NovaLiveMigrationPermitPostCopy\": {\"description\": \"If \\\"True\\\" activates the instance on the destination node before migration is complete, and to set an upper bound on the memory that needs to be transferred. Post copy gets enabled per default if the compute roles is not a realtime role or disabled by this parameter.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationPermitAutoConverge\": {\"description\": \"Defaults to \\\"True\\\" to slow down the instance CPU until the memory copy process is faster than the instance\'s memory writes when the migration performance is slow and might not complete. Auto converge will only be used if this flag is set to True and post copy is not permitted or post copy is unavailable due to the version of libvirt and QEMU.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"NovaCPUAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual CPU to physical CPU allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaRAMAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual RAM to physical RAM allocation ratio.\", \"default\": 1.0, \"tags\": [\"role_specific\"]}, \"NovaDiskAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual disk to physical disk allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaEnableVTPM\": {\"type\": \"boolean\", \"description\": \"Whether to enable support for enumlated Trusted Platform Module (TPM) devices.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaMaxDiskDevicesToAttach\": {\"type\": \"number\", \"description\": \"Maximum number of disk devices allowed to attach to a single server. Note that the number of disks supported by an server depends on the bus used. For example, the ide disk bus is limited to 4 attached devices. The configured maximum is enforced during server create, rebuild, evacuate, unshelve, live migrate, and attach volume. Operators changing this parameter on a compute service that is hosting servers should be aware that it could cause rebuilds to fail, if the maximum is decreased lower than the number of devices already attached to servers. Operators should also be aware that during a cold migration, the configured maximum is only enforced in-place and the destination is not checked before the move. -1 means unlimited\\n\", \"default\": -1, \"tags\": [\"role_specific\"]}, \"NovaPMEMMappings\": {\"type\": \"string\", \"description\": \"PMEM namespace mappings as backend for vPMEM feature. This parameter sets Nova\'s `pmem_namespaces` configuration options. PMEM namespaces needs to be create manually or with conjunction with `NovaPMEMNamespaces` parameter. Requires format: $LABEL:$NSNAME[|$NSNAME][,$LABEL:$NSNAME[|$NSNAME]].\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaPMEMNamespaces\": {\"type\": \"string\", \"description\": \"Creates PMEM namespaces on the host server using `ndctl` tool through Ansible. Requires format: $SIZE:$NSNAME[,$SIZE:$NSNAME...]. $SIZE supports the suffixes \\\"k\\\" or \\\"K\\\" for KiB, \\\"m\\\" or \\\"M\\\" for MiB, \\\"g\\\" or \\\"G\\\" for GiB and \\\"t\\\" or \\\"T\\\" for TiB. NOTE: This requires properly configured NVDIMM regions and enough space for requested namespaces.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaImageCacheTTL\": {\"type\": \"number\", \"description\": \"Time in seconds that nova compute should continue caching an image once it is no longer used by any instances on the host\\n\", \"default\": 86400, \"tags\": [\"role_specific\"]}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"type\": \"json\", \"description\": \"Map of vgpu type(s) the instances can get as key and list of corresponding device addresses as value. Ex. NovaVGPUTypesDeviceAddressesMapping: {\'nvidia-35\': [\'0000:84:00.0\', \'0000:85:00.0\'],\\n                                  \'nvidia-36\': [\'0000:86:00.0\']}\\nwhere `nvidia-35` and `nvidia-36` are vgpu types and corresponding values are list of associated device addresses.\\n\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NovaComputeDisableIrqBalance\": {\"default\": false, \"description\": \"Whether to disable irqbalance on compute nodes or not. Especially in Realtime Compute role one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUMode\": {\"type\": \"string\", \"description\": \"The libvirt CPU mode to configure. Defaults to \'host-model\' if virt_type is set to kvm, otherwise defaults to \'none\'\\n\", \"default\": \"host-model\", \"constraints\": [{\"allowed_values\": [\"custom\", \"host-model\", \"none\", \"host-passthrough\"]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModels\": {\"type\": \"comma_delimited_list\", \"description\": \"The named libvirt CPU model (see names listed in /usr/share/libvirt/cpu_map.xml). Only has effect if cpu_mode=\\\"custom\\\" and virt_type=\\\"kvm|qemu\\\"\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModelExtraFlags\": {\"type\": \"string\", \"description\": \"This allows specifying granular CPU feature flags when specifying CPU models. Only has effect if cpu_mode is not set to \'none\'.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaDisableImageDownloadToRbd\": {\"type\": \"boolean\", \"description\": \"Refuse to boot an instance if it would require downloading from glance and uploading to ceph instead of a COW clone.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaDisableComputeServiceCheckForFfu\": {\"type\": \"boolean\", \"description\": \"Facilitate a Fast-Forward upgrade where new control services are being started before compute nodes have been able to update their service record.\\n\", \"default\": false}, \"NovaStatedirOwnershipSkip\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths relative to nova_statedir to ignore when recursively setting the ownership and selinux context.\\n\", \"default\": [\"triliovault-mounts\"]}, \"NovaImageTypeExcludeList\": {\"type\": \"comma_delimited_list\", \"description\": \"List of image formats that should not be advertised as supported by the compute service.\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtMaxQueues\": {\"type\": \"number\", \"description\": \"Add parameter to configure the libvirt max_queues. The maximum number of virtio queue pairs that can be enabled when creating a multiqueue guest. The number of virtio queues allocated will be the lesser of the CPUs requested by the guest and the max value defined. Default 0 corresponds to not set\\n\", \"default\": 0, \"tags\": [\"role_specific\"]}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"NovaGlanceEnableRbdDownload\": {\"type\": \"boolean\", \"description\": \"Enable download of Glance images directly via RBD.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdDownloadMultistoreID\": {\"type\": \"string\", \"description\": \"The hash key, which is the backend ID, of the GlanceMultistoreConfig to be used for the role where NovaGlanceEnableRbdDownload is enabled and defaults should be overridden. If CephClientUserName or GlanceRbdPoolName are not set in the GlanceMultistoreConfig, the global values of those parameters will be used.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"NovaGlanceRbdCopyPollInterval\": {\"type\": \"number\", \"description\": \"The interval in seconds with which to poll Glance after asking for it to copy an image to the local rbd store.\\n\", \"default\": 15, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdCopyTimeout\": {\"type\": \"number\", \"description\": \"The overall maximum time we will wait for Glance to complete an image copy to our local rbd store.\\n\", \"default\": 600, \"tags\": [\"role_specific\"]}, \"CustomProviderInventories\": {\"description\": \"Array of hashes describing the custom providers for the compute role.\\nFormat:\\nname/uuid - Resource providers to target can be identified by either\\nUUID or name. In addition, the value $COMPUTE_NODE can be used in\\nthe UUID field to identify all nodes managed by the service.\\nExactly one of uuid or name is mandatory. If neither uuid or name\\nis provided, the special uuid $COMPUTE_NODE gets set in the template.\\n\\ninventories - (Optional) Hash of custom provider inventories. \'total\' is\\na mandatory property. Any other optional properties not populated will\\nbe given a default value by placement. If overriding a pre-existing\\nprovider values will not be preserved from the existing inventory.\\n\\ntraits - (Optional) Array of additional traits.\\nExample:\\nComputeParameters:\\n  CustomProviderInventories:\\n    - uuid: $COMPUTE_NODE\\n      inventories:\\n        CUSTOM_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n          reserved: 0\\n          min_unit: 1\\n          max_unit: 10\\n          step_size: 1\\n          allocation_ratio: 1.0\\n        CUSTOM_ANOTHER_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n      traits:\\n        - CUSTOM_P_STATE_ENABLED\\n        - CUSTOM_C_STATE_ENABLED\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaVcpuPinSet\": {\"description\": \"A list or range of host CPU cores to which processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is set, or to which both emulator threads and processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is unset. Ex. NovaVcpuPinSet: [\'4-12\',\'^8\'] will reserve cores from 4-12 excluding 8\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenstack mailing list.\\n\", \"parameters\": [\"NovaVcpuPinSet\"]}], \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"compute_startup_delay\": {\"and\": [{\"not\": {\"get_param\": \"EnableInstanceHA\"}}, {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaComputeStartupDelay\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, \"\"]}]}]}}]}, \"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"enable_live_migration_tunnelled\": {\"and\": [{\"or\": [{\"and\": [{\"get_param\": \"NovaNfsEnabled\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, true]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}]}, {\"not\": \"use_tls_for_live_migration\"}]}, \"libvirt_file_backed_memory_enabled\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtFileBackedMemory\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, \"\"]}]}]}}, \"reserved_huge_pages_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaReservedHugePages\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaReservedHugePages\"}, []]}]}}, \"is_realtime\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"TunedProfileName\"]}, \"realtime-virtual-host\"]}, \"ovs_dpdk_socket_memory_not_set\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"OvsDpdkSocketMemory\"}, \"\"]}]}, \"nova_libvirt_max_queues_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtMaxQueues\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, 0]}]}]}}, \"glance_enable_rbd_download_set\": {\"or\": [{\"and\": [{\"get_param\": \"NovaGlanceEnableRbdDownload\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, true]}]}, \"nova_glance_rbd_download_multistore_id_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceRbdDownloadMultistoreID\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"\"]}]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"NovaComputeCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"NovaServiceName\": \"compute\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::vcpu_pin_set\": \"NovaVcpuPinSet\", \"nova::compute::cpu_shared_set\": \"NovaComputeCpuSharedSet\", \"nova::compute::cpu_dedicated_set\": \"NovaComputeCpuDedicatedSet\", \"nova::compute::reserved_host_memory\": \"NovaReservedHostMemory\", \"nova::compute::reserved_huge_pages\": \"NovaReservedHugePages\", \"nova::compute::neutron_physnets_numa_nodes_mapping\": \"NeutronPhysnetNUMANodesMapping\", \"nova::compute::neutron_tunnel_numa_nodes\": \"NeutronTunnelNUMANodes\", \"nova::compute::resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt::rx_queue_size\": \"NovaLibvirtRxQueueSize\", \"nova::compute::libvirt::tx_queue_size\": \"NovaLibvirtTxQueueSize\", \"nova::compute::libvirt::file_backed_memory\": \"NovaLibvirtFileBackedMemory\", \"nova::compute::libvirt::volume_use_multipath\": \"NovaLibvirtVolumeUseMultipath\", \"nova::compute::libvirt::hw_machine_type\": \"NovaHWMachineType\", \"nova::compute::mkisofs_cmd\": \"NovaMkisofsCmd\", \"compute_enable_ksm\": \"NovaComputeEnableKsm\", \"nova::compute::rbd::libvirt_images_rbd_pool\": \"NovaRbdPoolName\", \"tripleo::profile::base::nova::compute::nova_nfs_enabled\": \"NovaNfsEnabled\", \"nfs_backend_enable\": \"NovaNfsEnabled\", \"nfs_share\": \"NovaNfsShare\", \"nfs_options\": \"NovaNfsOptions\", \"nfs_vers\": \"NovaNfsVersion\", \"nova::compute::libvirt::num_pcie_ports\": \"NovaLibvirtNumPciePorts\", \"nova::compute::libvirt::mem_stats_period_seconds\": \"NovaLibvirtMemStatsPeriodSeconds\", \"nova::compute::rbd::ephemeral_storage\": \"NovaEnableRbdBackend\", \"resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::cpu_allocation_ratio\": \"NovaCPUAllocationRatio\", \"nova::ram_allocation_ratio\": \"NovaRAMAllocationRatio\", \"nova::disk_allocation_ratio\": \"NovaDiskAllocationRatio\", \"nova::compute::max_disk_devices_to_attach\": \"NovaMaxDiskDevicesToAttach\", \"nova::compute::libvirt::pmem_namespaces\": \"NovaPMEMMappings\", \"nova_pmem_namespaces\": \"NovaPMEMNamespaces\", \"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\": \"NovaImageCacheTTL\", \"nova::compute::libvirt::swtpm_enabled\": \"NovaEnableVTPM\", \"nova::compute::vgpu::vgpu_types_device_addresses_mapping\": \"NovaVGPUTypesDeviceAddressesMapping\", \"compute_disable_irqbalance\": \"NovaComputeDisableIrqBalance\", \"nova::compute::libvirt::cpu_mode\": \"NovaLibvirtCPUMode\", \"nova::compute::libvirt::cpu_models\": \"NovaLibvirtCPUModels\", \"nova::compute::libvirt::cpu_model_extra_flags\": \"NovaLibvirtCPUModelExtraFlags\", \"nova_compute_opt_volumes\": \"NovaComputeOptVolumes\", \"nova_compute_startup_delay\": \"NovaComputeStartupDelay\", \"nova_compute_opt_env_vars\": \"NovaComputeOptEnvVars\", \"nova::workarounds::never_download_image_if_on_rbd\": \"NovaDisableImageDownloadToRbd\", \"nova::compute::image_type_exclude_list\": \"NovaImageTypeExcludeList\", \"nova_permit_post_copy\": \"NovaLiveMigrationPermitPostCopy\", \"nova_permit_auto_converge\": \"NovaLiveMigrationPermitAutoConverge\", \"nova_libvirt_max_queues\": \"NovaLibvirtMaxQueues\", \"nova_glance_enable_rbd_download\": \"NovaGlanceEnableRbdDownload\", \"nova_glance_rbd_download_multistore_id\": \"NovaGlanceRbdDownloadMultistoreID\", \"nova::compute::force_raw_images\": \"NovaComputeForceRawImages\", \"nova::compute::use_cow_images\": \"NovaComputeUseCowImages\", \"nova::compute::libvirt::preallocate_images\": \"NovaComputeLibvirtPreAllocateImages\", \"nova::compute::image_cache::manager_interval\": \"NovaComputeImageCacheManagerInterval\", \"nova::compute::image_cache::remove_unused_base_images\": \"NovaComputeImageCacheRemoveUnusedBaseImages\", \"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\", \"nova::compute::image_cache::precache_concurrency\": \"NovaComputeImageCachePrecacheConcurrency\", \"nova::compute::provider::custom_inventories\": \"CustomProviderInventories\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\": \"NovaGlanceRbdCopyPollInterval\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\": \"NovaGlanceRbdCopyTimeout\", \"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaVcpuPinSet\": {\"get_param\": \"NovaVcpuPinSet\"}, \"NovaComputeCpuSharedSet\": {\"get_param\": \"NovaComputeCpuSharedSet\"}, \"NovaComputeCpuDedicatedSet\": {\"get_param\": \"NovaComputeCpuDedicatedSet\"}, \"NovaReservedHostMemory\": {\"get_param\": \"NovaReservedHostMemory\"}, \"NovaReservedHugePages\": {\"if\": [\"reserved_huge_pages_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"if\": [\"ovs_dpdk_socket_memory_not_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"repeat\": {\"for_each\": {\"<%node%>\": {\"yaql\": {\"expression\": \"range(0,len($.data.dpdk_p)).join(\\\",\\\").split(\\\",\\\")\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}}}}, \"<%size%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\")) -> [$hz]*len($.data.dpdk_p)\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}, \"<%count%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>int(switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\"))) -> $.data.dpdk_p.select(int($)*1024/$hz).join(\\\",\\\").split(\',\')\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}}, \"template\": \"node:<%node%>,size:<%size%>,count:<%count%>\", \"permutations\": false}}]}]}, \"NeutronPhysnetNUMANodesMapping\": {\"get_param\": \"NeutronPhysnetNUMANodesMapping\"}, \"NeutronTunnelNUMANodes\": {\"get_param\": \"NeutronTunnelNUMANodes\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaLibvirtRxQueueSize\": {\"get_param\": \"NovaLibvirtRxQueueSize\"}, \"NovaLibvirtTxQueueSize\": {\"get_param\": \"NovaLibvirtTxQueueSize\"}, \"NovaLibvirtFileBackedMemory\": {\"get_param\": \"NovaLibvirtFileBackedMemory\"}, \"NovaLibvirtVolumeUseMultipath\": {\"get_param\": \"NovaLibvirtVolumeUseMultipath\"}, \"NovaHWMachineType\": {\"get_param\": \"NovaHWMachineType\"}, \"NovaComputeEnableKsm\": {\"get_param\": \"NovaComputeEnableKsm\"}, \"NovaRbdPoolName\": {\"get_param\": \"NovaRbdPoolName\"}, \"NovaMkisofsCmd\": {\"get_param\": \"NovaMkisofsCmd\"}, \"NovaNfsEnabled\": {\"get_param\": \"NovaNfsEnabled\"}, \"NovaNfsShare\": {\"get_param\": \"NovaNfsShare\"}, \"NovaNfsOptions\": {\"get_param\": \"NovaNfsOptions\"}, \"NovaNfsVersion\": {\"get_param\": \"NovaNfsVersion\"}, \"NovaLibvirtNumPciePorts\": {\"get_param\": \"NovaLibvirtNumPciePorts\"}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"get_param\": \"NovaLibvirtMemStatsPeriodSeconds\"}, \"NovaEnableRbdBackend\": {\"get_param\": \"NovaEnableRbdBackend\"}, \"NovaCPUAllocationRatio\": {\"get_param\": \"NovaCPUAllocationRatio\"}, \"NovaRAMAllocationRatio\": {\"get_param\": \"NovaRAMAllocationRatio\"}, \"NovaDiskAllocationRatio\": {\"get_param\": \"NovaDiskAllocationRatio\"}, \"NovaEnableVTPM\": {\"get_param\": \"NovaEnableVTPM\"}, \"NovaMaxDiskDevicesToAttach\": {\"get_param\": \"NovaMaxDiskDevicesToAttach\"}, \"NovaPMEMMappings\": {\"get_param\": \"NovaPMEMMappings\"}, \"NovaPMEMNamespaces\": {\"get_param\": \"NovaPMEMNamespaces\"}, \"NovaImageCacheTTL\": {\"get_param\": \"NovaImageCacheTTL\"}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"get_param\": \"NovaVGPUTypesDeviceAddressesMapping\"}, \"NovaComputeDisableIrqBalance\": {\"get_param\": \"NovaComputeDisableIrqBalance\"}, \"NovaLibvirtCPUMode\": {\"get_param\": \"NovaLibvirtCPUMode\"}, \"NovaLibvirtCPUModels\": {\"get_param\": \"NovaLibvirtCPUModels\"}, \"NovaLibvirtCPUModelExtraFlags\": {\"get_param\": \"NovaLibvirtCPUModelExtraFlags\"}, \"NovaComputeOptVolumes\": {\"get_param\": \"NovaComputeOptVolumes\"}, \"NovaComputeStartupDelay\": {\"get_param\": \"NovaComputeStartupDelay\"}, \"NovaComputeOptEnvVars\": {\"get_param\": \"NovaComputeOptEnvVars\"}, \"NovaDisableImageDownloadToRbd\": {\"get_param\": \"NovaDisableImageDownloadToRbd\"}, \"NovaImageTypeExcludeList\": {\"get_param\": \"NovaImageTypeExcludeList\"}, \"NovaLiveMigrationPermitPostCopy\": {\"get_param\": \"NovaLiveMigrationPermitPostCopy\"}, \"NovaLiveMigrationPermitAutoConverge\": {\"get_param\": \"NovaLiveMigrationPermitAutoConverge\"}, \"NovaLibvirtMaxQueues\": {\"get_param\": \"NovaLibvirtMaxQueues\"}, \"NovaGlanceEnableRbdDownload\": {\"get_param\": \"NovaGlanceEnableRbdDownload\"}, \"NovaGlanceRbdDownloadMultistoreID\": {\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"NovaComputeForceRawImages\": {\"get_param\": \"NovaComputeForceRawImages\"}, \"NovaComputeUseCowImages\": {\"get_param\": \"NovaComputeUseCowImages\"}, \"NovaComputeLibvirtPreAllocateImages\": {\"get_param\": \"NovaComputeLibvirtPreAllocateImages\"}, \"NovaComputeImageCacheManagerInterval\": {\"get_param\": \"NovaComputeImageCacheManagerInterval\"}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedBaseImages\"}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\"}, \"NovaComputeImageCachePrecacheConcurrency\": {\"get_param\": \"NovaComputeImageCachePrecacheConcurrency\"}, \"CustomProviderInventories\": {\"get_param\": \"CustomProviderInventories\"}, \"NovaGlanceRbdCopyPollInterval\": {\"get_param\": \"NovaGlanceRbdCopyPollInterval\"}, \"NovaGlanceRbdCopyTimeout\": {\"get_param\": \"NovaGlanceRbdCopyTimeout\"}, \"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"nova_compute_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for nova_compute\", \"value\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}, \"role_data\": {\"description\": \"Role data for the Nova Compute service.\", \"value\": {\"service_name\": \"nova_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"nova::compute::pci::passthrough\": {\"str_replace\": {\"template\": \"JSON_PARAM\", \"params\": {\"map_replace\": [{\"map_replace\": [{\"JSON_PARAM\": \"NovaPCIPassthrough\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaPCIPassthrough\": {\"get_param\": \"NovaPCIPassthrough\"}}}]}}}, \"nova::compute::libvirt::migration_support\": false, \"tripleo::profile::base::nova::migration::client::nova_compute_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::rbd::libvirt_images_rbd_glance_store_name\": {\"get_param\": \"GlanceBackendID\"}, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"tripleo::profile::base::nova::compute::cinder_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::cinder::username\": \"cinder\", \"nova::cinder::auth_type\": \"v3password\", \"nova::cinder::project_name\": \"service\", \"nova::cinder::password\": {\"get_param\": \"CinderPassword\"}, \"nova::cinder::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::cinder::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"nova::compute::instance_usage_audit\": true, \"nova::compute::instance_usage_audit_period\": \"hour\", \"nova::compute::consecutive_build_service_disable_threshold\": {\"get_param\": \"NovaAutoDisabling\"}, \"nova::compute::live_migration_wait_for_vif_plug\": {\"get_param\": \"NovaLiveMigrationWaitForVIFPlug\"}, \"nova::migration::libvirt::live_migration_permit_post_copy\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_post_copy\"]}]}, \"nova::migration::libvirt::live_migration_permit_auto_converge\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_auto_converge\"]}]}, \"nova::migration::libvirt::live_migration_tunnelled\": false, \"nova::compute::vncserver_proxyclient_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::compute::verify_glance_signatures\": {\"get_param\": [\"VerifyGlanceSignatures\"]}, \"nova::ram_allocation_ratio\": {\"if\": [\"libvirt_file_backed_memory_enabled\", \"1.0\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::ram_allocation_ratio\"]}]}, \"nova::compute::libvirt::max_queues\": {\"if\": [\"nova_libvirt_max_queues_set\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_max_queues\"]}]}, \"nova::workarounds::disable_compute_service_check_for_ffu\": {\"get_param\": \"NovaDisableComputeServiceCheckForFfu\"}}, {\"if\": [\"glance_enable_rbd_download_set\", {\"nova::glance::enable_rbd_download\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_enable_rbd_download\"]}, \"nova::glance::rbd_user\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_ceph_client_user_name) -> $.data.multistore.get($k).get(\\\"CephClientUserName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_ceph_client_user_name\": {\"get_param\": \"CephClientUserName\"}}}}, {\"get_param\": \"CephClientUserName\"}]}, \"nova::glance::rbd_pool\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_glance_rbd_pool_name) -> $.data.multistore.get($k).get(\\\"GlanceRbdPoolName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_glance_rbd_pool_name\": {\"get_param\": \"GlanceRbdPoolName\"}}}}, {\"get_param\": \"GlanceRbdPoolName\"}]}, \"nova::glance::rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key) -> list(coalesce($.data.multistore, {}).get($k)).flatten().select($.get(\\\"CephClusterName\\\"))\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}, {\"get_param\": \"CephClusterName\"}]}, \".conf\"]]}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_nova_compute\": [{\"get_param\": \"NovaComputeLoggingSource\"}]}, \"collectd\": {\"tripleo.collectd.plugins.nova_compute\": [\"virt\"], \"collectd::plugin::virt::connection\": \"qemu:///system\"}}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"nova_config\", \"step_config\": \"# TODO(emilien): figure how to deal with libvirt profile.\\n# We\'ll probably treat it like we do with Neutron plugins.\\n# Until then, just include it in the default nova-compute role.\\ninclude tripleo::profile::base::nova::compute::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_compute.json\": {\"command\": {\"list_join\": [\" \", [{\"if\": [\"compute_startup_delay\", {\"str_replace\": {\"template\": \"/var/lib/nova/delay-nova-compute --delay DELAY --nova-binary\", \"params\": {\"DELAY\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}}]}, \"/usr/bin/nova-compute\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}, {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\": {\"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"get_attr\": [\"NovaComputeCommon\", \"container_config_scripts\"]}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_statedir_owner\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"none\", \"user\": \"root\", \"security_opt\": [\"label=disable\"], \"privileged\": false, \"detach\": false, \"volumes\": [\"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"], \"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"NOVA_STATEDIR_OWNERSHIP_SKIP\": {\"list_join\": [\":\", {\"get_param\": \"NovaStatedirOwnershipSkip\"}]}}}}, \"step_5\": {\"map_merge\": [{\"nova_compute\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"ulimit\": {\"get_param\": \"DockerNovaComputeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"nova\", \"restart\": \"always\", \"depends_on\": {\"list_concat\": [[\"tripleo_nova_libvirt.target\"], {\"if\": [{\"get_param\": \"NovaNfsEnabled\"}, [\"var-lib-nova-instances.mount\"]]}]}, \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_volumes\"]}, [\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/run/nova:/run/nova:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/sys/class/net:/sys/class/net\", \"/sys/bus/pci:/sys/bus/pci\", \"/boot:/boot:ro\", \"/var/lib/nova:/var/lib/nova:shared\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_env_vars\"]}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, {\"LIBGUESTFS_BACKEND\": \"direct\"}]}}}, {\"if\": [{\"not\": {\"get_param\": \"NovaAdditionalCell\"}}, {\"nova_wait_for_compute_service\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/container-config-scripts:/container-config-scripts\"]]}, \"user\": \"nova\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}}}}]}]}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check for /var/lib/nova/instances directory exitance\", \"stat\": {\"path\": \"/var/lib/nova/instances\"}, \"register\": \"check_nova_instances_result\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/_nova_secontext\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/nova/instances\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/tmpfiles.d\"}]}, {\"name\": \"ensure /run/nova is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-nova.conf\", \"content\": \"d /run/nova 0777 root root - -\\n\"}}, {\"name\": \"create tempfiles\", \"command\": \"systemd-tmpfiles --create\"}], [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}], [{\"name\": \"delay installation of systemd-container\", \"when\": \"check_nova_instances_result.stat.exists\", \"block\": [{\"name\": \"check systemd-container package installed or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\", \"failed_when\": false}, {\"name\": \"get latest package from downloaded package versions\", \"shell\": \"ls -1t /var/tmp/systemd-container* | head -1\", \"register\": \"latest_systemd_container_package\", \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"], \"failed_when\": false}, {\"name\": \"Install systemd-container package on boot\", \"copy\": {\"dest\": \"/etc/systemd/system/install-systemd-container.service\", \"content\": \"[Unit]\\nDescription=Install systemd container package on system boot\\nBefore=tripleo_nova_virtqemud.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\nExecStartPost=rm -f /var/tmp/systemd-container*\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": [\"latest_systemd_container_package is defined\", \"(\'stdout\' in latest_systemd_container_package)\", \"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"enable install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"state\": \"stopped\", \"enabled\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"check if install-systemd-container service exists\", \"stat\": {\"path\": \"/etc/systemd/system/install-systemd-container.service\"}, \"register\": \"install_systemd_container_result\"}, {\"name\": \"disable and mask install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"not is_systemd_container_package.changed\", \"install_systemd_container_result.stat.exists\"]}]}, {\"name\": \"is Nova Resume Guests State On Host Boot enabled\", \"set_fact\": {\"resume_guests_state_on_host_boot_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"resume_guests_state_on_host_boot\"]}}}, {\"name\": \"install libvirt-guests systemd unit file (docker)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'docker\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs\", \"copy\": {\"dest\": \"/etc/systemd/system/libvirt-guests.service\", \"content\": \"[Unit]\\nDescription=Suspend/Resume Running libvirt Guests\\nAfter=network.target\\nAfter=time-sync.target\\nAfter=virt-guest-shutdown.target\\nAfter=docker.service\\nAfter=tripleo-container-shutdown.service\\nAfter=rhel-push-plugin.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\n# Hack just call traditional service until we factor\\n# out the code\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\nExecStop=/bin/{{container_cli}} stop nova_compute\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"libvirt-guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"libvirt-guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"install tripleo_nova_libvirt_guests systemd unit file (podman)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'podman\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\"}, {\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\"}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"tripleo_nova_libvirt_guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Do we prepend nova startup with a delay\", \"set_fact\": {\"nova_compute_delay\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}, {\"name\": \"install nova-compute delay wrapper script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/scripts/delay-nova-compute\"}, \"dest\": \"/var/lib/nova/delay-nova-compute\", \"mode\": 493}, \"when\": \"nova_compute_delay|int > 0\"}, {\"name\": \"Is irqbalance enabled\", \"set_fact\": {\"compute_irqbalance_disabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_disable_irqbalance\"]}}}, {\"name\": \"disable irqbalance service on compute\", \"when\": \"compute_irqbalance_disabled|bool\", \"service\": {\"name\": \"irqbalance.service\", \"state\": \"stopped\", \"enabled\": false}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"deploy_steps_tasks\": [{\"name\": \"install systemd-container for a greenfield\", \"when\": [\"step|int == 1\", \"not check_nova_instances_result.stat.exists\"], \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}}, {\"name\": \"validate nova-compute container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_compute\"}, \"register\": \"nova_compute_infos\", \"failed_when\": [\"nova_compute_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 6\"]}, {\"name\": \"manage PMEM namespaces for vPMEM\", \"include_role\": {\"name\": \"tripleo_nvdimm\"}, \"vars\": {\"tripleo_nvdimm_pmem_namespaces\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_pmem_namespaces\"]}}, \"when\": [\"step|int == 1\", \"tripleo_nvdimm_pmem_namespaces != \'\'\"]}, {\"name\": \"manage OS version 9 specific sysctls\", \"when\": [\"step|int == 1\", \"ansible_facts[\'os_family\'] == \'RedHat\'\", \"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"], \"block\": [{\"name\": \"Enable post-copy by setting unprivileged_userfaultfd\", \"sysctl\": {\"name\": \"vm.unprivileged_userfaultfd\", \"value\": 1, \"sysctl_set\": true, \"sysctl_file\": \"/etc/sysctl.d/99-tripleo-postcopy.conf\", \"state\": \"present\", \"reload\": true}}]}, {\"name\": \"enable/disable ksm\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"is KSM enabled\", \"set_fact\": {\"compute_ksm_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_enable_ksm\"]}}}, {\"name\": \"disable KSM on compute\", \"when\": \"not compute_ksm_enabled|bool\", \"block\": [{\"name\": \"Check for ksm\", \"shell\": \"systemctl is-active ksm.service || systemctl is-enabled ksm.service\", \"become\": true, \"failed_when\": false, \"register\": \"ksm_service_check\"}, {\"name\": \"disable KSM services\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"], \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\"], \"register\": \"ksmdisabled\"}, {\"name\": \"delete PageKSM after disable ksm on compute\", \"command\": \"echo 2 >/sys/kernel/mm/ksm/run\", \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\", \"ksmdisabled is changed\"]}]}, {\"name\": \"enable KSM on compute\", \"when\": \"compute_ksm_enabled|bool\", \"block\": [{\"name\": \"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\", \"package\": {\"name\": \"qemu-kvm-common\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"]}, {\"name\": \"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\", \"package\": {\"name\": \"ksmtuned\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"]}, {\"name\": \"enable ksmtunded\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"started\", \"enabled\": true}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"]}]}]}], \"external_post_deploy_tasks\": {\"get_attr\": [\"NovaComputeCommon\", \"nova_compute_common_deploy_steps_tasks\"]}, \"upgrade_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"nova_compute pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"absent\", \"fstype\": \"nfs4\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"nova_compute post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}], \"update_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}], \"post_update_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"post_upgrade_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-compute service ID\", \"command\": \"openstack compute service list --service nova-compute --column ID --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"is additional Cell?\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"Set fact for nova_compute services\", \"set_fact\": {\"nova_compute_service\": \"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Check search output\", \"fail\": {\"msg\": \"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\"}, \"when\": [\"(nova_compute_service | length) > 1\"]}, {\"name\": \"Disable nova services\", \"when\": [\"(nova_compute_service | length) == 1\"], \"block\": [{\"name\": \"Disable nova-compute service\", \"command\": \"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"when\": [\"not is_additional_cell|bool\"]}, {\"name\": \"Stop nova-compute container\", \"service\": {\"name\": \"tripleo_nova_compute\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_nova_compute\", \"failed_when\": \"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\"}, {\"name\": \"Delete nova-compute service\", \"command\": \"openstack compute service delete {{ nova_compute_service[0].ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(100,'2026-06-13 07:50:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(101,'2026-06-13 07:50:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (102,'2026-06-13 07:50:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure libvirt-guests\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsShutdownTimeout\": {\"default\": 300, \"description\": \"Number of seconds we\'re willing to wait for a guest to shut down. If this is 0, then there is no time out (use with caution, as guests might not respond to a shutdown request). The default value is 300 seconds (5 minutes).\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt_guests::shutdown_timeout\": \"NovaResumeGuestsShutdownTimeout\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaResumeGuestsShutdownTimeout\": {\"get_param\": \"NovaResumeGuestsShutdownTimeout\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for libvirt-guests\", \"value\": {\"service_name\": \"nova_libvirt_guests\", \"config_settings\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::compute::libvirt_guests\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(103,'2026-06-13 07:50:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(104,'2026-06-13 07:50:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(105,'2026-06-13 07:50:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(106,'2026-06-13 07:50:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(107,'2026-06-13 07:50:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for nova-compute containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"nova_statedir_ownership.py\": {\"mode\": \"0700\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\"}}, \"nova_wait_for_compute_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\"}}}}, \"nova_compute_common_deploy_steps_tasks\": {\"description\": \"Common host prep tasks for nova-compute services (compute + ironic)\", \"value\": [{\"block\": [{\"name\": \"is additonal Cell?\", \"set_fact\": {\"nova_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"check if discover hosts is required\", \"when\": [\"not nova_additional_cell|bool\", \"nova_cellv2_discovery_done is not defined\"], \"block\": [{\"name\": \"discover via nova_manager?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_manager\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_manager\"}, \"when\": [\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\"]}, {\"name\": \"discover via nova_api?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_api\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_api\"}, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\", \"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\"]}, {\"name\": \"Warn if no discovery host available\", \"fail\": {\"msg\": \"No hosts available to run nova cell_v2 host discovery.\"}, \"ignore_errors\": true, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\"]}, {\"name\": \"Discovering nova hosts\", \"command\": \"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\", \"become\": true, \"changed_when\": false, \"delegate_to\": \"{{ nova_cellv2_discovery_delegate_host }}\", \"when\": [\"nova_cellv2_discovery_delegate_host is defined\"]}, {\"set_fact\": {\"nova_cellv2_discovery_done\": true}}]}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(108,'2026-06-13 07:50:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(109,'2026-06-13 07:50:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Migration Target service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DockerNovaMigrationSshdPort\": {\"default\": 2022, \"description\": \"Port that dockerized nova migration target sshd service binds to.\", \"type\": \"number\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SshdBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Migration Target service.\", \"value\": {\"service_name\": \"nova_migration_target\", \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept libvirt subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept api subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SshdBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\": [{\"get_param\": [\"MigrationSshKey\", \"public_key\"]}], \"tripleo::profile::base::nova::migration::target::ssh_localaddrs\": [\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\", \"%{hiera(\'live_migration_ssh_inbound_addr\')}\"], \"live_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"cold_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"tripleo::profile::base::sshd::port\": [22]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"SshdBase\", \"role_data\", \"step_config\"]}, \"include tripleo::profile::base::nova::migration::target\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova-migration-target.json\": {\"command\": {\"str_replace\": {\"template\": \"dumb-init --single-child -- /usr/sbin/sshd -D -p SSHDPORT\", \"params\": {\"SSHDPORT\": {\"get_param\": \"DockerNovaMigrationSshdPort\"}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/host-ssh/ssh_host_*_key\", \"dest\": \"/etc/ssh/\", \"owner\": \"root\", \"perm\": \"0600\"}]}}, \"host_prep_tasks\": [{\"name\": \"Create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"loop\": [{\"path\": \"/run/libvirt\", \"setype\": \"virt_var_run_t\"}]}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}], \"docker_config\": {\"step_4\": {\"nova_migration_target\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/etc/ssh:/host-ssh:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-migration-target container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_migration_target\"}, \"register\": \"nova_migration_target_infos\", \"failed_when\": [\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"update_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}], \"upgrade_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(110,'2026-06-13 07:50:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (111,'2026-06-13 07:50:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": true, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"xYUZeqAicsuHn0JOHQOq1idQJ\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(112,'2026-06-13 07:50:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CdhGooXCxTME1ITxFl9q0xUTr\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"xYUZeqAicsuHn0JOHQOq1idQJ\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IOcEXVmeV2fpzQjbFPUW1TNW\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"high\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(113,'2026-06-13 07:50:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"NovaServiceName\": \"compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(114,'2026-06-13 07:50:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(115,'2026-06-13 07:50:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph Client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientConfigVars\": {\"default\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"type\": \"string\", \"description\": \"The undercloud path where cephadm exports the Ceph Client configuration.\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephExternalMonHost\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of externally managed Ceph Mon Host IPs. Only used for external Ceph deployments.\"}}, \"resources\": {\"CephBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"DefaultPasswords\": {\"get_param\": \"DefaultPasswords\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph Client service.\", \"value\": {\"service_name\": \"ceph_client\", \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"external_deploy_tasks\": {\"list_concat\": [{\"get_attr\": [\"CephBase\", \"role_data\", \"external_deploy_tasks\"]}, [{\"name\": \"ceph_base_external_deploy_init\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set some tripleo-ansible facts\", \"set_fact\": {\"ceph_external_multi_config\": {\"get_param\": \"CephExternalMultiConfig\"}}}]}, {\"name\": \"Configure Ceph Clients\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Check if the input variable file exists\", \"stat\": {\"path\": \"{{ tripleo_ceph_client_vars }}\"}, \"register\": \"ceph_input_vars\", \"vars\": {\"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}}}, {\"name\": \"Populate CephClientConfigVars from THT\", \"copy\": {\"dest\": \"{{ tripleo_ceph_client_vars }}\", \"content\": \"tripleo_ceph_client_fsid: \\\"{{ tripleo_ceph_client_fsid }}\\\"\\nexternal_cluster_mon_ips: \\\"{{ external_cluster_mon_ips }}\\\"\\n\"}, \"when\": [\"ceph_input_vars.stat.exists == False\", \"external_cluster_mon_ips | length > 0\"], \"vars\": {\"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}, \"tripleo_ceph_client_fsid\": {\"get_param\": \"CephClusterFSID\"}, \"external_cluster_mon_ips\": {\"get_param\": \"CephExternalMonHost\"}}}, {\"name\": \"configure ceph clients\", \"include_role\": {\"name\": \"tripleo_ceph_client\"}, \"vars\": {\"tripleo_ceph_client_config_home\": {\"get_param\": \"CephConfigPath\"}, \"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}}}, {\"include_role\": {\"name\": \"tripleo_ceph_client\"}, \"name\": \"tripleo client role\", \"vars\": {\"tripleo_ceph_client_config_home\": {\"get_param\": \"CephConfigPath\"}, \"multiple\": \"{{ item }}\"}, \"loop\": \"{{ ceph_external_multi_config }}\", \"when\": [\"ceph_external_multi_config is defined\"]}, {\"name\": \"Load variables for standalone ganesha\", \"include_vars\": \"{{ playbook_dir }}/cephadm/cephadm-extra-vars-heat.yml\", \"when\": [\"groups[\'ceph_mon\'] | default([]) | length == 0\", \"groups[\'ceph_nfs\'] | default([]) | length > 0\"]}, {\"name\": \"Config Standalone Ganesha\", \"include_role\": {\"name\": \"tripleo_cephadm\", \"tasks_from\": \"nfs\"}, \"when\": [\"groups[\'ceph_mon\'] | default([]) | length == 0\", \"groups[\'ceph_nfs\'] | default([]) | length > 0\"], \"vars\": {\"tripleo_cephadm_config_home\": {\"get_param\": \"CephConfigPath\"}}}]}]]}, \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"config_settings\": {}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(116,'2026-06-13 07:50:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"no\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}}, \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"config_settings\": {\"tripleo::profile::base::sshd::bannertext\": {\"get_param\": \"BannerText\"}, \"tripleo::profile::base::sshd::motd\": {\"get_param\": \"MessageOfTheDay\"}, \"tripleo::profile::base::sshd::options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo::profile::base::sshd::password_authentication\": {\"get_param\": \"PasswordAuthentication\"}}, \"step_config\": \"include tripleo::profile::base::sshd\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(117,'2026-06-13 07:50:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph Monitor service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephValidationRetries\": {\"type\": \"number\", \"default\": 40, \"description\": \"Number of retry attempts for Ceph validation\"}, \"CephValidationDelay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Interval (in seconds) in between validation checks\"}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}}, \"conditions\": {\"dashboard_enabled\": {\"equals\": [{\"get_param\": \"CephEnableDashboard\"}, true]}}, \"resources\": {\"CephBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"DefaultPasswords\": {\"get_param\": \"DefaultPasswords\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph Monitor service.\", \"value\": {\"service_name\": \"ceph_mon\", \"firewall_rules\": {\"110 ceph_mon\": {\"dport\": {\"list_concat\": [[6789], [3300], {\"if\": [\"dashboard_enabled\", [\"9100\"]]}]}}}, \"service_config_settings\": {\"collectd\": {\"tripleo.collectd.plugins.ceph_mon\": [\"ceph\"], \"collectd::plugin::ceph::daemons\": []}}, \"upgrade_tasks\": {\"get_attr\": [\"CephBase\", \"role_data\", \"upgrade_tasks\"]}, \"puppet_config\": {}, \"docker_config\": {}, \"external_deploy_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(118,'2026-06-13 07:50:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph base service. Shared by all Ceph services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NodeDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"json containing per-node configuration map\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}, \"CephConfigOverrides\": {\"type\": \"json\", \"description\": \"Extra config settings to dump into ceph.conf\", \"default\": {}}, \"ApplyCephConfigOverridesOnUpdate\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If true, CephConfigOverrides are applied to the Ceph cluster not only during the initial deployment but also during each update.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephMsgrSecureMode\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable Ceph msgr2 secure mode to enable on-wire encryption between Ceph daemons and also between Ceph clients and daemons.\\n\"}, \"CephPools\": {\"description\": \"Used to override settings (mainly target_size_ratio or pg_num) in pools. Pacific has pg_autoscale_mode enabled by default so set target_size_ratio as a percentage of the expected data consumption. The example below sets cinder volumes 40%, glance images 10%, nova vms 30% (20% of space free). Not set by default but overrides are encouraged to avoid data rebalancing. For example, CephPools:\\n  - name: volumes\\n    target_size_ratio: 0.4\\n    application: rbd\\n  - name: images\\n    target_size_ratio: 0.1\\n    application: rbd\\n  - name: vms\\n    target_size_ratio: 0.3\\n    application: rbd\\n\", \"default\": [], \"type\": \"json\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceBackend\": {\"default\": \"rbd\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GnocchiRbdPoolName\": {\"default\": \"metrics\", \"type\": \"string\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephRgwClientName\": {\"default\": \"radosgw\", \"type\": \"string\"}, \"CephRgwKey\": {\"description\": \"The cephx key for the radosgw client. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\"}, \"ManilaCephFSDataPoolName\": {\"default\": \"manila_data\", \"type\": \"string\"}, \"ManilaCephFSMetadataPoolName\": {\"default\": \"manila_metadata\", \"type\": \"string\"}, \"ManilaCephFSShareBackendName\": {\"default\": \"cephfs\", \"type\": \"string\"}, \"ManilaCephFSCephFSAuthId\": {\"default\": \"manila\", \"type\": \"string\"}, \"CephManilaClientKey\": {\"default\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}]}, \"CephIPv6\": {\"default\": false, \"type\": \"boolean\"}, \"SwiftPassword\": {\"description\": \"The password for the swift service account\", \"type\": \"string\", \"hidden\": true, \"default\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\"}, \"ContainerCephDaemonImage\": {\"description\": \"image\", \"type\": \"string\", \"default\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\"}, \"CephAnsiblePlaybookVerbosity\": {\"default\": 1, \"description\": \"The number of \'-v\', \'-vv\', etc. passed to ansible-playbook command\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 5}}]}, \"CephAnsibleEnvironmentVariables\": {\"default\": {}, \"description\": \"Mapping of Ansible environment variables to override defaults.\", \"type\": \"json\"}, \"SwiftFetchDirGetTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to download the fetch_directory from.\", \"type\": \"string\"}, \"SwiftFetchDirPutTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to upload the fetch_directory to.\", \"type\": \"string\"}, \"LocalCephAnsibleFetchDirectoryBackup\": {\"default\": \"\", \"description\": \"Filesystem path on undercloud to persist a copy of the data from the ceph-ansible fetch directory. Used as an alternative to backing up the fetch_directory in Swift. Path must be writable and readable by the user running ansible from config-download, e.g. the mistral user in the mistral-executor container is able to read/write to /var/lib/mistral/ceph_fetch\", \"type\": \"string\"}, \"CephOsdPercentageMin\": {\"default\": 0, \"description\": \"The minimum percentage of Ceph OSDs which must be running and in the Ceph cluster, according to ceph osd stat, for the deployment not to fail. Used to catch deployment errors early. Set this value to 0 to disable this check. Deprecated in Wallaby because of the move from ceph-ansible to cephadm; the later only brings up OSDs out of band and deployment does not block while waiting for them to come up, thus we cannot do this anymore.\", \"type\": \"number\"}, \"CephAnsiblePlaybook\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths to the ceph-ansible playbooks to execute. If not specified, the playbook will be determined automatically depending on type of operation being performed (deploy/update/upgrade).\\n\", \"default\": [\"default\"]}, \"CephAnsibleExtraConfig\": {\"type\": \"json\", \"description\": \"Extra vars for the ceph-ansible playbook\", \"default\": {}}, \"CephAnsibleSkipTags\": {\"type\": \"string\", \"description\": \"List of ceph-ansible tags to skip\", \"default\": \"package-install,with_pkg\"}, \"CephAnsibleRepo\": {\"type\": \"string\", \"description\": \"The repository that should be used to install the right ceph-ansible\\npackage. This value can be used by tripleo-validations to double check\\nthe right ceph-ansible version is installed.\\n\", \"default\": \"centos-ceph-nautilus\"}, \"CephAnsibleWarning\": {\"type\": \"boolean\", \"description\": \"In particular scenarios we want this validation to show the warning but\\ndon\'t fail because the package is installed on the system but repos are\\ndisabled.\\n\", \"default\": true}, \"CephPoolDefaultPgNum\": {\"description\": \"default pg_num to use for the RBD pools\", \"type\": \"number\", \"default\": 16}, \"CephPoolDefaultSize\": {\"description\": \"default minimum replication for RBD copies\", \"type\": \"number\", \"default\": 3}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\", \"default\": {}}, \"CephExtraKeys\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra keys which will be created on the deployed\\nCeph cluster. Uses ceph-ansible/library/ceph_key.py ansible module. Each\\nitem in the list must be in the following example format\\n  - name: \\\"client.glance\\\"\\n    caps:\\n      mgr: \\\"allow *\\\"\\n      mon: \\\"profile rbd\\\"\\n      osd: \\\"profile rbd pool=images\\\"\\n    key: \\\"AQBRgQ9eAAAAABAAv84zEilJYZPNuJ0Iwn9Ndg==\\\"\\n    mode: \\\"0600\\\"\\n\", \"default\": []}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderBackupBackend\": {\"default\": \"ceph\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"GnocchiBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Gnocchi backend to use. Should be one of swift, rbd, file or s3.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"s3\"]}]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CephClientConfigVars\": {\"default\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"type\": \"string\", \"description\": \"The undercloud path where cephadm exports the Ceph Client configuration.\"}, \"CephAnsibleSkipClient\": {\"description\": \"This boolean (when true) prevents the ceph-ansible client role execution\\nby adding the ceph-ansible tag \'ceph_client\' to the --skip-tags list.\\n\", \"type\": \"boolean\", \"default\": true}, \"CephDynamicSpec\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If true the tripleo_run_cephadm role will build an orchestrator-cli-service-spec\\nfile based on the data found in the inventory (which is based on composable roles)\\nby using the ceph_spec_bootstrap Ansible module in tripleo-ansible.\\n\"}, \"CephSpecPath\": {\"default\": \"{{ playbook_dir }}/cephadm/ceph_spec.yaml\", \"type\": \"string\", \"description\": \"The path on the undercloud to a valid Ceph orchestrator CLI service spec file.\\nIf you do not want the spec to be generated automatically and instead prefer\\nto supply your own spec, then place your spec at this path on the undercloud\\nand set CephDynamicSpec to false. If CephDynamicSpec is true and CephSpecPath\\nis set to a valid path, then the spec will be created at that path before it\\nis used to deploy Ceph. By default the spec will be created by config-download\\nin config-download/<stack>/cephadm/ceph_spec.yaml.\\n\"}, \"CephOsdSpec\": {\"description\": \"If CephDynamicSpec is true, then any valid OSD service specification set in\\nCephOsdSpec will appear in the genereated Ceph spec for the \'osd\' service_type.\\nReplaces CephAnsibleDisksConfig. This parameter has no effect if CephDynamicSpec\\nis false. Use this paramter to override the default of using all available block\\ndevices as data_devices. See the Ceph documentation for cephadm drivegroups.\\nExclude service_type, service_id, and placement from this parameter. In the\\nexample below all rotating devices will be data devices and all non-rotating\\ndevices will be used as shared devices (wal, db).\\n  CephOsdSpec:\\n    data_devices:\\n      rotational: 1\\n    db_devices:\\n      rotational: 0\\n\", \"type\": \"json\", \"default\": {\"data_devices\": {\"all\": true}}}, \"CephSpecFqdn\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If both CephDynamicSpec and CephSpecFqdn are true, then the hostname and\\nhosts of the generated Ceph spec will have their fully qualified domain\\nname instead of their short hostname. This parameter has no effect if\\nCephDynamicSpec is false.\\n\"}, \"CephCrushRules\": {\"type\": \"json\", \"description\": \"List of rules describing the device classes that will be found on the deployed\\nCeph cluster. They can be specified in the following form\\n- name: HDD\\n  root: default\\n  type: host\\n  class: hdd\\n  default: true\\n\", \"default\": []}, \"CephAdmDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, then cephadm sets the debug related mgr\\nconfig-key and produces a more verbose output.\\n\"}, \"CephAdmVerbose\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, the cephadm playbook is able to print\\nsome ceph related information during its execution.\\n\"}, \"DeployedCeph\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"DisableCephadm\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Disable cephadm after Ceph is deployed\"}, \"CephRbdTrashPurgeInterval\": {\"default\": 15, \"type\": \"string\", \"description\": \"The interval applied to the rbd trash purge scheduler, that can be\\nexpressed in minutes.\\n\"}, \"CephRbdTrashSchedulerEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable Ceph rbd trash scheduler\"}, \"CephadmDefaultContainer\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Use the default continer defined in cephadm instead of\\nthe one defined in container_image_prepare_defaults.yaml.\\n\"}, \"ExternalCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has been deployed outside of TripleO.\\nDeployedCeph and ExternalCeph are mutually exclusive.\\n\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"LocalCephAnsibleFetchDirectoryBackup\", \"SwiftFetchDirGetTempurl\", \"SwiftFetchDirPutTempurl\", \"CephIPv6\", \"CephAnsibleEnvironmentVariables\", \"CephAnsibleExtraConfig\", \"CephAnsiblePlaybook\", \"CephAnsiblePlaybookVerbosity\", \"CephAnsibleRepo\", \"CephAnsibleSkipTags\", \"CephAnsibleSkipClient\", \"CephAnsibleWarning\", \"CephOsdPercentageMin\", \"CephPoolDefaultPgNum\", \"CephPoolDefaultSize\"]}], \"conditions\": {\"custom_registry_host\": {\"yaql\": {\"data\": {\"get_param\": \"ContainerCephDaemonImage\"}, \"expression\": \"$.data.split(\'/\')[0].matches(\'(\\\\.|:)\')\"}}, \"ceph_authenticated_registry\": {\"and\": [{\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\").isEmpty()\"}}}, {\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\").isEmpty()\"}}}]}}, \"resources\": {\"ContainerImageUrlParts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"host\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, \"docker.io\"]}, \"image\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[2]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[0]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}]}, \"image_tag\": {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}}}, \"DefaultCephConfigOverrides\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {}}}}, \"CephAdmVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {\"tripleo_cephadm_fsid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo_cephadm_cluster\": {\"get_param\": \"CephClusterName\"}, \"tripleo_cephadm_container_cli\": {\"get_param\": \"ContainerCli\"}, \"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}, \"tripleo_cephadm_dashboard_enabled\": {\"get_param\": \"CephEnableDashboard\"}, \"cephfs\": {\"get_param\": \"ManilaCephFSShareBackendName\"}, \"tripleo_cephadm_container_ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}, \"tripleo_cephadm_container_image\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image\"]}, \"tripleo_cephadm_container_tag\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image_tag\"]}, \"tripleo_cephadm_crush_rules\": {\"get_param\": \"CephCrushRules\"}, \"tripleo_cephadm_debug\": {\"get_param\": \"CephAdmDebug\"}, \"tripleo_cephadm_verbose\": {\"get_param\": \"CephAdmVerbose\"}, \"tripleo_cephadm_rbd_trash\": {\"get_param\": \"CephRbdTrashPurgeInterval\"}, \"tripleo_cephadm_enable_trash_scheduler\": {\"get_param\": \"CephRbdTrashSchedulerEnable\"}, \"tripleo_cephadm_apply_ceph_conf_overrides_on_update\": {\"get_param\": \"ApplyCephConfigOverridesOnUpdate\"}, \"tripleo_cephadm_default_container\": {\"get_param\": \"CephadmDefaultContainer\"}, \"ceph_container_registry_auth\": {\"if\": [\"ceph_authenticated_registry\", true, false]}, \"ceph_container_registry_username\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\")\"}}, \"ceph_container_registry_password\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\")\"}}, \"public_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephMonNetwork\"]}]}]}, \"cluster_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephClusterNetwork\"]}]}]}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph base service.\", \"value\": {\"service_name\": \"ceph_base\", \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"config_settings\": {}, \"external_deploy_tasks\": [{\"name\": \"ceph_base_external_deploy_task\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"create cephadm working directory and related files\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"prepare.yml\"}, \"vars\": {\"ceph_pools\": {\"gnocchi_pool\": {\"name\": {\"get_param\": \"GnocchiRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"GnocchiBackend\"}, \"rbd\"]}, true, false]}}, \"nova_pool\": {\"name\": {\"get_param\": \"NovaRbdPoolName\"}, \"enabled\": {\"get_param\": \"NovaEnableRbdBackend\"}}, \"glance_pool\": {\"name\": {\"get_param\": \"GlanceRbdPoolName\"}, \"enabled\": {\"or\": [{\"yaql\": {\"data\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"expression\": \"$.data.values().where($ != null).GlanceBackend.contains(\\\"rbd\\\")\"}}, {\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}]}}, \"cinder_pool\": {\"name\": {\"get_param\": \"CinderRbdPoolName\"}, \"enabled\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"cinder_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}}, \"cinder_backup_pool\": {\"name\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, true, false]}}, \"extra_pools\": {\"get_param\": \"CephPools\"}}, \"manila_pools\": {\"data\": {\"get_param\": \"ManilaCephFSDataPoolName\"}, \"metadata\": {\"get_param\": \"ManilaCephFSMetadataPoolName\"}}, \"ceph_keys\": {\"openstack_client\": {\"name\": {\"get_param\": \"CephClientUserName\"}, \"key\": {\"get_param\": \"CephClientKey\"}}, \"manila\": {\"name\": {\"get_param\": \"ManilaCephFSCephFSAuthId\"}, \"key\": {\"get_param\": \"CephManilaClientKey\"}}, \"radosgw\": {\"name\": {\"get_param\": \"CephRgwClientName\"}, \"key\": {\"get_param\": \"CephRgwKey\"}}, \"extra_keys\": {\"get_param\": \"CephExtraKeys\"}}, \"ceph_config_overrides\": {\"get_param\": \"CephConfigOverrides\"}, \"tripleo_run_cephadm_spec_path\": {\"get_param\": \"CephSpecPath\"}, \"tripleo_cephadm_dynamic_spec\": {\"get_param\": \"CephDynamicSpec\"}, \"ceph_spec_fqdn\": {\"get_param\": \"CephSpecFqdn\"}, \"ceph_osd_spec\": {\"get_param\": \"CephOsdSpec\"}, \"ceph_default_overrides\": {\"global\": {\"if\": [{\"get_param\": \"CephMsgrSecureMode\"}, {\"map_merge\": [{\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}, {\"ms_cluster_mode\": \"secure\", \"ms_service_mode\": \"secure\", \"ms_client_mode\": \"secure\"}]}, {\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}]}}, \"cephadm_extra_vars\": {\"get_attr\": [\"CephAdmVars\", \"value\", \"vars\"]}, \"tripleo_cephadm_deployed_ceph\": {\"get_param\": \"DeployedCeph\"}}}, {\"name\": \"Prepare cephadm user and keys\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"enable_ceph_admin_user.yml\"}, \"when\": [\"not external_ceph\", \"(not deployed_ceph and (groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0)) or (deployed_ceph and ((groups[\'ceph_rgw\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rgw\'] | default([]) | length > 0) or (groups[\'ceph_mds\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_mds\'] | default([]) | length > 0) or (groups[\'ceph_nfs\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_nfs\'] | default([]) | length > 0) or (groups[\'ceph_rbdmirror\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rbdmirror\'] | default([]) | length > 0)))\"], \"vars\": {\"deployed_ceph\": {\"get_param\": \"DeployedCeph\"}, \"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}, {\"name\": \"Deploy or configure the cephadm Ceph cluster\", \"include_role\": {\"name\": \"tripleo_run_cephadm\"}, \"when\": [\"not external_ceph\", \"groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0\"], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}]}, {\"name\": \"ceph_base_external_deploy_task\", \"when\": [\"(step | int) == 3\", {\"get_param\": \"DisableCephadm\"}, \"not external_ceph\"], \"block\": [{\"name\": \"Pause cephadm\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"disable_cephadm.yml\"}}], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}], \"post_upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"DefaultPasswords\": {}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(119,'2026-06-13 07:50:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (120,'2026-06-13 07:50:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(121,'2026-06-13 07:50:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph base service. Shared by all Ceph services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NodeDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"json containing per-node configuration map\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}, \"CephConfigOverrides\": {\"type\": \"json\", \"description\": \"Extra config settings to dump into ceph.conf\", \"default\": {}}, \"ApplyCephConfigOverridesOnUpdate\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If true, CephConfigOverrides are applied to the Ceph cluster not only during the initial deployment but also during each update.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephMsgrSecureMode\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable Ceph msgr2 secure mode to enable on-wire encryption between Ceph daemons and also between Ceph clients and daemons.\\n\"}, \"CephPools\": {\"description\": \"Used to override settings (mainly target_size_ratio or pg_num) in pools. Pacific has pg_autoscale_mode enabled by default so set target_size_ratio as a percentage of the expected data consumption. The example below sets cinder volumes 40%, glance images 10%, nova vms 30% (20% of space free). Not set by default but overrides are encouraged to avoid data rebalancing. For example, CephPools:\\n  - name: volumes\\n    target_size_ratio: 0.4\\n    application: rbd\\n  - name: images\\n    target_size_ratio: 0.1\\n    application: rbd\\n  - name: vms\\n    target_size_ratio: 0.3\\n    application: rbd\\n\", \"default\": [], \"type\": \"json\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceBackend\": {\"default\": \"rbd\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GnocchiRbdPoolName\": {\"default\": \"metrics\", \"type\": \"string\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephRgwClientName\": {\"default\": \"radosgw\", \"type\": \"string\"}, \"CephRgwKey\": {\"description\": \"The cephx key for the radosgw client. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\"}, \"ManilaCephFSDataPoolName\": {\"default\": \"manila_data\", \"type\": \"string\"}, \"ManilaCephFSMetadataPoolName\": {\"default\": \"manila_metadata\", \"type\": \"string\"}, \"ManilaCephFSShareBackendName\": {\"default\": \"cephfs\", \"type\": \"string\"}, \"ManilaCephFSCephFSAuthId\": {\"default\": \"manila\", \"type\": \"string\"}, \"CephManilaClientKey\": {\"default\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}]}, \"CephIPv6\": {\"default\": false, \"type\": \"boolean\"}, \"SwiftPassword\": {\"description\": \"The password for the swift service account\", \"type\": \"string\", \"hidden\": true, \"default\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\"}, \"ContainerCephDaemonImage\": {\"description\": \"image\", \"type\": \"string\", \"default\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\"}, \"CephAnsiblePlaybookVerbosity\": {\"default\": 1, \"description\": \"The number of \'-v\', \'-vv\', etc. passed to ansible-playbook command\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 5}}]}, \"CephAnsibleEnvironmentVariables\": {\"default\": {}, \"description\": \"Mapping of Ansible environment variables to override defaults.\", \"type\": \"json\"}, \"SwiftFetchDirGetTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to download the fetch_directory from.\", \"type\": \"string\"}, \"SwiftFetchDirPutTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to upload the fetch_directory to.\", \"type\": \"string\"}, \"LocalCephAnsibleFetchDirectoryBackup\": {\"default\": \"\", \"description\": \"Filesystem path on undercloud to persist a copy of the data from the ceph-ansible fetch directory. Used as an alternative to backing up the fetch_directory in Swift. Path must be writable and readable by the user running ansible from config-download, e.g. the mistral user in the mistral-executor container is able to read/write to /var/lib/mistral/ceph_fetch\", \"type\": \"string\"}, \"CephOsdPercentageMin\": {\"default\": 0, \"description\": \"The minimum percentage of Ceph OSDs which must be running and in the Ceph cluster, according to ceph osd stat, for the deployment not to fail. Used to catch deployment errors early. Set this value to 0 to disable this check. Deprecated in Wallaby because of the move from ceph-ansible to cephadm; the later only brings up OSDs out of band and deployment does not block while waiting for them to come up, thus we cannot do this anymore.\", \"type\": \"number\"}, \"CephAnsiblePlaybook\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths to the ceph-ansible playbooks to execute. If not specified, the playbook will be determined automatically depending on type of operation being performed (deploy/update/upgrade).\\n\", \"default\": [\"default\"]}, \"CephAnsibleExtraConfig\": {\"type\": \"json\", \"description\": \"Extra vars for the ceph-ansible playbook\", \"default\": {}}, \"CephAnsibleSkipTags\": {\"type\": \"string\", \"description\": \"List of ceph-ansible tags to skip\", \"default\": \"package-install,with_pkg\"}, \"CephAnsibleRepo\": {\"type\": \"string\", \"description\": \"The repository that should be used to install the right ceph-ansible\\npackage. This value can be used by tripleo-validations to double check\\nthe right ceph-ansible version is installed.\\n\", \"default\": \"centos-ceph-nautilus\"}, \"CephAnsibleWarning\": {\"type\": \"boolean\", \"description\": \"In particular scenarios we want this validation to show the warning but\\ndon\'t fail because the package is installed on the system but repos are\\ndisabled.\\n\", \"default\": true}, \"CephPoolDefaultPgNum\": {\"description\": \"default pg_num to use for the RBD pools\", \"type\": \"number\", \"default\": 16}, \"CephPoolDefaultSize\": {\"description\": \"default minimum replication for RBD copies\", \"type\": \"number\", \"default\": 3}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\", \"default\": {}}, \"CephExtraKeys\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra keys which will be created on the deployed\\nCeph cluster. Uses ceph-ansible/library/ceph_key.py ansible module. Each\\nitem in the list must be in the following example format\\n  - name: \\\"client.glance\\\"\\n    caps:\\n      mgr: \\\"allow *\\\"\\n      mon: \\\"profile rbd\\\"\\n      osd: \\\"profile rbd pool=images\\\"\\n    key: \\\"AQBRgQ9eAAAAABAAv84zEilJYZPNuJ0Iwn9Ndg==\\\"\\n    mode: \\\"0600\\\"\\n\", \"default\": []}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderBackupBackend\": {\"default\": \"ceph\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"GnocchiBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Gnocchi backend to use. Should be one of swift, rbd, file or s3.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"s3\"]}]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CephClientConfigVars\": {\"default\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"type\": \"string\", \"description\": \"The undercloud path where cephadm exports the Ceph Client configuration.\"}, \"CephAnsibleSkipClient\": {\"description\": \"This boolean (when true) prevents the ceph-ansible client role execution\\nby adding the ceph-ansible tag \'ceph_client\' to the --skip-tags list.\\n\", \"type\": \"boolean\", \"default\": true}, \"CephDynamicSpec\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If true the tripleo_run_cephadm role will build an orchestrator-cli-service-spec\\nfile based on the data found in the inventory (which is based on composable roles)\\nby using the ceph_spec_bootstrap Ansible module in tripleo-ansible.\\n\"}, \"CephSpecPath\": {\"default\": \"{{ playbook_dir }}/cephadm/ceph_spec.yaml\", \"type\": \"string\", \"description\": \"The path on the undercloud to a valid Ceph orchestrator CLI service spec file.\\nIf you do not want the spec to be generated automatically and instead prefer\\nto supply your own spec, then place your spec at this path on the undercloud\\nand set CephDynamicSpec to false. If CephDynamicSpec is true and CephSpecPath\\nis set to a valid path, then the spec will be created at that path before it\\nis used to deploy Ceph. By default the spec will be created by config-download\\nin config-download/<stack>/cephadm/ceph_spec.yaml.\\n\"}, \"CephOsdSpec\": {\"description\": \"If CephDynamicSpec is true, then any valid OSD service specification set in\\nCephOsdSpec will appear in the genereated Ceph spec for the \'osd\' service_type.\\nReplaces CephAnsibleDisksConfig. This parameter has no effect if CephDynamicSpec\\nis false. Use this paramter to override the default of using all available block\\ndevices as data_devices. See the Ceph documentation for cephadm drivegroups.\\nExclude service_type, service_id, and placement from this parameter. In the\\nexample below all rotating devices will be data devices and all non-rotating\\ndevices will be used as shared devices (wal, db).\\n  CephOsdSpec:\\n    data_devices:\\n      rotational: 1\\n    db_devices:\\n      rotational: 0\\n\", \"type\": \"json\", \"default\": {\"data_devices\": {\"all\": true}}}, \"CephSpecFqdn\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If both CephDynamicSpec and CephSpecFqdn are true, then the hostname and\\nhosts of the generated Ceph spec will have their fully qualified domain\\nname instead of their short hostname. This parameter has no effect if\\nCephDynamicSpec is false.\\n\"}, \"CephCrushRules\": {\"type\": \"json\", \"description\": \"List of rules describing the device classes that will be found on the deployed\\nCeph cluster. They can be specified in the following form\\n- name: HDD\\n  root: default\\n  type: host\\n  class: hdd\\n  default: true\\n\", \"default\": []}, \"CephAdmDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, then cephadm sets the debug related mgr\\nconfig-key and produces a more verbose output.\\n\"}, \"CephAdmVerbose\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, the cephadm playbook is able to print\\nsome ceph related information during its execution.\\n\"}, \"DeployedCeph\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"DisableCephadm\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Disable cephadm after Ceph is deployed\"}, \"CephRbdTrashPurgeInterval\": {\"default\": 15, \"type\": \"string\", \"description\": \"The interval applied to the rbd trash purge scheduler, that can be\\nexpressed in minutes.\\n\"}, \"CephRbdTrashSchedulerEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable Ceph rbd trash scheduler\"}, \"CephadmDefaultContainer\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Use the default continer defined in cephadm instead of\\nthe one defined in container_image_prepare_defaults.yaml.\\n\"}, \"ExternalCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has been deployed outside of TripleO.\\nDeployedCeph and ExternalCeph are mutually exclusive.\\n\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"LocalCephAnsibleFetchDirectoryBackup\", \"SwiftFetchDirGetTempurl\", \"SwiftFetchDirPutTempurl\", \"CephIPv6\", \"CephAnsibleEnvironmentVariables\", \"CephAnsibleExtraConfig\", \"CephAnsiblePlaybook\", \"CephAnsiblePlaybookVerbosity\", \"CephAnsibleRepo\", \"CephAnsibleSkipTags\", \"CephAnsibleSkipClient\", \"CephAnsibleWarning\", \"CephOsdPercentageMin\", \"CephPoolDefaultPgNum\", \"CephPoolDefaultSize\"]}], \"conditions\": {\"custom_registry_host\": {\"yaql\": {\"data\": {\"get_param\": \"ContainerCephDaemonImage\"}, \"expression\": \"$.data.split(\'/\')[0].matches(\'(\\\\.|:)\')\"}}, \"ceph_authenticated_registry\": {\"and\": [{\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\").isEmpty()\"}}}, {\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\").isEmpty()\"}}}]}}, \"resources\": {\"ContainerImageUrlParts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"host\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, \"docker.io\"]}, \"image\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[2]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[0]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}]}, \"image_tag\": {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}}}, \"DefaultCephConfigOverrides\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {}}}}, \"CephAdmVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {\"tripleo_cephadm_fsid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo_cephadm_cluster\": {\"get_param\": \"CephClusterName\"}, \"tripleo_cephadm_container_cli\": {\"get_param\": \"ContainerCli\"}, \"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}, \"tripleo_cephadm_dashboard_enabled\": {\"get_param\": \"CephEnableDashboard\"}, \"cephfs\": {\"get_param\": \"ManilaCephFSShareBackendName\"}, \"tripleo_cephadm_container_ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}, \"tripleo_cephadm_container_image\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image\"]}, \"tripleo_cephadm_container_tag\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image_tag\"]}, \"tripleo_cephadm_crush_rules\": {\"get_param\": \"CephCrushRules\"}, \"tripleo_cephadm_debug\": {\"get_param\": \"CephAdmDebug\"}, \"tripleo_cephadm_verbose\": {\"get_param\": \"CephAdmVerbose\"}, \"tripleo_cephadm_rbd_trash\": {\"get_param\": \"CephRbdTrashPurgeInterval\"}, \"tripleo_cephadm_enable_trash_scheduler\": {\"get_param\": \"CephRbdTrashSchedulerEnable\"}, \"tripleo_cephadm_apply_ceph_conf_overrides_on_update\": {\"get_param\": \"ApplyCephConfigOverridesOnUpdate\"}, \"tripleo_cephadm_default_container\": {\"get_param\": \"CephadmDefaultContainer\"}, \"ceph_container_registry_auth\": {\"if\": [\"ceph_authenticated_registry\", true, false]}, \"ceph_container_registry_username\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\")\"}}, \"ceph_container_registry_password\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\")\"}}, \"public_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephMonNetwork\"]}]}]}, \"cluster_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephClusterNetwork\"]}]}]}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph base service.\", \"value\": {\"service_name\": \"ceph_base\", \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"config_settings\": {}, \"external_deploy_tasks\": [{\"name\": \"ceph_base_external_deploy_task\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"create cephadm working directory and related files\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"prepare.yml\"}, \"vars\": {\"ceph_pools\": {\"gnocchi_pool\": {\"name\": {\"get_param\": \"GnocchiRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"GnocchiBackend\"}, \"rbd\"]}, true, false]}}, \"nova_pool\": {\"name\": {\"get_param\": \"NovaRbdPoolName\"}, \"enabled\": {\"get_param\": \"NovaEnableRbdBackend\"}}, \"glance_pool\": {\"name\": {\"get_param\": \"GlanceRbdPoolName\"}, \"enabled\": {\"or\": [{\"yaql\": {\"data\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"expression\": \"$.data.values().where($ != null).GlanceBackend.contains(\\\"rbd\\\")\"}}, {\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}]}}, \"cinder_pool\": {\"name\": {\"get_param\": \"CinderRbdPoolName\"}, \"enabled\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"cinder_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}}, \"cinder_backup_pool\": {\"name\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, true, false]}}, \"extra_pools\": {\"get_param\": \"CephPools\"}}, \"manila_pools\": {\"data\": {\"get_param\": \"ManilaCephFSDataPoolName\"}, \"metadata\": {\"get_param\": \"ManilaCephFSMetadataPoolName\"}}, \"ceph_keys\": {\"openstack_client\": {\"name\": {\"get_param\": \"CephClientUserName\"}, \"key\": {\"get_param\": \"CephClientKey\"}}, \"manila\": {\"name\": {\"get_param\": \"ManilaCephFSCephFSAuthId\"}, \"key\": {\"get_param\": \"CephManilaClientKey\"}}, \"radosgw\": {\"name\": {\"get_param\": \"CephRgwClientName\"}, \"key\": {\"get_param\": \"CephRgwKey\"}}, \"extra_keys\": {\"get_param\": \"CephExtraKeys\"}}, \"ceph_config_overrides\": {\"get_param\": \"CephConfigOverrides\"}, \"tripleo_run_cephadm_spec_path\": {\"get_param\": \"CephSpecPath\"}, \"tripleo_cephadm_dynamic_spec\": {\"get_param\": \"CephDynamicSpec\"}, \"ceph_spec_fqdn\": {\"get_param\": \"CephSpecFqdn\"}, \"ceph_osd_spec\": {\"get_param\": \"CephOsdSpec\"}, \"ceph_default_overrides\": {\"global\": {\"if\": [{\"get_param\": \"CephMsgrSecureMode\"}, {\"map_merge\": [{\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}, {\"ms_cluster_mode\": \"secure\", \"ms_service_mode\": \"secure\", \"ms_client_mode\": \"secure\"}]}, {\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}]}}, \"cephadm_extra_vars\": {\"get_attr\": [\"CephAdmVars\", \"value\", \"vars\"]}, \"tripleo_cephadm_deployed_ceph\": {\"get_param\": \"DeployedCeph\"}}}, {\"name\": \"Prepare cephadm user and keys\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"enable_ceph_admin_user.yml\"}, \"when\": [\"not external_ceph\", \"(not deployed_ceph and (groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0)) or (deployed_ceph and ((groups[\'ceph_rgw\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rgw\'] | default([]) | length > 0) or (groups[\'ceph_mds\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_mds\'] | default([]) | length > 0) or (groups[\'ceph_nfs\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_nfs\'] | default([]) | length > 0) or (groups[\'ceph_rbdmirror\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rbdmirror\'] | default([]) | length > 0)))\"], \"vars\": {\"deployed_ceph\": {\"get_param\": \"DeployedCeph\"}, \"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}, {\"name\": \"Deploy or configure the cephadm Ceph cluster\", \"include_role\": {\"name\": \"tripleo_run_cephadm\"}, \"when\": [\"not external_ceph\", \"groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0\"], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}]}, {\"name\": \"ceph_base_external_deploy_task\", \"when\": [\"(step | int) == 3\", {\"get_param\": \"DisableCephadm\"}, \"not external_ceph\"], \"block\": [{\"name\": \"Pause cephadm\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"disable_cephadm.yml\"}}], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}], \"post_upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"DefaultPasswords\": {}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(122,'2026-06-13 07:50:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(123,'2026-06-13 07:50:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(124,'2026-06-13 07:50:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph Metadata service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph Metadata service.\", \"value\": {\"service_name\": \"ceph_mds\", \"firewall_rules\": {\"112 ceph_mds\": {\"dport\": {\"list_concat\": [[\"6800-7300\"], {\"if\": [{\"get_param\": \"CephEnableDashboard\"}, [\"9100\"]]}]}}}, \"puppet_config\": {}, \"docker_config\": {}, \"external_deploy_tasks\": [], \"external_update_tasks\": [], \"external_upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(125,'2026-06-13 07:50:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(126,'2026-06-13 07:50:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"iGVLW3iUSnJVJpZdHixGVnqNe\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"B5b9hxoqds8je7HIcmKZM8Gjs\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(127,'2026-06-13 07:50:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (128,'2026-06-13 07:50:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ovn Controller agent.\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ContainerOvnControllerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"ContainerOvnControllerConfigImage\": {\"description\": \"The container image to use for the ovn_controller config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the Southbound DB Server\", \"type\": \"number\", \"default\": 6642}, \"NeutronBridgeMappings\": {\"description\": \"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"datacentre:br-ex\", \"tags\": [\"role_specific\"]}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"OVNEncapType\": {\"description\": \"Type of encapsulation used in OVN. It can be \\\"geneve\\\" or \\\"vxlan\\\".\\n\", \"type\": \"string\", \"default\": \"geneve\", \"constraints\": [{\"allowed_values\": [\"geneve\", \"vxlan\"]}]}, \"OVNIntegrationBridge\": {\"description\": \"Name of the OVS bridge to use as integration bridge by OVN Controller.\\n\", \"type\": \"string\", \"default\": \"br-int\"}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNAvailabilityZone\": {\"description\": \"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"OVNCMSOptions\": {\"description\": \"The CMS options to configure in ovs db\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNEncapTos\": {\"description\": \"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\n\", \"type\": \"string\", \"default\": \"0\", \"tags\": [\"role_specific\"]}, \"OvsHwOffload\": {\"default\": false, \"description\": \"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"OVNRemoteProbeInterval\": {\"description\": \"Probe interval in ms\", \"type\": \"number\", \"default\": 60000}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"OVNOpenflowProbeInterval\": {\"description\": \"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\n\", \"type\": \"number\", \"default\": 60}, \"OVNOfctrlWaitBeforeClear\": {\"description\": \"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\n\", \"type\": \"number\", \"default\": 8000}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ContainerOvnCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OVNContainerCpusetCpus\": {\"description\": \"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNStaticBridgeMacMappings\": {\"type\": \"json\", \"default\": {}, \"description\": \"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\navailable, for instance in the standalone deployment, use this parameter\\nto provide static OVN bridge mac addresses. For example:\\n   controller-0:\\n     datacenter: 00:00:5E:00:53:00\\n     provider: 00:00:5E:00:53:01\\n   compute-0:\\n     datacenter: 00:00:5E:00:54:00\\n     provider: 00:00:5E:00:54:01\\n\", \"tags\": [\"role_specific\"]}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}, \"OVNControllerImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerGarpMaxTimeout\": {\"description\": \"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\n\", \"type\": \"number\", \"default\": 0}}, \"conditions\": {\"force_config_drive\": {\"equals\": [{\"get_param\": \"OVNMetadataEnabled\"}, false]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}, \"enable_vlan_transparency\": {\"equals\": [{\"get_param\": \"EnableVLANTransparency\"}, true]}, \"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"ovn_cpu_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"OVNContainerCpusetCpus\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNContainerCpusetCpus\"]}, \"\"]}}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}}, \"az_ovn_unset\": {\"and\": [{\"equals\": [{\"get_param\": \"OVNAvailabilityZone\"}, []]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn::controller::ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn::controller::ovn_cms_options\": {\"if\": [\"az_ovn_unset\", \"OVNCMSOptions\", \"OVNCMSOptionsMerged\"]}, \"ovn::controller::ovn_encap_tos\": \"OVNEncapTos\", \"vswitch::ovs::enable_hw_offload\": \"OvsHwOffload\", \"container_cpuset_cpus\": \"OVNContainerCpusetCpus\", \"ContainerOvnControllerImage\": \"ContainerOvnControllerImage\", \"ContainerOvnControllerConfigImage\": \"ContainerOvnControllerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}, \"OVNCMSOptionsMerged\": {\"list_join\": [\"\", [{\"str_replace\": {\"template\": \"$OVNCMSOptions\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}, \"\"]}}, {\"$OVNCMSOptions\": {\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}}, {\"$OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}}]}}}, {\"str_replace\": {\"template\": \",availability-zones=$OVNAvailabilityZone\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}}, {\"$OVNAvailabilityZone\": {\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}}, {\"$OVNAvailabilityZone\": {\"list_join\": [\",\", {\"get_param\": \"OVNAvailabilityZone\"}]}}]}}}]]}, \"OVNEncapTos\": {\"get_param\": \"OVNEncapTos\"}, \"OvsHwOffload\": {\"get_param\": \"OvsHwOffload\"}, \"OVNContainerCpusetCpus\": {\"get_param\": \"OVNContainerCpusetCpus\"}, \"ContainerOvnControllerImage\": {\"get_param\": \"ContainerOvnControllerImage\"}, \"ContainerOvnControllerConfigImage\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}}]}}}, \"OVNBridgeMappingsValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn_static_bridge_mac_mappings\": \"OVNStaticBridgeMacMappings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNStaticBridgeMacMappings\": {\"get_param\": \"OVNStaticBridgeMacMappings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ovn Controller agent.\", \"value\": {\"service_name\": \"ovn_controller\", \"firewall_rules\": {\"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::controller::ovn_encap_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}}}}, \"ovn::controller::ovn_encap_type\": {\"get_param\": \"OVNEncapType\"}, \"ovn::controller::ovn_bridge\": {\"get_param\": \"OVNIntegrationBridge\"}, \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": {\"get_param\": \"OVNRemoteProbeInterval\"}, \"ovn::controller::ovn_openflow_probe_interval\": {\"get_param\": \"OVNOpenflowProbeInterval\"}, \"ovn::controller::ovn_ofctrl_wait_before_clear\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}, \"ovn::controller::garp_max_timeout_sec\": {\"get_param\": \"OVNControllerGarpMaxTimeout\"}, \"ovn::controller::ovn_monitor_all\": true}, {\"if\": [\"force_config_drive\", {\"nova::compute::force_config_drive\": true}, {}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::agents::ovn::protocol\": \"ssl\"}, {}]}, {\"if\": [\"enable_vlan_transparency\", {\"vswitch::ovs::vlan_limit\": 0}, {}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\", {\"if\": [\"internal_tls_enabled\", {\"list_join\": [\" \", [\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\", {\"get_param\": \"InternalTLSCAFile\"}]]}, \"\"]}]]}, \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_controller\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"docker_config\": {\"step_4\": {\"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_controller\": {\"map_merge\": [{\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"]}, {\"if\": [\"ovn_cpu_set\", {\"cpuset_cpus\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"container_cpuset_cpus\"]}}]}, {\"healthcheck\": {\"test\": {\"list_join\": [\" \", [\"/openstack/healthcheck\", {\"yaql\": {\"expression\": \"str($.data.port)\", \"data\": {\"port\": {\"get_param\": \"OVNSouthboundServerPort\"}}}}]]}}, \"volumes\": {\"list_concat\": [[\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}, \"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\", \"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"ContainerOvnCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup\"}, \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\"}, \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": {\"str_replace\": {\"template\": \"create ovn mac address for $ROLE_NAME role nodes\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"role_name\": {\"get_param\": \"RoleName\"}, \"server_resource_names\": {\"str_replace\": {\"template\": \"{{ groups[\\\"$ROLE_NAME\\\"] }}\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"ovn_bridge_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_bridge_mappings\"]}, \"ovn_static_bridge_mac_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_static_bridge_mac_mappings\"]}}}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}], \"upgrade_tasks\": [{\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(129,'2026-06-13 07:50:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"CinderBackupBackend\": {\"default\": \"ceph\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBackupBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"CinderBackupBackend\": {\"get_param\": \"CinderBackupBackend\"}, \"CinderBackupRbdPoolName\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"CephClientUserName\": {\"get_param\": \"CephClientUserName\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::cinder::backup_bundle::cinder_backup_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::backup_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::backup::manage_service\": false, \"cinder::backup::enabled\": false}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"puppet_config\", \"step_config\"]}, \"include tripleo::profile::pacemaker::cinder::backup_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Backup tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Backup HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-backup temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-backup\", \"tripleo_ha_image_update_new_image\": \"{{cinder_backup_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_backup_image}}\"}, \"when\": [\"(pcmk_cinder_backup_image != \\\"\\\")\", \"(pcmk_cinder_backup_image != cinder_backup_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-backup container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_backup_image == cinder_backup_image_latest\", \"fail_msg\": \"cinder-backup image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder-backup container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"cinder_backup fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder backup bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA cinder_backup container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"Prepare switch of cinder_backup image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_backup image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-backup | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_backup_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_backup image facts\", \"set_fact\": {\"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_backup_image_current\": \"{{cinder_backup_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_backup image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image_current}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}, {\"name\": \"Create cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_backup_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_backup_bootstrap_node={{cinder_backup_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_backup retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_backup_bootstrap_node\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Update the cinder_backup bundle to use the new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-backup container image={{cinder_backup_image_latest}}\"}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_backup retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}, {\"name\": \"Retag the pacemaker image for cinder_backup\", \"when\": [\"step|int == 3\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step3\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(130,'2026-06-13 07:50:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph Manager service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephDashboardAdminUser\": {\"default\": \"admin\", \"description\": \"Admin user for the dashboard component\", \"type\": \"string\"}, \"CephDashboardAdminPassword\": {\"description\": \"Admin password for the dashboard component\", \"type\": \"string\", \"hidden\": true, \"default\": \"ez7ld4kZ0oywrDu0tWaOfh58A\"}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}, \"CephDashboardPort\": {\"type\": \"number\", \"default\": 8444, \"description\": \"Parameter that defines the ceph dashboard port.\"}, \"CephDashboardAdminRO\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Parameter used to set a read-only admin user.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"CephCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"and\": [{\"get_param\": \"CephEnableDashboard\"}, {\"get_param\": \"EnableInternalTLS\"}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"CephCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"CephBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"DefaultPasswords\": {\"get_param\": \"DefaultPasswords\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CephMgrAnsibleVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {\"tripleo_cephadm_dashboard_admin_user\": {\"get_param\": \"CephDashboardAdminUser\"}, \"tripleo_cephadm_dashboard_admin_password\": {\"get_param\": \"CephDashboardAdminPassword\"}, \"tripleo_cephadm_dashboard_port\": {\"get_param\": \"CephDashboardPort\"}, \"tripleo_cephadm_dashboard_admin_user_ro\": {\"get_param\": \"CephDashboardAdminRO\"}, \"tripleo_cephadm_dashboard_protocol\": {\"if\": [\"internal_tls_enabled\", \"https\", \"http\"]}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph Manager service.\", \"value\": {\"service_name\": \"ceph_mgr\", \"firewall_rules\": {\"113 ceph_mgr\": {\"dport\": {\"list_concat\": [[\"6800-7300\"], {\"if\": [{\"get_param\": \"CephEnableDashboard\"}, [{\"get_param\": \"CephDashboardPort\"}]]}]}}}, \"firewall_frontend_rules\": {\"if\": [{\"get_param\": \"CephEnableDashboard\"}, {\"100 ceph_dashboard\": {\"dport\": [{\"get_param\": \"CephDashboardPort\"}]}}]}, \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"external_deploy_tasks\": {\"list_concat\": [{\"get_attr\": [\"CephBase\", \"role_data\", \"external_deploy_tasks\"]}, {\"if\": [{\"get_param\": \"CephEnableDashboard\"}, [{\"name\": \"set tripleo-ansible ceph dashboard vars\", \"when\": \"step|int == 1\", \"set_fact\": {\"ceph_dashboard_vars\": {\"if\": [\"internal_tls_enabled\", {\"map_merge\": [{\"get_attr\": [\"CephMgrAnsibleVars\", \"value\", \"vars\"]}, {\"tripleo_cephadm_dashboard_crt\": \"/etc/pki/tls/certs/ceph_dashboard.crt\"}, {\"tripleo_cephadm_dashboard_key\": \"/etc/pki/tls/private/ceph_dashboard.key\"}, {\"tripleo_cephadm_dashboard_grafana_api_no_ssl_verify\": true}]}, {\"get_attr\": [\"CephMgrAnsibleVars\", \"value\", \"vars\"]}]}}}]]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ceph_dashboard\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": {\"if\": [\"internal_tls_enabled\", [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ceph_dashboard\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ceph_dashboard/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}}}, \"run_after\": \"# Get mgr systemd unit\\nmgr_unit=$(systemctl list-units | awk \'/ceph-mgr/ {print $1}\')\\n# Restart the mgr systemd unit\\nif [ -n \\\"$mgr_unit\\\" ]; then\\n    systemctl restart \\\"$mgr_unit\\\"\\nfi\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"CephCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(131,'2026-06-13 07:50:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Ceph base service. Shared by all Ceph services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"DefaultPasswords\": {\"default\": {}, \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NodeDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"json containing per-node configuration map\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"CephEnableDashboard\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Parameter used to trigger the dashboard deployment.\"}, \"CephConfigOverrides\": {\"type\": \"json\", \"description\": \"Extra config settings to dump into ceph.conf\", \"default\": {}}, \"ApplyCephConfigOverridesOnUpdate\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If true, CephConfigOverrides are applied to the Ceph cluster not only during the initial deployment but also during each update.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephMsgrSecureMode\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable Ceph msgr2 secure mode to enable on-wire encryption between Ceph daemons and also between Ceph clients and daemons.\\n\"}, \"CephPools\": {\"description\": \"Used to override settings (mainly target_size_ratio or pg_num) in pools. Pacific has pg_autoscale_mode enabled by default so set target_size_ratio as a percentage of the expected data consumption. The example below sets cinder volumes 40%, glance images 10%, nova vms 30% (20% of space free). Not set by default but overrides are encouraged to avoid data rebalancing. For example, CephPools:\\n  - name: volumes\\n    target_size_ratio: 0.4\\n    application: rbd\\n  - name: images\\n    target_size_ratio: 0.1\\n    application: rbd\\n  - name: vms\\n    target_size_ratio: 0.3\\n    application: rbd\\n\", \"default\": [], \"type\": \"json\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceBackend\": {\"default\": \"rbd\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GnocchiRbdPoolName\": {\"default\": \"metrics\", \"type\": \"string\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephRgwClientName\": {\"default\": \"radosgw\", \"type\": \"string\"}, \"CephRgwKey\": {\"description\": \"The cephx key for the radosgw client. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\"}, \"ManilaCephFSDataPoolName\": {\"default\": \"manila_data\", \"type\": \"string\"}, \"ManilaCephFSMetadataPoolName\": {\"default\": \"manila_metadata\", \"type\": \"string\"}, \"ManilaCephFSShareBackendName\": {\"default\": \"cephfs\", \"type\": \"string\"}, \"ManilaCephFSCephFSAuthId\": {\"default\": \"manila\", \"type\": \"string\"}, \"CephManilaClientKey\": {\"default\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}]}, \"CephIPv6\": {\"default\": false, \"type\": \"boolean\"}, \"SwiftPassword\": {\"description\": \"The password for the swift service account\", \"type\": \"string\", \"hidden\": true, \"default\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\"}, \"ContainerCephDaemonImage\": {\"description\": \"image\", \"type\": \"string\", \"default\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\"}, \"CephAnsiblePlaybookVerbosity\": {\"default\": 1, \"description\": \"The number of \'-v\', \'-vv\', etc. passed to ansible-playbook command\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 5}}]}, \"CephAnsibleEnvironmentVariables\": {\"default\": {}, \"description\": \"Mapping of Ansible environment variables to override defaults.\", \"type\": \"json\"}, \"SwiftFetchDirGetTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to download the fetch_directory from.\", \"type\": \"string\"}, \"SwiftFetchDirPutTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to upload the fetch_directory to.\", \"type\": \"string\"}, \"LocalCephAnsibleFetchDirectoryBackup\": {\"default\": \"\", \"description\": \"Filesystem path on undercloud to persist a copy of the data from the ceph-ansible fetch directory. Used as an alternative to backing up the fetch_directory in Swift. Path must be writable and readable by the user running ansible from config-download, e.g. the mistral user in the mistral-executor container is able to read/write to /var/lib/mistral/ceph_fetch\", \"type\": \"string\"}, \"CephOsdPercentageMin\": {\"default\": 0, \"description\": \"The minimum percentage of Ceph OSDs which must be running and in the Ceph cluster, according to ceph osd stat, for the deployment not to fail. Used to catch deployment errors early. Set this value to 0 to disable this check. Deprecated in Wallaby because of the move from ceph-ansible to cephadm; the later only brings up OSDs out of band and deployment does not block while waiting for them to come up, thus we cannot do this anymore.\", \"type\": \"number\"}, \"CephAnsiblePlaybook\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths to the ceph-ansible playbooks to execute. If not specified, the playbook will be determined automatically depending on type of operation being performed (deploy/update/upgrade).\\n\", \"default\": [\"default\"]}, \"CephAnsibleExtraConfig\": {\"type\": \"json\", \"description\": \"Extra vars for the ceph-ansible playbook\", \"default\": {}}, \"CephAnsibleSkipTags\": {\"type\": \"string\", \"description\": \"List of ceph-ansible tags to skip\", \"default\": \"package-install,with_pkg\"}, \"CephAnsibleRepo\": {\"type\": \"string\", \"description\": \"The repository that should be used to install the right ceph-ansible\\npackage. This value can be used by tripleo-validations to double check\\nthe right ceph-ansible version is installed.\\n\", \"default\": \"centos-ceph-nautilus\"}, \"CephAnsibleWarning\": {\"type\": \"boolean\", \"description\": \"In particular scenarios we want this validation to show the warning but\\ndon\'t fail because the package is installed on the system but repos are\\ndisabled.\\n\", \"default\": true}, \"CephPoolDefaultPgNum\": {\"description\": \"default pg_num to use for the RBD pools\", \"type\": \"number\", \"default\": 16}, \"CephPoolDefaultSize\": {\"description\": \"default minimum replication for RBD copies\", \"type\": \"number\", \"default\": 3}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\", \"default\": {}}, \"CephExtraKeys\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra keys which will be created on the deployed\\nCeph cluster. Uses ceph-ansible/library/ceph_key.py ansible module. Each\\nitem in the list must be in the following example format\\n  - name: \\\"client.glance\\\"\\n    caps:\\n      mgr: \\\"allow *\\\"\\n      mon: \\\"profile rbd\\\"\\n      osd: \\\"profile rbd pool=images\\\"\\n    key: \\\"AQBRgQ9eAAAAABAAv84zEilJYZPNuJ0Iwn9Ndg==\\\"\\n    mode: \\\"0600\\\"\\n\", \"default\": []}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderBackupBackend\": {\"default\": \"ceph\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"GnocchiBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Gnocchi backend to use. Should be one of swift, rbd, file or s3.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"s3\"]}]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CephClientConfigVars\": {\"default\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"type\": \"string\", \"description\": \"The undercloud path where cephadm exports the Ceph Client configuration.\"}, \"CephAnsibleSkipClient\": {\"description\": \"This boolean (when true) prevents the ceph-ansible client role execution\\nby adding the ceph-ansible tag \'ceph_client\' to the --skip-tags list.\\n\", \"type\": \"boolean\", \"default\": true}, \"CephDynamicSpec\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If true the tripleo_run_cephadm role will build an orchestrator-cli-service-spec\\nfile based on the data found in the inventory (which is based on composable roles)\\nby using the ceph_spec_bootstrap Ansible module in tripleo-ansible.\\n\"}, \"CephSpecPath\": {\"default\": \"{{ playbook_dir }}/cephadm/ceph_spec.yaml\", \"type\": \"string\", \"description\": \"The path on the undercloud to a valid Ceph orchestrator CLI service spec file.\\nIf you do not want the spec to be generated automatically and instead prefer\\nto supply your own spec, then place your spec at this path on the undercloud\\nand set CephDynamicSpec to false. If CephDynamicSpec is true and CephSpecPath\\nis set to a valid path, then the spec will be created at that path before it\\nis used to deploy Ceph. By default the spec will be created by config-download\\nin config-download/<stack>/cephadm/ceph_spec.yaml.\\n\"}, \"CephOsdSpec\": {\"description\": \"If CephDynamicSpec is true, then any valid OSD service specification set in\\nCephOsdSpec will appear in the genereated Ceph spec for the \'osd\' service_type.\\nReplaces CephAnsibleDisksConfig. This parameter has no effect if CephDynamicSpec\\nis false. Use this paramter to override the default of using all available block\\ndevices as data_devices. See the Ceph documentation for cephadm drivegroups.\\nExclude service_type, service_id, and placement from this parameter. In the\\nexample below all rotating devices will be data devices and all non-rotating\\ndevices will be used as shared devices (wal, db).\\n  CephOsdSpec:\\n    data_devices:\\n      rotational: 1\\n    db_devices:\\n      rotational: 0\\n\", \"type\": \"json\", \"default\": {\"data_devices\": {\"all\": true}}}, \"CephSpecFqdn\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If both CephDynamicSpec and CephSpecFqdn are true, then the hostname and\\nhosts of the generated Ceph spec will have their fully qualified domain\\nname instead of their short hostname. This parameter has no effect if\\nCephDynamicSpec is false.\\n\"}, \"CephCrushRules\": {\"type\": \"json\", \"description\": \"List of rules describing the device classes that will be found on the deployed\\nCeph cluster. They can be specified in the following form\\n- name: HDD\\n  root: default\\n  type: host\\n  class: hdd\\n  default: true\\n\", \"default\": []}, \"CephAdmDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, then cephadm sets the debug related mgr\\nconfig-key and produces a more verbose output.\\n\"}, \"CephAdmVerbose\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If this parameter is true, the cephadm playbook is able to print\\nsome ceph related information during its execution.\\n\"}, \"DeployedCeph\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"DisableCephadm\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Disable cephadm after Ceph is deployed\"}, \"CephRbdTrashPurgeInterval\": {\"default\": 15, \"type\": \"string\", \"description\": \"The interval applied to the rbd trash purge scheduler, that can be\\nexpressed in minutes.\\n\"}, \"CephRbdTrashSchedulerEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable Ceph rbd trash scheduler\"}, \"CephadmDefaultContainer\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Use the default continer defined in cephadm instead of\\nthe one defined in container_image_prepare_defaults.yaml.\\n\"}, \"ExternalCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has been deployed outside of TripleO.\\nDeployedCeph and ExternalCeph are mutually exclusive.\\n\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"LocalCephAnsibleFetchDirectoryBackup\", \"SwiftFetchDirGetTempurl\", \"SwiftFetchDirPutTempurl\", \"CephIPv6\", \"CephAnsibleEnvironmentVariables\", \"CephAnsibleExtraConfig\", \"CephAnsiblePlaybook\", \"CephAnsiblePlaybookVerbosity\", \"CephAnsibleRepo\", \"CephAnsibleSkipTags\", \"CephAnsibleSkipClient\", \"CephAnsibleWarning\", \"CephOsdPercentageMin\", \"CephPoolDefaultPgNum\", \"CephPoolDefaultSize\"]}], \"conditions\": {\"custom_registry_host\": {\"yaql\": {\"data\": {\"get_param\": \"ContainerCephDaemonImage\"}, \"expression\": \"$.data.split(\'/\')[0].matches(\'(\\\\.|:)\')\"}}, \"ceph_authenticated_registry\": {\"and\": [{\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\").isEmpty()\"}}}, {\"not\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\").isEmpty()\"}}}]}}, \"resources\": {\"ContainerImageUrlParts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"host\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, \"docker.io\"]}, \"image\": {\"if\": [\"custom_registry_host\", {\"yaql\": {\"expression\": \"let(location => $.data.rightSplit(\':\', 1)[0]) -> regex(\'(?:https?://)?(.*?)/(.*)\').split($location)[2]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}, {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[0]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}]}, \"image_tag\": {\"yaql\": {\"expression\": \"$.data.rightSplit(\':\', 1)[1]\", \"data\": {\"get_param\": \"ContainerCephDaemonImage\"}}}}}}, \"DefaultCephConfigOverrides\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {}}}}, \"CephAdmVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"vars\": {\"tripleo_cephadm_fsid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo_cephadm_cluster\": {\"get_param\": \"CephClusterName\"}, \"tripleo_cephadm_container_cli\": {\"get_param\": \"ContainerCli\"}, \"tripleo_ceph_client_vars\": {\"get_param\": \"CephClientConfigVars\"}, \"tripleo_cephadm_dashboard_enabled\": {\"get_param\": \"CephEnableDashboard\"}, \"cephfs\": {\"get_param\": \"ManilaCephFSShareBackendName\"}, \"tripleo_cephadm_container_ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}, \"tripleo_cephadm_container_image\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image\"]}, \"tripleo_cephadm_container_tag\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"image_tag\"]}, \"tripleo_cephadm_crush_rules\": {\"get_param\": \"CephCrushRules\"}, \"tripleo_cephadm_debug\": {\"get_param\": \"CephAdmDebug\"}, \"tripleo_cephadm_verbose\": {\"get_param\": \"CephAdmVerbose\"}, \"tripleo_cephadm_rbd_trash\": {\"get_param\": \"CephRbdTrashPurgeInterval\"}, \"tripleo_cephadm_enable_trash_scheduler\": {\"get_param\": \"CephRbdTrashSchedulerEnable\"}, \"tripleo_cephadm_apply_ceph_conf_overrides_on_update\": {\"get_param\": \"ApplyCephConfigOverridesOnUpdate\"}, \"tripleo_cephadm_default_container\": {\"get_param\": \"CephadmDefaultContainer\"}, \"ceph_container_registry_auth\": {\"if\": [\"ceph_authenticated_registry\", true, false]}, \"ceph_container_registry_username\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).keys().last(default => \\\"\\\")\"}}, \"ceph_container_registry_password\": {\"yaql\": {\"data\": {\"cred\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"ns\": {\"get_attr\": [\"ContainerImageUrlParts\", \"value\", \"host\"]}}, \"expression\": \"let(c => $.data.cred) -> $c.get($.data.ns, {}).values().last(default => \\\"\\\")\"}}, \"public_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephMonNetwork\"]}]}]}, \"cluster_network\": {\"list_join\": [\",\", {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"CephClusterNetwork\"]}]}]}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceph base service.\", \"value\": {\"service_name\": \"ceph_base\", \"upgrade_tasks\": [], \"puppet_config\": {}, \"docker_config\": {}, \"config_settings\": {}, \"external_deploy_tasks\": [{\"name\": \"ceph_base_external_deploy_task\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"create cephadm working directory and related files\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"prepare.yml\"}, \"vars\": {\"ceph_pools\": {\"gnocchi_pool\": {\"name\": {\"get_param\": \"GnocchiRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"GnocchiBackend\"}, \"rbd\"]}, true, false]}}, \"nova_pool\": {\"name\": {\"get_param\": \"NovaRbdPoolName\"}, \"enabled\": {\"get_param\": \"NovaEnableRbdBackend\"}}, \"glance_pool\": {\"name\": {\"get_param\": \"GlanceRbdPoolName\"}, \"enabled\": {\"or\": [{\"yaql\": {\"data\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"expression\": \"$.data.values().where($ != null).GlanceBackend.contains(\\\"rbd\\\")\"}}, {\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}]}}, \"cinder_pool\": {\"name\": {\"get_param\": \"CinderRbdPoolName\"}, \"enabled\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"cinder_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}}, \"cinder_backup_pool\": {\"name\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"enabled\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, true, false]}}, \"extra_pools\": {\"get_param\": \"CephPools\"}}, \"manila_pools\": {\"data\": {\"get_param\": \"ManilaCephFSDataPoolName\"}, \"metadata\": {\"get_param\": \"ManilaCephFSMetadataPoolName\"}}, \"ceph_keys\": {\"openstack_client\": {\"name\": {\"get_param\": \"CephClientUserName\"}, \"key\": {\"get_param\": \"CephClientKey\"}}, \"manila\": {\"name\": {\"get_param\": \"ManilaCephFSCephFSAuthId\"}, \"key\": {\"get_param\": \"CephManilaClientKey\"}}, \"radosgw\": {\"name\": {\"get_param\": \"CephRgwClientName\"}, \"key\": {\"get_param\": \"CephRgwKey\"}}, \"extra_keys\": {\"get_param\": \"CephExtraKeys\"}}, \"ceph_config_overrides\": {\"get_param\": \"CephConfigOverrides\"}, \"tripleo_run_cephadm_spec_path\": {\"get_param\": \"CephSpecPath\"}, \"tripleo_cephadm_dynamic_spec\": {\"get_param\": \"CephDynamicSpec\"}, \"ceph_spec_fqdn\": {\"get_param\": \"CephSpecFqdn\"}, \"ceph_osd_spec\": {\"get_param\": \"CephOsdSpec\"}, \"ceph_default_overrides\": {\"global\": {\"if\": [{\"get_param\": \"CephMsgrSecureMode\"}, {\"map_merge\": [{\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}, {\"ms_cluster_mode\": \"secure\", \"ms_service_mode\": \"secure\", \"ms_client_mode\": \"secure\"}]}, {\"get_attr\": [\"DefaultCephConfigOverrides\", \"value\", \"vars\"]}]}}, \"cephadm_extra_vars\": {\"get_attr\": [\"CephAdmVars\", \"value\", \"vars\"]}, \"tripleo_cephadm_deployed_ceph\": {\"get_param\": \"DeployedCeph\"}}}, {\"name\": \"Prepare cephadm user and keys\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"enable_ceph_admin_user.yml\"}, \"when\": [\"not external_ceph\", \"(not deployed_ceph and (groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0)) or (deployed_ceph and ((groups[\'ceph_rgw\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rgw\'] | default([]) | length > 0) or (groups[\'ceph_mds\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_mds\'] | default([]) | length > 0) or (groups[\'ceph_nfs\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_nfs\'] | default([]) | length > 0) or (groups[\'ceph_rbdmirror\'] | default([]) != groups[\'ceph_mon\'] | default([]) and groups[\'ceph_rbdmirror\'] | default([]) | length > 0)))\"], \"vars\": {\"deployed_ceph\": {\"get_param\": \"DeployedCeph\"}, \"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}, {\"name\": \"Deploy or configure the cephadm Ceph cluster\", \"include_role\": {\"name\": \"tripleo_run_cephadm\"}, \"when\": [\"not external_ceph\", \"groups[\'ceph_mon\'] | default([]) | length > 0 or groups[\'ceph_nfs\'] | default([]) | length > 0\"], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}]}, {\"name\": \"ceph_base_external_deploy_task\", \"when\": [\"(step | int) == 3\", {\"get_param\": \"DisableCephadm\"}, \"not external_ceph\"], \"block\": [{\"name\": \"Pause cephadm\", \"include_role\": {\"name\": \"tripleo_run_cephadm\", \"tasks_from\": \"disable_cephadm.yml\"}}], \"vars\": {\"external_ceph\": {\"get_param\": \"ExternalCeph\"}}}], \"post_upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"DefaultPasswords\": {}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(132,'2026-06-13 07:50:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(133,'2026-06-13 07:50:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(134,'2026-06-13 07:50:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IOcEXVmeV2fpzQjbFPUW1TNW\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(135,'2026-06-13 07:50:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder API service\\n\", \"parameters\": {\"ContainerCinderApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.api\", \"file\": \"/var/log/containers/cinder/cinder-api.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CinderDefaultVolumeType\": {\"default\": \"tripleo\", \"description\": \"The name of Cinder\'s default volume type.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \".*\\\\S.*\", \"description\": \"The default volume type name cannot be empty.\\n\"}]}, \"CinderEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Cinder database.\\n\", \"type\": \"boolean\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"32HDlh1wtNuoeOyht2a9njXCx\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionCinderApi\": {\"default\": \"overcloud-cinder-api\", \"type\": \"string\"}, \"CinderWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for cinder::wsgi::apache\", \"default\": 1}, \"CinderApiPolicies\": {\"description\": \"A hash of policies to configure for Cinder API.\\ne.g. { cinder-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"CinderApiWsgiTimeout\": {\"default\": 60, \"description\": \"The number of seconds until a Cinder API WSGI connection times out.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderApiImage\": \"ContainerCinderApiImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderApiImage\": {\"get_param\": \"ContainerCinderApiImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder API role.\", \"value\": {\"service_name\": \"cinder_api\", \"firewall_rules\": {\"119 cinder\": {\"dport\": [8776]}}, \"firewall_frontend_rules\": {\"100 cinder_haproxy_frontend\": {\"dport\": [8776]}}, \"firewall_ssl_frontend_rules\": {\"100 cinder_haproxy_frontend_ssl\": {\"dport\": [13776]}}, \"keystone_resources\": {\"cinder\": {\"users\": {\"cinder\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}}, \"cinderv3\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"CinderV3Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"CinderV3Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"CinderV3Admin\", \"uri\"]}}, \"users\": {\"cinderv3\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"volumev3\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"keystone_resources_managed\": false}, {\"cinder::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::authtoken::project_name\": \"service\", \"cinder::keystone::authtoken::user_domain_name\": \"Default\", \"cinder::keystone::authtoken::project_domain_name\": \"Default\", \"cinder::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::keystone::authtoken::interface\": \"internal\", \"cinder::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"cinder::policy::policies\": {\"get_param\": \"CinderApiPolicies\"}, \"cinder::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"cinder::api::default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}, \"cinder::api::enable_proxy_headers_parsing\": true, \"tripleo::profile::base::cinder::cinder_enable_db_purge\": {\"get_param\": \"CinderEnableDBPurge\"}, \"cinder::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"cinder::api::service_name\": \"httpd\", \"cinder::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::vhost_custom_fragment\": {\"str_replace\": {\"template\": \"Timeout TIMEOUT\", \"params\": {\"TIMEOUT\": {\"get_param\": \"CinderApiWsgiTimeout\"}}}}, \"cinder::wsgi::apache::workers\": {\"get_param\": \"CinderWorkers\"}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_api\": [{\"get_param\": \"CinderApiLoggingSource\"}]}, \"mysql\": {\"cinder::db::mysql::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::db::mysql::user\": \"cinder\", \"cinder::db::mysql::host\": \"%\", \"cinder::db::mysql::dbname\": \"cinder\"}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line,cinder_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec cinder_api su cinder -s /bin/bash -c \'cinder-manage db sync --bump-versions\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"cinder_api_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_3\": {\"cinder_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"cinder_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"cinder_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron cinder\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/cinder-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}, {\"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_api\", \"cinder_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}], \"external_deploy_tasks\": [{\"name\": \"Clean up legacy Cinder keystone catalog entries\", \"become\": true, \"openstack.cloud.catalog_service\": {\"cloud\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}, \"name\": \"{{ item.service_name }}\", \"service_type\": \"{{ item.service_type }}\", \"state\": \"absent\"}, \"loop\": [{\"service_name\": \"cinderv2\", \"service_type\": \"volumev2\"}, {\"service_name\": \"cinderv3\", \"service_type\": \"volume\"}], \"loop_control\": {\"index_var\": \"cinder_api_service\"}, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"]}, {\"name\": \"Manage Cinder\'s default volume type\", \"become\": true, \"vars\": {\"default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}}, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"when\": [\"step|int == 5\", \"not ansible_check_mode|bool\"], \"shell\": \"if ! openstack volume type show \\\"{{ default_volume_type }}\\\"; then\\n    openstack volume type create --public \\\"{{ default_volume_type }}\\\"\\nfi\\neval $(openstack volume type show __DEFAULT__ -f shell -c id -c description)\\nif [ -n \\\"$id\\\" ]; then\\n    if ! openstack volume type delete $id ; then\\n        tripleo_descr=\\\"For internal use, \'{{ default_volume_type }}\' is the default volume type\\\"\\n        if [ \\\"$description\\\" != \\\"$tripleo_descr\\\" ]; then\\n            openstack volume type set $id --description \\\"$tripleo_descr\\\"\\n        fi\\n    fi\\nfi\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"changed_when\": false}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (136,'2026-06-13 07:50:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(137,'2026-06-13 07:50:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::volume::manage_service\": false, \"cinder::volume::enabled\": false, \"cinder::backend_host\": \"hostgroup\"}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\"], [\"include tripleo::profile::pacemaker::cinder::volume_bundle\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Volume tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Volume HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-volume temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-volume\", \"tripleo_ha_image_update_new_image\": \"{{cinder_volume_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_volume_image}}\"}, \"when\": [\"(pcmk_cinder_volume_image != \\\"\\\")\", \"(pcmk_cinder_volume_image != cinder_volume_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-volume container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_volume_image == cinder_volume_image_latest\", \"fail_msg\": \"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"cinder_volume fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder volume bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"Prepare switch of cinder_volume image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_volume image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_volume_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_volume image facts\", \"set_fact\": {\"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_volume_image_current\": \"{{cinder_volume_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_volume image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image_current}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}, {\"name\": \"Create cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_volume_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_volume retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_volume_bootstrap_node\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"pcs resource bundle update cinder_volume for new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\"}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_volume retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}, {\"name\": \"Retag pacemaker cinder_volume\", \"when\": [\"step|int == 3\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"absent\"}}]}], {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}]}, \"post_upgrade_tasks\": [{\"name\": \"Start cinder_volume service (pacemaker)\", \"become\": true, \"when\": \"step|int == 1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(138,'2026-06-13 07:50:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CinderBackupBackend\": {\"default\": \"ceph\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupWorkers\": {\"type\": \"number\", \"default\": 1, \"description\": \"The number of cinder-backup processes to launch.\"}, \"CinderBackupMaxOperations\": {\"type\": \"number\", \"default\": 15, \"description\": \"The maximum number of concurrent cinder backup/restore operations (0 means unlimited).\"}, \"CinderBackupCompressionAlgorithm\": {\"default\": \"zlib\", \"description\": \"The compression algorithm used by Cinder Backup backends that are based on Cinder\'s \\\"chunked\\\" backup driver. This includes the swift, nfs, gcs and s3 backends. The ceph backend does not support the feature.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"zlib\", \"bzip2\", \"zstd\"]}]}, \"CinderBackupRbdClusterName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The Ceph cluster where backups are to be stored. If no value is specified then the CephClusterName value is used.\"}, \"CinderBackupRbdClientUserName\": {\"default\": \"\", \"type\": \"string\", \"description\": \"The Ceph client name used by the backup service. If no value is specified then the CephClientUserName value is used.\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CinderBackupNfsShare\": {\"default\": \"\", \"description\": \"NFS share to be mounted\", \"type\": \"string\"}, \"CinderBackupNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options passed to the NFS client. See NFS man page for details.\", \"type\": \"string\"}, \"CinderBackupGcsCredentials\": {\"default\": {}, \"description\": \"The GCS service account credentials, in JSON format.\", \"type\": \"json\"}, \"CinderBackupGcsProjectId\": {\"default\": \"\", \"description\": \"The GCS project ID.\", \"type\": \"string\"}, \"CinderBackupGcsBucket\": {\"default\": \"volumebackups\", \"description\": \"The GCS bucket where backups are to be stored.\", \"type\": \"string\"}, \"CinderBackupGcsBucketLocation\": {\"default\": \"\", \"description\": \"If set, it specifies the location where the GCS bucket should be created.\", \"type\": \"string\"}, \"CinderBackupS3EndpointUrl\": {\"default\": \"\", \"description\": \"The URL where the S3 server is listening.\", \"type\": \"string\"}, \"CinderBackupS3AccessKey\": {\"default\": \"\", \"description\": \"The S3 query token access key.\", \"type\": \"string\"}, \"CinderBackupS3SecretKey\": {\"default\": \"\", \"description\": \"The S3 query token secret key.\", \"type\": \"string\"}, \"CinderBackupS3Bucket\": {\"default\": \"volumebackups\", \"description\": \"The S3 bucket where backups are to be stored.\", \"type\": \"string\"}, \"MonitoringSubscriptionCinderBackup\": {\"default\": \"overcloud-cinder-backup\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderBackup\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::backup::backup_workers\": {\"get_param\": \"CinderBackupWorkers\"}, \"cinder::backup::backup_max_operations\": {\"get_param\": \"CinderBackupMaxOperations\"}}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, {\"cinder::backup::ceph::backup_ceph_user\": {\"str_replace\": {\"template\": \"USERNAME\", \"params\": {\"USERNAME\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClientUserName\"}, \"\"]}, {\"get_param\": \"CephClientUserName\"}, {\"get_param\": \"CinderBackupRbdClientUserName\"}]}}}}, \"cinder::backup::ceph::backup_ceph_pool\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"cinder::backup::ceph::backup_ceph_conf\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.conf\", \"params\": {\"CLUSTER\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClusterName\"}, \"\"]}, {\"get_param\": \"CephClusterName\"}, {\"get_param\": \"CinderBackupRbdClusterName\"}]}}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"swift\"]}, {\"cinder::backup::swift::backup_swift_container\": \"volumebackups\", \"cinder::backup::swift::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}, \"cinder::backup::swift::swift_catalog_info\": \"object-store:swift:internalURL\"}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"nfs\"]}, {\"cinder::backup::nfs::backup_share\": {\"get_param\": \"CinderBackupNfsShare\"}, \"cinder::backup::nfs::backup_mount_options\": {\"get_param\": \"CinderBackupNfsMountOptions\"}, \"cinder::backup::nfs::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"gcs\"]}, {\"tripleo::profile::base::cinder::backup::gcs::credentials\": {\"get_param\": \"CinderBackupGcsCredentials\"}, \"cinder::backup::google::backup_gcs_project_id\": {\"get_param\": \"CinderBackupGcsProjectId\"}, \"cinder::backup::google::backup_gcs_bucket\": {\"get_param\": \"CinderBackupGcsBucket\"}, \"cinder::backup::google::backup_gcs_bucket_location\": {\"get_param\": \"CinderBackupGcsBucketLocation\"}, \"cinder::config::cinder_config\": {\"DEFAULT/backup_compression_algorithm\": {\"value\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"s3\"]}, {\"cinder::backup::s3::backup_s3_endpoint_url\": {\"get_param\": \"CinderBackupS3EndpointUrl\"}, \"cinder::backup::s3::backup_s3_store_access_key\": {\"get_param\": \"CinderBackupS3AccessKey\"}, \"cinder::backup::s3::backup_s3_store_secret_key\": {\"get_param\": \"CinderBackupS3SecretKey\"}, \"cinder::backup::s3::backup_s3_store_bucket\": {\"get_param\": \"CinderBackupS3Bucket\"}, \"cinder::backup::s3::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_backup\": [{\"get_param\": \"DockerCinderBackupLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"str_replace\": {\"template\": \"include tripleo::profile::base::cinder::backup::DRIVER\", \"params\": {\"DRIVER\": {\"get_param\": \"CinderBackupBackend\"}}}}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_backup\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"deploy_steps_tasks\": [{\"name\": \"Clean up when switching cinder-backup from pcmk to active-active\", \"when\": [\"step|int == 1\"], \"become\": true, \"block\": [{\"name\": \"Check if cinder-backup is running under pacemaker\", \"command\": \"pcs status\", \"register\": \"cinder_backup_pcs_status\", \"check_mode\": false, \"failed_when\": false, \"changed_when\": false}, {\"when\": [\"\\\"cinder-backup\\\" in cinder_backup_pcs_status.stdout\"], \"block\": [{\"name\": \"Remove the openstack-cinder-backup pcs resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"delete\"}, \"run_once\": true}, {\"name\": \"Identify the cinder-backup pcmklatest container image\", \"shell\": \"{{container_cli}} images | awk \'$1 ~ \\\"cinder-backup\\\" && $2 == \\\"pcmklatest\\\" {print $1\\\":\\\"$2}\'\", \"register\": \"cinder_backup_pcmklatest_image\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Remove the cinder-backup pcmklatest container image\", \"command\": \"{{container_cli}} rmi {{cinder_backup_pcmklatest_image.stdout}}\", \"when\": [\"cinder_backup_pcmklatest_image.stdout|length > 0\"]}]}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder backup container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_backup\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_backup\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"CephClientUserName\": \"openstack\", \"CinderBackupBackend\": \"ceph\", \"CinderBackupRbdPoolName\": \"backups\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(139,'2026-06-13 07:50:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(140,'2026-06-13 07:50:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"], \"ComputeHCI\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(141,'2026-06-13 07:50:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(142,'2026-06-13 07:50:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(143,'2026-06-13 07:50:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(144,'2026-06-13 07:50:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (145,'2026-06-13 07:50:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(146,'2026-06-13 07:50:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized OVN Metadata agent\\n\", \"parameters\": {\"ContainerOvnMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"OvnMetadataAgentLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.neutron.agent.ovn-metadata\", \"file\": \"/var/log/containers/neutron/networking-ovn-metadata-agent.log\"}}, \"OVNEnableHaproxyDockerWrapper\": {\"description\": \"Generate a wrapper script so that haproxy is launched in a separate container.\", \"type\": \"boolean\", \"default\": true}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"OVNWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\"}, \"NeutronMetadataWorkers\": {\"default\": 1, \"description\": \"Sets the number of worker processes for the neutron OVN metadata agent.\\nThe default value results in the configuration being left unset and a\\nsystem-dependent default will be chosen (usually the number of\\nprocessors). Please note that this can result in a large number of\\nprocesses and memory consumption on systems with a large core count. On\\nsuch systems it is recommended that a non-default value be selected that\\nmatches the load requirements.\\n\", \"type\": \"string\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\"}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNDbConnectionTimeout\": {\"description\": \"Timeout in seconds for the OVSDB connection transaction\", \"type\": \"number\", \"default\": 180}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"MonitoringSubscriptionOvnMetadata\": {\"default\": \"overcloud-ovn-metadata\", \"type\": \"string\"}, \"OvnMetadataAgentDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging for OVN Metadata agent.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"DockerAdditionalSockets\": {\"default\": [\"/var/lib/openstack/docker.sock\"], \"description\": \"Additional domain sockets for the docker daemon to bind to (useful for mounting into containers that launch other containers)\", \"type\": \"comma_delimited_list\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"OvnMetadataCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OvnHardwareOffloadedQos\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable the QoS support for hardware offloaded ports\"}, \"OVNMetadataImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNMetadataUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}}, \"conditions\": {\"haproxy_wrapper_enabled\": {\"equals\": [{\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_metadata_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronMetadataWorkers\"}, \"\"]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"OvnMetadataCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NeutronLogging\": {\"type\": \"OS::TripleO::Services::Logging::NeutronCommon\", \"properties\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerOvnMetadataImage\": \"ContainerOvnMetadataImage\", \"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerOvnMetadataImage\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for OVNMetadata agent\", \"value\": {\"service_name\": \"ovn_metadata\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionOvnMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NeutronLogging\", \"config_settings\"]}, {\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\": \"/var/lib/neutron/ovn_metadata_haproxy_wrapper\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo::profile::base::neutron::container_cli\": {\"get_param\": \"ContainerCli\"}, \"neutron::agents::ovn_metadata::shared_secret\": {\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"neutron::agents::ovn_metadata::auth_password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::agents::ovn_metadata::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::agents::ovn_metadata::auth_tenant\": \"service\", \"neutron::agents::ovn_metadata::metadata_host\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataCellInternal\", \"host_nobrackets\"]}, \"neutron::agents::ovn_metadata::ovsdb_connection_timeout\": {\"get_param\": \"OVNDbConnectionTimeout\"}, \"neutron::agents::ovn_metadata::ovsdb_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}, \"neutron::agents::ovn_metadata::hwol_qos_enabled\": {\"get_param\": \"OvnHardwareOffloadedQos\"}, \"ovn::northbound::port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"neutron::agents::ovn_metadata::debug\": {\"if\": [{\"get_param\": \"OvnMetadataAgentDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::agents::ovn_metadata::metadata_protocol\": {\"if\": [\"internal_tls_enabled\", \"https\", \"http\"]}}, {\"if\": [\"neutron_metadata_workers_unset\", {}, {\"neutron::agents::ovn_metadata::metadata_workers\": {\"get_param\": \"NeutronMetadataWorkers\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::protocol\": \"ssl\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\"}, {}]}]}, \"puppet_config\": {\"puppet_tags\": \"neutron_config,ovn_metadata_agent_config\", \"config_volume\": \"neutron\", \"step_config\": \"include tripleo::profile::base::neutron::ovn_metadata\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_metadata_agent.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini\", {\"get_attr\": [\"NeutronLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/var/lib/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/ovn_metadata.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_2\": {\"create_haproxy_wrapper\": {\"start_order\": 1, \"detach\": false, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\"]]}}}, \"step_4\": {\"setup_ovs_manager\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"exec\", \"include tripleo::profile::base::neutron::ovn_metadata\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_metadata_agent\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"cgroupns\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\", \"/run/netns:/run/netns:shared\", \"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\"], {\"if\": [\"docker_enabled\", [\"/var/lib/openstack:/var/lib/openstack\"], null]}, {\"if\": [\"haproxy_wrapper_enabled\", [\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\"], null]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\", \"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}, {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_metadata\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_metadata\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_metadata/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_metadata_agent\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"OvnMetadataCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NeutronLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create /run/netns with temp namespace\", \"command\": \"ip netns add ns_temp\", \"register\": \"ipnetns_add_result\", \"failed_when\": false}, {\"name\": \"remove temp namespace\", \"command\": \"ip netns delete ns_temp\", \"failed_when\": false, \"when\": [\"ipnetns_add_result.rc is defined\", \"ipnetns_add_result.rc == 0\"]}, {\"name\": \"create /var/lib/neutron\", \"file\": {\"path\": \"/var/lib/neutron\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"set conditions\", \"set_fact\": {\"haproxy_wrapper_enabled\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"debug_enabled\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"docker_additional_sockets\": {\"get_param\": \"DockerAdditionalSockets\"}}}, {\"name\": \"create kill_scripts directory within /var/lib/neutron\", \"file\": {\"state\": \"directory\", \"path\": \"/var/lib/neutron/kill_scripts\"}}, {\"name\": \"create haproxy kill script\", \"when\": \"haproxy_wrapper_enabled|bool\", \"copy\": {\"dest\": \"/var/lib/neutron/kill_scripts/haproxy-kill\", \"mode\": 493, \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/kill-script\"}}}]]}, \"upgrade_tasks\": [], \"external_update_tasks\": [{\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\n\", \"register\": \"metadata_python_ovs_3_1\", \"failed_when\": false, \"loop\": \"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}, {\"name\": \"Update ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"become\": true, \"loop\": \"{{ hosts_to_update_metadata }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_metadata_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_metadata_agent image pull successful.\", \"when\": [\"\'results\' in ovn_metadata_image_update\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_metadata_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"tags\": [\"ovn_metadata_parallel\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0}]}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"never\", \"ovn_metadata_serial\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"loop_control\": {\"pause\": 1}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(147,'2026-06-13 07:50:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"openstacklocal\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(148,'2026-06-13 07:50:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(149,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(150,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Scheduler service\\n\", \"parameters\": {\"ContainerCinderSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderSchedulerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.scheduler\", \"file\": \"/var/log/containers/cinder/cinder-scheduler.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCinderScheduler\": {\"default\": \"overcloud-cinder-scheduler\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderSchedulerImage\": \"ContainerCinderSchedulerImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderSchedulerImage\": {\"get_param\": \"ContainerCinderSchedulerImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Scheduler role.\", \"value\": {\"service_name\": \"cinder_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderScheduler\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::scheduler::scheduler_driver\": \"cinder.scheduler.filter_scheduler.FilterScheduler\"}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_scheduler\": [{\"get_param\": \"CinderSchedulerLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::scheduler\"], [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_scheduler.json\": {\"command\": \"/usr/bin/cinder-scheduler --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}}, \"docker_config\": {\"step_2\": {\"cinder_scheduler_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_common_volumes\"]}, [\"/var/lib/kolla/config_files/cinder_scheduler.json:/var/lib/kolla/config_files/config.json:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(151,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(152,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(153,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (154,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"no\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(155,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(156,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(157,'2026-06-13 07:50:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron service\\n\", \"parameters\": {\"NeutronServiceName\": {\"description\": \"service name\", \"type\": \"string\"}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": {\"str_replace\": {\"template\": \"--log-file=/var/log/neutron/SERVICE.log\", \"params\": {\"SERVICE\": {\"get_param\": \"NeutronServiceName\"}}}}}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/neutron:/var/log/neutron:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(158,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(159,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"DockerCinderVolumeUlimit\": {\"default\": [\"nofile=131072\"], \"description\": \"ulimit for Cinder Volume Container\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableIscsiBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CinderISCSIAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderISCSIHelper\": {\"default\": \"lioadm\", \"description\": \"The iSCSI helper to use with cinder.\", \"type\": \"string\"}, \"CinderISCSIProtocol\": {\"default\": \"iscsi\", \"description\": \"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\", \"type\": \"string\"}, \"CinderNfsAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNfsServers\": {\"default\": \"\", \"description\": \"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderNfsSnapshotSupport\": {\"default\": false, \"description\": \"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"boolean\"}, \"CinderNasSecureFileOperations\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNasSecureFilePermissions\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderRbdBackendName\": {\"type\": \"comma_delimited_list\", \"default\": \"tripleo_ceph\", \"description\": \"A list of Cinder RBD backend names.\"}, \"CinderRbdAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderRbdFlattenVolumeFromSnapshot\": {\"default\": false, \"description\": \"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\n\", \"type\": \"boolean\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}, \"MonitoringSubscriptionCinderVolume\": {\"default\": \"overcloud-cinder-volume\", \"type\": \"string\"}, \"CinderEtcdLocalConnect\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"120 iscsi initiator\": {\"dport\": 3260}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderVolume\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"CinderCommon\", \"cinder_volume_config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\": {\"get_param\": \"CinderEnableIscsiBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_volume_cluster\": {\"get_param\": \"CinderVolumeCluster\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\": {\"get_param\": \"CinderNfsMountOptions\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\": {\"get_param\": \"CinderNfsServers\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\": {\"get_param\": \"CinderNfsSnapshotSupport\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\": {\"get_param\": \"CinderNasSecureFileOperations\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\": {\"get_param\": \"CinderNasSecureFilePermissions\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\": {\"get_param\": \"CinderISCSIHelper\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\": {\"get_param\": \"CinderISCSIProtocol\"}, \"tripleo::profile::base::cinder::volume::rbd::backend_name\": {\"get_param\": \"CinderRbdBackendName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\": {\"get_param\": \"CinderRbdPoolName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\": {\"get_param\": \"CinderRbdFlattenVolumeFromSnapshot\"}, \"tripleo::profile::base::cinder::volume::rbd::multi_config\": {\"get_param\": \"CinderRbdMultiConfig\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderISCSIAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\": {\"get_param\": \"CinderISCSIAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNfsAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\": {\"get_param\": \"CinderNfsAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderRbdAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\": {\"get_param\": \"CinderRbdAvailabilityZone\"}}]}, {\"if\": [{\"get_param\": \"CinderEtcdLocalConnect\"}, {\"tripleo::profile::base::cinder::volume::etcd_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"EtcdNetwork\"]}}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_volume\": [{\"get_param\": \"CinderVolumeLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\", \"include tripleo::profile::base::cinder::volume\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_volume\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"ulimit\": {\"get_param\": \"DockerCinderVolumeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"upgrade_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder volume container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_volume\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(160,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(161,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(162,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (163,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"32HDlh1wtNuoeOyht2a9njXCx\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"iGVLW3iUSnJVJpZdHixGVnqNe\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(164,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(165,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"32HDlh1wtNuoeOyht2a9njXCx\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"iGVLW3iUSnJVJpZdHixGVnqNe\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(166,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(167,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(168,'2026-06-13 07:50:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(169,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"ComputeHCI\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(170,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(171,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"32HDlh1wtNuoeOyht2a9njXCx\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"iGVLW3iUSnJVJpZdHixGVnqNe\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (172,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(173,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(174,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(175,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(176,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(177,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(178,'2026-06-13 07:50:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(179,'2026-06-13 07:50:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(180,'2026-06-13 07:50:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"32HDlh1wtNuoeOyht2a9njXCx\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"iGVLW3iUSnJVJpZdHixGVnqNe\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(181,'2026-06-13 07:50:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (182,'2026-06-13 07:50:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(183,'2026-06-13 07:50:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(184,'2026-06-13 07:50:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(185,'2026-06-13 07:50:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\n\", \"parameters\": {\"ContainerClustercheckImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerClustercheckConfigImage\": {\"description\": \"The container image to use for the clustercheck config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ClustercheckListener\": {\"default\": \"socat\", \"description\": \"How to expose the clustercheck service over TCP\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"socat\", \"xinetd\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlPuppetBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerClustercheckImage\": \"ContainerClustercheckImage\", \"ContainerClustercheckConfigImage\": \"ContainerClustercheckConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerClustercheckImage\": {\"get_param\": \"ContainerClustercheckImage\"}, \"ContainerClustercheckConfigImage\": {\"get_param\": \"ContainerClustercheckConfigImage\"}}}]}}}}, \"conditions\": {\"socat_listener\": {\"equals\": [{\"get_param\": \"ClustercheckListener\"}, \"socat\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service clustercheck using composable services.\", \"value\": {\"service_name\": \"clustercheck\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlPuppetBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::clustercheck::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$FQDN$NETWORK\')}\", \"params\": {\"$FQDN\": {\"if\": [\"socat_listener\", \"\", \"fqdn_\"]}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}}]}, \"puppet_config\": {\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": {\"if\": [\"socat_listener\", \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"/usr/sbin/xinetd -dontfork\"]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckImage\"]}, \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": null, \"upgrade_tasks\": null, \"update_tasks\": null, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(186,'2026-06-13 07:50:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(187,'2026-06-13 07:50:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Prepare container images\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImagePrepare\": {\"default\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images.\", \"type\": \"json\"}, \"ContainerImagePrepareLogFile\": {\"default\": \"/var/log/tripleo-container-image-prepare.log\", \"type\": \"string\", \"description\": \"Used to store outputs of \\\"openstack tripleo container image prepare\\\".\"}, \"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"DockerRegistryMirror\": {\"description\": \"Optional. Mirror to use for registry docker.io\", \"default\": \"\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ContainerImagePrepareDebug\": {\"default\": false, \"description\": \"Whether or not we want to activate --debug in tripleo container image prepare.\", \"type\": \"boolean\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"AdditionalArchitectures\": {\"default\": [], \"description\": \"List of additional architectures to enable.\", \"type\": \"comma_delimited_list\"}, \"ControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"CellControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeHCIContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeHCIServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ComputeHCI role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, \"ComputeHCICount\": {\"description\": \"Number of ComputeHCI nodes to deploy\", \"type\": \"number\", \"default\": 3}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for container image prepare\", \"value\": {\"service_name\": \"container_image_prepare\", \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": {\"get_param\": \"ContainerImagePrepareLogFile\"}, \"tripleo_container_image_prepare_debug\": {\"if\": [{\"get_param\": \"ContainerImagePrepareDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"ComputeHCI\", \"description\": \"Compute Node role hosting Ceph OSD too\\\\n\", \"tags\": [\"compute\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": {\"get_param\": \"ContainerImagePrepare\"}, \"DockerInsecureRegistryAddress\": {\"get_param\": \"DockerInsecureRegistryAddress\"}, \"NeutronMechanismDrivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"DockerRegistryMirror\": {\"get_param\": \"DockerRegistryMirror\"}, \"ContainerImageRegistryCredentials\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"AdditionalArchitectures\": {\"get_param\": \"AdditionalArchitectures\"}, \"ControllerContainerImagePrepare\": {\"get_param\": \"ControllerContainerImagePrepare\"}, \"ControllerServices\": {\"get_param\": \"ControllerServices\"}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerContainerImagePrepare\": {\"get_param\": \"CellControllerContainerImagePrepare\"}, \"CellControllerServices\": {\"get_param\": \"CellControllerServices\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeContainerImagePrepare\": {\"get_param\": \"CellControllerComputeContainerImagePrepare\"}, \"CellControllerComputeServices\": {\"get_param\": \"CellControllerComputeServices\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeContainerImagePrepare\": {\"get_param\": \"ComputeContainerImagePrepare\"}, \"ComputeServices\": {\"get_param\": \"ComputeServices\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageContainerImagePrepare\": {\"get_param\": \"BlockStorageContainerImagePrepare\"}, \"BlockStorageServices\": {\"get_param\": \"BlockStorageServices\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageContainerImagePrepare\": {\"get_param\": \"ObjectStorageContainerImagePrepare\"}, \"ObjectStorageServices\": {\"get_param\": \"ObjectStorageServices\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageContainerImagePrepare\": {\"get_param\": \"CephStorageContainerImagePrepare\"}, \"CephStorageServices\": {\"get_param\": \"CephStorageServices\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerContainerImagePrepare\": {\"get_param\": \"NetworkerContainerImagePrepare\"}, \"NetworkerServices\": {\"get_param\": \"NetworkerServices\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ComputeHCIContainerImagePrepare\": {\"get_param\": \"ComputeHCIContainerImagePrepare\"}, \"ComputeHCIServices\": {\"get_param\": \"ComputeHCIServices\"}, \"ComputeHCICount\": {\"get_param\": \"ComputeHCICount\"}}}}, \"when\": [\"(step | int) == 1\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(188,'2026-06-13 07:50:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"uQUhgxs2YR\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"VlqHymhjkGRBRoF82NE1acPVp\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(189,'2026-06-13 07:50:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": true, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"febd1289-7109-53bb-83fc-a5c42b947733\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (190,'2026-06-13 07:50:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"uQUhgxs2YR\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(191,'2026-06-13 07:50:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(192,'2026-06-13 07:50:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Gnocchi Metricd service\\n\", \"parameters\": {\"ContainerGnocchiMetricdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\"}, \"ContainerGnocchiConfigImage\": {\"description\": \"The container image to use for the gnocchi config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"GnocchiFileBasePath\": {\"default\": \"/var/lib/gnocchi\", \"description\": \"Path to use when file driver is used. This could be NFS or a flat file.\", \"type\": \"string\"}, \"GnocchiNfsEnabled\": {\"default\": false, \"description\": \"When using GnocchiBackend \'file\', mount NFS share for data storage\\n\", \"type\": \"boolean\"}, \"MonitoringSubscriptionGnocchiMetricd\": {\"default\": \"overcloud-gnocchi-metricd\", \"type\": \"string\"}, \"GnocchiMetricdWorkers\": {\"default\": 1, \"description\": \"Number of workers for Gnocchi MetricD\", \"type\": \"string\"}, \"MetricProcessingDelay\": {\"default\": 30, \"description\": \"Delay between processing metrics.\", \"type\": \"number\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"nfs_backend_enabled\": {\"equals\": [{\"get_param\": \"GnocchiNfsEnabled\"}, true]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GnocchiServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGnocchiMetricdImage\": \"ContainerGnocchiMetricdImage\", \"ContainerGnocchiConfigImage\": \"ContainerGnocchiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGnocchiMetricdImage\": {\"get_param\": \"ContainerGnocchiMetricdImage\"}, \"ContainerGnocchiConfigImage\": {\"get_param\": \"ContainerGnocchiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Gnocchi API role.\", \"value\": {\"service_name\": \"gnocchi_metricd\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"GnocchiServiceBase\", \"role_data\", \"config_settings\"]}, {\"gnocchi::metricd::workers\": {\"get_param\": \"GnocchiMetricdWorkers\"}, \"gnocchi::metricd::metric_processing_delay\": {\"get_param\": \"MetricProcessingDelay\"}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGnocchiMetricd\"}, \"service_config_settings\": {\"get_attr\": [\"GnocchiServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"gnocchi\", \"puppet_tags\": \"gnocchi_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::gnocchi::metricd\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/gnocchi_metricd.json\": {\"command\": \"/usr/bin/gnocchi-metricd\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/gnocchi\", \"owner\": \"gnocchi:gnocchi\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"gnocchi:gnocchi\", \"perm\": \"0600\"}]}}, \"docker_config\": {\"step_5\": {\"gnocchi_metricd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiMetricdImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/gnocchi_metricd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/gnocchi:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/gnocchi:/var/log/gnocchi:z\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, {\"str_replace\": {\"template\": \"GNOCCHI_FILE_BASE_PATH:GNOCCHI_FILE_BASE_PATH:SE_FLAGS\", \"params\": {\"GNOCCHI_FILE_BASE_PATH\": {\"get_param\": \"GnocchiFileBasePath\"}, \"SE_FLAGS\": {\"if\": [\"nfs_backend_enabled\", \"shared\", \"shared,z\"]}}}}]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/gnocchi\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"create persistent data directory\", \"file\": {\"path\": {\"get_param\": \"GnocchiFileBasePath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop gnocchi metricd container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"gnocchi_metricd\"], \"tripleo_delegate_to\": \"{{ groups[\'gnocchi_metricd\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(193,'2026-06-13 07:50:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(194,'2026-06-13 07:50:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Gnocchi service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GnocchiIndexerBackend\": {\"default\": \"mysql\", \"description\": \"The short name of the Gnocchi indexer backend to use.\", \"type\": \"string\"}, \"NumberOfStorageSacks\": {\"default\": 128, \"description\": \"Number of storage sacks to create.\", \"type\": \"number\"}, \"GnocchiPassword\": {\"description\": \"The password for the gnocchi service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1J2tbLy665illltBsArwgV2GL\"}, \"GnocchiRbdPoolName\": {\"default\": \"metrics\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"GnocchiDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Gnocchi services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GnocchiStorageSwiftEndpointType\": {\"default\": \"internalURL\", \"description\": \"Set to modify which endpoint type is gnocchi accessing swift from.\", \"type\": \"string\"}, \"GnocchiStorageS3Endpoint\": {\"default\": \"\", \"description\": \"The endpoint url for S3 storage.\", \"type\": \"string\"}, \"GnocchiStorageS3RegionName\": {\"default\": \"\", \"description\": \"S3 Region name.\", \"type\": \"string\"}, \"GnocchiStorageS3AccessKeyId\": {\"default\": \"\", \"description\": \"S3 storage access key Id.\", \"type\": \"string\"}, \"GnocchiStorageS3AccessSecret\": {\"default\": \"\", \"description\": \"S3 storage access key secret.\", \"type\": \"string\", \"hidden\": true}, \"GnocchiStorageS3BucketPrefix\": {\"default\": \"\", \"description\": \"S3 storage bucket prefix.\", \"type\": \"string\"}, \"GnocchiFileBasePath\": {\"default\": \"/var/lib/gnocchi\", \"description\": \"Path to use when file driver is used. This could be NFS or a flat file.\", \"type\": \"string\"}}, \"conditions\": {\"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}}, \"outputs\": {\"aux_parameters\": {\"description\": \"Additional parameters referenced outside the base file\", \"value\": {\"gnocchi_indexer_backend\": {\"get_param\": \"GnocchiIndexerBackend\"}}}, \"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"gnocchi_base\", \"config_settings\": {\"gnocchi_redis_password\": {\"get_param\": \"RedisPassword\"}, \"gnocchi::logging::debug\": {\"if\": [{\"get_param\": \"GnocchiDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"gnocchi::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"gnocchi\", \"password\": {\"get_param\": \"GnocchiPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/gnocchi\", \"query\": {\"if\": [\"enable_sqlalchemy_collectd\", {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"gnochhi\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"gnocchi::db::sync::extra_opts\": {\"str_replace\": {\"template\": \" --sacks-number NUM_SACKS\", \"params\": {\"NUM_SACKS\": {\"get_param\": \"NumberOfStorageSacks\"}}}}, \"gnocchi::storage::file::file_basepath\": {\"get_param\": \"GnocchiFileBasePath\"}, \"gnocchi::storage::swift::swift_user\": \"service:gnocchi\", \"gnocchi::storage::swift::swift_auth_version\": 3, \"gnocchi::storage::swift::swift_key\": {\"get_param\": \"GnocchiPassword\"}, \"gnocchi::storage::swift::swift_authurl\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"gnocchi::storage::swift::swift_endpoint_type\": {\"get_param\": \"GnocchiStorageSwiftEndpointType\"}, \"gnocchi::storage::ceph::ceph_pool\": {\"get_param\": \"GnocchiRbdPoolName\"}, \"gnocchi::storage::ceph::ceph_username\": {\"get_param\": \"CephClientUserName\"}, \"gnocchi::storage::ceph::ceph_conffile\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"gnocchi::storage::ceph::ceph_keyring\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".client.\", {\"get_param\": \"CephClientUserName\"}, \".keyring\"]]}, \"gnocchi::storage::s3::s3_endpoint_url\": {\"get_param\": \"GnocchiStorageS3Endpoint\"}, \"gnocchi::storage::s3::s3_region_name\": {\"get_param\": \"GnocchiStorageS3RegionName\"}, \"gnocchi::storage::s3::s3_access_key_id\": {\"get_param\": \"GnocchiStorageS3AccessKeyId\"}, \"gnocchi::storage::s3::s3_secret_access_key\": {\"get_param\": \"GnocchiStorageS3AccessSecret\"}, \"gnocchi::storage::s3::s3_bucket_prefix\": {\"get_param\": \"GnocchiStorageS3BucketPrefix\"}, \"gnocchi::statsd::resource_id\": \"0a8b55df-f90f-491c-8cb9-7cdecec6fc26\", \"gnocchi::statsd::flush_delay\": 10, \"gnocchi::statsd::archive_policy_name\": \"low\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(195,'2026-06-13 07:50:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"rbd\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(196,'2026-06-13 07:50:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(197,'2026-06-13 07:50:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized gnocchi service\\n\", \"parameters\": {\"ContainerGnocchiApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\"}, \"ContainerGnocchiConfigImage\": {\"description\": \"The container image to use for the gnocchi config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\"}, \"GnocchiApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.gnocchi.api\", \"file\": \"/var/log/containers/gnocchi/app.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"NumberOfStorageSacks\": {\"default\": 128, \"description\": \"Number of storage sacks to create.\", \"type\": \"number\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"GnocchiFileBasePath\": {\"default\": \"/var/lib/gnocchi\", \"description\": \"Path to use when file driver is used. This could be NFS or a flat file.\", \"type\": \"string\"}, \"GnocchiPassword\": {\"description\": \"The password for the gnocchi service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1J2tbLy665illltBsArwgV2GL\"}, \"GnocchiBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Gnocchi backend to use. Should be one of swift, rbd, file or s3.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"s3\"]}]}, \"GnocchiNfsEnabled\": {\"default\": false, \"description\": \"When using GnocchiBackend \'file\', mount NFS share for data storage\\n\", \"type\": \"boolean\"}, \"GnocchiNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for data storage (when GnocchiNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GnocchiNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"Nfs mount options for data storage (when GnocchiNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GnocchiIncomingStorageDriver\": {\"default\": \"redis\", \"description\": \"Storage driver to use for incoming metric data\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionGnocchiApi\": {\"default\": \"overcloud-gnocchi-api\", \"type\": \"string\"}, \"GnocchiApiPolicies\": {\"description\": \"A hash of policies to configure for Gnocchi API.\\ne.g. { gnocchi-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"GnocchiCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"conditions\": {\"cors_allowed_origin_unset\": {\"equals\": [{\"get_param\": \"GnocchiCorsAllowedOrigin\"}, \"\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"nfs_backend_enabled\": {\"equals\": [{\"get_param\": \"GnocchiNfsEnabled\"}, true]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GnocchiServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGnocchiApiImage\": \"ContainerGnocchiApiImage\", \"ContainerGnocchiConfigImage\": \"ContainerGnocchiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGnocchiApiImage\": {\"get_param\": \"ContainerGnocchiApiImage\"}, \"ContainerGnocchiConfigImage\": {\"get_param\": \"ContainerGnocchiConfigImage\"}}}]}}}}, \"outputs\": {\"gnocchi_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for gnocchi_api\", \"value\": [{\"name\": \"Mount Gnocchi NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GnocchiNfsEnabled\"}, \"nfs_share\": {\"get_param\": \"GnocchiNfsShare\"}, \"nfs_options\": {\"get_param\": \"GnocchiNfsOptions\"}, \"file_base_path\": {\"get_param\": \"GnocchiFileBasePath\"}}, \"mount\": {\"name\": \"{{file_base_path}}\", \"state\": \"mounted\", \"src\": \"{{nfs_share}}\", \"fstype\": \"nfs\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled\"}]}, \"role_data\": {\"description\": \"Role data for the gnocchi API role.\", \"value\": {\"service_name\": \"gnocchi_api\", \"firewall_rules\": {\"129 gnocchi-api\": {\"dport\": [8041]}}, \"firewall_frontend_rules\": {\"100 gnocchi_haproxy_frontend\": {\"dport\": [8041]}}, \"firewall_ssl_frontend_rules\": {\"100 gnocchi_haproxy_frontend_ssl\": {\"dport\": [13041]}}, \"keystone_resources\": {\"gnocchi\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"uri\"]}}, \"users\": {\"gnocchi\": {\"password\": {\"get_param\": \"GnocchiPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"metric\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGnocchiApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"GnocchiServiceBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false}, {\"if\": [\"cors_allowed_origin_unset\", {}, {\"gnocchi::cors::allowed_origin\": {\"get_param\": \"GnocchiCorsAllowedOrigin\"}, \"gnocchi::api::middlewares\": \"oslo_middleware.cors.CORS\"}]}, {\"gnocchi::api::enabled\": true, \"gnocchi::api::enable_proxy_headers_parsing\": true, \"gnocchi::api::service_name\": \"httpd\", \"gnocchi::policy::policies\": {\"get_param\": \"GnocchiApiPolicies\"}, \"gnocchi::cors::max_age\": 3600, \"gnocchi::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"gnocchi::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"gnocchi::cors::allow_methods\": \"GET,POST,PUT,DELETE,OPTIONS,PATCH\", \"gnocchi::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"gnocchi::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"gnocchi::keystone::authtoken::password\": {\"get_param\": \"GnocchiPassword\"}, \"gnocchi::keystone::authtoken::project_name\": \"service\", \"gnocchi::keystone::authtoken::user_domain_name\": \"Default\", \"gnocchi::keystone::authtoken::project_domain_name\": \"Default\", \"gnocchi::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"gnocchi::keystone::authtoken::interface\": \"internal\", \"gnocchi::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"gnocchi::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"gnocchi::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}}}, \"tripleo::profile::base::gnocchi::api::gnocchi_backend\": {\"get_param\": \"GnocchiBackend\"}, \"tripleo::profile::base::gnocchi::api::incoming_storage_driver\": {\"get_param\": \"GnocchiIncomingStorageDriver\"}, \"tripleo::profile::base::gnocchi::api::gnocchi_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"gnocchi::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}}}, \"gnocchi::wsgi::apache::wsgi_process_display_name\": \"gnocchi_wsgi\"}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"GnocchiServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_gnocchi_api\": [{\"get_param\": \"GnocchiApiLoggingSource\"}]}, \"mysql\": {\"gnocchi::db::mysql::password\": {\"get_param\": \"GnocchiPassword\"}, \"gnocchi::db::mysql::user\": \"gnocchi\", \"gnocchi::db::mysql::host\": \"%\", \"gnocchi::db::mysql::dbname\": \"gnocchi\"}}]}, \"puppet_config\": {\"config_volume\": \"gnocchi\", \"puppet_tags\": \"gnocchi_api_paste_ini,gnocchi_config,exec\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::gnocchi::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/gnocchi_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/gnocchi\", \"owner\": \"gnocchi:gnocchi\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"gnocchi:gnocchi\", \"perm\": \"0600\"}, {\"path\": {\"list_join\": [\"/\", [{\"get_param\": \"GnocchiFileBasePath\"}, \"tmp\"]]}, \"owner\": \"gnocchi:gnocchi\", \"perm\": \"0750\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/gnocchi_db_sync.json\": {\"command\": {\"str_replace\": {\"template\": \"/usr/bin/bootstrap_host_exec gnocchi_api /usr/bin/gnocchi-upgrade --sacks-number=SACK_NUM\", \"params\": {\"SACK_NUM\": {\"get_param\": \"NumberOfStorageSacks\"}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/gnocchi\", \"owner\": \"gnocchi:gnocchi\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"gnocchi:gnocchi\", \"perm\": \"0600\"}, {\"path\": {\"list_join\": [\"/\", [{\"get_param\": \"GnocchiFileBasePath\"}, \"tmp\"]]}, \"owner\": \"gnocchi:gnocchi\", \"perm\": \"0750\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"gnocchi_init_log\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiApiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/gnocchi:/var/log/gnocchi:z\", \"/var/log/containers/httpd/gnocchi-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R gnocchi:gnocchi /var/log/gnocchi\"]}, \"gnocchi_init_lib\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiApiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [{\"str_replace\": {\"template\": \"GNOCCHI_FILE_BASE_PATH:GNOCCHI_FILE_BASE_PATH:SE_FLAGS\", \"params\": {\"GNOCCHI_FILE_BASE_PATH\": {\"get_param\": \"GnocchiFileBasePath\"}, \"SE_FLAGS\": {\"if\": [\"nfs_backend_enabled\", \"shared\", \"shared,z\"]}}}}], \"command\": [\"/bin/bash\", \"-c\", {\"str_replace\": {\"template\": \"chown -R gnocchi:gnocchi GNOCCHI_FILE_BASE_PATH\", \"params\": {\"GNOCCHI_FILE_BASE_PATH\": {\"get_param\": \"GnocchiFileBasePath\"}}}}]}}, \"step_5\": {\"gnocchi_db_sync\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/gnocchi_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/gnocchi:/var/lib/kolla/config_files/src:ro\", {\"str_replace\": {\"template\": \"GNOCCHI_FILE_BASE_PATH:GNOCCHI_FILE_BASE_PATH:SE_FLAGS\", \"params\": {\"GNOCCHI_FILE_BASE_PATH\": {\"get_param\": \"GnocchiFileBasePath\"}, \"SE_FLAGS\": {\"if\": [\"nfs_backend_enabled\", \"shared\", \"shared,z\"]}}}}, \"/var/log/containers/gnocchi:/var/log/gnocchi:z\", \"/var/log/containers/httpd/gnocchi-api:/var/log/httpd:z\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"gnocchi_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiApiImage\"]}, \"start_order\": 1, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [{\"str_replace\": {\"template\": \"GNOCCHI_FILE_BASE_PATH:GNOCCHI_FILE_BASE_PATH:SE_FLAGS\", \"params\": {\"GNOCCHI_FILE_BASE_PATH\": {\"get_param\": \"GnocchiFileBasePath\"}, \"SE_FLAGS\": {\"if\": [\"nfs_backend_enabled\", \"shared\", \"shared,z\"]}}}}, \"/var/lib/kolla/config_files/gnocchi_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/gnocchi:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/gnocchi:/var/log/gnocchi:z\", \"/var/log/containers/httpd/gnocchi-api:/var/log/httpd:z\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\"], []]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"], []]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [[{\"name\": \"create logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/gnocchi\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/gnocchi-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], [{\"name\": \"Mount Gnocchi NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GnocchiNfsEnabled\"}, \"nfs_share\": {\"get_param\": \"GnocchiNfsShare\"}, \"nfs_options\": {\"get_param\": \"GnocchiNfsOptions\"}, \"file_base_path\": {\"get_param\": \"GnocchiFileBasePath\"}}, \"mount\": {\"name\": \"{{file_base_path}}\", \"state\": \"mounted\", \"src\": \"{{nfs_share}}\", \"fstype\": \"nfs\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled\"}], [{\"name\": \"ensure GnocchiFileBasePath exists\", \"file\": {\"path\": {\"get_param\": \"GnocchiFileBasePath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}]]}, \"upgrade_tasks\": [{\"name\": \"gnocchi-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Gnocchi NFS share\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GnocchiNfsEnabled\"}, \"file_base_path\": {\"get_param\": \"GnocchiFileBasePath\"}}, \"mount\": {\"name\": \"{{file_base_path}}\", \"state\": \"absent\", \"fstype\": \"nfs\"}, \"when\": \"nfs_backend_enabled\"}]}, {\"name\": \"gnocchi-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Gnocchi NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GnocchiNfsEnabled\"}, \"nfs_share\": {\"get_param\": \"GnocchiNfsShare\"}, \"nfs_options\": {\"get_param\": \"GnocchiNfsOptions\"}, \"file_base_path\": {\"get_param\": \"GnocchiFileBasePath\"}}, \"mount\": {\"name\": \"{{file_base_path}}\", \"state\": \"mounted\", \"src\": \"{{nfs_share}}\", \"fstype\": \"nfs\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled\"}]}], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop gnocchi container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"gnocchi_api\"], \"tripleo_delegate_to\": \"{{ groups[\'gnocchi_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (198,'2026-06-13 07:50:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"], \"ComputeHCI\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(199,'2026-06-13 07:50:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(201,'2026-06-13 07:50:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Gnocchi service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GnocchiIndexerBackend\": {\"default\": \"mysql\", \"description\": \"The short name of the Gnocchi indexer backend to use.\", \"type\": \"string\"}, \"NumberOfStorageSacks\": {\"default\": 128, \"description\": \"Number of storage sacks to create.\", \"type\": \"number\"}, \"GnocchiPassword\": {\"description\": \"The password for the gnocchi service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1J2tbLy665illltBsArwgV2GL\"}, \"GnocchiRbdPoolName\": {\"default\": \"metrics\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"GnocchiDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Gnocchi services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GnocchiStorageSwiftEndpointType\": {\"default\": \"internalURL\", \"description\": \"Set to modify which endpoint type is gnocchi accessing swift from.\", \"type\": \"string\"}, \"GnocchiStorageS3Endpoint\": {\"default\": \"\", \"description\": \"The endpoint url for S3 storage.\", \"type\": \"string\"}, \"GnocchiStorageS3RegionName\": {\"default\": \"\", \"description\": \"S3 Region name.\", \"type\": \"string\"}, \"GnocchiStorageS3AccessKeyId\": {\"default\": \"\", \"description\": \"S3 storage access key Id.\", \"type\": \"string\"}, \"GnocchiStorageS3AccessSecret\": {\"default\": \"\", \"description\": \"S3 storage access key secret.\", \"type\": \"string\", \"hidden\": true}, \"GnocchiStorageS3BucketPrefix\": {\"default\": \"\", \"description\": \"S3 storage bucket prefix.\", \"type\": \"string\"}, \"GnocchiFileBasePath\": {\"default\": \"/var/lib/gnocchi\", \"description\": \"Path to use when file driver is used. This could be NFS or a flat file.\", \"type\": \"string\"}}, \"conditions\": {\"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}}, \"outputs\": {\"aux_parameters\": {\"description\": \"Additional parameters referenced outside the base file\", \"value\": {\"gnocchi_indexer_backend\": {\"get_param\": \"GnocchiIndexerBackend\"}}}, \"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"gnocchi_base\", \"config_settings\": {\"gnocchi_redis_password\": {\"get_param\": \"RedisPassword\"}, \"gnocchi::logging::debug\": {\"if\": [{\"get_param\": \"GnocchiDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"gnocchi::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"gnocchi\", \"password\": {\"get_param\": \"GnocchiPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/gnocchi\", \"query\": {\"if\": [\"enable_sqlalchemy_collectd\", {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"gnochhi\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"gnocchi::db::sync::extra_opts\": {\"str_replace\": {\"template\": \" --sacks-number NUM_SACKS\", \"params\": {\"NUM_SACKS\": {\"get_param\": \"NumberOfStorageSacks\"}}}}, \"gnocchi::storage::file::file_basepath\": {\"get_param\": \"GnocchiFileBasePath\"}, \"gnocchi::storage::swift::swift_user\": \"service:gnocchi\", \"gnocchi::storage::swift::swift_auth_version\": 3, \"gnocchi::storage::swift::swift_key\": {\"get_param\": \"GnocchiPassword\"}, \"gnocchi::storage::swift::swift_authurl\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"gnocchi::storage::swift::swift_endpoint_type\": {\"get_param\": \"GnocchiStorageSwiftEndpointType\"}, \"gnocchi::storage::ceph::ceph_pool\": {\"get_param\": \"GnocchiRbdPoolName\"}, \"gnocchi::storage::ceph::ceph_username\": {\"get_param\": \"CephClientUserName\"}, \"gnocchi::storage::ceph::ceph_conffile\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"gnocchi::storage::ceph::ceph_keyring\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".client.\", {\"get_param\": \"CephClientUserName\"}, \".keyring\"]]}, \"gnocchi::storage::s3::s3_endpoint_url\": {\"get_param\": \"GnocchiStorageS3Endpoint\"}, \"gnocchi::storage::s3::s3_region_name\": {\"get_param\": \"GnocchiStorageS3RegionName\"}, \"gnocchi::storage::s3::s3_access_key_id\": {\"get_param\": \"GnocchiStorageS3AccessKeyId\"}, \"gnocchi::storage::s3::s3_secret_access_key\": {\"get_param\": \"GnocchiStorageS3AccessSecret\"}, \"gnocchi::storage::s3::s3_bucket_prefix\": {\"get_param\": \"GnocchiStorageS3BucketPrefix\"}, \"gnocchi::statsd::resource_id\": \"0a8b55df-f90f-491c-8cb9-7cdecec6fc26\", \"gnocchi::statsd::flush_delay\": 10, \"gnocchi::statsd::archive_policy_name\": \"low\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(202,'2026-06-13 07:50:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance internal service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GlanceApiInternalLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api_internal.log\"}}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiInternalConfigImage\": {\"description\": \"The container image to use for the glance_api_internal config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"GlanceApi\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiInternalConfigImage\": \"ContainerGlanceApiInternalConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiInternalConfigImage\": {\"get_param\": \"ContainerGlanceApiInternalConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the internal Glance API.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\"]}, {\"service_name\": \"glance_api_internal\", \"firewall_rules\": {\"112 glance_api_internal\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 glance_api_internal_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"keystone_resources\": {}, \"config_settings\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_glance_api_internal\": [{\"get_param\": \"GlanceApiInternalLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"glance_api_internal\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [{\"str_replace\": {\"template\": \"class { \'tripleo::profile::base::glance::api\':\\n  bind_port => PORT,\\n  tls_proxy_port => PORT,\\n  log_file => \'/var/log/glance/api_internal.log\',\\n  show_image_direct_url => true,\\n  show_multiple_locations => true,\\n}\\n\", \"params\": {\"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiInternalConfigImage\"]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"glance_api_internal\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\", \"volumes\"]}}}}}]}, \"glance_api_internal_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\", \"volumes\"]}}}}}]}]}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api internal container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api_internal\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api_internal\'] | default([]) }}\"}}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(203,'2026-06-13 07:50:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(204,'2026-06-13 07:50:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(205,'2026-06-13 07:50:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(206,'2026-06-13 07:50:48',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::ComputeHCI\", \"properties\": {\"CloudDomain\": \"localdomain\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"Hostname\": \"overcloud-computehci-0\", \"NodeIndex\": \"0\", \"ComputeHCISchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"ceph_client\", \"ceph_osd\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"UserData\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\"}}, \"1\": {\"type\": \"OS::TripleO::ComputeHCI\", \"properties\": {\"CloudDomain\": \"localdomain\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"Hostname\": \"overcloud-computehci-1\", \"NodeIndex\": \"1\", \"ComputeHCISchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"ceph_client\", \"ceph_osd\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"UserData\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\"}}, \"2\": {\"type\": \"OS::TripleO::ComputeHCI\", \"properties\": {\"CloudDomain\": \"localdomain\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"Hostname\": \"overcloud-computehci-2\", \"NodeIndex\": \"2\", \"ComputeHCISchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"ceph_client\", \"ceph_osd\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"UserData\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\"}}}, \"outputs\": {\"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}, {\"get_attr\": [\"1\", \"ip_address\"]}, {\"get_attr\": [\"2\", \"ip_address\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}, {\"get_attr\": [\"1\", \"hosts_entry\"]}, {\"get_attr\": [\"2\", \"hosts_entry\"]}]}, \"storage_mgmt_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_mgmt_ip_address\"]}, {\"get_attr\": [\"1\", \"storage_mgmt_ip_address\"]}, {\"get_attr\": [\"2\", \"storage_mgmt_ip_address\"]}]}, \"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}, \"1\": {\"get_attr\": [\"1\", \"nova_server_resource\"]}, \"2\": {\"get_attr\": [\"2\", \"nova_server_resource\"]}}}, \"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"1\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"2\", \"internal_api_ip_address\"]}]}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}, {\"get_attr\": [\"1\", \"tenant_ip_address\"]}, {\"get_attr\": [\"2\", \"tenant_ip_address\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}, {\"get_attr\": [\"1\", \"nova_server_resource\"]}, {\"get_attr\": [\"2\", \"nova_server_resource\"]}]}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}, {\"get_attr\": [\"1\", \"storage_ip_address\"]}, {\"get_attr\": [\"2\", \"storage_ip_address\"]}]}, \"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}, {\"get_attr\": [\"1\", \"hostname\"]}, {\"get_attr\": [\"2\", \"hostname\"]}]}, \"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}, {\"get_attr\": [\"1\", \"blacklist_hostname\"]}, {\"get_attr\": [\"2\", \"blacklist_hostname\"]}]}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"1\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"2\", \"blacklist_ip_address\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}, {\"get_attr\": [\"1\", \"hostname_map\"]}, {\"get_attr\": [\"2\", \"hostname_map\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"1\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"2\", \"ansible_host_vars_map\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}, \"1\": {\"get_resource\": \"1\"}, \"2\": {\"get_resource\": \"2\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(207,'2026-06-13 07:50:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (208,'2026-06-13 07:50:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack ComputeHCI node configured by Puppet\", \"parameters\": {\"OvercloudComputeHCIFlavor\": {\"description\": \"Flavor for the ComputeHCI node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"ComputeHCIImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeHCIIPs\": {\"default\": {}, \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeHCIServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeHCISchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeHCIControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"ComputeHCI_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_StorageMgmt_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"ComputeHCI\": {\"type\": \"OS::TripleO::ComputeHCIServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"get_param\": \"ComputeHCIImage\"}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeHCIFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeHCIIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"ComputeHCIServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeHCISchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"StorageMgmtPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"StorageMgmt\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_StorageMgmt_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_mgmt_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtIpSubnet\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_subnet\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storage\"]]}}, \"storage_mgmt\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storagemgmt\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storagemgmt\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"ComputeHCI\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::ComputeHCI::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"ComputeHCIExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeHCIExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeHCIExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"ComputeHCIAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHCIHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"ComputeHCIAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHCIHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for ComputeHCI server\", \"value\": {\"get_resource\": \"ComputeHCI\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"storage_mgmt_ip_address\": {\"description\": \"IP address of the server in the StorageMgmt network\", \"value\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"Hostname\": \"overcloud-computehci-2\", \"CloudDomain\": \"localdomain\", \"ComputeHCISchedulerHints\": {}, \"NodeIndex\": 2, \"ServiceNames\": \"boot_params_service,ca_certs,ceph_client,ceph_osd,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"UserData\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(209,'2026-06-13 07:50:48',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\", \"name\": \"np0000072646\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(210,'2026-06-13 07:50:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(211,'2026-06-13 07:50:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(212,'2026-06-13 07:50:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack ComputeHCI node configured by Puppet\", \"parameters\": {\"OvercloudComputeHCIFlavor\": {\"description\": \"Flavor for the ComputeHCI node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"ComputeHCIImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeHCIIPs\": {\"default\": {}, \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeHCIServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeHCISchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeHCIControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"ComputeHCI_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_StorageMgmt_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"ComputeHCI\": {\"type\": \"OS::TripleO::ComputeHCIServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"get_param\": \"ComputeHCIImage\"}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeHCIFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeHCIIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"ComputeHCIServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeHCISchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"StorageMgmtPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"StorageMgmt\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_StorageMgmt_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_mgmt_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtIpSubnet\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_subnet\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storage\"]]}}, \"storage_mgmt\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storagemgmt\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storagemgmt\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"ComputeHCI\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::ComputeHCI::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"ComputeHCIExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeHCIExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeHCIExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"ComputeHCIAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHCIHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"ComputeHCIAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHCIHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for ComputeHCI server\", \"value\": {\"get_resource\": \"ComputeHCI\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"storage_mgmt_ip_address\": {\"description\": \"IP address of the server in the StorageMgmt network\", \"value\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"Hostname\": \"overcloud-computehci-1\", \"CloudDomain\": \"localdomain\", \"ComputeHCISchedulerHints\": {}, \"NodeIndex\": 1, \"ServiceNames\": \"boot_params_service,ca_certs,ceph_client,ceph_osd,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"UserData\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(213,'2026-06-13 07:50:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(214,'2026-06-13 07:50:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781336959, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": true, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"rbd\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(215,'2026-06-13 07:50:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat CloudWatch API service, disabled by default since Pike\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the disabled Heat CloudWatch API\", \"value\": {\"service_name\": \"heat_api_cloudwatch_disabled\", \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(216,'2026-06-13 07:50:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000072646-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (217,'2026-06-13 07:50:49',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\", \"name\": \"np0000072645\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(218,'2026-06-13 07:50:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000072645-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(219,'2026-06-13 07:50:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(220,'2026-06-13 07:50:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack ComputeHCI node configured by Puppet\", \"parameters\": {\"OvercloudComputeHCIFlavor\": {\"description\": \"Flavor for the ComputeHCI node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"ComputeHCIImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeHCIIPs\": {\"default\": {}, \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeHCIServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeHCISchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeHCIControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"ComputeHCI_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_StorageMgmt_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"ComputeHCI_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeHCIIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"ComputeHCI\": {\"type\": \"OS::TripleO::ComputeHCIServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"get_param\": \"ComputeHCIImage\"}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeHCIFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeHCIIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeHCIControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"ComputeHCIServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeHCISchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"StorageMgmtPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"StorageMgmt\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_StorageMgmt_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_mgmt_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::ComputeHCI::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"ComputeHCI_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeHCIIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ComputeHCIIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"ComputeHCI\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtIpSubnet\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_subnet\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storage\"]]}}, \"storage_mgmt\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storagemgmt\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"storagemgmt\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"ComputeHCI\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"ComputeHCI\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::ComputeHCI::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"ComputeHCIExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeHCIExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeHCIExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"ComputeHCI\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"ComputeHCIAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHCIHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"ComputeHCIAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"ComputeHCI\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHCIHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"ComputeHCI\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for ComputeHCI server\", \"value\": {\"get_resource\": \"ComputeHCI\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"ComputeHCI\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"ComputeHCI\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"storage_mgmt_ip_address\": {\"description\": \"IP address of the server in the StorageMgmt network\", \"value\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"Hostname\": \"overcloud-computehci-0\", \"CloudDomain\": \"localdomain\", \"ComputeHCISchedulerHints\": {}, \"NodeIndex\": 0, \"ServiceNames\": \"boot_params_service,ca_certs,ceph_client,ceph_osd,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\", \"NovaComputeStartupDelay\": 180}, \"UserData\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(221,'2026-06-13 07:50:50',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"d2c646d1-5aad-4d88-b994-6e5921fd3309\", \"name\": \"np0000072644\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(222,'2026-06-13 07:50:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(223,'2026-06-13 07:50:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(224,'2026-06-13 07:50:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000072644-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(225,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(226,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Gnocchi Statsd service\\n\", \"parameters\": {\"ContainerGnocchiStatsdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\"}, \"ContainerGnocchiConfigImage\": {\"description\": \"The container image to use for the gnocchi config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"GnocchiFileBasePath\": {\"default\": \"/var/lib/gnocchi\", \"description\": \"Path to use when file driver is used. This could be NFS or a flat file.\", \"type\": \"string\"}, \"GnocchiNfsEnabled\": {\"default\": false, \"description\": \"When using GnocchiBackend \'file\', mount NFS share for data storage\\n\", \"type\": \"boolean\"}, \"MonitoringSubscriptionGnocchiStatsd\": {\"default\": \"overcloud-gnocchi-statsd\", \"type\": \"string\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"nfs_backend_enabled\": {\"equals\": [{\"get_param\": \"GnocchiNfsEnabled\"}, true]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GnocchiServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGnocchiStatsdImage\": \"ContainerGnocchiStatsdImage\", \"ContainerGnocchiConfigImage\": \"ContainerGnocchiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGnocchiStatsdImage\": {\"get_param\": \"ContainerGnocchiStatsdImage\"}, \"ContainerGnocchiConfigImage\": {\"get_param\": \"ContainerGnocchiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Gnocchi API role.\", \"value\": {\"service_name\": \"gnocchi_statsd\", \"firewall_rules\": {\"140 gnocchi-statsd\": {\"dport\": 8125, \"proto\": \"udp\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGnocchiStatsd\"}, \"config_settings\": {\"get_attr\": [\"GnocchiServiceBase\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"get_attr\": [\"GnocchiServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"gnocchi\", \"puppet_tags\": \"gnocchi_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::gnocchi::statsd\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/gnocchi_statsd.json\": {\"command\": \"/usr/bin/gnocchi-statsd\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/gnocchi\", \"owner\": \"gnocchi:gnocchi\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"gnocchi:gnocchi\", \"perm\": \"0600\"}]}}, \"docker_config\": {\"step_5\": {\"gnocchi_statsd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGnocchiStatsdImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/gnocchi_statsd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/gnocchi:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/gnocchi:/var/log/gnocchi:z\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, {\"str_replace\": {\"template\": \"GNOCCHI_FILE_BASE_PATH:GNOCCHI_FILE_BASE_PATH:SE_FLAGS\", \"params\": {\"GNOCCHI_FILE_BASE_PATH\": {\"get_param\": \"GnocchiFileBasePath\"}, \"SE_FLAGS\": {\"if\": [\"nfs_backend_enabled\", \"shared\", \"shared,z\"]}}}}]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/gnocchi\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"create persistent data directory\", \"file\": {\"path\": {\"get_param\": \"GnocchiFileBasePath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop gnocchi statsd container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"gnocchi_statsd\"], \"tripleo_delegate_to\": \"{{ groups[\'gnocchi_statsd\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (227,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"067a977c-c526-4227-9e18-7618974b60ad\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(228,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072646_Storage\", \"DnsName\": \"np0000072646\", \"ControlPlaneIP\": \"192.168.122.108\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 2, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(229,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageMgmtDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072646_StorageMgmt\", \"DnsName\": \"np0000072646\", \"ControlPlaneIP\": \"192.168.122.108\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 2, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(230,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072645_Tenant\", \"DnsName\": \"np0000072645\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 1, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(231,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"InternalApiDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072646_InternalApi\", \"DnsName\": \"np0000072646\", \"ControlPlaneIP\": \"192.168.122.108\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 2, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(232,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageMgmtDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072645_StorageMgmt\", \"DnsName\": \"np0000072645\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 1, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(233,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"f0325376-07d0-49fb-9625-1dad8a0cec75\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(234,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072646_Tenant\", \"DnsName\": \"np0000072646\", \"ControlPlaneIP\": \"192.168.122.108\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 2, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(235,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072645_Storage\", \"DnsName\": \"np0000072645\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 1, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(236,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"InternalApiDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072645_InternalApi\", \"DnsName\": \"np0000072645\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 1, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(237,'2026-06-13 07:50:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (238,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"parameters\": {\"ContainerHeatApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"ContainerHeatApiConfigImage\": {\"description\": \"The container image to use for the heat_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api\", \"file\": \"/var/log/containers/heat/heat_api.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"HeatApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatApiOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"AIErP5AszUhhw1jzcg4LrBB60\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApi\": {\"default\": \"overcloud-heat-api\", \"type\": \"string\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiImage\": \"ContainerHeatApiImage\", \"ContainerHeatApiConfigImage\": \"ContainerHeatApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiImage\": {\"get_param\": \"ContainerHeatApiImage\"}, \"ContainerHeatApiConfigImage\": {\"get_param\": \"ContainerHeatApiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API role.\", \"value\": {\"service_name\": \"heat_api\", \"firewall_rules\": {\"125 heat_api\": {\"dport\": [8004]}}, \"firewall_frontend_rules\": {\"100 heat_api_haproxy_frontend\": {\"dport\": [8004]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_haproxy_frontend_ssl\": {\"dport\": [13004]}}, \"keystone_resources\": {\"heat\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"uri\"]}}, \"users\": {\"heat\": {\"password\": {\"get_param\": \"HeatPassword\"}}, \"heat_stack_domain_admin\": {\"password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"roles\": [\"admin\"], \"domain\": \"heat_stack\"}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"orchestration\", \"roles\": [\"heat_stack_user\"], \"domains\": [\"heat_stack\"]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiLogging\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::wsgi::apache_api::vhost_custom_fragment\": \"Timeout 600\", \"heat::api::service_name\": \"httpd\", \"heat::wsgi::apache_api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api\": [{\"get_param\": \"HeatApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api\", \"puppet_tags\": \"heat_config,file,concat,file_line,heat_api_paste_ini\", \"step_config\": \"include tripleo::profile::base::heat::api\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, {\"get_param\": \"HeatApiOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatApiOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"heat_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron heat\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api\", \"heat_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(239,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072644_Storage\", \"DnsName\": \"np0000072644\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(240,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageMgmtDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072644_StorageMgmt\", \"DnsName\": \"np0000072644\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(241,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"InternalApiDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072644_InternalApi\", \"DnsName\": \"np0000072644\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(242,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"d3dbe09c-759a-4ebb-8c79-6bd0e98787e1\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(243,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000072644_Tenant\", \"DnsName\": \"np0000072644\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"ComputeHCI\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(244,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(245,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"AIErP5AszUhhw1jzcg4LrBB60\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"messagingv2\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ComputeHCI\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/computehci-role.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.157\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.157\", \"storage_mgmt\": \"172.20.0.196\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.196\", \"internal_api\": \"172.17.0.249\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.249\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.204\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.204\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8042\", \"uri_no_suffix\": \"http://172.17.0.249:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8042\", \"uri_no_suffix\": \"http://172.21.0.204:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9311\", \"uri_no_suffix\": \"http://172.17.0.249:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9311\", \"uri_no_suffix\": \"http://172.21.0.204:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8444\", \"uri_no_suffix\": \"http://192.168.122.99:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:3100\", \"uri_no_suffix\": \"http://172.18.0.157:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.249:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.204:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:8787\", \"uri_no_suffix\": \"http://192.168.122.99:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.204:2049\", \"uri_no_suffix\": \"nfs://172.21.0.204:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9293\", \"uri_no_suffix\": \"http://172.17.0.249:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9292\", \"uri_no_suffix\": \"http://172.21.0.204:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8041\", \"uri_no_suffix\": \"http://172.17.0.249:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8041\", \"uri_no_suffix\": \"http://172.21.0.204:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.249:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.204:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.204:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.99:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.204:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:5050\", \"uri_no_suffix\": \"http://192.168.122.99:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5050\", \"uri_no_suffix\": \"http://172.21.0.204:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.99\", \"host_nobrackets\": \"192.168.122.99\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.99:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.99:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.249:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.204:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.249:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.204:5666\", \"uri_no_suffix\": \"amqp://172.21.0.204:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9696\", \"uri_no_suffix\": \"http://172.17.0.249:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9696\", \"uri_no_suffix\": \"http://172.21.0.204:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.249:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.204:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:6080\", \"uri_no_suffix\": \"http://172.17.0.249:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.249:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.204:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:9876\", \"uri_no_suffix\": \"http://172.17.0.249:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:9876\", \"uri_no_suffix\": \"http://172.21.0.204:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.249:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.204:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.157\", \"host_nobrackets\": \"172.18.0.157\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.157:8080\", \"uri_no_suffix\": \"http://172.18.0.157:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:8080\", \"uri_no_suffix\": \"http://172.21.0.204:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.249:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.249:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.204\", \"host_nobrackets\": \"172.21.0.204\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.204:6080\", \"uri_no_suffix\": \"http://172.21.0.204:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.249\", \"host_nobrackets\": \"172.17.0.249\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.249:8775\", \"uri_no_suffix\": \"http://172.17.0.249:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(246,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"067a977c-c526-4227-9e18-7618974b60ad\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ComputeHCIServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeHCIParameters\": {}, \"ComputeHCIExtraConfig\": {}, \"ComputeHCIExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"ComputeHCIHostnameResolveNetwork\": \"internal_api\", \"ComputeHCIMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-computehci-0\": \"np0000072644\", \"overcloud-computehci-1\": \"np0000072645\", \"overcloud-computehci-2\": \"np0000072646\", \"overcloud-controller-0\": \"np0000072641\", \"overcloud-controller-1\": \"np0000072642\", \"overcloud-controller-2\": \"np0000072643\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"GnocchiMetricdWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"NotificationDriver\": \"messagingv2\", \"GnocchiArchivePolicy\": \"high\", \"CeilometerEnableGnocchi\": true, \"ManagePipeline\": true, \"EventPipelinePublishers\": [\"gnocchi://\"], \"PipelinePublishers\": [\"gnocchi://\"], \"CephClusterFSID\": \"febd1289-7109-53bb-83fc-a5c42b947733\", \"CephDynamicSpec\": false, \"DeployedCeph\": true, \"CephSpecFqdn\": true, \"CephadmDefaultContainer\": false, \"ContainerCephDaemonImage\": \"registry.redhat.io/rhceph/rhceph-7-rhel9:latest\", \"CephClusterName\": \"ceph\", \"CephClientConfigVars\": \"/home/zuul/overcloud-deploy/overcloud/ceph_client.yml\", \"ApplyCephConfigOverridesOnUpdate\": true, \"CinderEnableIscsiBackend\": false, \"CinderEnableRbdBackend\": true, \"CinderBackupBackend\": \"ceph\", \"NovaEnableRbdBackend\": true, \"GlanceBackend\": \"rbd\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"CloudDomain\": \"localdomain\", \"CloudName\": \"overcloud.localdomain\", \"CloudNameCtlplane\": \"overcloud.ctlplane.localdomain\", \"CloudNameInternal\": \"overcloud.internalapi.localdomain\", \"CloudNameStorage\": \"overcloud.storage.localdomain\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.localdomain\", \"ComputeCount\": 0, \"ComputeHCICount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"ComputeHCIHostnameFormat\": \"%stackname%-computehci-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072641-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072642-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072643-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072644-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072645-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072646-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072641\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072642\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072643\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072644\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072645\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072646\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.204\", \"ip_address_uri\": \"172.21.0.204\", \"ip_subnet\": \"172.21.0.204/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.249\", \"ip_address_uri\": \"172.17.0.249\", \"ip_subnet\": \"172.17.0.249/24\"}, \"storage\": {\"ip_address\": \"172.18.0.157\", \"ip_address_uri\": \"172.18.0.157\", \"ip_subnet\": \"172.18.0.157/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.196\", \"ip_address_uri\": \"172.20.0.196\", \"ip_subnet\": \"172.20.0.196/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.localdomain.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.localdomain.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.localdomain.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.localdomain.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.localdomain.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"qQTfK3QSUeIRLWmSj1sIu5GBg\", \"AdminToken\": \"q02N2b4awK98fyykL41iUX2Hh\", \"AodhPassword\": \"9AJygE1s9mctpR1exZtvx6E4S\", \"CeilometerMeteringSecret\": \"CdhGooXCxTME1ITxFl9q0xUTr\", \"CeilometerPassword\": \"xYUZeqAicsuHn0JOHQOq1idQJ\", \"CephClientKey\": \"AQB/Cy1qAAAAABAAso9PcCEB9dj79A4OhgSYqg==\", \"CephDashboardAdminPassword\": \"ez7ld4kZ0oywrDu0tWaOfh58A\", \"CephManilaClientKey\": \"AQB/Cy1qAAAAABAAb69h0fuFjB6lO5AeA59gog==\", \"CephRgwKey\": \"AQB/Cy1qAAAAABAASzsZvJwxPoEJpSX1s8AsPg==\", \"CinderPassword\": \"32HDlh1wtNuoeOyht2a9njXCx\", \"ContainerAodhApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\", \"ContainerAodhEvaluatorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\", \"ContainerAodhListenerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\", \"ContainerAodhNotifierImage\": \"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGnocchiApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\", \"ContainerGnocchiMetricdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\", \"ContainerGnocchiStatsdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781336959, \"GlancePassword\": \"V8ZZH1Pi60CDrMvV9pGBSBGoB\", \"GnocchiPassword\": \"1J2tbLy665illltBsArwgV2GL\", \"HAProxyStatsPassword\": \"oaknv7sJpWgseT5FPyXO5zDcE\", \"HeatAuthEncryptionKey\": \"xa0s8TT0R5wqGAjLqNAe1LjAtVOVIgDs\", \"HeatPassword\": \"AIErP5AszUhhw1jzcg4LrBB60\", \"HeatStackDomainAdminPassword\": \"ALQOUwlOSxtNBWOM4ILF7f1PZ\", \"HorizonSecret\": \"ApZCsCXIbp\", \"KeystoneCredential0\": \"vOVXcCvUNw0RPQw_7Ss7SsVDHjRYI9flzCA_QMUVjsc=\", \"KeystoneCredential1\": \"xK8CeK2Ooxh5xz2llZ08yl0Nn8G6cO7_aY72Y4mevIM=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"Za--VN4m0-9N0TYuGrPIcyA5OOgfZ8RsYibwPFtQu54=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"qioF_vtK69Y5KPMa2XqAYK19JnYL_KyljT4V4Z8prw8=\"}}, \"LibvirtTLSPassword\": \"ZuVZJ7ioeMJbtM3T0byAOXGtb\", \"ManilaPassword\": \"AU5xgb18uVnmHDdpPSLWbOanI\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA12R8iIyJvUNTGQwhxkOgigSvsPE90yT8EkajXfNMpL3wscsh\\naKnPXy4wnfirpMwXlKnkwCLZxiDLFS0JJTXnbywJZ4ENc+mnTXGgBas9f189ZKkm\\neM2J8OGOcbSedReCA33AxJT2YlvHzojBBv0KQUc8bZ9uEi/V2rgAr51dP/+J5Bsk\\nqwZ9vDNKkeUZ7aNho0YsWK1bM87upccQ6/7pfsQTaslcAaDg8teQlq83it1eTwL6\\nGsslaWUqzE+A5PS7Nurr71/Tbk8ulsbd+Dpbzm4GJsHvSDA1+ca38Bit+BRVFQZi\\nPK+cJ0vs0UCiZN4BJ1V9mZ0t/iAjxMObYuEcPwIDAQABAoIBABX6n4iRirag6Zhb\\nOBESso2S59iu7Uef9QbqZV4/ZvlClo6V801KUqpcPMLJ7r3sw5U8duayR7WjgAWj\\nqFS/OOQLwtPog9Zpp9RLvXAGpspaDho49n+KPcKySYZJz4eURASWLvcAWln0EqH9\\nK3FKneLGYaCwDZvWfMSKVSuWa78NZPjGApOaulHGG90jAT8MCECTIRp0xHwIQH+t\\n6IP5O4mhr318lUEg275dgpuloLoLTj6VtIuL6vJOpC2NxLnKJx8APU7qvomrYX82\\njVl5wnlleOdYHzv9GIiUE7BqeRpiBbmlVJUJEtTIvOw7DSrAeC+CMfJ56/nPoOLw\\nrVePO5UCgYEA6kfhZy4FVqhO/3qu4m93B/Az0YYCE5MyOJ0Grv1/fpUKZEL1aKde\\nrljUmjJEBBfNzags0Z6FvB36DCOwhDH9vs3ldPgMI+Gcp8yN0RegTIOUu13oCbkD\\nTDVoTb5odCQwdjE5qWd1mQAi0xmKxIL4BmM6o+a14IUByyPtUYz8v70CgYEA61xW\\nF7EN3VmB42sDNnArzZHxz0S/4H0UM7r9DKqnyKq1ERbd7rtQbHkUqwzrgKKfeBR0\\nTvxguYCk2N23zR1GJziQUJ9RfIGKsH4oakLh6faJz4J4wdvM1BzjUGS1vM87+AO0\\nSld9H3d9QH8wwCpM6vnpmriX2oIcRYEtQCkhPasCgYEAjuYFIFA7xV2nwcDtBwSC\\nD/99O+GHRrVTvqBYwUeyCl2SFxGYapsb7zATjXH3dp+mUjiwDbOpUtLd/6WNNzTe\\n1xDzUmMx1Hj6eocUQWMtzT287IQc0kFdN5Cj7DelsqGYRZ9E0oVef1JL64L6114j\\nNpIz5GEGssmuDF//kuxyBekCgYEAgLFlleDHPwBhSHPMNukQ2n/x466o6FwcPskA\\n8vshcVT+WtDRG2eq6xUt2vXek+DYJ7Wvfzz6upQAD2D0zqAyKuH/70WeLeE7b5Qc\\nDzZxBxg6dI/X7dB86IK/PMdEpHAAT3XfEENUdG9GuoyRoJHAqz9pn6NNzToVsV+X\\n2Zxjw68CgYBRW9ITkidag9/KSM29gLQwoT8s+0gAKfyvCWQndBtosLxIWWMH3e8b\\nRcNxvlutlhuZDGhhFzlsuQ2coaoECc+9+Zw4+giprlWOneibRCIbWaeZhcOkg35Y\\nc1eDvSWAmJ40iV3K8NemcyLC1Lz7uE5Vv0l0TBkfiOWvmaK3Fc5dVQ==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDXZHyIjIm9Q1MZDCHGQ6CKBK+w8T3TJPwSRqNd80ykvfCxyyFoqc9fLjCd+KukzBeUqeTAItnGIMsVLQklNedvLAlngQ1z6adNcaAFqz1/Xz1kqSZ4zYnw4Y5xtJ51F4IDfcDElPZiW8fOiMEG/QpBRzxtn24SL9XauACvnV0//4nkGySrBn28M0qR5Rnto2GjRixYrVszzu6lxxDr/ul+xBNqyVwBoODy15CWrzeK3V5PAvoayyVpZSrMT4Dk9Ls26uvvX9NuTy6Wxt34OlvObgYmwe9IMDX5xrfwGK34FFUVBmI8r5wnS+zRQKJk3gEnVX2ZnS3+ICPEw5ti4Rw/ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"8KGW6cfrbhIvkPmGFPeFuM9Ox\", \"MysqlMariabackupPassword\": \"VlqHymhjkGRBRoF82NE1acPVp\", \"MysqlRootPassword\": \"uQUhgxs2YR\", \"NeutronMetadataProxySharedSecret\": \"JGgc6Xpe5NkxyuI7CIcWyz4UT\", \"NeutronPassword\": \"Ffxmj5IYUj9OQerFFBtU7gvn7\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"iGVLW3iUSnJVJpZdHixGVnqNe\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"mTlOOLR7cKbDILml\", \"PlacementPassword\": \"B5b9hxoqds8je7HIcmKZM8Gjs\", \"RabbitCookie\": \"VNaLt8DGHM9nqw24i9V7\", \"RabbitPassword\": \"4njLECGVbPsQP4FWX5rpa4uqO\", \"RedisPassword\": \"oplbMbZH0QEXUwAU1DLUpdwtQ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"5mTGZ3tULlgN05hljD7pOeXSo\", \"SnmpdReadonlyUserPassword\": \"IOcEXVmeV2fpzQjbFPUW1TNW\", \"SwiftHashSuffix\": \"2nz873hZytZZQ9l1o3kwDMgND\", \"SwiftPassword\": \"oJoDtCRLW6xtlNaag5ZMm1zp9\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.localdomain undercloud.ctlplane\"], \"ComputeHCINetworkConfigTemplate\": \"templates/net_config_static_bridge.j2\"}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(247,'2026-06-13 07:50:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ComputeHCI::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputeHCIPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputeHCIPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ComputeHCI::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCI::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::ComputeHCI::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::ComputeHCI::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::ComputeHCI::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeHCIServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeHCIServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ComputeHCI::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::ComputeHCIServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/computehci-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mds.yaml\", \"OS::TripleO::Services::CephMgr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mgr.yaml\", \"OS::TripleO::Services::CephMon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-mon.yaml\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-osd.yaml\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cephadm/ceph-client.yaml\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-api-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiMetricd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-metricd-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiStatsd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/gnocchi/gnocchi-statsd-container-puppet.yaml\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-api-container-puppet.yaml\", \"OS::TripleO::Services::AodhEvaluator\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-evaluator-container-puppet.yaml\", \"OS::TripleO::Services::AodhListener\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-listener-container-puppet.yaml\", \"OS::TripleO::Services::AodhNotifier\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/aodh/aodh-notifier-container-puppet.yaml\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::ComputeHCI::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"f0325376-07d0-49fb-9625-1dad8a0cec75\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::Con